(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    288702,       6732]
NotebookOptionsPosition[    166201,       4185]
NotebookOutlinePosition[    250844,       5964]
CellTagsIndexPosition[    250776,       5959]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Collections", "SectionInline",ExpressionUUID->
   "1dd4645c-8530-4f1d-817d-854891d599ff"],
  $Line = 0; Null]], "Section",
 CounterAssignments->{{"Section", 2}, {"Subsection", 2}, {
   "Subsubsection", 2}, {"Exercise", 2}},
 CellTags->"C:3",
 CellLabel->"In[1]:=",
 CellID->1397384692,ExpressionUUID->"e13c5211-6608-4dfa-a2a3-b4ecc531ac72"],

Cell[TextData[{
 "Now that we have had our first look at the use of the Wolfram Language \
through simple arithmetical operations, it is time to look at presenting data \
or at least ",
 StyleBox["lists of numbers",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.71644584234542*^9, 3.716445885874069*^9}, 
   3.7164629209793916`*^9, 3.751680727806816*^9},
 FontTracking->-0.15,
 CellID->1261610270,ExpressionUUID->"9ec3f099-7716-4eff-a4ab-ca00913f2236"],

Cell["\<\
This will be very important when we get to analyzing data, as it is most \
common to have data stored in lists. The Wolfram Language can store many \
forms of data in lists, and this allows for easy manipulation of the elements \
(values) contained in lists.\
\>", "Text",
 CellChangeTimes->{{3.71644584234542*^9, 3.7164459736792955`*^9}, {
   3.716462921032323*^9, 3.7164629210948305`*^9}, {3.751680737954688*^9, 
   3.751680778194922*^9}, 3.7570989841819077`*^9, {3.8075352486571674`*^9, 
   3.8075352589207983`*^9}},
 CellID->1777761059,ExpressionUUID->"07d6ddb9-73f7-4b57-bb92-8f74bad84257"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lists", "Subsection",
 CellChangeTimes->{{3.6898253131993856`*^9, 3.689825315894034*^9}, {
  3.689825511036891*^9, 3.689825514365974*^9}},
 CellID->890137902,ExpressionUUID->"bc2ce47e-5695-4ba4-85cb-21248dd623d2"],

Cell["\<\
We have seen how easy it is to do simple arithmetic in the previous chapter. \
While it is convenient to add values one by one, we might find it more \
convenient to store quite a few more of them prior to any calculation or \
action. Collections, or sets of elements, be they numbers or mathematical \
variables or strings (words and letters), can be stored as lists. Lists can \
be created in two ways:\
\>", "Text",
 CellChangeTimes->{{3.708331640555382*^9, 3.7083318052602005`*^9}, 
   3.716445993942384*^9, 3.7164629211321664`*^9, {3.751680820968879*^9, 
   3.751680822439925*^9}, {3.75709898422631*^9, 3.757098984316718*^9}, {
   3.807466066614795*^9, 3.8074660677829123`*^9}, {3.8075355428820877`*^9, 
   3.8075355441098614`*^9}, 3.8157481623783712`*^9},
 CellID->1176633912,ExpressionUUID->"f2f40288-daa2-411b-8421-220049974e43"],

Cell[CellGroupData[{

Cell[TextData[{
 "Using curly braces, ",
 ButtonBox["{",
  BaseStyle->"Link",
  ButtonData->"List"],
 StyleBox[ButtonBox["...",
  BaseStyle->"Link",
  ButtonData->"List"],
  FontColor->GrayLevel[0.6]],
 ButtonBox["}",
  BaseStyle->"Link",
  ButtonData->"List"],
 ", with the elements separated by commas"
}], "ItemNumbered",
 CellChangeTimes->{{3.6898254327092*^9, 3.689825453730679*^9}, {
   3.689904989955576*^9, 3.6899049996739187`*^9}, {3.757084612260694*^9, 
   3.7570846417008247`*^9}, {3.7572120258027143`*^9, 3.757212059518224*^9}, 
   3.80935275081527*^9},
 CellID->1656737408,ExpressionUUID->"ede83636-449c-4d42-ab97-9085f31d1e8c"],

Cell[TextData[{
 "Using the ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " function, again with the elements separated by commas"
}], "ItemNumbered",
 CellChangeTimes->{{3.6898254327092*^9, 3.689825460445867*^9}, {
  3.689825606753496*^9, 3.689825622949462*^9}, {3.6899050050432796`*^9, 
  3.6899050202902946`*^9}, {3.7156649340384097`*^9, 3.715664937646949*^9}, {
  3.75708455940238*^9, 3.757084574431315*^9}, {3.757211924141183*^9, 
  3.757211928338313*^9}},
 CellID->512649254,ExpressionUUID->"00856b78-e840-454c-b60d-6036ee61b068"]
}, Open  ]],

Cell["\<\
Arithmetical operators, such as addition and multiplication, can act on \
elements in a list. Lists can even be nested, creating a list of lists.\
\>", "Text",
 CellChangeTimes->{{3.7083318348999305`*^9, 3.708331869635499*^9}, {
   3.715664975575982*^9, 3.715664975576985*^9}, {3.7164629211790466`*^9, 
   3.7164629212480736`*^9}, {3.7516808544438095`*^9, 3.751680867263316*^9}, 
   3.757098984363892*^9, {3.808237348355229*^9, 3.8082373519706106`*^9}},
 CellID->391620214,ExpressionUUID->"6098a51b-068c-4d47-bb06-6dc7d629469e"],

Cell["\<\
It is common in computer languages to refer to collections or entities, such \
as lists, as objects. In the case of a list, we will then refer to a list \
object. For ease of identification of list objects, we will refer to them in \
uppercase format in the text below, i.e. Lists.\
\>", "Text",
 CellChangeTimes->{{3.751680873689739*^9, 3.751680945041701*^9}, {
  3.757098984411244*^9, 3.757098984457218*^9}},
 CellID->2071042290,ExpressionUUID->"4b2a7547-0038-49b2-b224-7d7700c2639c"],

Cell[CellGroupData[{

Cell["Creating Lists", "Subsubsection",
 CellChangeTimes->{{3.689905070570182*^9, 3.6899050771627083`*^9}, 
   3.716462921279297*^9},
 CellID->1592817454,ExpressionUUID->"0ca856bc-b363-4ebf-be7a-e5da2bb18962"],

Cell[TextData[{
 "In the Wolfram Language code that follows, we create our first List. \
Through the use of the assignment operator (",
 ButtonBox["=",
  BaseStyle->"Link",
  ButtonData->"Set"],
 "), we also assign this List (an object containing a list of elements) to a ",
 StyleBox["computer variable",
  FontSlant->"Italic"],
 ". Such a variable is a space in memory, where our List will be stored for \
easy retrieval. Within certain limits, we can name this computer variable \
whatever we wish. The convention is to start with a lowercase letter and \
indicate separate words by starting each such word with an uppercase letter. \
Do not use one of the more than 6000 Wolfram Language function names and try \
to keep the names meaningful. Doing so will allow you to deduce its use when \
you review your code at a later time or when you share it with others."
}], "Text",
 CellChangeTimes->{{3.708331898070202*^9, 3.708332072157403*^9}, {
   3.708333074114086*^9, 3.708333123111376*^9}, {3.715665030477163*^9, 
   3.715665032633659*^9}, {3.715665079575405*^9, 3.715665099120214*^9}, {
   3.716462921317095*^9, 3.7164629213952303`*^9}, {3.7516809624595766`*^9, 
   3.7516810305653763`*^9}, {3.751681248989306*^9, 3.7516812506233892`*^9}, {
   3.757098984505062*^9, 3.7570989847424927`*^9}, 3.761631842931512*^9, {
   3.7616318912010927`*^9, 3.7616318947451696`*^9}, 3.782055492095883*^9, 
   3.782055639548263*^9, 3.807534767247754*^9, {3.8075359331090946`*^9, 
   3.807535968847066*^9}, {3.8075448053066034`*^9, 3.8075448098854156`*^9}, {
   3.815748199553239*^9, 3.815748209656945*^9}},
 FontTracking->-0.05,
 CellID->2099289523,ExpressionUUID->"8d5b0d84-2e5d-42c6-84f3-675d6772a1f3"],

Cell[TextData[{
 "In the first example below, the List is stored in the computer variable \
named ",
 Cell[BoxData[
 "myList1"], "InlineCodeText",ExpressionUUID->
  "63df6421-f7f7-4e1a-9171-2ae0d9868a0c"],
 ". You will note that the List contains a mix of numbers and a word (termed \
a string). The latter is placed inside of quotation marks, to indicate that \
it is not the name of a function or variable, but instead a ",
 ButtonBox["String",
  BaseStyle->"Link"],
 "."
}], "Text",
 CellChangeTimes->{{3.708331898070202*^9, 3.7083321835800204`*^9}, {
   3.7156651529095793`*^9, 3.715665162373766*^9}, 3.716446128080476*^9, {
   3.7164629214325376`*^9, 3.7164629215167217`*^9}, {3.751681047342394*^9, 
   3.7516810555587378`*^9}, {3.757085023044413*^9, 3.757085031987363*^9}, {
   3.757085989541429*^9, 3.757086030592947*^9}, {3.757098984788815*^9, 
   3.757098984835537*^9}, {3.7572122231944637`*^9, 3.757212229117422*^9}, {
   3.7616319484969244`*^9, 3.761631959016757*^9}, 3.8075360271519475`*^9, 
   3.809352761575244*^9},
 CellID->1750176498,ExpressionUUID->"74bf92dd-e2e5-433b-b6b9-56d8ae070211"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Method 1", "Subsubsection",
 CellChangeTimes->{{3.809352874773967*^9, 3.809352878195518*^9}, {
  3.8122036607557697`*^9, 3.812203661091255*^9}},
 CellID->862205497,ExpressionUUID->"675c4b66-92d8-4f0f-9fad-ded5b693bc82"],

Cell[TextData[{
 "Use curly braces to create a computer variable called ",
 Cell[BoxData[
  FormBox["myList1", TraditionalForm]], "InlineCode",ExpressionUUID->
  "401a08a4-f61f-48d5-a442-4b7291688f3c"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.689825319140888*^9, 3.689825350117218*^9}, {
   3.6899069228343573`*^9, 3.689906966894486*^9}, 3.716462921532349*^9, {
   3.7570850428514643`*^9, 3.757085079611732*^9}, {3.75708792063848*^9, 
   3.757087921990498*^9}, {3.757100035698353*^9, 3.757100036881667*^9}, {
   3.757212248827957*^9, 3.7572122628305283`*^9}, {3.8075360463861437`*^9, 
   3.807536059665492*^9}, {3.8093529064010572`*^9, 3.8093529082991333`*^9}},
 CellID->1132888927,ExpressionUUID->"86692462-d09a-4df3-ae4c-d15a3400b99c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList1", "=", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3", ",", "\"\<Mathematica\>\""}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.689825319140888*^9, 3.689825350117218*^9}, {
   3.6899069228343573`*^9, 3.689906966894486*^9}, 3.716462921532349*^9, {
   3.7570850428514643`*^9, 3.7570850493556023`*^9}},
 CellLabel->"In[1]:=",
 CellID->1739760727,ExpressionUUID->"ae41e8ab-03b4-4728-9a34-4b37d2d2a9d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.68982535295315*^9, 3.689905572879681*^9, 
  3.689906977911285*^9, 3.708334516667174*^9, 3.7084295571879196`*^9, 
  3.7164461514145603`*^9, 3.757220058944703*^9, 3.7616324396130667`*^9, 
  3.812204079094123*^9},
 CellLabel->"Out[1]=",
 CellID->846622092,ExpressionUUID->"17bb7e99-8bda-4b42-8ddb-c096afdcf6a6"]
}, Open  ]],

Cell[TextData[{
 "The Wolfram Language creates a space in your computer\[CloseCurlyQuote]s \
memory and gives it a name. In this case, we called it ",
 Cell[BoxData[
  FormBox["myList1", TraditionalForm]], "InlineCodeText",ExpressionUUID->
  "70bf8d28-6ff6-4b39-8215-1af92fecd413"],
 ". The assignment operator (",
 ButtonBox["=",
  BaseStyle->"Link",
  ButtonData->"Set"],
 ") assigns what is on its right-hand side to whatever is on its left-hand \
side. It is not an equal sign like we might use in formal mathematics."
}], "Text",
 CellChangeTimes->{{3.7164461553802123`*^9, 3.7164462976970477`*^9}, 
   3.716462921547976*^9, {3.751681093243991*^9, 3.7516811218049383`*^9}, {
   3.751681267658531*^9, 3.751681386858644*^9}, {3.7570850853459387`*^9, 
   3.757085091787146*^9}, {3.757086036455018*^9, 3.757086036460249*^9}, {
   3.757098984884061*^9, 3.7570989849781637`*^9}, 3.7571014300705338`*^9, {
   3.7616320417924585`*^9, 3.761632059418047*^9}, 3.776705681903646*^9, {
   3.8075360783857365`*^9, 3.8075361067877083`*^9}},
 CellID->1437664982,ExpressionUUID->"15b880e1-b8f1-4e69-a8fa-3af28d0d80b4"],

Cell["\<\
It is now trivial to retrieve the List by simply referencing the computer \
variable name. Note how the string (the word \
\[OpenCurlyDoubleQuote]Mathematica\[CloseCurlyDoubleQuote] that we placed \
inside of quotation marks) is displayed without quotation marks.\
\>", "Text",
 CellChangeTimes->{{3.708332206459999*^9, 3.7083322646612935`*^9}, 
   3.7164629216145415`*^9, {3.751681408798564*^9, 3.7516814098810883`*^9}, 
   3.757098985025585*^9, {3.7616320928406067`*^9, 3.7616321092602944`*^9}, {
   3.807536157573888*^9, 3.8075361678344903`*^9}},
 CellID->1496840077,ExpressionUUID->"9f2bc6e9-fdba-4bc8-b2b3-242252eb0954"],

Cell["\<\
Retrieve an object from memory by simply referencing and evaluating:\
\>", "CodeCaption",
 CellChangeTimes->{{3.6899069807117968`*^9, 3.6899070327568417`*^9}, 
   3.7164629216165476`*^9, {3.75708515208289*^9, 3.757085160874568*^9}, {
   3.80753617639561*^9, 3.807536183250042*^9}, 3.809352941865184*^9},
 CellID->1767733181,ExpressionUUID->"d7b1f78d-45aa-485c-90d6-7c54f97865bd"],

Cell[CellGroupData[{

Cell[BoxData["myList1"], "Input",
 CellChangeTimes->{{3.6899069807117968`*^9, 3.6899070327568417`*^9}, 
   3.7164629216165476`*^9, 3.75708515208289*^9},
 CellLabel->"In[2]:=",
 CellID->645349003,ExpressionUUID->"5ecb97ef-7a6b-4090-aead-209e215a159b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.689907033565976*^9, 3.7572200589657907`*^9, 
  3.8122040790997763`*^9},
 CellLabel->"Out[2]=",
 CellID->2098338869,ExpressionUUID->"109ec80c-7400-4015-bff9-988bc875483c"]
}, Open  ]],

Cell[TextData[{
 "In the code below, we accomplish the same task using the ",
 Cell[BoxData[
  FormBox[
   StyleBox["List", "InlineCodeText"], TraditionalForm]],ExpressionUUID->
  "46f52a50-967f-42f9-86bd-20bb45ec0507"],
 " function. We assign it to the computer variable name ",
 Cell[BoxData[
 "myList2"], "InlineCodeText",ExpressionUUID->
  "394736b5-600d-40e3-a1d5-020905933274"],
 "."
}], "Text",
 CellChangeTimes->{{3.7156652045493107`*^9, 3.715665228341645*^9}, {
   3.751681437228602*^9, 3.7516814465728545`*^9}, {3.757085212416347*^9, 
   3.7570852505327587`*^9}, 3.757098985075572*^9, {3.757212325291112*^9, 
   3.757212331118086*^9}, {3.8157483334087353`*^9, 3.8157483337837667`*^9}},
 CellID->1408799405,ExpressionUUID->"e1f5bbcd-931f-443f-804f-8b8ef93687cc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Method 2", "Subsubsection",
 CellChangeTimes->{
  3.809352979913814*^9, {3.812203663451313*^9, 3.8122036638753242`*^9}},
 CellID->1923527635,ExpressionUUID->"c2c49437-f244-41b1-8ecf-b42a14a96b9b"],

Cell[TextData[{
 "Use the ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " function to create the computer variable ",
 Cell[BoxData[
 "myList2"], "InlineCode",ExpressionUUID->
  "a86cb5ff-c069-4f50-8b48-ea10ca488f47"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.6898253554451036`*^9, 3.689825383573517*^9}, {
  3.7570878711196117`*^9, 3.757087884030633*^9}, {3.807536236938423*^9, 
  3.8075363086400576`*^9}},
 CellID->1684391660,ExpressionUUID->"d68f9d1e-c2fc-41a4-82ad-674d42361699"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList2", "=", 
  RowBox[{"List", "[", 
   RowBox[{"1", ",", "2", ",", "3", ",", "\"\<Mathematica\>\""}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6898253554451036`*^9, 3.689825383573517*^9}, {
  3.7570878711196117`*^9, 3.7570878747111397`*^9}},
 CellLabel->"In[3]:=",
 CellID->1902442557,ExpressionUUID->"6b00df46-e7fe-4662-9f83-c99d7e247be6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6898253878761787`*^9, 3.757220059010075*^9, 
  3.7616324433839884`*^9, 3.8122040791205587`*^9},
 CellLabel->"Out[3]=",
 CellID->804920249,ExpressionUUID->"e72b37b3-e458-43b3-896e-c35dbed50bfe"]
}, Open  ]],

Cell[TextData[{
 "While a single equal sign is the assignment operator, the Wolfram Language \
also contains the double equal symbol (",
 ButtonBox["==\[VeryThinSpace]",
  BaseStyle->"Link",
  ButtonData->"Equal"],
 "), which is the shorthand notation for the ",
 ButtonBox["Equal",
  BaseStyle->"Link"],
 " function. This is used to test whether two computer variables are equal. \
This system of checking certain conditions is referred to as Boolean logic. \
The results are either ",
 ButtonBox["True",
  BaseStyle->"Link"],
 " or ",
 ButtonBox["False",
  BaseStyle->"Link"],
 ". It is quite easy to see that ",
 Cell[BoxData[
 "myList1"], "InlineCodeText",ExpressionUUID->
  "74ca2189-dc89-48ec-927c-56a1b894d52a"],
 " and ",
 Cell[BoxData[
 "myList2"], "InlineCodeText",ExpressionUUID->
  "c9a5a6b8-91ba-41bd-b526-8a1064edc04d"],
 " contain the same information. Let\[CloseCurlyQuote]s test this with the \
use of the ",
 ButtonBox["==",
  BaseStyle->"Link",
  ButtonData->"Equal"],
 " symbol."
}], "Text",
 CellChangeTimes->{{3.761632261672565*^9, 3.7616324317138147`*^9}, {
   3.761632911633754*^9, 3.761632932010607*^9}, {3.761633555642523*^9, 
   3.761633619666875*^9}, 3.77670367887781*^9, {3.7767038727442493`*^9, 
   3.776703921222177*^9}, {3.7767040974938707`*^9, 3.7767041452358513`*^9}, {
   3.77670565732578*^9, 3.7767056574714813`*^9}, {3.807538305862628*^9, 
   3.807538336776294*^9}, 3.8075383964660997`*^9, {3.807538513477667*^9, 
   3.807538551347423*^9}, {3.809353015443556*^9, 3.809353018339655*^9}},
 CellID->655840147,ExpressionUUID->"8635c076-e3c7-4326-9be8-402ed2c4f2e2"],

Cell[TextData[{
 "Use Boolean logic to test whether the computer variables ",
 Cell[BoxData[
 "myList1"], "InlineCode",ExpressionUUID->
  "afedeb02-4fa8-4b84-9281-f1f55cfa72f7"],
 " and ",
 Cell[BoxData[
 "myList2"], "InlineCode",ExpressionUUID->
  "86376854-a738-42ab-8cd5-9710ed77c1d6"],
 " are the same:"
}], "CodeCaption",
 PageBreakAbove->True,
 CellChangeTimes->{{3.6899069807117968`*^9, 3.6899070327568417`*^9}, 
   3.7164629216165476`*^9, {3.75708515208289*^9, 3.757085160874568*^9}, {
   3.761632490481382*^9, 3.76163252356116*^9}, {3.7767039486404037`*^9, 
   3.776703957111641*^9}, {3.807538554227458*^9, 3.80753855985765*^9}},
 CellID->265226226,ExpressionUUID->"9fcf9447-170e-4ab5-b069-e720797dd990"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList1", "\[Equal]", "myList2"}]], "Input",
 CellChangeTimes->{{3.761632454488881*^9, 3.761632460849654*^9}},
 CellLabel->"In[4]:=",
 CellID->31015232,ExpressionUUID->"89719a46-a31b-4145-bc33-a97f5ba0703e"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.761632462504361*^9, 3.8122040791259203`*^9},
 CellLabel->"Out[4]=",
 CellID->1295132490,ExpressionUUID->"7d4f75cd-ea0a-4daa-b0a2-94bb79a0075d"]
}, Open  ]],

Cell[TextData[{
 "Use the ",
 ButtonBox["Equal",
  BaseStyle->"Link"],
 " function:"
}], "CodeCaption",
 CellChangeTimes->{{3.6899069807117968`*^9, 3.6899070327568417`*^9}, 
   3.7164629216165476`*^9, {3.75708515208289*^9, 3.757085160874568*^9}, {
   3.761632490481382*^9, 3.76163252356116*^9}, {3.7616336307139344`*^9, 
   3.7616336379542494`*^9}, {3.807538566172841*^9, 3.807538571694826*^9}},
 CellID->31600184,ExpressionUUID->"b38d4b79-c6c5-415a-ba7f-a290ac6dd2ae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Equal", "[", 
  RowBox[{"myList1", ",", "myList2"}], "]"}]], "Input",
 CellChangeTimes->{{3.761633641301262*^9, 3.761633649034799*^9}},
 CellLabel->"In[5]:=",
 CellID->16492371,ExpressionUUID->"f31e63ce-2866-4ced-ab1d-cb84bb8744d3"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.7616336493399544`*^9, 3.8122040791313133`*^9},
 CellLabel->"Out[5]=",
 CellID->397513438,ExpressionUUID->"c7133c17-b966-42a3-abdc-b160a0f2218f"]
}, Open  ]],

Cell[TextData[{
 "The Wolfram Langue evaluates this question and indeed returns a ",
 ButtonBox["True",
  BaseStyle->"Link"],
 " value."
}], "Text",
 CellChangeTimes->{{3.7616326752329082`*^9, 3.761632695400891*^9}, 
   3.807538584486107*^9},
 CellID->525909639,ExpressionUUID->"72b71f44-c6fb-43e7-a64d-3d75563a07d3"],

Cell[TextData[{
 "Then there is the shorthand notation triple equal symbol (",
 ButtonBox["===",
  BaseStyle->"Link",
  ButtonData->"SameQ"],
 "). The full function name is ",
 ButtonBox["SameQ",
  BaseStyle->"Link"],
 ". This Boolean function shorthand checks for both value and type, in as \
much as 3 is an integer but 3.0 is a decimal value (referred to as a \
floating-point value). The code below shows the difference between these two \
functions."
}], "Text",
 CellChangeTimes->{{3.761633156033809*^9, 3.761633274234421*^9}, {
   3.7616333516180735`*^9, 3.7616333662422366`*^9}, {3.761633661690421*^9, 
   3.7616336713222556`*^9}, {3.7767037145920277`*^9, 
   3.7767037162764797`*^9}, {3.77670389276033*^9, 3.776703894437211*^9}, {
   3.776703974788175*^9, 3.776703978908119*^9}, {3.776704065853492*^9, 
   3.776704082529875*^9}, 3.776705657500869*^9, 3.807538401701835*^9, {
   3.8075385911550217`*^9, 3.807538602049757*^9}, {3.8075386367024865`*^9, 
   3.8075386784195795`*^9}, 3.8075389353766923`*^9, {3.8075448737603865`*^9, 
   3.807544883042639*^9}, {3.8082380833458757`*^9, 3.8082380838246384`*^9}, {
   3.815748356320717*^9, 3.815748356591752*^9}},
 CellID->525071160,ExpressionUUID->"934a0679-fc5e-422b-96b5-3f550decc1e0"],

Cell["The values 3 and 3.0 are indeed equal:", "CodeCaption",
 CellChangeTimes->{{3.6899069807117968`*^9, 3.6899070327568417`*^9}, 
   3.7164629216165476`*^9, {3.75708515208289*^9, 3.757085160874568*^9}, {
   3.761632490481382*^9, 3.76163252356116*^9}, {3.7616332971133747`*^9, 
   3.7616333040978365`*^9}},
 CellID->685340947,ExpressionUUID->"d362218c-3b91-4bba-8c8b-0e78bb76588f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"3", "\[Equal]", "3.0"}]], "Input",
 CellChangeTimes->{{3.7616332787862473`*^9, 3.761633280058293*^9}},
 CellLabel->"In[6]:=",
 CellID->183621007,ExpressionUUID->"e3e76c3d-dab5-4d51-af02-a4b77665cd1d"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.7616332804343243`*^9, 3.8122040791520042`*^9},
 CellLabel->"Out[6]=",
 CellID->186726649,ExpressionUUID->"6461675e-301e-4ac0-8870-185c0d2b5ea6"]
}, Open  ]],

Cell["They are not of the same type, though:", "CodeCaption",
 CellChangeTimes->{{3.6899069807117968`*^9, 3.6899070327568417`*^9}, 
   3.7164629216165476`*^9, {3.75708515208289*^9, 3.757085160874568*^9}, {
   3.761632490481382*^9, 3.76163252356116*^9}, {3.761633313433543*^9, 
   3.761633321673522*^9}},
 CellID->119047235,ExpressionUUID->"d7888a45-4b92-471a-a7ae-8db1d50c8a80"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"3", "===", "3.0"}]], "Input",
 CellChangeTimes->{{3.7616332828920984`*^9, 3.7616332844741883`*^9}},
 CellLabel->"In[7]:=",
 CellID->539934307,ExpressionUUID->"fa25d783-8229-497f-8923-50e2d0d1b0c3"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.7616332858476477`*^9, 3.812204079157526*^9},
 CellLabel->"Out[7]=",
 CellID->841181476,ExpressionUUID->"85709621-f5d2-4d4f-b5d8-97dcc2784f71"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["SameQ",
  BaseStyle->"Link"],
 " is the full function name:"
}], "CodeCaption",
 CellChangeTimes->{{3.6899069807117968`*^9, 3.6899070327568417`*^9}, 
   3.7164629216165476`*^9, {3.75708515208289*^9, 3.757085160874568*^9}, {
   3.761632490481382*^9, 3.76163252356116*^9}, {3.7616334369460154`*^9, 
   3.7616334587624693`*^9}, 3.807538694996251*^9},
 CellID->15187266,ExpressionUUID->"4f90c401-4311-479e-9a86-18ba8c8c8f47"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SameQ", "[", 
  RowBox[{"3", ",", "3.0"}], "]"}]], "Input",
 CellChangeTimes->{{3.7616334460538*^9, 3.7616334506343555`*^9}},
 CellLabel->"In[8]:=",
 CellID->2335321,ExpressionUUID->"e9948f0e-ad2f-4389-bbc5-9bba70d6c94f"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.7616334515156517`*^9, 3.8122040791630287`*^9},
 CellLabel->"Out[8]=",
 CellID->852218931,ExpressionUUID->"07ad7964-c725-4ffa-82de-e6edc4895293"]
}, Open  ]],

Cell[TextData[{
 "We need not only test for equality. The ",
 ButtonBox["!=",
  BaseStyle->"Link",
  ButtonData->"Unequal"],
 " shorthand symbol or the ",
 ButtonBox["Unequal",
  BaseStyle->"Link"],
 " function checks whether values are dissimilar. The shorthand symbol (",
 ButtonBox["=!=",
  BaseStyle->"Link",
  ButtonData->"UnsameQ"],
 ") or the function ",
 ButtonBox["UnsameQ",
  BaseStyle->"Link"],
 " checks for both value and type."
}], "Text",
 CellChangeTimes->{{3.7616337130426245`*^9, 3.7616338337787914`*^9}, {
  3.776703734779312*^9, 3.77670376790689*^9}, {3.776703993691743*^9, 
  3.7767040604285173`*^9}, {3.776705657542345*^9, 3.7767056575930243`*^9}, {
  3.807538872729686*^9, 3.8075389096409845`*^9}},
 CellID->316965284,ExpressionUUID->"b6d3a359-94a1-436e-b233-23d2380db427"],

Cell[TextData[{
 "The values 3 and 3.0 are indeed equal, hence a ",
 ButtonBox["False",
  BaseStyle->"Link"],
 " value is returned:"
}], "CodeCaption",
 CellChangeTimes->{{3.6899069807117968`*^9, 3.6899070327568417`*^9}, 
   3.7164629216165476`*^9, {3.75708515208289*^9, 3.757085160874568*^9}, {
   3.761632490481382*^9, 3.76163252356116*^9}, {3.761633928386963*^9, 
   3.7616339453070917`*^9}, 3.807538953175922*^9},
 CellID->355944966,ExpressionUUID->"c5b99961-5009-444e-aa70-12aa43700831"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"3", "\[NotEqual]", "3.0"}]], "Input",
 CellChangeTimes->{{3.7616338823091736`*^9, 3.7616338945630846`*^9}},
 CellLabel->"In[9]:=",
 CellID->761846243,ExpressionUUID->"d7729c99-d933-4821-91cb-8f846176b6f6"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.7616338881131945`*^9, 3.7616338952254477`*^9}, 
   3.812204079168754*^9},
 CellLabel->"Out[9]=",
 CellID->1675131474,ExpressionUUID->"87259ca6-c83b-4b7f-b81d-f34945851cc5"]
}, Open  ]],

Cell[TextData[{
 "While the values 3 and 3.0 are equal, they are not of the same type, hence ",
 ButtonBox["True",
  BaseStyle->"Link"],
 " is returned:"
}], "CodeCaption",
 CellChangeTimes->{{3.6899069807117968`*^9, 3.6899070327568417`*^9}, 
   3.7164629216165476`*^9, {3.75708515208289*^9, 3.757085160874568*^9}, {
   3.761632490481382*^9, 3.76163252356116*^9}, {3.7616339552582684`*^9, 
   3.761633972170786*^9}, 3.807538980564295*^9, {3.808238120265386*^9, 
   3.808238120613516*^9}},
 CellID->427400363,ExpressionUUID->"602cb161-df2a-4844-b362-5cb7f311bc7e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"3", "=!=", "3.0"}]], "Input",
 CellChangeTimes->{{3.761633911372998*^9, 3.761633916250379*^9}},
 CellLabel->"In[10]:=",
 CellID->63912589,ExpressionUUID->"8b0f0689-44bc-4293-a9f6-839c6dd22827"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.761633917643655*^9, 3.812204079174221*^9},
 CellLabel->"Out[10]=",
 CellID->424071348,ExpressionUUID->"a879ac56-ea30-43c4-87b1-a80a0fb05772"]
}, Open  ]],

Cell[TextData[{
 "Finally, there are the more familiar ",
 StyleBox[ButtonBox[">",
  BaseStyle->"Link",
  ButtonData->"Greater"],
  FontWeight->"Bold"],
 ", ",
 StyleBox[ButtonBox["<",
  BaseStyle->"Link",
  ButtonData->"Less"],
  FontWeight->"Bold"],
 ", ",
 ButtonBox["\[GreaterEqual]",
  BaseStyle->"Link",
  ButtonData->"GreaterEqual"],
 ", and ",
 ButtonBox["\[LessEqual]",
  BaseStyle->"Link",
  ButtonData->"LessEqual"],
 " symbols (respectively greater than, less than, greater than or equal to, \
and less than or equal to). Using these is akin to the use of the double \
equal sign in that a Boolean question is asked. Below we simply check whether \
the integer 4 is less than the integer 3 (which it obviously is not). In the \
spoken word, this would be read as, \[OpenCurlyDoubleQuote]Is four less than \
three?\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.7616325348253546`*^9, 3.761632650337743*^9}, {
   3.761632998114627*^9, 3.761633109026373*^9}, {3.761633983517281*^9, 
   3.7616339949641314`*^9}, {3.7616340355081916`*^9, 
   3.7616340551400204`*^9}, {3.776704179563387*^9, 3.77670420478323*^9}, {
   3.776705657623267*^9, 3.776705657692979*^9}, {3.807539082526667*^9, 
   3.80753910125465*^9}, {3.8075392415945673`*^9, 3.807539273596297*^9}, {
   3.8075449033016706`*^9, 3.807544913091391*^9}, {3.80823816803246*^9, 
   3.808238186093902*^9}, {3.812204411707128*^9, 3.8122044118584137`*^9}, {
   3.8157483906642447`*^9, 3.815748425488367*^9}, 3.816617579990361*^9},
 CellID->104671427,ExpressionUUID->"75c4517b-2c4e-46a4-99fd-5ebd92f5eac8"],

Cell["Check whether 4 is less than 3:", "CodeCaption",
 CellChangeTimes->{{3.807539289717166*^9, 3.807539296620823*^9}},
 CellID->577359980,ExpressionUUID->"f5832416-7190-49de-9b5c-4acebb1a6314"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"4", "<", "3"}]], "Input",
 CellChangeTimes->{{3.761632626296938*^9, 3.7616326550177784`*^9}},
 CellLabel->"In[11]:=",
 CellID->160938468,ExpressionUUID->"f7337dcd-73bb-43b1-b489-f2ef3d1b6eef"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.7616326287855425`*^9, 3.7616326566942935`*^9}, 
   3.812204079192984*^9},
 CellLabel->"Out[11]=",
 CellID->2016405090,ExpressionUUID->"16082b5f-67ce-4b54-94e5-00b6833126e1"]
}, Open  ]],

Cell[TextData[{
 "As expected, we note the return of a ",
 ButtonBox["False",
  BaseStyle->"Link"],
 " value."
}], "Text",
 CellChangeTimes->{{3.761632706769302*^9, 3.7616327242016454`*^9}, 
   3.8075393062523327`*^9},
 CellID->275632639,ExpressionUUID->"c360c095-83b8-4734-a29d-5b4fa635790e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using Arithmetical Operations on Lists", "Subsubsection",
 CellChangeTimes->{{3.689905103329749*^9, 3.6899051145388603`*^9}, 
   3.7164629216478024`*^9, {3.757085261706149*^9, 3.757085264234315*^9}},
 CellID->694058349,ExpressionUUID->"6eafdb1c-8ba6-427c-afd4-50c938bf8600"],

Cell["\<\
Arithmetical operators, such as multiplication, can act on the elements in a \
list. In the first example, we wish to multiply each element in the list by \
the number (scalar) 2. \
\>", "Text",
 CellChangeTimes->{{3.7083322732634573`*^9, 3.7083323231168113`*^9}, {
   3.7156652571642075`*^9, 3.715665266815184*^9}, {3.716446329574484*^9, 
   3.716446331150798*^9}, {3.7164629216947083`*^9, 3.7164629217324886`*^9}, {
   3.757098985123784*^9, 3.7570989851719522`*^9}, {3.7616341056111803`*^9, 
   3.761634126723081*^9}, {3.8075399749790726`*^9, 3.8075399831732063`*^9}, {
   3.8075449400831165`*^9, 3.8075449426598477`*^9}, 3.809355638832899*^9, 
   3.809355674096243*^9},
 CellID->2054984786,ExpressionUUID->"890243cf-609c-4179-b3c9-764b4b3121aa"],

Cell["\<\
Multiply the List by a scalar. Note how the string is seen as mathematical \
symbol:\
\>", "CodeCaption",
 CellChangeTimes->{{3.689825669321514*^9, 3.6898257229982986`*^9}, 
   3.716462921748148*^9, {3.7570878885269213`*^9, 3.757087909910561*^9}, {
   3.807539988626578*^9, 3.8075399892010794`*^9}, {3.808238234396606*^9, 
   3.8082382466334333`*^9}, 3.809353126146945*^9},
 FontTracking->0.1,
 CellID->149803601,ExpressionUUID->"1724cf29-2ff9-4edd-9a25-d0c115a16dd0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"2", "*", "myList1"}]], "Input",
 CellChangeTimes->{{3.689825669321514*^9, 3.6898257229982986`*^9}, 
   3.716462921748148*^9, 3.7570878885269213`*^9},
 CellLabel->"In[12]:=",
 CellID->2068892239,ExpressionUUID->"70b683da-e884-4fa6-8456-dda2ff2e0b5c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "4", ",", "6", ",", 
   RowBox[{"2", " ", "\<\"Mathematica\"\>"}]}], "}"}]], "Output",
 CellChangeTimes->{3.689825700652907*^9, 3.757220059042817*^9, 
  3.8122040791980753`*^9},
 CellLabel->"Out[12]=",
 CellID->280914323,ExpressionUUID->"107f7c8b-0edf-4f71-8a73-feb11b90288a"]
}, Open  ]],

Cell["\<\
We can add a number (scalar) value to each element in a List. In the next \
example, the number 3 is added to each element.\
\>", "Text",
 CellChangeTimes->{{3.708332340831281*^9, 3.7083323652337294`*^9}, {
   3.7164463548148746`*^9, 3.716446381034342*^9}, {3.716462921763742*^9, 
   3.71646292181664*^9}, 3.757098985221156*^9, {3.8075404003986864`*^9, 
   3.8075404046574326`*^9}, {3.80754494962912*^9, 3.8075449533983107`*^9}, {
   3.8093532224576483`*^9, 3.80935322411591*^9}, {3.815748490183519*^9, 
   3.815748493455277*^9}},
 CellID->711722051,ExpressionUUID->"08b88633-9ac8-45dc-bab9-8c2908b6758a"],

Cell[TextData[{
 "Elementwise addition of a scalar to a ",
 ButtonBox["List",
  BaseStyle->"Link"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.689825805978407*^9, 3.689825822268682*^9}, 
   3.716462921832303*^9, {3.757087936742652*^9, 3.757087944518263*^9}, {
   3.75708832908075*^9, 3.757088349958744*^9}, {3.761634227372547*^9, 
   3.761634227372547*^9}, 3.807540428090952*^9, {3.8082390073314533`*^9, 
   3.808239031228714*^9}},
 CellID->428597367,ExpressionUUID->"d0b7a73d-404e-446c-a5f1-904864b18665"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"3", "+", "myList1"}]], "Input",
 CellChangeTimes->{{3.689825805978407*^9, 3.689825822268682*^9}, 
   3.716462921832303*^9, 3.757087936742652*^9},
 CellLabel->"In[13]:=",
 CellID->1517454332,ExpressionUUID->"65f34ee3-5048-41ec-8db0-41dc982c9e91"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "5", ",", "6", ",", 
   RowBox[{"3", "+", "\<\"Mathematica\"\>"}]}], "}"}]], "Output",
 CellChangeTimes->{3.689825823670931*^9, 3.7572200590647373`*^9, 
  3.812204079204247*^9},
 CellLabel->"Out[13]=",
 CellID->1157970555,ExpressionUUID->"3940656e-f37d-4b6c-808c-65316556b8a5"]
}, Open  ]],

Cell[TextData[{
 "Next, we see an example of pairwise multiplication. Each element is \
multiplied by its corresponding element in the second List, in the order in \
which they appear. Note that for this to work, we need the same number of \
elements in each List. In the output, we note that 1 squared is 1, 2 times 2 \
is 4, 3 times 3 is 9, and Mathematica times Mathematica is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Mathematica", "2"], TraditionalForm]],ExpressionUUID->
  "90d73290-548d-46fc-a58b-9a879b9a5723"],
 "."
}], "Text",
 CellChangeTimes->{{3.7083323726835485`*^9, 3.708332422808547*^9}, {
  3.7156653079837255`*^9, 3.7156653853822346`*^9}, {3.7156655630732465`*^9, 
  3.7156655844784307`*^9}, {3.7164629218635225`*^9, 3.7164629219124093`*^9}, {
  3.757098985272653*^9, 3.757098985371121*^9}, {3.761634165707407*^9, 
  3.7616341673631945`*^9}, {3.807540438152917*^9, 3.80754044002098*^9}, {
  3.8075404710918403`*^9, 3.807540480204813*^9}, {3.807544961581009*^9, 
  3.8075449987468166`*^9}},
 CellID->1415545780,ExpressionUUID->"b23798f8-18b4-4b37-b9f9-87213c7fc22b"],

Cell["Multiply Lists:", "CodeCaption",
 CellChangeTimes->{{3.6898257506267776`*^9, 3.68982577789004*^9}, 
   3.716462921916956*^9, {3.7570879597667513`*^9, 3.757087968678955*^9}, 
   3.757088368661182*^9, {3.8075404854345503`*^9, 3.8075404881782913`*^9}},
 CellID->1254082994,ExpressionUUID->"d6c8f0fa-d4a3-44f1-9a83-66afe4290378"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList1", "*", "myList2"}]], "Input",
 CellChangeTimes->{{3.6898257506267776`*^9, 3.68982577789004*^9}, 
   3.716462921916956*^9, 3.7570879597667513`*^9},
 CellLabel->"In[14]:=",
 CellID->1771149749,ExpressionUUID->"e41b1b2f-78c9-4612-aaa8-1c6452113b1d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "4", ",", "9", ",", 
   SuperscriptBox["\<\"Mathematica\"\>", "2"]}], "}"}]], "Output",
 CellChangeTimes->{3.689825755261355*^9, 3.7572200591099043`*^9, 
  3.812204079222451*^9},
 CellLabel->"Out[14]=",
 CellID->1514308771,ExpressionUUID->"01e15cdd-4057-464b-a6fb-ec943635b69e"]
}, Open  ]],

Cell["\<\
Lastly, we see an example where each of the corresponding elements in the two \
Lists are added to each other. This will only work if, once again, the Lists \
have the same number of elements in them.\
\>", "Text",
 CellChangeTimes->{{3.708332434086833*^9, 3.7083324557003202`*^9}, {
   3.7164464212714305`*^9, 3.7164464676313095`*^9}, {3.7164629219482117`*^9, 
   3.7164629219794645`*^9}, 3.7570989854188137`*^9, {3.7616341968834195`*^9, 
   3.761634200970481*^9}, 3.807466143952528*^9, {3.812204526050433*^9, 
   3.812204527481873*^9}},
 CellID->383797465,ExpressionUUID->"6c1e7f96-c274-4fa9-bbe5-6132b18081b7"],

Cell["Add Lists:", "CodeCaption",
 CellChangeTimes->{
  3.7164629219950905`*^9, {3.757088379172511*^9, 3.757088388932283*^9}, {
   3.807540501151251*^9, 3.8075405014893713`*^9}},
 CellID->1590602314,ExpressionUUID->"29bfebc1-9d0d-4849-b94b-daa45ec01766"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList1", "+", "myList2"}]], "Input",
 CellChangeTimes->{
  3.7164629219950905`*^9, {3.757088379172511*^9, 3.7570883818527527`*^9}},
 CellLabel->"In[15]:=",
 CellID->321934162,ExpressionUUID->"8cc2a4a1-3d5c-4964-a91e-7d060261a178"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "4", ",", "6", ",", 
   RowBox[{"2", " ", "\<\"Mathematica\"\>"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6898258706086187`*^9, 3.7572200591509438`*^9, 
  3.8122040792277737`*^9},
 CellLabel->"Out[15]=",
 CellID->1158813600,ExpressionUUID->"c8968e99-5586-4f82-b4bc-a61b25c08b3e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nesting Lists", "Subsubsection",
 PageBreakAbove->True,
 CellChangeTimes->{{3.689905149272833*^9, 3.689905152221286*^9}, 
   3.689909871221451*^9, 3.716462922016737*^9},
 CellID->427267616,ExpressionUUID->"70856f29-ca32-4880-8ffd-e325db52a1e2"],

Cell[TextData[{
 "Lists themselves can be elements in a larger List. Below we place both ",
 Cell[BoxData[
 "myList1"], "InlineCodeText",ExpressionUUID->
  "738d7f60-148d-4ecf-a8c0-f4f2efd00fc4"],
 " and ",
 Cell[BoxData[
 "myList2"], "InlineCodeText",ExpressionUUID->
  "4e83ef72-1d7d-423c-98fb-e59e0ac6ff65"],
 " in a List called ",
 Cell[BoxData[
 "myList3"], "InlineCodeText",ExpressionUUID->
  "f1b27a70-a98d-4d82-a72e-37dc4f5ae4b0"],
 ". Note the use of double curly braces in the output. The computer variable ",
 Cell[BoxData[
 "myList3"], "InlineCodeText",ExpressionUUID->
  "46c0d74a-7569-4f15-b4da-8ac68c709f30"],
 " is indeed a List of Lists."
}], "Text",
 CellChangeTimes->{{3.7083325517735977`*^9, 3.70833259451222*^9}, {
  3.715665423917199*^9, 3.7156654477751236`*^9}, {3.716446499911739*^9, 
  3.7164465050164185`*^9}, {3.71646292206366*^9, 3.7164629221796007`*^9}, {
  3.757085305495619*^9, 3.757085348639522*^9}, {3.7570860639769278`*^9, 
  3.7570861325637217`*^9}, {3.757087127263118*^9, 3.757087136292623*^9}, {
  3.757098985470728*^9, 3.757098985567856*^9}, {3.757212371483082*^9, 
  3.75721240649454*^9}},
 CellID->2048990191,ExpressionUUID->"defce31a-d1c1-4fa7-ad1d-62d1012dd7d4"],

Cell["Make a List of Lists:", "CodeCaption",
 CellChangeTimes->{{3.6898258872302437`*^9, 3.689825911883985*^9}, 
   3.716462922195228*^9, {3.757088396764542*^9, 3.7570884175802107`*^9}, {
   3.807543815460804*^9, 3.807543816425229*^9}},
 CellID->330376845,ExpressionUUID->"dde86163-a63d-45c4-b5dc-12959d24a7f5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList3", "=", 
  RowBox[{"{", 
   RowBox[{"myList1", ",", "myList2"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6898258872302437`*^9, 3.689825911883985*^9}, 
   3.716462922195228*^9, 3.757088396764542*^9},
 CellLabel->"In[16]:=",
 CellID->1581341515,ExpressionUUID->"ac1dfa08-5750-4e5c-be37-50a856437bc0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.689825913002063*^9, 3.757220059196422*^9, 
  3.8122040792329607`*^9},
 CellLabel->"Out[16]=",
 CellID->650980557,ExpressionUUID->"a28d6b5a-6d0d-4eb0-9894-0a72f250db3f"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Matrices", "Subsection",
 CellChangeTimes->{{3.689825948068618*^9, 3.689825949380143*^9}},
 CellID->955668172,ExpressionUUID->"8fb41a92-0f79-4fcb-a812-b5f21985b635"],

Cell["\<\
Matrices consist of rows and columns of elements. They are very useful \
mathematical objects. We store matrices in the Wolfram Language as nested \
Lists. In the first example, we recreate the matrix in the expression below, \
which contains two rows and two columns of numbers.\
\>", "Text",
 CellChangeTimes->{{3.708333166746173*^9, 3.708333233794258*^9}, {
   3.708333273083547*^9, 3.7083332842294655`*^9}, {3.7156654601758895`*^9, 
   3.7156655565381327`*^9}, {3.7164465627047215`*^9, 3.716446590295534*^9}, 
   3.7164629222173724`*^9, {3.757098985615655*^9, 3.7570989857164087`*^9}, {
   3.8075438348262377`*^9, 3.8075438358784847`*^9}, 3.809353287297639*^9},
 CellID->884770891,ExpressionUUID->"3e2c7203-84ba-49f0-8a08-c5018d45ad94"],

Cell[BoxData[GridBox[{
   {
    RowBox[{"(", GridBox[{
       {"1", "2"},
       {"3", "7"}
      }], ")"}]}
  },
  GridBoxAlignment->{"Columns" -> {{"Center"}}}]], "DisplayFormula",
 CellChangeTimes->{3.7164465490943317`*^9},
 CellID->1167593209,ExpressionUUID->"f70082c2-e4fc-44ff-ac45-d8c17e067818"],

Cell[TextData[{
 "The first row contains the numbers 1 and 2. The second row contains the \
numbers 3 and 7. The first column then contains the numbers 1 and 3 and the \
second column contains the numbers 2 and 7. Let\[CloseCurlyQuote]s call this \
nested list ",
 Cell[BoxData[
 "myMatrix1"], "InlineCodeText",ExpressionUUID->
  "ccb626ef-c53d-4ec3-a2fd-8923dace5354"],
 "."
}], "Text",
 CellChangeTimes->{{3.7164465956256027`*^9, 3.716446627623788*^9}, 
   3.716462922264288*^9, {3.757085357497621*^9, 3.757085365977941*^9}, {
   3.75708608512156*^9, 3.757086085126943*^9}, {3.7570872004747477`*^9, 
   3.75708720047996*^9}, {3.757098985765048*^9, 3.757098985870434*^9}, {
   3.757214681744542*^9, 3.7572146909890347`*^9}, {3.807545009679919*^9, 
   3.807545046620654*^9}, 3.8093557349922237`*^9},
 CellID->33497377,ExpressionUUID->"9a194d3b-bae3-457e-8c9d-38e12348f214"],

Cell[TextData[{
 "Create a matrix named ",
 Cell[BoxData[
 "myMatrix1"], "InlineCode",ExpressionUUID->
  "7311ed3d-c234-4f8d-913b-49336af05b71"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.8075438643390927`*^9, 3.807543911463353*^9}},
 CellID->216047554,ExpressionUUID->"4da7eaa7-03d1-4c72-8a36-2d2d933a03ae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myMatrix1", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "7"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6898260008217163`*^9, 3.689826022141477*^9}, {
  3.708333299254776*^9, 3.7083333190668077`*^9}},
 CellLabel->"In[17]:=",
 CellID->349699725,ExpressionUUID->"fa82acd4-902a-4504-96d1-893bd7ac01e0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "7"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6898260238809547`*^9, 3.7083333204998183`*^9, 
  3.716446714800094*^9, 3.757220059243607*^9, 3.7616344211730795`*^9, 
  3.7616346176729937`*^9, 3.812204079239367*^9},
 CellLabel->"Out[17]=",
 CellID->1748523681,ExpressionUUID->"e059b69f-f0c4-4c5f-901d-712bc2f7fe1f"]
}, Open  ]],

Cell["\<\
Note that if we wish to represent a matrix where the entries are done in \
row-wise fashion, i.e. the first row contained the values 1 and 2, they are \
entered as the first element in the nested List.\
\>", "Text",
 CellChangeTimes->{{3.761634450267027*^9, 3.761634516747675*^9}, {
   3.7616345756513677`*^9, 3.7616345765549507`*^9}, {3.807543985944661*^9, 
   3.8075439943971443`*^9}, 3.8075440410177846`*^9, {3.807545050700716*^9, 
   3.807545055262726*^9}},
 FontTracking->-0.1,
 CellID->314154751,ExpressionUUID->"40a7f073-b21e-4432-baaa-5d0f6c7c2be1"],

Cell[TextData[{
 "To show this matrix in proper mathematical notation as we did above, we can \
accomplish this with the ",
 ButtonBox["MatrixForm",
  BaseStyle->"Link"],
 " function. It can be used in prefix, postfix, or function form."
}], "Text",
 CellChangeTimes->{{3.7083333390959034`*^9, 3.7083334025712404`*^9}, {
   3.7083334362536755`*^9, 3.7083334486943483`*^9}, {3.7085869827710905`*^9, 
   3.708586988572365*^9}, {3.7164466447514567`*^9, 3.7164466853754063`*^9}, 
   3.716462922295508*^9, {3.7516815974154034`*^9, 3.751681601338214*^9}, {
   3.757087212643343*^9, 3.757087217889606*^9}, {3.757098985920083*^9, 
   3.7570989859697638`*^9}, {3.757214706530512*^9, 3.757214711293674*^9}, {
   3.761634591715914*^9, 3.7616346071397977`*^9}, {3.8075441005766892`*^9, 
   3.807544100767229*^9}, {3.807544131228372*^9, 3.807544131614868*^9}, {
   3.8093534217932663`*^9, 3.809353440418358*^9}},
 CellID->731805509,ExpressionUUID->"49e7f9ab-4290-4ccd-ab4b-5ffe78d619b3"],

Cell[TextData[{
 "Using the ",
 ButtonBox["@",
  BaseStyle->"Link",
  ButtonData->"ref/Prefix"],
 " ",
 ButtonBox["Prefix",
  BaseStyle->"Link"],
 " notation:"
}], "CodeCaption",
 CellChangeTimes->{{3.7164466963020506`*^9, 3.7164467121020126`*^9}, {
   3.757088438884225*^9, 3.757088448659946*^9}, {3.809353473272995*^9, 
   3.809353476633753*^9}, 3.809353540652019*^9},
 CellID->816343394,ExpressionUUID->"2ac945f8-5894-4f1d-a8d9-377d0f9ac77a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "@", "myMatrix1"}]], "Input",
 CellChangeTimes->{{3.7164466963020506`*^9, 3.7164467121020126`*^9}, {
  3.757088438884225*^9, 3.7570884409644547`*^9}},
 CellLabel->"In[18]:=",
 CellID->1159046616,ExpressionUUID->"a278cb8a-7a6f-4feb-a142-0200e56e8338"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2"},
     {"3", "7"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.716446718078594*^9, 3.757220061526993*^9, 
  3.812204079258882*^9},
 CellLabel->"Out[18]//MatrixForm=",
 CellID->1271281019,ExpressionUUID->"1f52344a-c529-4794-bdb7-b62e2eeb6e89"]
}, Open  ]],

Cell["\<\
Note that no additional spaces are necessary with the postfix notation:\
\>", "CodeCaption",
 CellMargins->{{66, 10}, {4, 7}},
 PageBreakAbove->True,
 CellChangeTimes->{{3.689826029605062*^9, 3.689826057595858*^9}, {
   3.7083334180228105`*^9, 3.7083334264754696`*^9}, {3.7085869761991835`*^9, 
   3.708586976828*^9}, 3.7164466900144343`*^9, {3.757088452988392*^9, 
   3.7570884606119833`*^9}, 3.809353570266616*^9},
 CellID->884860518,ExpressionUUID->"f6f9dba9-f952-488b-b702-83367a89ed12"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myMatrix1", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.689826029605062*^9, 3.689826057595858*^9}, {
   3.7083334180228105`*^9, 3.7083334264754696`*^9}, {3.7085869761991835`*^9, 
   3.708586976828*^9}, 3.7164466900144343`*^9, 3.757088452988392*^9},
 CellLabel->"In[19]:=",
 CellID->1735216604,ExpressionUUID->"31a8b4bc-d920-4905-84ec-7fa488ab1ad2"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2"},
     {"3", "7"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.689826042681978*^9, 3.708333410068844*^9, 
  3.716446722827804*^9, 3.757220061750667*^9, 3.8122040792650948`*^9},
 CellLabel->"Out[19]//MatrixForm=",
 CellID->1105282330,ExpressionUUID->"4d53444d-97e0-482e-9cd0-a70634c74223"]
}, Open  ]],

Cell["For the purposes of this book, function form is fine:", "CodeCaption",
 CellChangeTimes->{{3.689826062579803*^9, 3.689826076142658*^9}, {
   3.7083334554046946`*^9, 3.7083334565558105`*^9}, {3.757088463436377*^9, 
   3.7570884740120773`*^9}, 3.809353589112927*^9},
 CellID->757925017,ExpressionUUID->"0d027a53-4979-4c95-9220-c064508177d3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "myMatrix1", "]"}]], "Input",
 CellChangeTimes->{{3.689826062579803*^9, 3.689826076142658*^9}, {
   3.7083334554046946`*^9, 3.7083334565558105`*^9}, 3.757088463436377*^9},
 CellLabel->"In[20]:=",
 CellID->1535090383,ExpressionUUID->"7abe4af4-0070-4b87-9755-f3b8de3c994c"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "2"},
     {"3", "7"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.689826076468133*^9, 3.7083334123440547`*^9, 
  3.7164467256945252`*^9, 3.757220061863751*^9, 3.812204079286454*^9},
 CellLabel->"Out[20]//MatrixForm=",
 CellID->746573760,ExpressionUUID->"5b3a9cb9-8d3a-4eff-a335-7e35c2c68751"]
}, Open  ]],

Cell[TextData[{
 "It is important to note that while we use ",
 ButtonBox["MatrixForm",
  BaseStyle->"Link"],
 " for visual representation, we should omit it when doing calculations. In \
the next piece of code, we add the value 3 to each element in our original \
computer variable ",
 Cell[BoxData[
 "myMatrix1"], "InlineCodeText",ExpressionUUID->
  "c80c047d-41fe-4554-97bd-c07be9f6215a"],
 "."
}], "Text",
 CellChangeTimes->{{3.761634330475315*^9, 3.7616344138832135`*^9}, {
   3.776704320693619*^9, 3.776704329517548*^9}, 3.776705657743762*^9, {
   3.8075441487717705`*^9, 3.80754415345224*^9}, {3.8075450649488597`*^9, 
   3.8075450668392067`*^9}},
 CellID->120358242,ExpressionUUID->"d9664a32-7473-4575-a089-b418163e3454"],

Cell["Add 3 to each element in the matrix:", "CodeCaption",
 CellChangeTimes->{{3.689826062579803*^9, 3.689826076142658*^9}, {
  3.7083334554046946`*^9, 3.7083334565558105`*^9}, {3.757088463436377*^9, 
  3.7570884740120773`*^9}, {3.7616346398112345`*^9, 3.7616346462278557`*^9}, {
  3.8075441625482516`*^9, 3.807544166306773*^9}},
 CellID->511598552,ExpressionUUID->"bbb2a3b5-a4f8-41a6-af41-8ed7c33e0604"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myMatrix1", "+", "3"}]], "Input",
 CellChangeTimes->{
  3.7616344160976143`*^9, {3.761634623107915*^9, 3.761634627283913*^9}},
 CellLabel->"In[21]:=",
 CellID->296195294,ExpressionUUID->"1bd5ac03-0594-4835-902c-ba1c7e7c40d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "10"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7616346279223356`*^9, 3.8122040792925463`*^9},
 CellLabel->"Out[21]=",
 CellID->2065718546,ExpressionUUID->"a23885ad-0ddb-4d78-8cbd-92633dbd378a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["List Comprehension", "Subsection",
 CellMargins->{{64, 3}, {7, 27}},
 CellChangeTimes->{{3.689826163087462*^9, 3.6898261680161657`*^9}, 
   3.782057517465973*^9},
 CellID->675494573,ExpressionUUID->"6c27edc1-a8dd-4287-b12d-1722128e43a1"],

Cell[TextData[{
 "Instead of adding values to a List in manual fashion by typing them in one \
at a time, we can use an expression (a recipe or a pattern) to create the \
values. This is done using the very powerful ",
 ButtonBox["Table",
  BaseStyle->"Link"],
 " function. Doing so is sometimes referred to as List",
 StyleBox[" comprehension",
  FontSlant->"Italic"],
 ". Until you see it in action a few times, it might appear a little \
confusing. "
}], "Text",
 InitializationCell->True,
 CellChangeTimes->{{3.70833349854158*^9, 3.7083337800266905`*^9}, {
   3.7156656384438457`*^9, 3.715665676692407*^9}, {3.7156657121372986`*^9, 
   3.71566575103962*^9}, {3.716446810287859*^9, 3.7164468595563087`*^9}, {
   3.716462922348911*^9, 3.716462922433096*^9}, {3.7516816639664745`*^9, 
   3.751681698417205*^9}, 3.751681749393001*^9, {3.757085378488126*^9, 
   3.7570853833972473`*^9}, {3.757088486315488*^9, 3.7570884863156223`*^9}, {
   3.757098986021635*^9, 3.757098986441986*^9}, {3.7572147486912527`*^9, 
   3.757214775783412*^9}, 3.761634712051484*^9, 3.76163474481166*^9},
 CellID->1438730369,ExpressionUUID->"a6b718f9-995f-4c82-ae1e-98aa4be4ec9a"],

Cell[TextData[{
 "As an example then, let\[CloseCurlyQuote]s create a list of the first 10 \
positive integers, that is, 1 through 10. Instead of typing the values, we \
will use a placeholder name. In the code below, we will use the letter ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]],ExpressionUUID->
  "fcd7611d-543c-458e-8f3a-e1209a9bd37a"],
 ". We do not want to manipulate this placeholder in any way, i.e. multiply \
it by 2, so we just state it on its own. Then, inside of curly braces, we \
reference this placeholder and then its ",
 StyleBox["start",
  FontSlant->"Italic"],
 " and ",
 StyleBox["stop",
  FontSlant->"Italic"],
 " values and its ",
 StyleBox["step size",
  FontSlant->"Italic"],
 ". We will start at 1 and go to 10 in steps of 1. This ",
 StyleBox["start-stop-step size",
  FontSlant->"Italic"],
 " is referred to as the ",
 StyleBox["iterator",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.7616347584386544`*^9, 3.761634777892044*^9}, {
   3.7616348556600122`*^9, 3.761634882484568*^9}, 3.776705657791876*^9, 
   3.8075445904833126`*^9, {3.8075446232770343`*^9, 3.807544668651457*^9}, {
   3.8075450739632416`*^9, 3.8075450770314054`*^9}, 3.80935577672033*^9},
 CellID->136117311,ExpressionUUID->"7a69bff5-d379-4139-abb9-dc46e90fb192"],

Cell["\<\
Create a List of integers starting at 1 and incrementing in steps of 1 to the \
value 10:\
\>", "CodeCaption",
 CellChangeTimes->{{3.6898262156818523`*^9, 3.689826264030752*^9}, {
   3.68982636629694*^9, 3.6898263922955914`*^9}, {3.6899052121186857`*^9, 
   3.68990525835957*^9}, 3.7164629224487553`*^9, {3.7571001020341673`*^9, 
   3.75710012056122*^9}, 3.7616349454042377`*^9, 3.807466167551888*^9},
 CellID->75446563,ExpressionUUID->"e1574714-8270-4a3f-9e00-6d4d615c6cd9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myTable1", "=", 
  RowBox[{"Table", "[", 
   RowBox[{"i", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "10", ",", "1"}], "}"}]}], "]"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.6898262156818523`*^9, 3.689826264030752*^9}, {
   3.68982636629694*^9, 3.6898263922955914`*^9}, {3.6899052121186857`*^9, 
   3.68990525835957*^9}, 3.7164629224487553`*^9, {3.7571001020341673`*^9, 
   3.757100104171021*^9}},
 CellLabel->"In[22]:=",
 CellID->2076158683,ExpressionUUID->"c704a606-db69-4b39-aa2c-0e1dc14781c7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", 
   ",", "9", ",", "10"}], "}"}]], "Output",
 CellChangeTimes->{3.6898262654973993`*^9, 3.757220061911766*^9, 
  3.812204079298771*^9},
 CellLabel->"Out[22]=",
 CellID->163481573,ExpressionUUID->"21f33a2f-106e-4f2a-bd0a-38a4967721a8"]
}, Open  ]],

Cell[TextData[{
 "The Wolfram Language makes use of a few defaults for the iterator. If a \
single value is used, it is assumed that the start is 1 and that the step \
size is ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "a1e97080-a5af-444f-a709-0dd08fabd6ac"],
 "."
}], "Text",
 CellChangeTimes->{{3.761634827467492*^9, 3.7616348364117107`*^9}, {
   3.761634907667684*^9, 3.7616349355879993`*^9}, 3.776705657841663*^9, {
   3.807544689188797*^9, 3.807544690730717*^9}},
 CellID->148162651,ExpressionUUID->"456e2520-a0ab-4b83-add5-ae8045fd7d32"],

Cell["Omit the start and step size values:", "CodeCaption",
 CellChangeTimes->{{3.6898262156818523`*^9, 3.689826264030752*^9}, {
   3.68982636629694*^9, 3.6898263922955914`*^9}, {3.6899052121186857`*^9, 
   3.68990525835957*^9}, 3.7164629224487553`*^9, {3.7571001020341673`*^9, 
   3.75710012056122*^9}, {3.7616349454042377`*^9, 3.7616349689965906`*^9}, {
   3.8074661706371965`*^9, 3.807466171623295*^9}, {3.8075451071191535`*^9, 
   3.807545108138421*^9}},
 CellID->437282718,ExpressionUUID->"1a8eb419-13f9-41a0-8e2f-af5d3af58dd8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{"i", ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.761634971847163*^9, 3.761634983852682*^9}},
 CellLabel->"In[23]:=",
 CellID->265909620,ExpressionUUID->"56be93cb-e63f-42a0-9a48-dc33df01109a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", 
   ",", "9", ",", "10"}], "}"}]], "Output",
 CellMargins->{{99, 10}, {9, 7}},
 CellChangeTimes->{3.7616349840700965`*^9, 3.812204079318899*^9},
 CellLabel->"Out[23]=",
 CellID->1003212898,ExpressionUUID->"55dcbc2a-198d-47cc-8a09-973137363ec7"]
}, Open  ]],

Cell["We can also use different start values and step sizes.", "Text",
 PageBreakAbove->True,
 CellChangeTimes->{{3.7616349970753617`*^9, 3.761635013556179*^9}},
 CellID->416832771,ExpressionUUID->"7ee1c2de-d510-4754-a6f0-2d54b88efc6a"],

Cell["Use a different starting value and step size:", "CodeCaption",
 CellChangeTimes->{{3.6898262156818523`*^9, 3.689826264030752*^9}, {
   3.68982636629694*^9, 3.6898263922955914`*^9}, {3.6899052121186857`*^9, 
   3.68990525835957*^9}, 3.7164629224487553`*^9, {3.7571001020341673`*^9, 
   3.75710012056122*^9}, 3.7616349454042377`*^9, {3.761635019332033*^9, 
   3.7616350339394083`*^9}, {3.807545115776085*^9, 3.807545122463348*^9}},
 CellID->298044940,ExpressionUUID->"2395795f-df26-4044-874b-015e69efa676"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{"i", ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "2", ",", "4", ",", "0.2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7616350355185766`*^9, 3.7616350465323267`*^9}},
 CellLabel->"In[24]:=",
 CellID->449329642,ExpressionUUID->"60e73008-3971-46f9-98fe-36aeed754ea4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2.`", ",", "2.2`", ",", "2.4`", ",", "2.6`", ",", "2.8`", ",", "3.`", ",", 
   "3.2`", ",", "3.4000000000000004`", ",", "3.6`", ",", "3.8`", ",", "4.`"}],
   "}"}]], "Output",
 CellChangeTimes->{3.7616350468677893`*^9, 3.8122040793250723`*^9},
 CellLabel->"Out[24]=",
 CellID->1105064089,ExpressionUUID->"ad741057-c32a-4b8f-a196-53fa25c0cdcc"]
}, Open  ]],

Cell["The Wolfram Language even allows us to go in reverse.", "Text",
 CellChangeTimes->{{3.7616350549954615`*^9, 3.761635065803526*^9}},
 CellID->352701977,ExpressionUUID->"71d3f5f9-1869-4455-98ef-42fdfe4d1045"],

Cell["Iterate backward:", "CodeCaption",
 CellChangeTimes->{{3.6898262156818523`*^9, 3.689826264030752*^9}, {
   3.68982636629694*^9, 3.6898263922955914`*^9}, {3.6899052121186857`*^9, 
   3.68990525835957*^9}, 3.7164629224487553`*^9, {3.7571001020341673`*^9, 
   3.75710012056122*^9}, 3.7616349454042377`*^9, {3.7616350709561186`*^9, 
   3.761635075603962*^9}, {3.8075451291131735`*^9, 3.8075451342136135`*^9}},
 CellID->306444229,ExpressionUUID->"7b761daf-7845-4c5e-98f0-f5c9add064bc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{"i", ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "10", ",", "1", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7616350770545535`*^9, 3.7616350878444414`*^9}},
 CellLabel->"In[25]:=",
 CellID->189634114,ExpressionUUID->"6d2f4fe8-1de4-46fd-ba7e-077dc3f8ffc4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "10", ",", "9", ",", "8", ",", "7", ",", "6", ",", "5", ",", "4", ",", "3", 
   ",", "2", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.761635088123718*^9, 3.812204079331521*^9},
 CellLabel->"Out[25]=",
 CellID->1373564567,ExpressionUUID->"33edb437-2cf3-4b8a-82c6-49027e53f945"]
}, Open  ]],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s create a second list, going through the values 1 to \
5 and squaring each. Our expression now becomes ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["i", "2"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "1e096f37-34db-44cf-8671-8e763bec07f0"],
 ". (Remember that we create the superscript syntax for the square by hitting \
",
 Cell[BoxData[
  TemplateBox[{"esc"},
   "Key0"]], "InlineCodeText",ExpressionUUID->
  "33c913f9-d42f-4b9e-ae77-e2af76aba387"],
 " or ",
 Cell[BoxData[
  TemplateBox[{"command"},
   "Key0"]], "InlineCodeText",ExpressionUUID->
  "961afaf4-d2f6-49f2-a229-d48ef5b813aa"],
 " and the number ",
 Cell[BoxData[
  FormBox["6", TraditionalForm]],ExpressionUUID->
  "d3c6a4ce-e3b0-40e8-99f4-001dcc74a1f5"],
 ", or alternatively, we could use the caret (",
 ButtonBox["^",
  BaseStyle->"Link",
  ButtonData->"Power"],
 ") symbol.)"
}], "Text",
 CellChangeTimes->{{3.70833382107987*^9, 3.708333854465248*^9}, {
   3.7156657744397926`*^9, 3.715665819455549*^9}, {3.716446886366471*^9, 
   3.7164469164874353`*^9}, 3.7164629224799995`*^9, {3.7516817756581125`*^9, 
   3.7516817977594624`*^9}, {3.757098986498495*^9, 3.757098986549444*^9}, 
   3.757100172996275*^9, {3.776704383860757*^9, 3.776704429496426*^9}, {
   3.7767045306086483`*^9, 3.776704561459221*^9}, {3.776704818735283*^9, 
   3.776704859258197*^9}, {3.807545143124892*^9, 3.807545186384796*^9}, 
   3.809353618411531*^9},
 CellID->43001309,ExpressionUUID->"07115bc6-9644-4d83-8cda-a2fe1ee88dad"],

Cell[TextData[{
 "Use  ",
 Cell[BoxData[
  SuperscriptBox[
   StyleBox["i",
    FontSlant->"Italic"], "2"]], "InlineMath",ExpressionUUID->
  "9119bf87-e268-4cca-aa46-796d841b17c8"],
 " as the expression to calculate the square of the first five natural \
numbers:"
}], "CodeCaption",
 CellChangeTimes->{{3.815748643445139*^9, 3.815748652412366*^9}},
 CellID->213763186,ExpressionUUID->"54fe8d43-e11d-4238-8b9b-c473a44bf775"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myTable2", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SuperscriptBox["i", "2"], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "5", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.689826285262986*^9, 3.6898263201475554`*^9}, {
  3.6898264023416357`*^9, 3.689826443903191*^9}, {3.8074663929029512`*^9, 
  3.8074663939638453`*^9}},
 CellLabel->"In[26]:=",
 CellID->1168494971,ExpressionUUID->"acb3fb07-ce39-4974-9feb-d476fed66270"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "4", ",", "9", ",", "16", ",", "25"}], "}"}]], "Output",
 CellChangeTimes->{3.689826320866695*^9, 3.75722006196093*^9, 
  3.8122040793390703`*^9},
 CellLabel->"Out[26]=",
 CellID->50472319,ExpressionUUID->"0ada5eb5-7cc7-4c5a-8f18-744fe8cff52a"]
}, Open  ]],

Cell[TextData[{
 "It can be quite useful to iterate through more than one placeholder. In the \
Wolfram Language, the iteration starts at the last placeholder. This is done \
for each of the preceding placeholder values. Next we see an example of \
iteration through the values 1 to 9 in steps of 4, that is, 1, 5, and 9. This \
is for the placeholder ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]], "InlineMath",ExpressionUUID->
  "cde51963-4825-4001-af6c-55c697d2d0cf"],
 ". This happens for each of the values in the preceding placeholder, ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]], "InlineMath",ExpressionUUID->
  "81fb4d97-5503-403e-a5dc-95ccc01f9a9b"],
 ", which in turn iterates through 1 to 9 in steps of 2, which is 1, 3, 5, 7, \
and 9. In this example, we add each of the values. Since ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]], "InlineMath",ExpressionUUID->
  "e598321a-a1f1-4094-ae54-63762c1697ba"],
 " starts at 1 and ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]], "InlineMath",ExpressionUUID->
  "daea9942-a0d5-452c-b9eb-5e48d8640a06"],
 " starts at 1, the first addition will be ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "+", "1"}], "=", "2"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"b7254e7d-37b7-4055-8363-905892a8a88b"],
 ", followed by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "+", "5"}], "=", "6"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"e84ca5ac-718b-463d-ba51-1b89a71ff175"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "+", "9"}], "=", "10"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"5dd620f4-555a-45a1-9ae0-b01759ded622"],
 " as we iterate through all the values of ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]], "InlineMath",ExpressionUUID->
  "7f2b697f-e44e-44ab-a34d-a166888eeab4"],
 " for the first value of ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]], "InlineMath",ExpressionUUID->
  "7d5a9d1e-5102-43b6-a8cf-6ac00d5ecdfe"],
 ". Then we move to the next ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]], "InlineMath",ExpressionUUID->
  "e8ff1142-bf19-469b-b4b9-d1107e42e13f"],
 " value and again iterate through all the ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]], "InlineMath",ExpressionUUID->
  "a0365686-f7b5-4011-9eff-19b469450617"],
 " values."
}], "Text",
 CellChangeTimes->{{3.7083338800333533`*^9, 3.708334220493642*^9}, {
   3.71566584126614*^9, 3.7156658844320183`*^9}, {3.7517660131902633`*^9, 
   3.751766035237254*^9}, {3.7517660777492943`*^9, 3.751766084280507*^9}, {
   3.757098986602723*^9, 3.757098987032599*^9}, {3.776704695699885*^9, 
   3.7767046962427483`*^9}, {3.8075456260500917`*^9, 3.807545736426464*^9}, 
   3.815748723190936*^9},
 CellID->2022399558,ExpressionUUID->"e818c775-61e6-4202-af8c-054150f17931"],

Cell[TextData[{
 "Use more than one index to create a nested ",
 ButtonBox["List:",
  BaseStyle->"Link"],
 " "
}], "CodeCaption",
 CellChangeTimes->{{3.689826466956697*^9, 3.689826617666354*^9}, {
  3.6898266888159513`*^9, 3.689826709584029*^9}, {3.6898267499544153`*^9, 
  3.689826750625099*^9}, {3.689826798338931*^9, 3.689826816352865*^9}, {
  3.689826921568612*^9, 3.6898269226777077`*^9}, {3.689905281005953*^9, 
  3.689905282744746*^9}, {3.7164629224956026`*^9, 3.7164629224956026`*^9}, {
  3.75708850929342*^9, 3.75708853688379*^9}, {3.7570885751766253`*^9, 
  3.7570885811622877`*^9}, {3.757100184978402*^9, 3.7571002476350603`*^9}, {
  3.8074664357776637`*^9, 3.8074664578994513`*^9}},
 CellID->98206590,ExpressionUUID->"b282b8bf-54ac-454f-bffc-4cd008842c0e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myTable3", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"i", "+", "j"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "9", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "9", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.689826466956697*^9, 3.689826617666354*^9}, {
   3.6898266888159513`*^9, 3.689826709584029*^9}, {3.6898267499544153`*^9, 
   3.689826750625099*^9}, {3.689826798338931*^9, 3.689826816352865*^9}, {
   3.689826921568612*^9, 3.6898269226777077`*^9}, {3.689905281005953*^9, 
   3.689905282744746*^9}, {3.7164629224956026`*^9, 3.7164629224956026`*^9}, 
   3.75708850929342*^9},
 CellLabel->"In[27]:=",
 CellID->433268949,ExpressionUUID->"4060eb99-13df-44b1-bbd4-7866e578af8b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "6", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "8", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "10", ",", "14"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "12", ",", "16"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "14", ",", "18"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.689826515414369*^9, 3.6898267517207336`*^9, 
  3.689826923411386*^9, 3.689905636251309*^9, 3.708334706318674*^9, 
  3.7164473213091393`*^9, 3.7572200620117197`*^9, 3.761635349063599*^9, 
  3.812204079358844*^9},
 CellLabel->"Out[27]=",
 CellID->32224868,ExpressionUUID->"c90f6e35-95a8-48d2-8ef0-93c95aa123f0"]
}, Open  ]],

Cell[TextData[{
 "The first nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " will be created by ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "+", "1"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "ba2b0170-8f0f-43f9-8b13-cd8724d4407e"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "+", "5"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "7fdf930b-08e9-4150-a126-03bc23bf8908"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "+", "9"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "46726291-f387-485a-823c-11d51a279fd3"],
 " (looping through all the ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]], "InlineMath",ExpressionUUID->
  "7e2a012e-8236-4a55-9289-5a9bfc87ec3c"],
 "\[CloseCurlyQuote]s for each ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]], "InlineMath",ExpressionUUID->
  "35a7df17-63c6-43a1-93f1-a9080d102b8d"],
 " loop). The second nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " will be created by ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", "+", "1"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "eaa2f6b8-b924-41b0-a6f3-ca2a949e4968"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", "+", "5"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "8f260f5c-7e14-48cf-873d-aa292738c78a"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", "+", "9"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "a606c72d-9b9c-44ef-be5f-c2e73bf27e45"],
 "."
}], "Text",
 CellChangeTimes->{
  3.80746646460478*^9, {3.807466509767264*^9, 3.807466511076133*^9}, {
   3.807466827782188*^9, 3.8074668474361877`*^9}, {3.807546310946289*^9, 
   3.8075463751165104`*^9}, {3.812204745466337*^9, 3.812204749634865*^9}, {
   3.815748742071043*^9, 3.815748762022791*^9}, 3.815748808415153*^9},
 CellID->213854862,ExpressionUUID->"34ef9b04-c83a-42ba-ac9d-bb83c862e9fb"],

Cell[TextData[{
 "Practice using the ",
 ButtonBox["Table",
  BaseStyle->"Link"],
 " function."
}], "Text",
 CellChangeTimes->{{3.716447000552867*^9, 3.716447030573329*^9}, {
   3.751766136191456*^9, 3.751766143825317*^9}, {3.757087240742778*^9, 
   3.757087245225586*^9}, {3.7570885516653976`*^9, 3.75708855166543*^9}, 
   3.757098987084104*^9, 3.757214853444573*^9, {3.8122047414262753`*^9, 
   3.812204741777855*^9}},
 CellID->1395799009,ExpressionUUID->"06c51ab5-89ac-42ee-aef3-d1eab4c39754"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Accessing Elements of a List", "Subsection",
 CellMargins->{{64, 3}, {12, 17}},
 PageBreakAbove->True,
 CellChangeTimes->{{3.6898271208181334`*^9, 3.6898271270847483`*^9}, 
   3.716462922517747*^9, 3.7820575227600517`*^9},
 CellID->82584435,ExpressionUUID->"fc1bc442-6f43-4255-9301-0783f3faef20"],

Cell[TextData[{
 "While it is handy to use list comprehension or even to manually type in \
large lists, it will inevitably become necessary to reference some of the \
values. Fortunately, each element in these Lists has an ",
 StyleBox["address",
  FontSlant->"Italic"],
 ", also called an index value. We can reference these addresses to access \
specific values. Address referencing in the Wolfram Language is done by the \
use of a set of double square brackets. Let\[CloseCurlyQuote]s have a look \
again at ",
 Cell[BoxData[
 "myList1"], "InlineCodeText",ExpressionUUID->
  "615375d3-04ca-4fad-bdca-80532201a8d5"],
 ". Each element in the list has an index (address), starting with the value \
1."
}], "Text",
 CellChangeTimes->{{3.7083342886931467`*^9, 3.708334483059533*^9}, {
   3.7156659276101575`*^9, 3.715665941159092*^9}, {3.7164470510713253`*^9, 
   3.716447068265555*^9}, {3.71646292256466*^9, 3.7164629227491055`*^9}, {
   3.7517661555592637`*^9, 3.75176616711187*^9}, {3.7517662318910103`*^9, 
   3.7517662660096426`*^9}, {3.757085396734193*^9, 3.757085403746101*^9}, {
   3.7570872605485897`*^9, 3.75708726055396*^9}, {3.757098987142592*^9, 
   3.75709898736316*^9}, {3.757214867944563*^9, 3.7572148825383787`*^9}, {
   3.80935368792311*^9, 3.809353688434627*^9}, {3.8093537867949877`*^9, 
   3.8093537970349627`*^9}, 3.809355834304151*^9},
 CellID->722163083,ExpressionUUID->"e4bf0bff-a077-4720-b83c-5de41dcde910"],

Cell[TextData[{
 "Print ",
 Cell[BoxData[
 "myList1"], "InlineCode",ExpressionUUID->
  "0943b18a-7991-4266-9032-91d7892f2be6"],
 " to the screen:"
}], "CodeCaption",
 CellChangeTimes->{{3.708334509511817*^9, 3.7083345123017063`*^9}, {
  3.7156659583492346`*^9, 3.715665972160204*^9}, {3.757088593061002*^9, 
  3.7570886004753523`*^9}, {3.7767047241704903`*^9, 3.776704725470295*^9}, {
  3.8075464776131363`*^9, 3.8075464780980544`*^9}},
 CellID->1964846784,ExpressionUUID->"1ac7a278-dc79-4383-8355-7ebc814d31e1"],

Cell[CellGroupData[{

Cell[BoxData["myList1"], "Input",
 CellChangeTimes->{{3.708334509511817*^9, 3.7083345123017063`*^9}, {
   3.7156659583492346`*^9, 3.715665972160204*^9}, 3.757088593061002*^9},
 CellLabel->"In[28]:=",
 CellID->918184561,ExpressionUUID->"656b0b80-085e-464b-83b7-a340bec2a0a0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7083345216190057`*^9, 3.757220062112804*^9, 
  3.812204079364843*^9},
 CellLabel->"Out[28]=",
 CellID->437477432,ExpressionUUID->"e2325406-e269-4e7b-85fd-1b75a7520fb3"]
}, Open  ]],

Cell["\<\
In the next code cell, we recall the computer variable and then put the \
number 1 inside of double square brackets, indicating the first element in \
the List, which happens to be 1.\
\>", "Text",
 CellChangeTimes->{{3.7164471103826103`*^9, 3.7164471546538496`*^9}, 
   3.7164629227803583`*^9, 3.7517662726876683`*^9, {3.807546507564354*^9, 
   3.8075465224631453`*^9}, {3.808241104251802*^9, 3.808241108237959*^9}},
 CellID->16264016,ExpressionUUID->"81f91e3a-3979-4f4d-8e5a-5d2b1a18c9b8"],

Cell["The first element:", "CodeCaption",
 CellChangeTimes->{{3.7083345335532365`*^9, 3.708334541558606*^9}, {
  3.757088603971806*^9, 3.757088616883312*^9}},
 CellID->618893743,ExpressionUUID->"0ae1dc8f-5ff0-4bdf-addd-2b19db10e904"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList1", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7083345335532365`*^9, 3.708334541558606*^9}, 
   3.757088603971806*^9},
 CellLabel->"In[29]:=",
 CellID->806540824,ExpressionUUID->"c379a331-32cc-45b3-b1d9-08d401fbb515"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.708334541907379*^9, 3.757220062161006*^9, 
  3.812204079384918*^9},
 CellLabel->"Out[29]=",
 CellID->1846675943,ExpressionUUID->"a39b14f6-9701-4cd4-b670-e4959dd7553f"]
}, Open  ]],

Cell["What about the fourth element?", "Text",
 CellChangeTimes->{{3.7156659906698256`*^9, 3.715666001429422*^9}},
 CellID->107084649,ExpressionUUID->"a11ae196-1954-45e4-8a16-33b9075e73b2"],

Cell["The fourth element:", "CodeCaption",
 CellChangeTimes->{{3.708334544668357*^9, 3.7083345545576167`*^9}, {
  3.7570886205475407`*^9, 3.757088627835248*^9}},
 CellID->180399557,ExpressionUUID->"7c613ee7-1b17-4658-b4e4-230ab0a953d3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList1", "[", 
  RowBox[{"[", "4", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.708334544668357*^9, 3.7083345545576167`*^9}, 
   3.7570886205475407`*^9},
 CellLabel->"In[30]:=",
 CellID->1209951394,ExpressionUUID->"eac82336-6e1d-4af6-8b5d-b8431c9f2c48"],

Cell[BoxData["\<\"Mathematica\"\>"], "Output",
 CellChangeTimes->{3.708334555191902*^9, 3.757220062211267*^9, 
  3.812204079390904*^9},
 CellLabel->"Out[30]=",
 CellID->1648907557,ExpressionUUID->"3e147346-2217-4969-a020-66a6df3dcbc9"]
}, Open  ]],

Cell[TextData[{
 "The Wolfram Language has a more attractive double bracket format as well, \
sometimes called \[OpenCurlyDoubleQuote]operator\[CloseCurlyDoubleQuote] \
form. Simply type the ",
 Cell[BoxData[
  TemplateBox[{"esc"},
   "Key0"]], "InlineCodeText",ExpressionUUID->
  "3fe9c72a-d27e-4ffc-b75f-3756065454fb"],
 " key before and after each set of brackets, that is, ",
 Cell[BoxData[
  TemplateBox[{"esc"},
   "Key0"]], "InlineCodeText",ExpressionUUID->
  "abfce073-4b96-42b4-9c13-2c607f5b0207"],
 " [[ ",
 Cell[BoxData[
  TemplateBox[{"esc"},
   "Key0"]], "InlineCodeText",ExpressionUUID->
  "15cdd413-0993-4b60-952b-605ba8fecc7f"],
 " and ",
 Cell[BoxData[
  TemplateBox[{"esc"},
   "Key0"]], "InlineCodeText",ExpressionUUID->
  "4af2b086-c081-49aa-8d9c-19d42819464f"],
 " ]] ",
 Cell[BoxData[
  TemplateBox[{"esc"},
   "Key0"]], "InlineCodeText",ExpressionUUID->
  "6df85ba3-4d0b-4a23-a3e9-e4628f619f8d"],
 "."
}], "Text",
 CellChangeTimes->{{3.708334575252556*^9, 3.708334611378213*^9}, {
  3.7083348644851055`*^9, 3.7083348806848946`*^9}, {3.7517662909091115`*^9, 
  3.75176634023976*^9}, {3.7571002794034224`*^9, 3.7571002828985147`*^9}, {
  3.7571003815874662`*^9, 3.757100386242197*^9}, {3.807467033379188*^9, 
  3.8074671011261883`*^9}, {3.8075465396729565`*^9, 3.807546540992482*^9}, {
  3.815748895046968*^9, 3.815748916102284*^9}},
 CellID->1524256067,ExpressionUUID->"b25b47b4-e03a-437b-a8f4-984e4020c219"],

Cell["Use operator notation:", "CodeCaption",
 CellChangeTimes->{{3.7083346176601152`*^9, 3.708334623050138*^9}, {
  3.7164471736614413`*^9, 3.716447182014469*^9}, {3.757088643707676*^9, 
  3.757088650283251*^9}, {3.807467109953188*^9, 3.8074671111671877`*^9}, {
  3.8075465490416107`*^9, 3.8075465501307383`*^9}},
 CellID->839293006,ExpressionUUID->"e426db1f-27e4-4be7-afb8-6c1e54999423"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList1", "\[LeftDoubleBracket]", "4", 
  "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.7083346176601152`*^9, 3.708334623050138*^9}, {
   3.7164471736614413`*^9, 3.716447182014469*^9}, 3.757088643707676*^9},
 CellLabel->"In[31]:=",
 CellID->1560745284,ExpressionUUID->"8dea1273-d23e-4b0b-8919-91638c918652"],

Cell[BoxData["\<\"Mathematica\"\>"], "Output",
 CellChangeTimes->{3.7083346239772267`*^9, 3.7572200622610207`*^9, 
  3.812204079396679*^9},
 CellLabel->"Out[31]=",
 CellID->2060329611,ExpressionUUID->"e17d0a4b-ecb6-4518-88b0-97750e19861d"]
}, Open  ]],

Cell[TextData[{
 "Sometimes you may need to index the last element in a list. This might be \
difficult as we do not always know the number of elements in the List. The ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "a4f77a6d-fe00-4fc6-b003-12f3db829065"],
 " index allows us to easily index the last element. The ",
 ButtonBox["Last",
  BaseStyle->"Link"],
 " function also works on lists to grab the last value."
}], "Text",
 CellChangeTimes->{{3.708334636522338*^9, 3.708334657781165*^9}, {
   3.7156660253741093`*^9, 3.7156660332542024`*^9}, 3.716462922833807*^9, {
   3.7517663618080134`*^9, 3.7517664553447*^9}, {3.757098987418639*^9, 
   3.757098987473907*^9}, {3.807467150005188*^9, 3.807467213769188*^9}, 
   3.807467254404188*^9, 3.807534389216391*^9, {3.807546923673828*^9, 
   3.8075469278796206`*^9}, {3.8082412045335712`*^9, 3.8082412049235897`*^9}, 
   3.809353829600829*^9, 3.809355864128235*^9},
 CellID->1316985479,ExpressionUUID->"0f5b78c1-302a-42ce-8408-66dfdb801385"],

Cell["Index the last item in the List:", "CodeCaption",
 CellChangeTimes->{{3.8075469468479843`*^9, 3.807546952463149*^9}},
 CellID->331136608,ExpressionUUID->"59ff2bd7-80ca-4f35-b56a-de730932ee01"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList1", "\[LeftDoubleBracket]", 
  RowBox[{"-", "1"}], "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.7083346625021906`*^9, 3.708334668675685*^9}},
 CellLabel->"In[32]:=",
 CellID->460995924,ExpressionUUID->"3c8a7afc-2514-44ca-881c-b1788a149776"],

Cell[BoxData["\<\"Mathematica\"\>"], "Output",
 CellChangeTimes->{3.7083346700129876`*^9, 3.757220062310092*^9, 
  3.812204079402857*^9},
 CellLabel->"Out[32]=",
 CellID->1933447849,ExpressionUUID->"6a131174-0e64-4760-91cd-6f51d146250f"]
}, Open  ]],

Cell[TextData[{
 "You may wonder what happens to a List of Lists (a matrix) when we use \
indexing. Let\[CloseCurlyQuote]s recall ",
 Cell[BoxData[
  FormBox["myTable3", TraditionalForm]], "InlineCodeText",ExpressionUUID->
  "c8734911-3393-43e9-aa06-a2c851f29ea0"],
 " and see what happens if we index the first element."
}], "Text",
 PageBreakAbove->True,
 CellChangeTimes->{{3.708334677709919*^9, 3.7083347248763165`*^9}, {
   3.7164629228650603`*^9, 3.716462922918962*^9}, {3.7517664645803075`*^9, 
   3.7517664973035727`*^9}, {3.757085418471628*^9, 3.7570854195773687`*^9}, {
   3.757087275083378*^9, 3.757087275088705*^9}, 3.757098987529971*^9, 
   3.807546960671693*^9},
 CellID->399378628,ExpressionUUID->"d6b46333-4302-4397-89a2-d85b61890abd"],

Cell[TextData[{
 "Print ",
 Cell[BoxData[
 "myTable3"], "InlineCode",ExpressionUUID->
  "2333608a-47a6-48a8-803f-53d8af40a415"],
 " to the screen:"
}], "CodeCaption",
 CellChangeTimes->{{3.7156660571039667`*^9, 3.715666084366541*^9}, {
  3.757088662163514*^9, 3.757088668995131*^9}, {3.7767049697620697`*^9, 
  3.77670497753223*^9}, {3.807546970212779*^9, 3.807546970922944*^9}},
 CellID->1470203921,ExpressionUUID->"412765a5-51ba-440a-aa1d-737876b28453"],

Cell[CellGroupData[{

Cell[BoxData["myTable3"], "Input",
 CellChangeTimes->{{3.7156660571039667`*^9, 3.715666084366541*^9}, 
   3.757088662163514*^9},
 CellLabel->"In[33]:=",
 CellID->966462749,ExpressionUUID->"448a7e74-2823-4b58-86bf-97575743954a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "6", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "8", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "10", ",", "14"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "12", ",", "16"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "14", ",", "18"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7164473301652517`*^9, 3.757220062361185*^9, 
  3.812204079421829*^9},
 CellLabel->"Out[33]=",
 CellID->1882935386,ExpressionUUID->"cea4e90e-0c6e-4d42-880e-7932ab0a248d"]
}, Open  ]],

Cell["View it in matrix form:", "CodeCaption",
 CellChangeTimes->{{3.7164473371280622`*^9, 3.716447355378212*^9}, {
  3.757088671659333*^9, 3.7570886774031477`*^9}, {3.8075469753148875`*^9, 
  3.8075469756419683`*^9}},
 CellID->1906429292,ExpressionUUID->"a303853f-002d-4921-96e6-2da156f931a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myTable3", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.7164473371280622`*^9, 3.716447355378212*^9}, 
   3.757088671659333*^9},
 CellLabel->"In[34]:=",
 CellID->295170369,ExpressionUUID->"c66094b6-2cec-46bd-a53d-ceed32f542af"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"2", "6", "10"},
     {"4", "8", "12"},
     {"6", "10", "14"},
     {"8", "12", "16"},
     {"10", "14", "18"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.716447355838342*^9, 3.7572200624110327`*^9, 
  3.812204079427938*^9},
 CellLabel->"Out[34]//MatrixForm=",
 CellID->1176010310,ExpressionUUID->"43dff31d-ac46-4e89-afa1-524fc5ef6b1e"]
}, Open  ]],

Cell["Address the first element:", "CodeCaption",
 CellChangeTimes->{{3.708334731576263*^9, 3.708334740749407*^9}, {
  3.7164472215809884`*^9, 3.7164472286622267`*^9}, {3.7570886994433193`*^9, 
  3.757088708275054*^9}, {3.8075469797670035`*^9, 3.8075469800731907`*^9}},
 CellID->689390384,ExpressionUUID->"7f61c000-ecc5-4d12-8cf1-0e3d5f596a20"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myTable3", "\[LeftDoubleBracket]", "1", 
  "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.708334731576263*^9, 3.708334740749407*^9}, {
   3.7164472215809884`*^9, 3.7164472286622267`*^9}, 3.7570886994433193`*^9},
 CellLabel->"In[35]:=",
 CellID->1770390207,ExpressionUUID->"6250cb3f-f537-451e-a38d-894610b0b7f7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "6", ",", "10"}], "}"}]], "Output",
 CellChangeTimes->{3.7083347414260015`*^9, 3.757220062461123*^9, 
  3.812204079453476*^9},
 CellLabel->"Out[35]=",
 CellID->1913276829,ExpressionUUID->"5ddf5efc-526c-454d-a477-8fe89e2c35a6"]
}, Open  ]],

Cell[TextData[{
 "Note that since it is a List of Lists (each of which we can term a ",
 StyleBox["subList",
  FontSlant->"Italic"],
 "), we get the first subList back. If we consider this to be part of a \
matrix, we get the first row back. This is important, since we can reference \
a certain element by its row and column value. Note that the column value \
will be the address index within the subList. This row and column indexing is \
expressed as two values, separated by a comma, so if we want the element in \
row 1, column 2 (that will be the second element in the first subList), we do \
the following."
}], "Text",
 CellChangeTimes->{{3.708334748877242*^9, 3.7083348452705855`*^9}, {
   3.708334889202549*^9, 3.7083349762740774`*^9}, {3.7156660999995604`*^9, 
   3.7156661005099316`*^9}, 3.716447275149887*^9, {3.716462922950219*^9, 
   3.716462923150814*^9}, {3.757085450055747*^9, 3.757085463051215*^9}, {
   3.757087282773567*^9, 3.757087303922303*^9}, {3.757098987592214*^9, 
   3.757098987822474*^9}, {3.757214920343857*^9, 3.757214925633995*^9}, {
   3.8075470814910393`*^9, 3.807547148498247*^9}, {3.8157490389657793`*^9, 
   3.8157490445494833`*^9}, {3.816446742177494*^9, 3.816446751725088*^9}},
 CellID->598134374,ExpressionUUID->"2abce069-3497-4a80-975c-c3004288c764"],

Cell["\<\
Find the second element in the first subList. If viewed as a matrix, this \
will be the element in row 1, column 2:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7083349878306875`*^9, 3.7083349939654675`*^9}, {
   3.716447278877677*^9, 3.7164473093750057`*^9}, 3.7164473729827967`*^9, 
   3.716462923166439*^9, {3.757088713675198*^9, 3.757088754338822*^9}, {
   3.757100436200879*^9, 3.757100436600235*^9}, {3.8075471561035576`*^9, 
   3.8075471701779876`*^9}, 3.8157490794702263`*^9, 3.81644679564489*^9},
 CellID->473472211,ExpressionUUID->"2581380a-a529-45c3-a04f-d1eaabc960ad"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myTable3", "\[LeftDoubleBracket]", 
  RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.7083349878306875`*^9, 3.7083349939654675`*^9}, {
   3.716447278877677*^9, 3.7164473093750057`*^9}, 3.7164473729827967`*^9, 
   3.716462923166439*^9, 3.757088713675198*^9},
 CellLabel->"In[36]:=",
 CellID->446546551,ExpressionUUID->"39d4454e-7561-4ca1-884b-fc4f5867030d"],

Cell[BoxData["6"], "Output",
 CellChangeTimes->{3.70833499481467*^9, 3.7572200625112123`*^9, 
  3.812204079459371*^9},
 CellLabel->"Out[36]=",
 CellID->23534825,ExpressionUUID->"7b91a3d2-01a3-4f55-9c77-d29c424a9cc1"]
}, Open  ]],

Cell[TextData[{
 "A very useful notation is that of the double semicolon (",
 ButtonBox[";;",
  BaseStyle->"Link",
  ButtonData->"Span"],
 "). It basically states that you want all the elements. Imagine then that we \
want all of the elements in column ",
 Cell[BoxData[
  FormBox["3", TraditionalForm]],ExpressionUUID->
  "d2a408bf-85e0-467c-9184-06c09103462d"],
 ", that is, all of the last elements in each subList."
}], "Text",
 CellChangeTimes->{{3.708335013797512*^9, 3.708335076749351*^9}, 
   3.716462923182066*^9, 3.757085468810926*^9, 3.757087317321846*^9, {
   3.757098987879056*^9, 3.757098987935302*^9}, 3.7572149444281816`*^9, 
   3.807547821701972*^9, {3.8075478625063515`*^9, 3.807547899361585*^9}, 
   3.8122047898664093`*^9, 3.815749127669737*^9, 3.816446800885256*^9},
 CellID->820756450,ExpressionUUID->"7857e98e-728b-4fe4-87c0-7c82f1746cd8"],

Cell["\<\
Get all of the last elements in each subList. If viewed as a matrix, this \
will be all of the elements in column 3:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7083350914689083`*^9, 3.7083351280000343`*^9}, {
   3.716447436413888*^9, 3.716447483263144*^9}, 3.7164629231976924`*^9, {
   3.757088763482999*^9, 3.757088783890667*^9}, {3.7571004409202337`*^9, 
   3.757100444810985*^9}, {3.8075479111392107`*^9, 3.8075479148143883`*^9}, {
   3.8075480061492805`*^9, 3.8075480182838125`*^9}, 3.815749130541216*^9, 
   3.816446803868971*^9},
 CellID->1166190469,ExpressionUUID->"e965cb13-23b4-46b1-b461-05222c84578f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myTable3", "\[LeftDoubleBracket]", 
  RowBox[{"All", ",", "3"}], "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.7083350914689083`*^9, 3.7083351280000343`*^9}, {
   3.716447436413888*^9, 3.716447483263144*^9}, 3.7164629231976924`*^9, 
   3.757088763482999*^9, {3.761635265252796*^9, 3.7616352669326763`*^9}},
 CellLabel->"In[37]:=",
 CellID->854376435,ExpressionUUID->"83ec7c73-487e-44df-b658-e1492894a9f0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10", ",", "12", ",", "14", ",", "16", ",", "18"}], "}"}]], "Output",\

 CellChangeTimes->{3.708335129333542*^9, 3.757220062562902*^9, 
  3.812204079465054*^9},
 CellLabel->"Out[37]=",
 CellID->412812727,ExpressionUUID->"b00453ab-bc41-42c7-8504-6f7164e9a35a"]
}, Open  ]],

Cell[TextData[{
 "The addressing above states that you want all of the row values in column \
3. We can also use the ",
 ButtonBox[";;",
  BaseStyle->"Link",
  ButtonData->"Span"],
 " shorthand notation instead of the ",
 ButtonBox["All",
  BaseStyle->"Link"],
 " function."
}], "Text",
 PageBreakAbove->True,
 CellChangeTimes->{{3.708335148361369*^9, 3.7083351812324667`*^9}, {
   3.7164474210550365`*^9, 3.716447431702923*^9}, {3.7517665874671955`*^9, 
   3.751766587855506*^9}, {3.757085477974008*^9, 3.757085478995305*^9}, {
   3.7570873220303583`*^9, 3.757087322035503*^9}, {3.757088793902953*^9, 
   3.7570887939086733`*^9}, 3.757098987990382*^9, {3.7616352855399427`*^9, 
   3.761635311092255*^9}, {3.776705035818152*^9, 3.776705054190029*^9}, {
   3.8075480291050687`*^9, 3.8075480304595175`*^9}, {3.8075480625833025`*^9, 
   3.8075480638569555`*^9}, {3.8075484367816114`*^9, 3.8075484473836913`*^9}},
 
 CellID->1816560023,ExpressionUUID->"683224aa-f5fa-44ad-b350-ce76dd2b419d"],

Cell[TextData[{
 "Use ",
 ButtonBox[";;",
  BaseStyle->"Link",
  ButtonData->"Span"],
 " instead of ",
 ButtonBox["All",
  BaseStyle->"Link"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7083351983152833`*^9, 3.7083352042233896`*^9}, {
   3.71644749148529*^9, 3.71644750151832*^9}, {3.757088807851981*^9, 
   3.75708881621061*^9}, 3.757214985366199*^9, {3.761635329787964*^9, 
   3.7616353346375184`*^9}, {3.7767051333544083`*^9, 3.77670513905313*^9}, {
   3.807548068328003*^9, 3.807548075023657*^9}},
 CellID->149297162,ExpressionUUID->"33f31649-6913-4a87-9432-86ca294fc19c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myTable3", "\[LeftDoubleBracket]", 
  RowBox[{";;", ",", "3"}], "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.7083351983152833`*^9, 3.7083352042233896`*^9}, {
   3.71644749148529*^9, 3.71644750151832*^9}, 3.757088807851981*^9, {
   3.7616353400775356`*^9, 3.761635341444574*^9}},
 CellLabel->"In[38]:=",
 CellID->258471199,ExpressionUUID->"a6dedef1-597c-4950-9cd2-8a0d1038f486"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10", ",", "12", ",", "14", ",", "16", ",", "18"}], "}"}]], "Output",\

 CellChangeTimes->{3.708335204854841*^9, 3.757220062624192*^9, 
  3.7616353582183228`*^9, 3.812204079473246*^9},
 CellLabel->"Out[38]=",
 CellID->1771322879,ExpressionUUID->"545a324a-d1e2-437f-8995-edda9098595b"]
}, Open  ]],

Cell["\<\
We can also use the double semicolon to specify a range of addresses. Let\
\[CloseCurlyQuote]s ask for the elements 2 through 4 in column 3.\
\>", "Text",
 CellChangeTimes->{{3.7083352302599883`*^9, 3.7083352757070827`*^9}, 
   3.715666212821493*^9, {3.7164475121100607`*^9, 3.7164475127497425`*^9}, 
   3.7570989880527782`*^9, {3.761635384444106*^9, 3.761635407227846*^9}, {
   3.8075484541147738`*^9, 3.807548480261155*^9}, 3.808241604042427*^9},
 CellID->999722292,ExpressionUUID->"42fe21fe-e6ce-4078-8707-79f30ea8d13d"],

Cell["\<\
Get the last elements in subLists 2 through 4. If viewed as a matrix, these \
will be elements 2 through 4 in column 3:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7083352803342967`*^9, 3.708335290951828*^9}, {
   3.7164475235168395`*^9, 3.716447595295992*^9}, 3.7164629232133183`*^9, {
   3.75708882409883*^9, 3.757088837594296*^9}, {3.75710045326493*^9, 
   3.757100453552135*^9}, {3.8075484995176487`*^9, 3.8075485102542195`*^9}, 
   3.8157498420132017`*^9, 3.816446866372958*^9},
 CellID->420507516,ExpressionUUID->"0fb2aaed-f277-4960-a2b4-7ce087d7c400"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myTable3", "\[LeftDoubleBracket]", 
  RowBox[{
   RowBox[{"2", ";;", "4"}], ",", "3"}], "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.7083352803342967`*^9, 3.708335290951828*^9}, {
   3.7164475235168395`*^9, 3.716447595295992*^9}, 3.7164629232133183`*^9, 
   3.75708882409883*^9},
 CellLabel->"In[39]:=",
 CellID->906852107,ExpressionUUID->"af096c98-2376-4d3e-aa84-9bfad4906859"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"12", ",", "14", ",", "16"}], "}"}]], "Output",
 CellChangeTimes->{3.7083352915767746`*^9, 3.757220062656021*^9, 
  3.8122040794922047`*^9},
 CellLabel->"Out[39]=",
 CellID->57828992,ExpressionUUID->"624c40d0-ed1d-4ad0-ba45-823a5c141148"]
}, Open  ]],

Cell[TextData[{
 "Now, if we only want elements from rows 2 and 4 in column 3, we need to use \
curly braces (i.e. a ",
 ButtonBox["List",
  BaseStyle->"Link"],
 ")."
}], "Text",
 CellChangeTimes->{{3.7083353082371054`*^9, 3.7083353483927145`*^9}, 
   3.71566622981495*^9, 3.7164629232351513`*^9, {3.7570854871283627`*^9, 
   3.757085487985126*^9}, {3.757087330155025*^9, 3.757087330160611*^9}, {
   3.7570888472549458`*^9, 3.757088866590789*^9}, {3.757215014827692*^9, 
   3.7572150215955477`*^9}, {3.807549642209158*^9, 3.807549642476441*^9}},
 CellID->1185877168,ExpressionUUID->"e79869ab-8253-4a95-ba14-9e72c7bbcf56"],

Cell["\<\
Get the last elements for subLists 2 and 4 only. When viewed as a matrix, \
this will be elements in rows 2 and 4 for column 3:\
\>", "CodeCaption",
 CellChangeTimes->{{3.708335353981639*^9, 3.708335362281789*^9}, {
   3.716447616861598*^9, 3.7164476773355103`*^9}, 3.7164629232507777`*^9, {
   3.757088903947751*^9, 3.75708891588207*^9}, {3.757100458024122*^9, 
   3.757100458392063*^9}, {3.8075496529247923`*^9, 3.8075496547060404`*^9}, 
   3.807616540032137*^9, 3.815749845308025*^9, 3.8164468687966433`*^9},
 CellID->241834769,ExpressionUUID->"45fddff0-1ae4-42ef-b33f-d78be43dc54c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myTable3", "\[LeftDoubleBracket]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "4"}], "}"}], ",", "3"}], 
  "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.708335353981639*^9, 3.708335362281789*^9}, {
   3.716447616861598*^9, 3.7164476773355103`*^9}, 3.7164629232507777`*^9, 
   3.757088903947751*^9},
 CellLabel->"In[40]:=",
 CellID->502985276,ExpressionUUID->"77200e8c-521d-4e3c-822c-509498d42674"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"12", ",", "16"}], "}"}]], "Output",
 CellChangeTimes->{3.7083353637212825`*^9, 3.757220062713921*^9, 
  3.812204079498159*^9},
 CellLabel->"Out[40]=",
 CellID->1269260100,ExpressionUUID->"afd374d8-aa68-4bab-9c9b-3398a931fa48"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Size of a List", "Subsection",
 CellChangeTimes->{{3.689827625693207*^9, 3.6898276280064573`*^9}, 
   3.7164629232886696`*^9, 3.782057529096184*^9},
 CellID->1310767211,ExpressionUUID->"18532cdc-959f-4935-a689-7fbc164d5754"],

Cell[TextData[{
 "It may be useful to know how many elements there are in a List. For this, \
we use the ",
 ButtonBox["Length",
  BaseStyle->"Link"],
 " function. In conjunction with ",
 ButtonBox["List",
  BaseStyle->"Link"],
 ", it will return the number of elements. In the case of a List of Lists, it \
will return the number of subLists."
}], "Text",
 CellChangeTimes->{{3.708335460423921*^9, 3.708335513315502*^9}, {
   3.708429424561509*^9, 3.7084294259473715`*^9}, {3.7164629233308125`*^9, 
   3.7164629234792123`*^9}, 3.7261223371922903`*^9, {3.7570855407602882`*^9, 
   3.757085545547222*^9}, {3.7570873388258533`*^9, 3.757087338831152*^9}, {
   3.7570888781579037`*^9, 3.7570888837038527`*^9}, {3.757098988107793*^9, 
   3.757098988217071*^9}, 3.8075497243433485`*^9, {3.809353938016794*^9, 
   3.8093539406496353`*^9}, 3.815749861868692*^9, 3.8164468715970287`*^9},
 CellID->1177264351,ExpressionUUID->"06466b8d-36d2-473a-8144-ba52114decc0"],

Cell[TextData[{
 "Recall ",
 Cell[BoxData[
 "myList1"], "InlineCode",ExpressionUUID->
  "d673a6af-4e45-4381-a14c-91936bb37a8d"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.6899055858650103`*^9, 3.689905595520624*^9}, {
  3.757088922754314*^9, 3.757088929730092*^9}, {3.757215044856464*^9, 
  3.757215045586151*^9}},
 CellID->1515107446,ExpressionUUID->"fb8def20-ec40-4460-a8c4-6d0c5d167fa7"],

Cell[CellGroupData[{

Cell[BoxData["myList1"], "Input",
 CellChangeTimes->{{3.6899055858650103`*^9, 3.689905595520624*^9}, 
   3.757088922754314*^9},
 CellLabel->"In[41]:=",
 CellID->678848326,ExpressionUUID->"b0cdcd71-1e07-4735-8886-9b5133bd5ecd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.689905596620438*^9, 3.757220062761244*^9, 
  3.8122040795184937`*^9},
 CellLabel->"Out[41]=",
 CellID->1499435049,ExpressionUUID->"0d83b327-4c7e-46f7-93f3-c9099ef8ae95"]
}, Open  ]],

Cell[TextData[{
 "Calculate the number of elements in ",
 Cell[BoxData[
 "myList1"], "InlineCode",ExpressionUUID->
  "3b2793fe-7046-4fb3-b661-262fc9fc7630"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.689827632443136*^9, 3.68982763847747*^9}, {
   3.7164477056533775`*^9, 3.7164477175337286`*^9}, 3.716462923493251*^9, {
   3.757088932498294*^9, 3.757088939105906*^9}, {3.807549736750198*^9, 
   3.8075497563561525`*^9}},
 CellID->528456400,ExpressionUUID->"a52e12d6-c60f-4ba3-a8e9-9bf6013d60f7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "myList1", "]"}]], "Input",
 CellChangeTimes->{{3.689827632443136*^9, 3.68982763847747*^9}, {
   3.7164477056533775`*^9, 3.7164477175337286`*^9}, 3.716462923493251*^9, 
   3.757088932498294*^9},
 CellLabel->"In[42]:=",
 CellID->217209853,ExpressionUUID->"3bd8bb43-6fde-4b99-a4be-4808afd89388"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{3.689827638819222*^9, 3.757220062811303*^9, 
  3.812204079524519*^9},
 CellLabel->"Out[42]=",
 CellID->284270998,ExpressionUUID->"83df9f62-d88e-4a30-9f04-454116041e69"]
}, Open  ]],

Cell[TextData[{
 "In the next example, we take a look at the nested List ",
 Cell[BoxData[
 "myTable3"], "InlineCodeText",ExpressionUUID->
  "efc1ab12-a0e6-4483-8b0f-75fae14ca837"],
 "."
}], "Text",
 PageBreakAbove->True,
 CellChangeTimes->{{3.716447730253589*^9, 3.716447754750174*^9}, 
   3.7164629235188494`*^9, {3.757085552112648*^9, 3.757085559152936*^9}, {
   3.757087346575951*^9, 3.7570873465814533`*^9}, {3.757215057406686*^9, 
   3.7572150633130074`*^9}, {3.8075497666105595`*^9, 3.8075497787820683`*^9}},
 
 CellID->2117634305,ExpressionUUID->"0e281c41-adad-4532-be1c-13616f270381"],

Cell[TextData[{
 "Recall ",
 Cell[BoxData[
 "myTable3"], "InlineCode",ExpressionUUID->
  "e0244c10-0832-4d25-b878-6e5fc7435ffd"],
 " and find the number of subLists:"
}], "CodeCaption",
 CellChangeTimes->{{3.6899056027141447`*^9, 3.6899056200241213`*^9}, {
   3.757088946627347*^9, 3.7570889535299273`*^9}, {3.757215077087237*^9, 
   3.757215077795541*^9}, {3.8075497873507338`*^9, 3.8075498124644756`*^9}, 
   3.815749954740758*^9, 3.816446874220639*^9},
 CellID->833282404,ExpressionUUID->"418c3ef4-438a-4cbc-92de-c9a9b741aecd"],

Cell[CellGroupData[{

Cell[BoxData["myTable3"], "Input",
 CellChangeTimes->{{3.6899056027141447`*^9, 3.6899056200241213`*^9}, 
   3.757088946627347*^9},
 CellLabel->"In[43]:=",
 CellID->1450247492,ExpressionUUID->"35abbb66-6641-4180-99cc-e6c6793ec46a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "6", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "8", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "10", ",", "14"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "12", ",", "16"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "14", ",", "18"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6899056421618633`*^9, 3.7572200628630657`*^9, 
  3.812204079530284*^9},
 CellLabel->"Out[43]=",
 CellID->1739032458,ExpressionUUID->"5e48d64c-55f5-45f0-b981-9a332a3b4d55"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "myTable3", "]"}]], "Input",
 CellChangeTimes->{{3.6898276426821012`*^9, 3.68982765257787*^9}},
 CellLabel->"In[44]:=",
 CellID->688870368,ExpressionUUID->"1490e206-66d6-4124-ad36-c9c144cdec0c"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{{3.689827648143118*^9, 3.689827653092259*^9}, 
   3.757220062911675*^9, 3.812204079536325*^9},
 CellLabel->"Out[44]=",
 CellID->666085936,ExpressionUUID->"4adeffa2-2fd0-4d4c-95d3-7541b147e571"]
}, Open  ]],

Cell["\<\
We note that it returns the number of subLists as we expected.\
\>", "Text",
 CellChangeTimes->{{3.7164477829413176`*^9, 3.716447803526424*^9}, 
   3.7164629235635047`*^9, 3.815749956483819*^9, 3.816446878156658*^9},
 CellID->1125472484,ExpressionUUID->"7b92dc2b-0f7d-4016-a624-7f20648175fb"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s see what happens if we have a deeper nesting. In the \
example below, we have a ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " containing five subLists, which in turn each contain two subLists, which \
in turn each contain two elements. We\[CloseCurlyQuote]ll use the ",
 ButtonBox["Length",
  BaseStyle->"Link"],
 " function and check the result."
}], "Text",
 CellChangeTimes->{{3.7083355599822607`*^9, 3.7083355727179613`*^9}, {
   3.7084317125755587`*^9, 3.708431788735224*^9}, {3.715666266041689*^9, 
   3.715666284165496*^9}, {3.7164629235946074`*^9, 3.7164629236666546`*^9}, {
   3.757085568838416*^9, 3.757085573091172*^9}, {3.757087355380548*^9, 
   3.7570873553857822`*^9}, {3.757088963011791*^9, 3.757088980834717*^9}, {
   3.757098988281363*^9, 3.757098988337809*^9}, {3.757215133907898*^9, 
   3.757215150884039*^9}, {3.8076165806152625`*^9, 3.8076166002078714`*^9}, 
   3.809353985938665*^9, 3.809354035833006*^9, {3.815749968732235*^9, 
   3.8157499845721903`*^9}, {3.816446881372982*^9, 3.816446884925083*^9}},
 FontTracking->-0.05,
 CellID->780075812,ExpressionUUID->"f14c1e91-8344-41e3-b5f3-7e51d8c48e58"],

Cell["Create a deeply nested List:", "CodeCaption",
 CellChangeTimes->{{3.708335596333727*^9, 3.708335674263734*^9}, {
   3.716447828365939*^9, 3.716447836878893*^9}, 3.7164629236822805`*^9, {
   3.7570889869073887`*^9, 3.7570889936175547`*^9}, {3.8076166166714897`*^9, 
   3.8076166170465*^9}},
 CellID->346507349,ExpressionUUID->"3fd7c2c0-8331-4c1c-9ad7-ec640fb31c6f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList4", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"3", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "5"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"4", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "1"}], "}"}]}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.708335596333727*^9, 3.708335674263734*^9}, {
   3.716447828365939*^9, 3.716447836878893*^9}, 3.7164629236822805`*^9, 
   3.7570889869073887`*^9},
 CellLabel->"In[45]:=",
 CellID->275741712,ExpressionUUID->"3588865c-003b-4e38-b488-07d5269c37b9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "3"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "1"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.708335675260107*^9, 3.708431795190324*^9, 
  3.7164478597790117`*^9, 3.7572200629613323`*^9, 3.8122040795563297`*^9},
 CellLabel->"Out[45]=",
 CellID->74074541,ExpressionUUID->"6a8eeef0-d713-4231-87f9-a7b990271bbb"]
}, Open  ]],

Cell["The length of the deeply nested List:", "CodeCaption",
 CellChangeTimes->{{3.7083356782108154`*^9, 3.7083356852613*^9}, {
   3.7164478459330907`*^9, 3.716447854534102*^9}, 3.7164629236822805`*^9, {
   3.757088995698009*^9, 3.7570890032176533`*^9}},
 CellID->564384831,ExpressionUUID->"ea03e624-8367-4208-800a-407e9297830d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "myList4", "]"}]], "Input",
 CellChangeTimes->{{3.7083356782108154`*^9, 3.7083356852613*^9}, {
   3.7164478459330907`*^9, 3.716447854534102*^9}, 3.7164629236822805`*^9, 
   3.757088995698009*^9},
 CellLabel->"In[46]:=",
 CellID->1924649204,ExpressionUUID->"1711a30c-481e-4726-8012-dcebf68bdf33"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{3.708335686432358*^9, 3.7084317984787626`*^9, 
  3.757220063011385*^9, 3.8122040795624657`*^9},
 CellLabel->"Out[46]=",
 CellID->1577778974,ExpressionUUID->"6c6487d9-9de0-492e-a07b-ea9ad0f2ef57"]
}, Open  ]],

Cell["The matrix form is seen in the output below.", "Text",
 CellChangeTimes->{{3.716447978427476*^9, 3.7164479997093477`*^9}, 
   3.716462923720056*^9, {3.8076166288660045`*^9, 3.8076166396442127`*^9}, {
   3.809354071754322*^9, 3.809354090225773*^9}},
 CellID->711449915,ExpressionUUID->"b75fb5ff-518a-4a1d-9271-4a21758afc7b"],

Cell["\<\
The matrix form of a deeply nested list, is also called a tensor:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7164480069832473`*^9, 3.716448047317895*^9}, 
   3.716462923735773*^9, {3.757089006786049*^9, 3.757089033171722*^9}, {
   3.807616644988904*^9, 3.8076166463712544`*^9}, {3.809354107610396*^9, 
   3.809354115577943*^9}, {3.809354162081833*^9, 3.8093541638416157`*^9}},
 CellID->149774909,ExpressionUUID->"c3b013f9-3e07-4415-8a3a-9e3e295fe1f2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "@", "myList4"}]], "Input",
 CellChangeTimes->{{3.7164480069832473`*^9, 3.716448047317895*^9}, 
   3.716462923735773*^9, 3.757089006786049*^9},
 CellLabel->"In[47]:=",
 CellID->1449222407,ExpressionUUID->"6faf4d20-37ce-481e-bbaa-22bf37d57c79"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"1"},
          {"2"}
         },
         GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"1"},
          {"3"}
         },
         GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"3"},
          {"4"}
         },
         GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"2"},
          {"5"}
         },
         GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"0"},
          {"1"}
         },
         GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"3"},
          {"3"}
         },
         GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"2"},
          {"0"}
         },
         GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"1"},
          {"2"}
         },
         GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}}],
        Column], "\[NoBreak]", ")"}]},
     {
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"4"},
          {"2"}
         },
         GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}}],
        Column], "\[NoBreak]", ")"}], 
      RowBox[{"(", "\[NoBreak]", 
       TagBox[GridBox[{
          {"4"},
          {"1"}
         },
         GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}}],
        Column], "\[NoBreak]", ")"}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.71644801732755*^9, 3.757220063096568*^9, 
  3.812204079586248*^9},
 CellLabel->"Out[47]//MatrixForm=",
 CellID->603142862,ExpressionUUID->"94f0d5ec-c22d-4292-9127-f2cd06ddf455"]
}, Open  ]],

Cell[TextData[{
 "We note that it is the number of first-level subLists that is returned when \
using the ",
 ButtonBox["Length",
  BaseStyle->"Link"],
 " function. We can always use addressing to get to elements we want. In the \
example, we ask for the value of the second element in the second nested List \
of the first nested List, which is ",
 Cell[BoxData[
  FormBox["3", TraditionalForm]],ExpressionUUID->
  "92001a3f-189e-42e5-9606-b706b3391015"],
 "."
}], "Text",
 CellChangeTimes->{{3.7083357059777784`*^9, 3.708335771422107*^9}, {
   3.7083358638113804`*^9, 3.708335881390958*^9}, 3.7084295044189663`*^9, {
   3.7164478935269766`*^9, 3.716447911222417*^9}, {3.716448060903001*^9, 
   3.7164481681591153`*^9}, {3.7164629237513986`*^9, 
   3.7164629238360853`*^9}, {3.7517667175290003`*^9, 3.751766728936905*^9}, {
   3.757085581791391*^9, 3.757085586579084*^9}, {3.757087366131135*^9, 
   3.757087366136344*^9}, {3.75708904604519*^9, 3.757089058721376*^9}, {
   3.757098988393894*^9, 3.7570989884502563`*^9}, {3.757215192625139*^9, 
   3.757215198941036*^9}, {3.80761665535706*^9, 3.807616686854561*^9}, 
   3.8157499934441643`*^9, 3.816446887309001*^9},
 FontTracking->0.1,
 CellID->535161521,ExpressionUUID->"250b06a2-b73d-4e13-ae8c-8f98762fe45e"],

Cell["Address a deeply nested List:", "CodeCaption",
 PageBreakAbove->True,
 CellChangeTimes->{{3.7164481727630987`*^9, 3.7164482200466604`*^9}, 
   3.7164629238517103`*^9, {3.757089073578826*^9, 3.757089081305225*^9}, {
   3.807616696029192*^9, 3.807616696442086*^9}},
 CellID->798169811,ExpressionUUID->"40280a23-28ce-4c3d-b5ee-05045ea141cc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList4", "\[LeftDoubleBracket]", 
  RowBox[{"1", ",", "2", ",", "2"}], "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.7164481727630987`*^9, 3.7164482200466604`*^9}, 
   3.7164629238517103`*^9, 3.757089073578826*^9},
 CellLabel->"In[48]:=",
 CellID->715077577,ExpressionUUID->"0dedf459-4ac2-4585-9d23-e240665fa94a"],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{{3.716448211292791*^9, 3.71644822054615*^9}, 
   3.757220063230237*^9, 3.812204079593068*^9},
 CellLabel->"Out[48]=",
 CellID->899267794,ExpressionUUID->"9524d97f-687f-4d6a-bf70-37648f2e75da"]
}, Open  ]],

Cell[TextData[{
 "To get the total number of elements in a list, we can use the ",
 ButtonBox["Flatten",
  BaseStyle->"Link"],
 " function to create a non-nested List. This removes all the elements from \
the subLists and places them in a single List, the elements of which we can \
then count. In order to do this, we nest the Wolfram Language functions, that \
is ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Length",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{
    ButtonBox["Flatten",
     BaseStyle->"CodeLink"], "[", "]"}], "]"}]], "InlineCodeText",
  ExpressionUUID->"c20aabac-7732-4e6b-a277-ee527d183937"],
 "."
}], "Text",
 CellChangeTimes->{
  3.71644807064799*^9, {3.716462923882963*^9, 3.7164629239207387`*^9}, {
   3.7517667673914824`*^9, 3.7517668486870193`*^9}, {3.757085608245963*^9, 
   3.7570856346255608`*^9}, {3.757087375351565*^9, 3.757087396028874*^9}, {
   3.757089107654121*^9, 3.757089112474084*^9}, {3.7570989885137167`*^9, 
   3.7570989885699587`*^9}, {3.757215531685947*^9, 3.7572155875274143`*^9}, 
   3.76163548901342*^9, {3.8076167068094234`*^9, 3.8076167229812317`*^9}, {
   3.80935413902662*^9, 3.809354139234002*^9}, 3.815750016372047*^9, 
   3.816446889957115*^9},
 CellID->1077154262,ExpressionUUID->"e4cc6584-f51a-4db3-903c-02e911717722"],

Cell[TextData[{
 "Flatten the nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7083357790112877`*^9, 3.7083358138463697`*^9}, 
   3.7164629239363685`*^9, {3.757089084793521*^9, 3.757089092129259*^9}, {
   3.761635506492616*^9, 3.761635508428653*^9}, 3.77670521842404*^9, {
   3.80761673991745*^9, 3.8076167402496176`*^9}},
 CellID->444537224,ExpressionUUID->"aa4ed038-90e3-4ce1-81cb-d5986be697ba"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flatten", "[", "myList4", "]"}]], "Input",
 CellChangeTimes->{{3.7083357790112877`*^9, 3.7083358138463697`*^9}, 
   3.7164629239363685`*^9, 3.757089084793521*^9},
 CellLabel->"In[49]:=",
 CellID->904911756,ExpressionUUID->"f84bd8f6-3ed8-4efb-9b93-4d09fc6d41a9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "1", ",", "3", ",", "3", ",", "4", ",", "2", ",", "5", 
   ",", "0", ",", "1", ",", "3", ",", "3", ",", "2", ",", "0", ",", "1", ",", 
   "2", ",", "4", ",", "2", ",", "4", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.7083358143006415`*^9, 3.757220063395239*^9, 
  3.812204079613689*^9},
 CellLabel->"Out[49]=",
 CellID->3906172,ExpressionUUID->"581947f5-2315-4a80-8c9a-8197f856893e"]
}, Open  ]],

Cell[TextData[{
 "The List is flattened with the use of the ",
 ButtonBox["Flatten",
  BaseStyle->"Link"],
 " function and the elements are then counted using the ",
 ButtonBox["Length",
  BaseStyle->"Link"],
 " function."
}], "Text",
 CellChangeTimes->{{3.716447918646477*^9, 3.7164479599522667`*^9}, {
  3.75708565065697*^9, 3.7570856625524406`*^9}, {3.757087405540979*^9, 
  3.7570874102159653`*^9}, {3.757089137777823*^9, 3.75708914630267*^9}, {
  3.761635543093198*^9, 3.7616355921966057`*^9}},
 CellID->412882155,ExpressionUUID->"f5771b0b-7622-4fde-a1f8-dc9a0bf95ee9"],

Cell["\<\
Count the number of elements by nesting the Wolfram Language functions:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7083358181332817`*^9, 3.7083358417914124`*^9}, {
  3.7083358905498934`*^9, 3.708335899038101*^9}, {3.757089153234457*^9, 
  3.757089161193214*^9}, {3.807616749073426*^9, 3.807616749402548*^9}},
 CellID->790715628,ExpressionUUID->"582912c6-c874-4f52-a099-7f81447e62cb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Flatten", "[", "myList4", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7083358181332817`*^9, 3.7083358417914124`*^9}, {
   3.7083358905498934`*^9, 3.708335899038101*^9}, 3.757089153234457*^9},
 CellLabel->"In[50]:=",
 CellID->796709554,ExpressionUUID->"f21ed69f-f52e-4bab-a763-98512c27ca48"],

Cell[BoxData["20"], "Output",
 CellChangeTimes->{3.7083358422466035`*^9, 3.757220063565791*^9, 
  3.812204079620675*^9},
 CellLabel->"Out[50]=",
 CellID->1226523394,ExpressionUUID->"581cc729-7e76-44a5-8634-6ef82e2579d7"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appending Elements to a List", "Subsection",
 CellChangeTimes->{{3.689827737673015*^9, 3.689827772404839*^9}, {
   3.7156663366075373`*^9, 3.71566633685386*^9}, {3.716459929400177*^9, 
   3.7164599363883753`*^9}, 3.7164629239676495`*^9, 3.782057535024074*^9},
 CellID->1626406724,ExpressionUUID->"a770e73d-a34e-4f68-afc2-140310f07b03"],

Cell[TextData[{
 "We can add elements to a List using the ",
 ButtonBox["Append",
  BaseStyle->"Link"],
 " function. In the example below, we revisit ",
 Cell[BoxData[
 "myList1"], "InlineCodeText",ExpressionUUID->
  "6479104f-fd86-4942-8d1b-67a49c594e6e"],
 " and add the string (text) \[OpenCurlyDoubleQuote]This is great!\
\[CloseCurlyDoubleQuote] to it. The ",
 ButtonBox["Append",
  BaseStyle->"Link"],
 " function takes the computer variable (object) as first argument, followed \
by the element (number, list, or string) that should be appended to the end."
}], "Text",
 CellChangeTimes->{{3.7084295214160595`*^9, 3.7084295882204175`*^9}, {
   3.7084297742739534`*^9, 3.708429818774775*^9}, {3.7154948801089115`*^9, 
   3.715494880146*^9}, {3.716459967101158*^9, 3.716459978023068*^9}, {
   3.716462923998873*^9, 3.7164629240366526`*^9}, {3.757085666070718*^9, 
   3.7570856830324173`*^9}, {3.7570874162945967`*^9, 
   3.7570874256920767`*^9}, {3.757089165781827*^9, 3.7570891792426777`*^9}, {
   3.7570989886254387`*^9, 3.757098988682317*^9}, {3.757215613796884*^9, 
   3.757215618736271*^9}, 3.8076184191211805`*^9, {3.8076184871991434`*^9, 
   3.8076184913301287`*^9}, 3.807618867683683*^9, 3.809354284762203*^9},
 CellID->1845951252,ExpressionUUID->"5c684947-d42d-4360-8f9b-2330f7c3c4fb"],

Cell[TextData[{
 "The original ",
 Cell[BoxData[
 "myList1"], "InlineCode",ExpressionUUID->
  "3c32237f-4752-41f3-b2e8-fd0e57800c95"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7084295991763215`*^9, 3.70842961238105*^9}, {
  3.757089191986383*^9, 3.757089226999091*^9}},
 CellID->206444155,ExpressionUUID->"637611fb-ebfe-423d-bc27-7e2146470994"],

Cell[CellGroupData[{

Cell[BoxData["myList1"], "Input",
 CellChangeTimes->{{3.7084295991763215`*^9, 3.70842961238105*^9}, 
   3.757089191986383*^9},
 CellLabel->"In[51]:=",
 CellID->1723344177,ExpressionUUID->"d46cc6e8-e0fe-4df1-987f-5871a1ec94ca"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7572200636934834`*^9, 3.812204079639874*^9},
 CellLabel->"Out[51]=",
 CellID->483155405,ExpressionUUID->"d720b73b-8b98-4f41-8099-c3f8a4ed4248"]
}, Open  ]],

Cell[TextData[{
 "Append the string to ",
 Cell[BoxData[
 "myList1"], "InlineCode",ExpressionUUID->
  "408744ef-4221-482e-9770-4099942d18ad"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7084296195391674`*^9, 3.7084296426195927`*^9}, {
  3.708429770970518*^9, 3.708429771665412*^9}, {3.757089202265134*^9, 
  3.7570892141624002`*^9}, {3.807618497628334*^9, 3.8076184979535155`*^9}},
 CellID->1520823180,ExpressionUUID->"7c19c57d-ba1b-4f75-828a-6001398e4a21"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Append", "[", 
  RowBox[{"myList1", ",", "\"\<This is great!\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.7084296195391674`*^9, 3.7084296426195927`*^9}, {
   3.708429770970518*^9, 3.708429771665412*^9}, 3.757089202265134*^9, 
   3.80761887209566*^9},
 CellLabel->"In[52]:=",
 CellID->1630310558,ExpressionUUID->"f2931652-f035-40d0-bac1-cfdb639d2acf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>", 
   ",", "\<\"This is great!\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.708429601530072*^9, 3.708429643004401*^9, 
  3.757220063744545*^9, 3.807618875333971*^9, 3.812204079646525*^9},
 CellLabel->"Out[52]=",
 CellID->757222528,ExpressionUUID->"5459b302-daab-419f-9e6c-e46cd8eca129"]
}, Open  ]],

Cell[TextData[{
 "Note, though, that if we call ",
 Cell[BoxData[
 "myList1"], "InlineCode",ExpressionUUID->
  "fcaf7e58-00c6-4d62-9fc9-15bbf3f989d5"],
 " again, the appended string is not there:"
}], "CodeCaption",
 CellChangeTimes->{{3.7084296554710107`*^9, 3.7084296880662837`*^9}, {
  3.751766953247557*^9, 3.7517669540925198`*^9}, {3.7570856870145073`*^9, 
  3.7570856878277073`*^9}, {3.7570874361546173`*^9, 3.757087436159749*^9}, {
  3.7572156416215897`*^9, 3.757215646345189*^9}, {3.8076185075988045`*^9, 
  3.8076185147606463`*^9}, {3.8157500336680527`*^9, 3.815750034907517*^9}, {
  3.816446983989922*^9, 3.816446983991747*^9}},
 CellID->545581921,ExpressionUUID->"a87d99dd-7b40-40e4-9aa7-8492af217212"],

Cell[CellGroupData[{

Cell[BoxData["myList1"], "Input",
 CellChangeTimes->{{3.708429648594914*^9, 3.7084296496489725`*^9}},
 CellLabel->"In[53]:=",
 CellID->1987657204,ExpressionUUID->"370be3d4-50d5-47d1-b9d4-6cc0b600b993"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7084296501281962`*^9, 3.757220063795389*^9, 
  3.8122040796671352`*^9},
 CellLabel->"Out[53]=",
 CellID->650935974,ExpressionUUID->"e04a5edd-7bb0-48c9-b685-c00dffcb4232"]
}, Open  ]],

Cell[TextData[{
 "We can make this change permanent during our current session by using the \
",
 ButtonBox["AppendTo",
  BaseStyle->"Link"],
 " function."
}], "Text",
 PageBreakAbove->True,
 CellChangeTimes->{{3.7084297414034743`*^9, 3.708429764880879*^9}, 
   3.708430073263255*^9, {3.7570856925835333`*^9, 3.757085696312385*^9}, {
   3.757087680212553*^9, 3.757087680217731*^9}, {3.757089244844145*^9, 
   3.757089248421103*^9}, {3.7616356685327363`*^9, 3.761635677780508*^9}, 
   3.807618524961963*^9},
 CellID->431623092,ExpressionUUID->"f57b4359-8f1c-415c-b004-0a90ad65935a"],

Cell[TextData[{
 "Use the ",
 ButtonBox["AppendTo",
  BaseStyle->"Link"],
 " function to make a permanent addition:"
}], "CodeCaption",
 CellChangeTimes->{{3.7084298373547773`*^9, 3.708429881738083*^9}, {
  3.7570892642100573`*^9, 3.757089277672655*^9}, {3.8076185295358014`*^9, 
  3.8076185304354177`*^9}},
 CellID->89547678,ExpressionUUID->"49babbfe-489f-4503-97fc-70c333d57b2b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AppendTo", "[", 
  RowBox[{"myList1", ",", "\"\<This is great!\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.7084298373547773`*^9, 3.708429881738083*^9}, 
   3.7570892642100573`*^9},
 CellLabel->"In[54]:=",
 CellID->131065750,ExpressionUUID->"72bd3337-765d-4e87-b45e-b43139a9bc22"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>", 
   ",", "\<\"This is great!\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.708429851633687*^9, 3.757220063847376*^9, 
  3.812204079673483*^9},
 CellLabel->"Out[54]=",
 CellID->999217200,ExpressionUUID->"4a90f4a2-8856-4e7f-ade5-df1569a5ca8a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["myList1"], "Input",
 CellChangeTimes->{{3.708429855899845*^9, 3.708429857369713*^9}},
 CellLabel->"In[55]:=",
 CellID->1068322581,ExpressionUUID->"1dfc325a-e159-4717-84be-c98229b41bc6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>", 
   ",", "\<\"This is great!\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.7084298577701826`*^9, 3.7572200638953857`*^9, 
  3.8122040796926317`*^9},
 CellLabel->"Out[55]=",
 CellID->521360860,ExpressionUUID->"e022d7a0-3244-4ec5-aee4-add2f6d572fd"]
}, Open  ]],

Cell["\<\
As mentioned, this permanency only refers to our current session. Once we \
close Mathematica or restart the Wolfram Language kernel, all the information \
inside of our computer variables, and indeed the computer variable names \
themselves, are lost. We have to re-execute each cell to reinstate them.\
\>", "Text",
 CellChangeTimes->{{3.761635708724674*^9, 3.761635826556655*^9}, {
   3.776705657903068*^9, 3.776705657952281*^9}, 3.8076185502971897`*^9},
 CellID->48280919,ExpressionUUID->"01dbb2b3-109f-4798-ac0e-5f347c713014"],

Cell[TextData[{
 "There is another way to append elements to a List, and it uses assignment. \
It is actually important to take a closer look at this example involving \
assignment. As mentioned in the prior Lists, ",
 ButtonBox["=",
  BaseStyle->"Link",
  ButtonData->"Set"],
 " assigns whatever is on the right-hand side of it to whatever is on the \
left-hand side of it. In this incarnation, it is most unlike our mathematical \
sense of the equal sign, which equates and does not assign."
}], "Text",
 CellChangeTimes->{{3.7084299010526648`*^9, 3.7084300552187004`*^9}, {
  3.7164600556624713`*^9, 3.7164600586380253`*^9}, {3.7517669921735225`*^9, 
  3.751767023813553*^9}, {3.751767070331354*^9, 3.751767074141964*^9}, {
  3.757098988745821*^9, 3.757098988858128*^9}, {3.7616358447572055`*^9, 
  3.7616358567005587`*^9}, {3.807618588944358*^9, 3.807618634998536*^9}},
 CellID->704672186,ExpressionUUID->"8602c2fd-cfdd-4187-86fa-c99cb5274939"],

Cell[TextData[{
 "In the next example, we create a computer variable called ",
 Cell[BoxData[
 "x"], "InlineCodeText",ExpressionUUID->
  "e33aaac7-6732-4995-bfb3-c0300e478923"],
 " and assign to it the number ",
 Cell[BoxData[
  FormBox["5", TraditionalForm]],ExpressionUUID->
  "7328ee89-eb58-4209-8429-5b7500d643cb"],
 "."
}], "Text",
 CellChangeTimes->{{3.7084299010526648`*^9, 3.708430117631176*^9}, 
   3.7517670952811317`*^9, {3.757085700430645*^9, 3.7570857011854973`*^9}, {
   3.757087694421638*^9, 3.7570877084936028`*^9}, {3.807618651401375*^9, 
   3.8076186552059116`*^9}},
 FontTracking->0.1,
 CellID->53116897,ExpressionUUID->"39b54084-b11a-4632-bee6-6dbe0eba513b"],

Cell[TextData[{
 "Assign the integer value 5 to the computer variable ",
 Cell[BoxData[
 "x"], "InlineCode",ExpressionUUID->"1330a2b1-c83f-48a6-b088-055f4d54645d"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7084301297074466`*^9, 3.7084301301817746`*^9}, {
  3.7164601026671658`*^9, 3.7164601194363823`*^9}, {3.757089282528675*^9, 
  3.7570892899444017`*^9}, {3.807618665132787*^9, 3.8076187212006545`*^9}},
 CellID->1529974374,ExpressionUUID->"b536a907-a7b7-4240-8a0b-20926fc3d755"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x", "=", "5"}]], "Input",
 CellChangeTimes->{{3.7084301297074466`*^9, 3.7084301301817746`*^9}, {
   3.7164601026671658`*^9, 3.7164601194363823`*^9}, 3.757089282528675*^9},
 CellLabel->"In[56]:=",
 CellID->915164175,ExpressionUUID->"d6376119-c5eb-4d08-84e9-8066872f599a"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{3.7084301310941515`*^9, 3.7572200639455757`*^9, 
  3.812204079698711*^9},
 CellLabel->"Out[56]=",
 CellID->778694260,ExpressionUUID->"f424fe7d-60a1-4643-9643-d966d484088b"]
}, Open  ]],

Cell[TextData[{
 "This is an assignment. The computer variable ",
 Cell[BoxData[
 "x"], "InlineCodeText",ExpressionUUID->
  "ff74be4f-9d1d-46df-ae30-28f721e4cb1d"],
 " holds an integer object with the value ",
 Cell[BoxData[
  FormBox["5", TraditionalForm]],ExpressionUUID->
  "be9ee247-ee15-4417-8edc-e082e86eba5e"],
 ". This was assigned to the computer variable by the equal sign. Watch now \
as we assign a new value to the computer variable, using its previously held \
value."
}], "Text",
 CellChangeTimes->{{3.708430141905094*^9, 3.708430194857036*^9}, 
   3.7156664418619804`*^9, {3.7164601435038657`*^9, 3.716460153566011*^9}, 
   3.757085707754191*^9, {3.757098988916009*^9, 3.7570989890359907`*^9}},
 CellID->153943211,ExpressionUUID->"f944847e-d988-4ba7-bf44-912fe4642966"],

Cell[TextData[{
 "Add 1 to the value currently held in the computer variable ",
 Cell[BoxData[
 "x"], "InlineCode",ExpressionUUID->"27582be9-6d5f-4018-a966-738d6419cc9f"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7084302014798636`*^9, 3.708430203034211*^9}, {
  3.7164601651445885`*^9, 3.7164601857323465`*^9}, {3.757089298080638*^9, 
  3.757089311621901*^9}, {3.8076187440149975`*^9, 3.8076187446383505`*^9}},
 CellID->1753236289,ExpressionUUID->"60446ac4-dd21-471e-8638-258940fdaa17"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x", "=", 
  RowBox[{"x", "+", "1"}]}]], "Input",
 CellChangeTimes->{{3.7084302014798636`*^9, 3.708430203034211*^9}, {
   3.7164601651445885`*^9, 3.7164601857323465`*^9}, 3.757089298080638*^9},
 CellLabel->"In[57]:=",
 CellID->246140459,ExpressionUUID->"f43be3e6-720d-481b-b046-1bfe57f529af"],

Cell[BoxData["6"], "Output",
 CellChangeTimes->{3.7084302039350705`*^9, 3.7572200639944363`*^9, 
  3.81220407971976*^9},
 CellLabel->"Out[57]=",
 CellID->749083002,ExpressionUUID->"ac1e06ae-b2da-4a21-8194-a0d9dd0d7836"]
}, Open  ]],

Cell[TextData[{
 "Algebraically, this makes no sense. If we try and solve for ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "f5c5d6aa-6986-41c2-90af-ce391a31ac93"],
 " as a mathematical variable we get ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "=", "1"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "bd4ca869-0a94-4065-9202-407190b3a030"],
 ". On the right-hand side we see ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "+", "1"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "37a3c42e-abbe-40b5-a3fe-eb2447b9a0c2"],
 ". As it stands, the computer variable ",
 Cell[BoxData[
 "x"], "InlineCodeText",ExpressionUUID->
  "77fa9ac8-7b9e-4c85-981b-12fd6cd67706"],
 " holds the value ",
 Cell[BoxData[
  FormBox["5", TraditionalForm]],ExpressionUUID->
  "ea5dab92-cb24-444a-9eea-afa7ffeb6f78"],
 ". We then add ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "544be01b-946a-4d26-9b4c-289b4e890c85"],
 " to it, resulting in the value ",
 Cell[BoxData[
  FormBox["6", TraditionalForm]],ExpressionUUID->
  "934275e6-9751-4f17-8e52-129272a1f2ef"],
 ". This new value is now assigned to the computer variable ",
 Cell[BoxData[
 "x"], "InlineCodeText",ExpressionUUID->
  "a2ed5b32-1e07-4285-b713-4b5a3dcb0bcc"],
 ". The value ",
 Cell[BoxData[
  FormBox["5", TraditionalForm]],ExpressionUUID->
  "5874e044-dd3a-403a-823e-4cff63c4b5bb"],
 ", which it held, is now replaced or overwritten by the value ",
 Cell[BoxData[
  FormBox["6", TraditionalForm]],ExpressionUUID->
  "7bc63ba6-c489-4b84-8dbd-fdd0e71207c7"],
 "."
}], "Text",
 CellChangeTimes->{{3.708430242889801*^9, 3.7084303852692986`*^9}, {
   3.7156664667018104`*^9, 3.715666483246174*^9}, {3.71646020801583*^9, 
   3.71646024761965*^9}, 3.7517671421616087`*^9, {3.757085709378151*^9, 
   3.757085711145988*^9}, {3.7570989890912952`*^9, 3.757098989382139*^9}, {
   3.807618773217374*^9, 3.807618793409025*^9}},
 CellID->1175517480,ExpressionUUID->"cbd8c043-80f9-461f-8d32-6ceee579837f"],

Cell[TextData[{
 "Instead of using the ",
 ButtonBox["AppendTo",
  BaseStyle->"Link"],
 " function, we can use a similar principle. We\[CloseCurlyQuote]ll recreate ",
 Cell[BoxData[
 "myList1"], "InlineCodeText",ExpressionUUID->
  "c6dd1b3a-4a85-447c-8772-7cedde42e4d5"],
 " and then permanently append our string to the end of it."
}], "Text",
 PageBreakAbove->True,
 InitializationCell->True,
 CellChangeTimes->{{3.7084304001060724`*^9, 3.708430454960579*^9}, 
   3.751767181731864*^9, {3.7570857264488163`*^9, 3.757085735793023*^9}, {
   3.7570877233448353`*^9, 3.7570877233499603`*^9}, {3.757089328853194*^9, 
   3.7570893325304317`*^9}, 3.75709898944958*^9, 3.8076188030172167`*^9},
 CellID->72733960,ExpressionUUID->"d7a54b47-5d4a-450f-99fe-6b8e62f58d03"],

Cell[TextData[{
 "Recreate the ",
 Cell[BoxData[
 "myList1"], "InlineCode",ExpressionUUID->
  "afc5b7e3-75e1-4d93-80b5-f11cb675c3d5"],
 " computer variable:"
}], "CodeCaption",
 CellChangeTimes->{{3.7084304621463537`*^9, 3.708430485563737*^9}, {
  3.757089344593609*^9, 3.757089379561702*^9}, {3.807618819542761*^9, 
  3.8076188215882907`*^9}},
 CellID->521470577,ExpressionUUID->"caa92eba-4ed5-48ee-a49e-54febf6cd432"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList1", "=", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3", ",", "\"\<Mathematica\>\""}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.7084304621463537`*^9, 3.708430485563737*^9}, 
   3.757089344593609*^9},
 CellLabel->"In[58]:=",
 CellID->925381945,ExpressionUUID->"01ce54ad-f43d-4d0d-9b15-e6d63b984e69"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.708430488587797*^9, 3.7164602683971796`*^9, 
  3.7164603202630916`*^9, 3.757220064077983*^9, 3.8122040797258587`*^9},
 CellLabel->"Out[58]=",
 CellID->1288875900,ExpressionUUID->"41a27eb9-de4b-4c6c-8e26-a13bd8d48fb7"]
}, Open  ]],

Cell[TextData[{
 "Use assignment to append to this ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " by overwriting it:"
}], "CodeCaption",
 CellChangeTimes->{{3.708430493571808*^9, 3.708430532324853*^9}, 
   3.7164629240679092`*^9, {3.751767208513356*^9, 3.7517672117072983`*^9}, {
   3.7570893473695583`*^9, 3.757089375334896*^9}, {3.807618827471401*^9, 
   3.807618837371559*^9}},
 CellID->601984031,ExpressionUUID->"9f1cd74a-53c8-4b57-91c8-98f3ac2691d4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myList1", "=", 
  RowBox[{"Append", "[", 
   RowBox[{"myList1", ",", "\"\<This is great!\>\""}], "]"}]}]], "Input",
 CellChangeTimes->{{3.708430493571808*^9, 3.708430532324853*^9}, 
   3.7164629240679092`*^9, {3.751767208513356*^9, 3.7517672117072983`*^9}, 
   3.7570893473695583`*^9},
 CellLabel->"In[59]:=",
 CellID->817778041,ExpressionUUID->"bfd0bbbf-940d-43ff-a338-b3a648e4910c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>", 
   ",", "\<\"This is great!\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.708430533003478*^9, 3.716460324291854*^9, 
  3.757220064211012*^9, 3.812204079731647*^9},
 CellLabel->"Out[59]=",
 CellID->469704011,ExpressionUUID->"31f75199-61fe-43d0-ad5f-fe6df37db8d1"]
}, Open  ]],

Cell["Check to see of the change was permanent:", "CodeCaption",
 CellChangeTimes->{{3.7164602877572994`*^9, 3.7164603049670663`*^9}, {
  3.7570893487936077`*^9, 3.757089370104025*^9}, {3.807618845178257*^9, 
  3.8076188455164213`*^9}},
 CellID->2008428110,ExpressionUUID->"9ee38b4e-f408-4294-a347-c172411949cc"],

Cell[CellGroupData[{

Cell[BoxData["myList1"], "Input",
 CellChangeTimes->{{3.7164602877572994`*^9, 3.7164603049670663`*^9}, 
   3.7570893487936077`*^9},
 CellLabel->"In[60]:=",
 CellID->500194287,ExpressionUUID->"1418ee42-5a07-43a0-b3f1-ec987966a0eb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "\<\"Mathematica\"\>", 
   ",", "\<\"This is great!\"\>"}], "}"}]], "Output",
 CellChangeTimes->{{3.7164603059956536`*^9, 3.7164603272431135`*^9}, 
   3.7572200643627043`*^9, 3.8122040797384768`*^9},
 CellLabel->"Out[60]=",
 CellID->165426505,ExpressionUUID->"21f1bf87-ff8a-4f23-8d73-7964f7446cfd"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Selecting Items from a List", "Subsection",
 CellChangeTimes->{{3.6899073201748238`*^9, 3.689907324470667*^9}, 
   3.7164629240835342`*^9, 3.782057540863953*^9},
 CellID->502424813,ExpressionUUID->"c0d0a88e-257e-4c87-ab48-fc6d15c4f160"],

Cell[TextData[{
 "While it is useful to store elements in a List and to select certain values \
using an index or addressing system, it is much more useful to select \
elements from a List based on some criteria. Imagine then for a moment that \
we have a List stored in a computer variable. This list holds the values for \
some laboratory measurements taken during an experiment. \
We\[CloseCurlyQuote]ll call it ",
 Cell[BoxData[
 "myVariable"], "InlineCodeText",ExpressionUUID->
  "984cb440-a6a9-4752-81cb-6a3a2851ed2c"],
 " and add some values to it manually."
}], "Text",
 CellChangeTimes->{{3.708430596642311*^9, 3.708430712747411*^9}, {
  3.7156665435344725`*^9, 3.7156665491365986`*^9}, {3.7164603417627077`*^9, 
  3.7164603655333443`*^9}, {3.716462924136462*^9, 3.716462924283655*^9}, {
  3.751767229766077*^9, 3.751767264139573*^9}, {3.757085741711372*^9, 
  3.7570857426000843`*^9}, {3.757098989506151*^9, 3.757098989620719*^9}, {
  3.7616359255575743`*^9, 3.7616359434127345`*^9}, {3.8093543645378304`*^9, 
  3.809354391345586*^9}},
 CellID->348132087,ExpressionUUID->"676de3e5-4a88-402f-8d80-f75cee64135d"],

Cell["\<\
Creating a List of 20 measurements taken during our experiment:\
\>", "CodeCaption",
 CellChangeTimes->{{3.689907435286414*^9, 3.68990756604167*^9}, {
   3.689907648089704*^9, 3.689907648359817*^9}, {3.7084307246915474`*^9, 
   3.708430743064175*^9}, 3.716462924299283*^9, {3.757089471521154*^9, 
   3.7570894819275513`*^9}},
 CellID->1310531781,ExpressionUUID->"71bd9648-b057-4f8d-9335-8e708c22e671"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myVariable", "=", 
  RowBox[{"{", 
   RowBox[{
   "15.4", ",", "12.3", ",", "16.3", ",", "15.0", ",", "20.1", ",", "19", ",",
     "8", ",", "15.2", ",", "16.5", ",", "15.0", ",", "18.3", ",", "14.3", 
    ",", "9.8", ",", "2.1", ",", "18.3", ",", "17.2", ",", "15.5", ",", 
    "25.9", ",", "14.9", ",", "20.1"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.689907435286414*^9, 3.68990756604167*^9}, {
   3.689907648089704*^9, 3.689907648359817*^9}, {3.7084307246915474`*^9, 
   3.708430743064175*^9}, 3.716462924299283*^9, 3.757089471521154*^9},
 CellLabel->"In[61]:=",
 CellID->723876709,ExpressionUUID->"b57894df-3b6f-45ca-9560-f96969f37307"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "15.4`", ",", "12.3`", ",", "16.3`", ",", "15.`", ",", "20.1`", ",", "19", 
   ",", "8", ",", "15.2`", ",", "16.5`", ",", "15.`", ",", "18.3`", ",", 
   "14.3`", ",", "9.8`", ",", "2.1`", ",", "18.3`", ",", "17.2`", ",", 
   "15.5`", ",", "25.9`", ",", "14.9`", ",", "20.1`"}], "}"}]], "Output",
 CellChangeTimes->{3.689907566984333*^9, 3.689907650990609*^9, 
  3.7084307465370617`*^9, 3.716460395877267*^9, 3.75722006451175*^9, 
  3.7616359510637555`*^9, 3.8122040797584667`*^9},
 CellLabel->"Out[61]=",
 CellID->1479430317,ExpressionUUID->"b100e7fa-f849-4c12-b9c9-c1ce88d5df11"]
}, Open  ]],

Cell[TextData[{
 "Suppose now that we only want to work on values that are greater than or \
equal to ",
 Cell[BoxData[
  FormBox["18", TraditionalForm]],ExpressionUUID->
  "7ca00a16-d9eb-4c67-b0c2-50c28e855487"],
 ". This is quite easy to accomplish using the ",
 ButtonBox["Select",
  BaseStyle->"Link"],
 " function. The first argument holds the List name (the computer variable \
name holding the list object) followed by the criteria we wish to set. The \
Wolfram Language uses the pound or hash sign (",
 Cell[BoxData[
  FormBox[
   ButtonBox["#",
    BaseStyle->"Link",
    ButtonData->"Slot"], TraditionalForm]],ExpressionUUID->
  "792c5338-62c1-4b13-b444-03f9ef2f7fb7"],
 ") as a placeholder for each element in the List. The greater than or equal \
to sign is typed as ",
 Cell[BoxData[
  TemplateBox[{"esc"},
   "Key0"]], "InlineCodeText",ExpressionUUID->
  "0f27159e-8b74-4ec8-b1f8-6c33c6401fc9"],
 " >= ",
 Cell[BoxData[
  TemplateBox[{"esc"},
   "Key0"]], "InlineCodeText",ExpressionUUID->
  "af4049c6-b80f-4880-993d-a027f8778aed"],
 ". Always remember the ",
 ButtonBox["&",
  BaseStyle->"Link",
  ButtonData->"Function"],
 " sign that follows the criteria."
}], "Text",
 CellChangeTimes->{{3.708430760128731*^9, 3.708430873420747*^9}, {
  3.7084309242212744`*^9, 3.7084309303633676`*^9}, {3.708431001000059*^9, 
  3.7084310234871945`*^9}, {3.716460433336362*^9, 3.7164604469674654`*^9}, {
  3.7164629243367243`*^9, 3.716462924416833*^9}, {3.7517673019232426`*^9, 
  3.751767302228421*^9}, {3.757085748041512*^9, 3.757085751912126*^9}, {
  3.757087735164508*^9, 3.757087735167881*^9}, {3.757098989688497*^9, 
  3.757098989860916*^9}, {3.757215706413608*^9, 3.757215709557288*^9}, {
  3.8076200200634985`*^9, 3.8076201197788277`*^9}, {3.80762657492332*^9, 
  3.80762661324666*^9}, {3.8076267938630886`*^9, 3.807626827560551*^9}},
 CellID->1640815672,ExpressionUUID->"93752a6a-2f84-4759-9abc-6ccb04274377"],

Cell[TextData[{
 "Select all the values greater than or equal to 18. The ",
 Cell[BoxData[
 "\[GreaterEqual]"], "InlineFormula",ExpressionUUID->
  "d40c84b5-2e00-46c7-b926-b1bbd6434e24"],
 " sign asks a Boolean question, so the number is returned only when a true \
value is found: "
}], "CodeCaption",
 PageBreakAbove->True,
 CellChangeTimes->{{3.6899076019539347`*^9, 3.6899076404640713`*^9}, {
   3.689907781574546*^9, 3.689907802700902*^9}, {3.689907944729392*^9, 
   3.689907973033084*^9}, {3.708430887851548*^9, 3.7084309764080486`*^9}, {
   3.7164605007935247`*^9, 3.716460513974828*^9}, 3.757089490713263*^9, {
   3.757089532320105*^9, 3.757089600543107*^9}, {3.7571005314817247`*^9, 
   3.757100535177586*^9}, {3.757100973551507*^9, 3.757101001086584*^9}, {
   3.7571011769885674`*^9, 3.757101256896797*^9}, {3.8076200558102303`*^9, 
   3.8076200558102303`*^9}, {3.807626630164744*^9, 3.807626763314829*^9}},
 CellID->1351488177,ExpressionUUID->"cca1ce84-2139-4a3b-befb-2765f5e0bad9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Select", "[", 
   RowBox[{"myVariable", ",", 
    RowBox[{
     RowBox[{"#", "\[GreaterEqual]", "18"}], "&"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.6899076019539347`*^9, 3.6899076404640713`*^9}, {
  3.689907781574546*^9, 3.689907802700902*^9}, {3.689907944729392*^9, 
  3.689907973033084*^9}, {3.708430887851548*^9, 3.7084309764080486`*^9}, {
  3.7164605007935247`*^9, 3.716460513974828*^9}, {3.757089490713263*^9, 
  3.7570895124260807`*^9}},
 CellLabel->"In[62]:=",
 CellID->439151463,ExpressionUUID->"f8cc6735-0dbd-4fad-9af8-d8d1e41397ec"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "20.1`", ",", "19", ",", "18.3`", ",", "18.3`", ",", "25.9`", ",", 
   "20.1`"}], "}"}]], "Output",
 CellChangeTimes->{{3.689907641309367*^9, 3.689907655609096*^9}, 
   3.70843089520373*^9, 3.757220064629369*^9, 3.81220407976458*^9},
 CellLabel->"Out[62]=",
 CellID->1219672853,ExpressionUUID->"6d970419-beb1-4055-b813-4f57a3a39e1a"]
}, Open  ]],

Cell[TextData[{
 "All of the values that show up are now greater than or equal to ",
 Cell[BoxData[
  FormBox["18", TraditionalForm]],ExpressionUUID->
  "bcff5860-c916-4888-be30-87deddcc54d7"],
 "."
}], "Text",
 CellChangeTimes->{{3.7164605256575537`*^9, 3.716460544361871*^9}, {
  3.8076279146836452`*^9, 3.807627914913039*^9}},
 CellID->1082804118,ExpressionUUID->"be8d4c3f-9e98-48d4-a5d1-89943f258819"],

Cell[TextData[{
 "We can do the same with string values. Below we create a List of genus and \
species names and assign it to the computer variable ",
 Cell[BoxData[
 "myOrganisms"], "InlineCodeText",ExpressionUUID->
  "e7fb7750-3653-4101-a813-102512710100"],
 ". "
}], "Text",
 CellChangeTimes->{{3.708431028460802*^9, 3.708431039869987*^9}, {
   3.708431110143489*^9, 3.7084311619395237`*^9}, {3.716460557818127*^9, 
   3.7164605579022894`*^9}, 3.7164629244526005`*^9, {3.751767367043515*^9, 
   3.751767368853296*^9}, {3.757085754157721*^9, 3.7570857548506327`*^9}, {
   3.757087748422982*^9, 3.757087748428484*^9}, 3.7570989899284286`*^9, {
   3.757215761180913*^9, 3.7572157664720984`*^9}, {3.818958350969063*^9, 
   3.818958358321916*^9}},
 CellID->912386548,ExpressionUUID->"70eb9f4b-8d0d-47de-8800-50a85363bd8b"],

Cell["Creating a list of string values:", "CodeCaption",
 CellChangeTimes->{{3.689907702719303*^9, 3.6899077178141003`*^9}, {
   3.7084311665313063`*^9, 3.708431304417138*^9}, 3.7164629244682293`*^9, {
   3.757089621703315*^9, 3.757089629166754*^9}, 3.7767053517249107`*^9, {
   3.8076279320971193`*^9, 3.8076279330795326`*^9}, 3.8093544470952997`*^9},
 CellID->1447472656,ExpressionUUID->"e6516669-0f9e-4a5c-9406-e563940feebe"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myOrganisms", "=", 
  RowBox[{"{", 
   RowBox[{
   "\"\<Staphylococcus aureus\>\"", ",", "\"\<Proteus mirabilis\>\"", ",", 
    "\"\<Acinetobacter baumanii\>\"", ",", "\"\<Eschericia coli\>\"", ",", 
    "\"\<Klebsiella pneumoniae\>\"", ",", "\"\<Proteus mirabilis\>\"", ",", 
    "\"\<Streptococcus pyogenes\>\"", ",", "\"\<Staphylococcus aureus\>\"", 
    ",", "\"\<Proteus mirabilis\>\"", ",", "\"\<Acinetobacter baumanii\>\"", 
    ",", "\"\<Eschericia coli\>\"", ",", "\"\<Klebsiella pneumoniae\>\"", 
    ",", "\"\<Streptococcus pyogenes\>\"", ",", 
    "\"\<Acinetobacter baumanii\>\"", ",", "\"\<Eschericia coli\>\"", ",", 
    "\"\<Proteus mirabilis\>\""}], "}"}]}]], "Input",
 CellChangeTimes->{{3.689907702719303*^9, 3.6899077178141003`*^9}, {
   3.7084311665313063`*^9, 3.708431304417138*^9}, 3.7164629244682293`*^9, 
   3.757089621703315*^9},
 CellLabel->"In[63]:=",
 CellID->361137086,ExpressionUUID->"c7982b3c-a806-42d1-944a-3efe8ed89024"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Staphylococcus aureus\"\>", ",", "\<\"Proteus mirabilis\"\>", 
   ",", "\<\"Acinetobacter baumanii\"\>", ",", "\<\"Eschericia coli\"\>", 
   ",", "\<\"Klebsiella pneumoniae\"\>", ",", "\<\"Proteus mirabilis\"\>", 
   ",", "\<\"Streptococcus pyogenes\"\>", 
   ",", "\<\"Staphylococcus aureus\"\>", ",", "\<\"Proteus mirabilis\"\>", 
   ",", "\<\"Acinetobacter baumanii\"\>", ",", "\<\"Eschericia coli\"\>", 
   ",", "\<\"Klebsiella pneumoniae\"\>", 
   ",", "\<\"Streptococcus pyogenes\"\>", 
   ",", "\<\"Acinetobacter baumanii\"\>", ",", "\<\"Eschericia coli\"\>", 
   ",", "\<\"Proteus mirabilis\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.689907728607553*^9, 3.7084313076200314`*^9, 
  3.716460589513833*^9, 3.75722006469069*^9, 3.8122040797851057`*^9},
 CellLabel->"Out[63]=",
 CellID->1310229756,ExpressionUUID->"19f57d57-68a4-481f-9478-897f1f890cef"]
}, Open  ]],

Cell[TextData[{
 "We may only want to work with a single species. We use the ",
 ButtonBox["Select",
  BaseStyle->"Link"],
 " function and assign the result to a new computer variable."
}], "Text",
 CellChangeTimes->{{3.7084313161639423`*^9, 3.70843134338529*^9}, 
   3.7164606070095167`*^9, {3.75708576113317*^9, 3.757085764720052*^9}, {
   3.757087761705413*^9, 3.757087761710596*^9}, {3.757089644526766*^9, 
   3.757089648355001*^9}, 3.757098989985756*^9},
 CellID->1219672247,ExpressionUUID->"98dad1c6-1103-4c79-9fae-c429d8a62572"],

Cell[TextData[{
 "Use the ",
 ButtonBox["Select",
  BaseStyle->"Link"],
 " function and ",
 ButtonBox["==",
  BaseStyle->"Link",
  ButtonData->"Equal"],
 " to get a single species:"
}], "CodeCaption",
 CellChangeTimes->{{3.689907730585855*^9, 3.6899077675973797`*^9}, {
  3.689907913693243*^9, 3.689907925601993*^9}, {3.68990798181828*^9, 
  3.689907986439144*^9}, {3.708431355925001*^9, 3.708431392457349*^9}, {
  3.757089658360211*^9, 3.757089666262748*^9}, {3.8076281061941586`*^9, 
  3.8076281572601233`*^9}},
 CellID->1300044714,ExpressionUUID->"4ca8a021-26ce-40bc-84a5-4b1f767ff277"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"myImportantOrganism", "=", 
  RowBox[{"Select", "[", 
   RowBox[{"myOrganisms", ",", 
    RowBox[{
     RowBox[{"#", "\[Equal]", "\"\<Acinetobacter baumanii\>\""}], "&"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.689907730585855*^9, 3.6899077675973797`*^9}, {
   3.689907913693243*^9, 3.689907925601993*^9}, {3.68990798181828*^9, 
   3.689907986439144*^9}, {3.708431355925001*^9, 3.708431392457349*^9}, 
   3.757089658360211*^9},
 CellLabel->"In[64]:=",
 CellID->1599814578,ExpressionUUID->"f66b7515-aa3c-493e-82a1-58e325cd7772"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Acinetobacter baumanii\"\>", 
   ",", "\<\"Acinetobacter baumanii\"\>", 
   ",", "\<\"Acinetobacter baumanii\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.6899077680066767`*^9, 3.708431394043086*^9, 
  3.716460621781352*^9, 3.757220064720533*^9, 3.812204079791478*^9},
 CellLabel->"Out[64]=",
 CellID->734192754,ExpressionUUID->"67628bb8-dbec-4749-8ab2-db1595695700"]
}, Open  ]],

Cell["\<\
This example was a bit trivial. In later chapters, we will have multiple \
variables nested as a List of Lists. We will use the matrix view, making our \
data appear as a spreadsheet. Every column holds the values for a variable. \
If we extract only a single organism as in the previous example, we will also \
extract only its corresponding values in the other columns.\
\>", "Text",
 CellChangeTimes->{{3.7084314039532204`*^9, 3.708431554822072*^9}, {
   3.7156666618715568`*^9, 3.715666664134915*^9}, {3.7164629244838533`*^9, 
   3.716462924521661*^9}, {3.751767429237158*^9, 3.7517674324888163`*^9}, {
   3.757098990043339*^9, 3.7570989902275343`*^9}, {3.807629376875123*^9, 
   3.807629381060074*^9}, 3.815750109347645*^9},
 CellID->358146904,ExpressionUUID->"0d41a9de-754e-45f4-b522-c78cf8ac4af8"],

Cell[TextData[{
 "Lastly, it may be useful to extract the index value for the criteria that \
we set. In the next example, we use the ",
 Cell[BoxData[
  FormBox["Position", TraditionalForm]], "InlineCodeText",ExpressionUUID->
  "a8c9deec-fa88-400d-8289-83fa30074d4a"],
 " function to see what positions (index values) the ",
 StyleBox["Acinetobacter baumanii",
  FontSlant->"Italic"],
 " organism held."
}], "Text",
 CellChangeTimes->{{3.708431580778255*^9, 3.70843165177946*^9}, {
   3.757085769117672*^9, 3.757085772864167*^9}, {3.7570877790821*^9, 
   3.75708777908764*^9}, 3.757098990285671*^9, {3.761636066548592*^9, 
   3.7616360675172777`*^9}, {3.807629399429988*^9, 3.807629406458847*^9}, 
   3.815750126388342*^9},
 CellID->2125836634,ExpressionUUID->"a4da01d7-2a7e-4b91-8d97-2ef46f93060a"],

Cell["The index values:", "CodeCaption",
 CellChangeTimes->{{3.689907822196231*^9, 3.68990784715565*^9}, {
  3.708431669751853*^9, 3.7084316873625145`*^9}, {3.7570896750230303`*^9, 
  3.757089683998654*^9}},
 CellID->1250872499,ExpressionUUID->"a92fb277-0b71-4431-875a-5b690c1adf5e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Position", "[", 
  RowBox[{"myOrganisms", ",", "\"\<Acinetobacter baumanii\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.689907822196231*^9, 3.68990784715565*^9}, {
   3.708431669751853*^9, 3.7084316873625145`*^9}, 3.7570896750230303`*^9},
 CellLabel->"In[65]:=",
 CellID->589907810,ExpressionUUID->"a507ecff-cde7-4882-9923-fbc729c1f2da"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "3", "}"}], ",", 
   RowBox[{"{", "10", "}"}], ",", 
   RowBox[{"{", "14", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.6899078480543737`*^9, 3.7084316879950943`*^9, 
  3.75722006476153*^9, 3.812204079797525*^9},
 CellLabel->"Out[65]=",
 CellID->136580816,ExpressionUUID->"b10c8300-52b5-43dd-9a90-3afbdd327696"]
}, Open  ]],

Cell[TextData[{
 "We see that it was listed as elements ",
 Cell[BoxData[
  FormBox["3", TraditionalForm]],ExpressionUUID->
  "28605ca2-adc4-45a3-a71d-a2ceb8b80183"],
 ", ",
 Cell[BoxData[
  FormBox["10", TraditionalForm]],ExpressionUUID->
  "ddfe5723-3ce9-41b8-8c39-98e6addb026d"],
 ", and ",
 Cell[BoxData[
  FormBox["14", TraditionalForm]],ExpressionUUID->
  "0d7c1e36-8b5c-4cc4-934c-0f881f6825ec"],
 "."
}], "Text",
 PageBreakAbove->True,
 CellChangeTimes->{{3.716460678395897*^9, 3.7164607144305124`*^9}, 
   3.7164629245685415`*^9, 3.809354544001463*^9},
 CellID->1648354604,ExpressionUUID->"009e36b3-1b66-4258-8c9e-610fbb65d1ce"],

Cell[TextData[{
 "That\[CloseCurlyQuote]s it for the ",
 Cell[BoxData[
 "List"], "InlineCodeText",ExpressionUUID->
  "9da52ad9-9100-495f-bbaf-25fe017405b0"],
 " function. As we start doing some real statistics and data analysis, we \
will see a lot of data stored in Lists and nested Lists."
}], "Text",
 CellChangeTimes->{{3.7164607195073376`*^9, 3.716460760107375*^9}, {
   3.716462924599798*^9, 3.7164629246684256`*^9}, 3.757098990354644*^9, {
   3.809354572926902*^9, 3.809354608268659*^9}, 3.815750160427455*^9},
 CellID->1356783128,ExpressionUUID->"19fcae7b-5dfb-4822-bce4-56e494aea66b"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox["Exercises",
  $Line = 0; Null]], "ExerciseSection",
 CellLabel->"In[66]:=",
 CellID->1969701267,ExpressionUUID->"ae89b352-2115-458a-bdf4-cc58c9b78ec7"],

Cell[TextData[{
 "Create a list with the following elements: 1, 2, 3, 4. Store the ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " in the computer variable ",
 Cell[BoxData[
 "myList1"], "InlineCode",ExpressionUUID->
  "b207bec6-2526-4aad-9dc8-3f046571bb4e"],
 "."
}], "Exercise",
 CellChangeTimes->{
  3.724600545624035*^9, {3.7462864618078566`*^9, 3.7462864656638565`*^9}, {
   3.757099055758911*^9, 3.757099075792304*^9}},
 CellID->513209901,ExpressionUUID->"43b6179a-82ab-4377-900b-9e99512c8df0"],

Cell[TextData[{
 "Repeat the process in problem 1 for the elements 10, 11, 12, 13 and store \
it in the computer variable ",
 Cell[BoxData[
 "myList2"], "InlineCode",ExpressionUUID->
  "63a8900a-199b-4f97-8802-1bdcde388fc4"],
 "."
}], "Exercise",
 CellChangeTimes->{
  3.724600545624035*^9, {3.7462864618078566`*^9, 3.7462864656638565`*^9}, {
   3.757099055758911*^9, 3.7570991027828217`*^9}, {3.7570991550022993`*^9, 
   3.757099160692507*^9}, {3.8076294384348865`*^9, 3.8076294389405384`*^9}},
 FontTracking->0.15,
 CellID->2040268941,ExpressionUUID->"e78876f3-e5ad-461b-88db-0ba158e8738c"],

Cell[TextData[{
 "Add ",
 Cell[BoxData[
 "myList1"], "InlineCode",ExpressionUUID->
  "38e4eead-d222-49e4-ba3f-f2fbdcafdb84"],
 " and ",
 Cell[BoxData[
 "myList2"], "InlineCode",ExpressionUUID->
  "b0ff728d-b6af-4cae-814c-f80cb991b30a"],
 "."
}], "Exercise",
 CellChangeTimes->{
  3.724600545624035*^9, {3.7462864618078566`*^9, 3.7462864656638565`*^9}, {
   3.757099055758911*^9, 3.757099122855257*^9}},
 CellID->809918388,ExpressionUUID->"192dcbc3-a7ac-4599-8d6a-207e8307b4fd"],

Cell[TextData[{
 "Multiply the elements of ",
 Cell[BoxData[
 "myList1"], "InlineCode",ExpressionUUID->
  "2643196c-3342-4bf7-9976-8d715606f615"],
 " and ",
 Cell[BoxData[
 "myList2"], "InlineCode",ExpressionUUID->
  "225c245b-2493-41a9-871e-e63cc079c25d"],
 "."
}], "Exercise",
 CellChangeTimes->{
  3.724600545624035*^9, {3.7462864618078566`*^9, 3.7462864656638565`*^9}, {
   3.757099055758911*^9, 3.757099122855257*^9}, {3.757099180390136*^9, 
   3.7570991966792097`*^9}},
 CellID->1703760825,ExpressionUUID->"72ed5838-78d7-40db-9c23-ea2496babb57"],

Cell[TextData[{
 "Use the ",
 ButtonBox["Table",
  BaseStyle->"Link"],
 " function to create a list of the cubes of the integers ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "2a427811-8bd3-4915-a3d6-761bf2ad13a6"],
 " through ",
 Cell[BoxData[
  FormBox["7", TraditionalForm]],ExpressionUUID->
  "4fe778c7-9070-4e3d-911d-534ae4d90252"],
 ". Save the created list to the computer variable ",
 Cell[BoxData[
 "myCubes"], "InlineCode",ExpressionUUID->
  "ca0e5dad-1def-4e05-a9be-2d77299abbbd"],
 "."
}], "Exercise",
 CellChangeTimes->{
  3.724600545624035*^9, {3.7462864618078566`*^9, 3.7462864656638565`*^9}, {
   3.757099055758911*^9, 3.757099122855257*^9}, {3.757099180390136*^9, 
   3.757099228357313*^9}},
 CellID->2032224541,ExpressionUUID->"249ae6aa-e18c-4ddc-a036-72b097f7612e"],

Cell[TextData[{
 "Use ",
 ButtonBox["[[",
  BaseStyle->"Link",
  ButtonData->"Part"],
 StyleBox[ButtonBox["...",
  BaseStyle->"Link",
  ButtonData->"Part"],
  FontColor->GrayLevel[0.6]],
 ButtonBox["]]",
  BaseStyle->"Link",
  ButtonData->"Part"],
 " addressing to extract the fifth element of ",
 Cell[BoxData[
 "myCubes"], "InlineCode",ExpressionUUID->
  "234bdaf9-913c-49d7-81e3-82065f8f1add"],
 "."
}], "Exercise",
 CellChangeTimes->{
  3.724600545624035*^9, {3.7462864618078566`*^9, 3.7462864656638565`*^9}, {
   3.757099055758911*^9, 3.757099122855257*^9}, {3.757099180390136*^9, 
   3.7570992437121572`*^9}, 3.7570993488736153`*^9, 3.757099465380025*^9, {
   3.807629473581751*^9, 3.8076294918395777`*^9}, {3.8076296560504637`*^9, 
   3.80762970059175*^9}, 3.8093563208507338`*^9},
 CellID->2004325695,ExpressionUUID->"2f9ed6d1-8cdc-4f74-aa9b-1bb3daf4d93e"],

Cell[TextData[{
 "Use the ",
 ButtonBox["Table",
  BaseStyle->"Link"],
 " function to add two values, ",
 Cell[BoxData[
  StyleBox["i", "TI"]],
  CellChangeTimes->{{3.8074663539475255`*^9, 3.8074663539545264`*^9}, 
    3.8074663848107605`*^9, 3.807545211195086*^9, 3.8075452490956135`*^9, {
    3.807545391276783*^9, 3.8075454782376747`*^9}, {3.807545555953256*^9, 
    3.807545584345338*^9}},ExpressionUUID->
  "2dde93eb-12bf-4f17-8914-ec8d079a99a5"],
 " and ",
 Cell[BoxData[
  StyleBox["j", "TI"]],
  CellChangeTimes->{{3.8074663539475255`*^9, 3.8074663539545264`*^9}, 
    3.8074663848107605`*^9, 3.807545211195086*^9, 3.8075452490956135`*^9, {
    3.807545391276783*^9, 3.8075454782376747`*^9}, {3.807545555953256*^9, 
    3.807545584345338*^9}},ExpressionUUID->
  "6fb65ed3-1e07-426b-9b68-4a0f3121ae79"],
 ", with ",
 Cell[BoxData[
  StyleBox["i", "TI"]],
  CellChangeTimes->{{3.8074663539475255`*^9, 3.8074663539545264`*^9}, 
    3.8074663848107605`*^9, 3.807545211195086*^9, 3.8075452490956135`*^9, {
    3.807545391276783*^9, 3.8075454782376747`*^9}, {3.807545555953256*^9, 
    3.807545584345338*^9}},ExpressionUUID->
  "4cc167d3-1e0a-46a1-b935-c37cdaacefbb"],
 " iterating through the values 1, 2, 3, 4, 5 and ",
 Cell[BoxData[
  StyleBox["j", "TI"]],
  CellChangeTimes->{{3.8074663539475255`*^9, 3.8074663539545264`*^9}, 
    3.8074663848107605`*^9, 3.807545211195086*^9, 3.8075452490956135`*^9, {
    3.807545391276783*^9, 3.8075454782376747`*^9}, {3.807545555953256*^9, 
    3.807545584345338*^9}},ExpressionUUID->
  "cd0be849-a01a-4966-8a10-43ce1f4cb5f9"],
 " iterating through 1, 2. Save the resulting nested list in the computer \
variable ",
 Cell[BoxData[
 "myPairs"], "InlineCode",ExpressionUUID->
  "ca44134f-0747-4c5c-8cd9-197a897e5ff8"],
 "."
}], "Exercise",
 CellChangeTimes->{
  3.724600545624035*^9, {3.7462864618078566`*^9, 3.7462864656638565`*^9}, {
   3.757099055758911*^9, 3.757099122855257*^9}, {3.757099180390136*^9, 
   3.757099289726097*^9}, {3.807629505895676*^9, 3.8076295175645547`*^9}, 
   3.8076297326203427`*^9, {3.807629770727169*^9, 3.807629775960828*^9}, {
   3.8076299370952635`*^9, 3.80762998986067*^9}},
 CellID->1190261921,ExpressionUUID->"ebf9aa0c-9425-4d8e-b603-312dbdbd8a81"],

Cell[TextData[{
 "Express ",
 Cell[BoxData[
 "myPairs"], "InlineCode",ExpressionUUID->
  "e1e29d89-6a2f-4d65-b2fd-13fb424097eb"],
 " in matrix format."
}], "Exercise",
 CellChangeTimes->{
  3.724600545624035*^9, {3.7462864618078566`*^9, 3.7462864656638565`*^9}, {
   3.757099055758911*^9, 3.757099122855257*^9}, {3.757099180390136*^9, 
   3.757099311482161*^9}},
 CellID->1252693244,ExpressionUUID->"ac2724dd-56d2-4400-8372-e6326d3a19d1"],

Cell[TextData[{
 "Use ",
 ButtonBox["[[",
  BaseStyle->"Link",
  ButtonData->"Part"],
 StyleBox[ButtonBox["...",
  BaseStyle->"Link",
  ButtonData->"Part"],
  FontColor->GrayLevel[0.6]],
 ButtonBox["]]",
  BaseStyle->"Link",
  ButtonData->"Part"],
 " addressing to display only the values in the last column of problem 8, ",
 Cell[BoxData[
 "myPairs"], "InlineCode",ExpressionUUID->
  "ec9cdcea-0b1b-442e-bb49-3ff1d110a2e2"],
 ", i.e. all the rows in column 2."
}], "Exercise",
 CellChangeTimes->{
  3.724600545624035*^9, {3.7462864618078566`*^9, 3.7462864656638565`*^9}, {
   3.757099055758911*^9, 3.757099122855257*^9}, {3.757099180390136*^9, 
   3.757099336904339*^9}, 3.7570993762767344`*^9, {3.757099433711298*^9, 
   3.75709945194077*^9}, {3.757099560512464*^9, 3.757099561492506*^9}, {
   3.7616361497098684`*^9, 3.7616361613990097`*^9}, 3.776705685223851*^9, 
   3.8076300214161577`*^9, 3.80935632706682*^9},
 CellID->1331898665,ExpressionUUID->"66e16d5e-f85c-4703-a20b-01cac09af03c"],

Cell[TextData[{
 "Use the ",
 ButtonBox["Table",
  BaseStyle->"Link"],
 " function to create a list of the first 10 even numbers, i.e. 2, 4, 6, 8, \
10, 12, 14, 16, 18, 20. Save the ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object in the computer variable ",
 Cell[BoxData[
 "myEvens"], "InlineCode",ExpressionUUID->
  "7ddb7923-5489-4d7f-8eba-16efdb96d346"],
 "."
}], "Exercise",
 CellChangeTimes->{
  3.724600545624035*^9, {3.7462864618078566`*^9, 3.7462864656638565`*^9}, {
   3.757099055758911*^9, 3.757099122855257*^9}, {3.757099180390136*^9, 
   3.757099336904339*^9}, {3.7570993762767344`*^9, 3.757099414733385*^9}, {
   3.7570994614440727`*^9, 3.757099519227599*^9}},
 CellID->1900617830,ExpressionUUID->"5763cc2c-d101-4673-b2d1-4b51eebaac1b"],

Cell[TextData[{
 "Use the ",
 ButtonBox["Select",
  BaseStyle->"Link"],
 " function to select only values that are less than 10 from ",
 Cell[BoxData[
 "myEvens"], "InlineCode",ExpressionUUID->
  "98ded1c7-7dba-4c75-b1e6-5aab2527ee7c"],
 "."
}], "Exercise",
 CellChangeTimes->{
  3.724600545624035*^9, {3.7462864618078566`*^9, 3.7462864656638565`*^9}, {
   3.757099055758911*^9, 3.757099122855257*^9}, {3.757099180390136*^9, 
   3.757099336904339*^9}, {3.7570993762767344`*^9, 3.757099414733385*^9}, {
   3.7570994614440727`*^9, 3.757099550749591*^9}, {3.761636226476763*^9, 
   3.761636231324892*^9}},
 CellID->156189696,ExpressionUUID->"8e4b4391-f12d-4100-9c7d-5c3c62cd031f"],

Cell[TextData[{
 "Transform ",
 Cell[BoxData[
 "myEvens"], "InlineCode",ExpressionUUID->
  "f713acd2-9a77-4d3b-89bf-6a186e1bd1a2"],
 " with the next 10 even numbers and flatten to a single ",
 ButtonBox["List",
  BaseStyle->"Link"],
 "."
}], "Exercise",
 CellChangeTimes->{
  3.724600545624035*^9, {3.7462864618078566`*^9, 3.7462864656638565`*^9}, {
   3.757099055758911*^9, 3.757099122855257*^9}, {3.757099180390136*^9, 
   3.757099336904339*^9}, {3.7570993762767344`*^9, 3.757099414733385*^9}, {
   3.7570994614440727`*^9, 3.757099550749591*^9}, {3.757099590868945*^9, 
   3.757099606227405*^9}, {3.7616362578537436`*^9, 3.7616362869096375`*^9}},
 CellID->1450589640,ExpressionUUID->"295cf33a-49c5-4389-94bc-120b5dd89ce2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 CellID->2111815718,ExpressionUUID->"60356ba7-655c-44b0-a60b-5f0aabf6eca6"],

Cell[TextData[{
 StyleBox[ButtonBox["For a list of other functions used with List \
manipulation, try this guide from the Wolfram Language & System Documentation \
Center ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/guide/ListManipulation.html"],
     None},
  ButtonNote->
   "https://reference.wolfram.com/language/guide/ListManipulation.html"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/APH24lBF",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolfr.am/APH24lBF"], None},
  ButtonNote->"http://wolfr.am/APH24lBF"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{
  3.746269404508712*^9, {3.7462857234063983`*^9, 3.746285751218179*^9}, {
   3.7462858072927856`*^9, 3.746285809571014*^9}, {3.757099714283596*^9, 
   3.757099720243217*^9}, {3.8082420637012634`*^9, 3.8082420641470795`*^9}, {
   3.808242141370105*^9, 3.8082421498185506`*^9}},
 CellID->26626102,ExpressionUUID->"39297a7e-57b9-4e07-9291-a7427361d3f4"],

Cell[TextData[{
 StyleBox[ButtonBox["More things you can do with, and to, Lists are explained \
in Section 5 of Stephen Wolfram\[CloseCurlyQuote]s ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/language/elementary-introduction/2nd-ed/05-\
operations-on-lists.html"], None},
  ButtonNote->
   "http://www.wolfram.com/language/elementary-introduction/2nd-ed/05-\
operations-on-lists.html"],
  BaseStyle -> "Hyperlink"],
 StyleBox[ButtonBox["An Elementary Introduction to the Wolfram Language",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/language/elementary-introduction/2nd-ed/05-\
operations-on-lists.html"], None},
  ButtonNote->
   "http://www.wolfram.com/language/elementary-introduction/2nd-ed/05-\
operations-on-lists.html"],
  FontSlant->"Italic",
  BaseStyle -> "Hyperlink"],
 StyleBox[ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/language/elementary-introduction/2nd-ed/05-\
operations-on-lists.html"], None},
  ButtonNote->
   "http://www.wolfram.com/language/elementary-introduction/2nd-ed/05-\
operations-on-lists.html"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/eiwl-5",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolfr.am/eiwl-5"], None},
  ButtonNote->"http://wolfr.am/eiwl-5"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{
  3.746269404508712*^9, {3.7462857234063983`*^9, 3.746285751218179*^9}, {
   3.7462858072927856`*^9, 3.746285809571014*^9}, {3.757099714283596*^9, 
   3.757099720243217*^9}, {3.8082421717409153`*^9, 3.8082421983283753`*^9}},
 CellID->716471692,ExpressionUUID->"65fae1be-b491-4b5c-a87e-321a5794bb9b"]
}, Open  ]]
}, Open  ]]
},
Editable->False,
Saveable->False,
WindowSize->{808, 911},
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{"\[ThinSpace]", "\[ThinSpace]", 
          StyleBox[
          "Introduction to Statistics\t\t\t\t\t\nwith the Wolfram Language", 
           LineSpacing -> {1, 1}, FontFamily -> "Source Sans Pro", FontSize -> 
           24, FontColor -> GrayLevel[1]], "\[ThinSpace]"}, 
         "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {65, 75}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"02-Klopper-BasicMath.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"02-Klopper-BasicMath.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> GrayLevel[0.2], Evaluator -> Automatic, 
                  Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Chapter 2\"", TooltipDelay -> 0.15, 
              LabelStyle -> "TextStyling"], 
             Annotation[#, "Chapter 2", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"04-Klopper-WorkingWithData.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"04-Klopper-WorkingWithData.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  GrayLevel[0.2], Evaluator -> Automatic, Method -> 
                  "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Chapter 4\"", TooltipDelay -> 0.15, 
              LabelStyle -> "TextStyling"], 
             Annotation[#, "Chapter 4", "Tooltip"]& ]}, "RowWithSeparators"], 
          Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> GrayLevel[0.2], 
             ImageSize -> {35, 30}, Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> RGBColor[0.12, 0.18, 0.26], 
             ImageSize -> {35, 30}, Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "1 | Introduction" :> 
          NotebookLocate[{"01-Klopper-IntroDataAnalysis.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "2 | Evaluating Basic Math" :> 
          NotebookLocate[{"02-Klopper-BasicMath.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "3 | Collections" :> 
          NotebookLocate[{"03-Klopper-Collections.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "4 | Working with Datasets" :> 
          NotebookLocate[{"04-Klopper-WorkingWithData.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "5 | Data Types" :> 
          NotebookLocate[{"05-Klopper-DataTypes.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "6 | Simple Descriptive Statistics" :> 
          NotebookLocate[{"06-Klopper-DescriptiveStatistics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "7 | Visualizing Data" :> 
          NotebookLocate[{"07-Klopper-VisualizingData.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "8 | Distributions" :> 
          NotebookLocate[{"08-Klopper-Distributions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "9 | Hypothesis Testing" :> 
          NotebookLocate[{"09-Klopper-HypothesisTesting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10 | Parametric Tests, Comparing Means" :> 
          NotebookLocate[{"10-Klopper-ParametricTests.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "11 | Correlation" :> 
          NotebookLocate[{"11-Klopper-Correlation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "12 | Linear Regression" :> 
          NotebookLocate[{"12-Klopper-LinearRegression.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "13 | Comparing Categorical Variables" :> 
          NotebookLocate[{"13-Klopper-ComparingCategoricalVariables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "14 | Nonparametric Tests" :> 
          NotebookLocate[{"14-Klopper-NonparametricTests.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "15 | A Research Project Demonstration" :> 
          NotebookLocate[{"15-Klopper-ResearchProject.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> RGBColor[0.12, 0.18, 0.26], 
   CellMargins -> {{0, 0}, {0, -1}}, CellFrameMargins -> {{27, 0}, {1, 7}}, 
   Background -> RGBColor[0.12, 0.18, 0.26], CellTags -> 
   "DockedCellLogoCell"], 
  Cell["JUAN H. KLOPPER", "Text", FontFamily -> "Source Sans Pro", FontWeight -> 
   "Light", FontSize -> 15, CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> 
   False, CellMargins -> {{0, 0}, {-1, -1}}, 
   CellFrameMargins -> {{27, 0}, {2, 4}}, CellFrameColor -> 
   RGBColor[1., 0.7, 0.1], FontTracking -> "Extended", FontColor -> 
   GrayLevel[1], Background -> RGBColor[0.9, 0.4, 0.], CellTags -> 
   "DockedCellLogoCell"]},
PrintingCopies->1,
PrintingStartingPageNumber->19,
PrintingPageRange->{1, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    Introduction to Statistics with the Wolfram Language", "Header"]}],
     "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], 
   None, None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["  |  Collections", "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 34}, {Inherited, Inherited}}]}},
PrintingOptions->{"FirstPageFooter"->False,
"FirstPageHeader"->False,
"PaperOrientation"->"Portrait",
"PaperSize"->{504, 720}},
ShowAutoSpellCheck->False,
FrontEndVersion->"12.2 for Mac OS X x86 (64-bit) (December 12, 2020)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> 
       "Source San Pro", FontSize -> 8, FontWeight -> "Plain", FontSlant -> 
       "Plain", FontColor -> GrayLevel[0.45]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Source San Pro", FontSize -> 
       8, FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth :> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, 
       AutoStyleOptions -> {
        "FormattingErrorTooltips" -> False, "HighlightComments" -> False, 
         "HighlightEmphasizedSyntaxErrors" -> False, 
         "HighlightExcessArguments" -> False, "HighlightFormattingErrors" -> 
         False, "HighlightGlobalToLocalScopeConflicts" -> False, 
         "HighlightGraphicsCompatibilityProblems" -> False, 
         "HighlightLocalScopeConflicts" -> False, "HighlightMissingArguments" -> 
         False, "HighlightNoKernelPresent" -> False, 
         "HighlightOrderOfEvaluationConflicts" -> False, "HighlightStrings" -> 
         True, "HighlightSymbolContexts" -> False, "HighlightSymbolShadowing" -> 
         False, "HighlightSyntaxErrors" -> False, "HighlightUndefinedSymbols" -> 
         False, "HighlightUnknownOptions" -> False, 
         "HighlightUnwantedAssignments" -> False}, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey :> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Open]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey :> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey :> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 64}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["GrayPointSix"], FontColor -> GrayLevel[0.6]], 
         Cell[
          StyleData["GrayPointSix", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, DefaultNewCellStyle -> 
          "ExerciseInput", CounterIncrements -> "Exercise", MenuSortingValue -> 
          10020, MenuCommandKey :> "2", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth :> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, DefaultReturnCreatedCellStyle -> 
          "Answer", CounterIncrements -> "Question", MenuSortingValue -> 
          10030, MenuCommandKey :> "3", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth :> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, ReturnCreatesNewCell -> True, 
          DefaultReturnCreatedCellStyle -> "Question", 
          LineSpacing -> {1.125, 1., 2.}, MenuSortingValue -> 10032, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          ReturnCreatesNewCell -> True, CellFrameLabelMargins -> 3, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 12}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Baskerville", FontSize -> 
          18, FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Italic", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", StripStyleOnPaste -> True, PageBreakWithin -> False, 
          GroupPageBreakWithin -> False, GeneratedCell -> True, 
          CellAutoOverwrite -> True, ShowCellLabel -> False, 
          DefaultFormatType -> DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221]], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, 
          GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, 
          ShowCellLabel -> False, SpanMaxSize -> 1, FontSize -> 14], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Comment"], FontFamily -> "Verdana", FontSize -> 13, 
          FontColor -> RGBColor[0.3, 0.3, 0.2], Background -> 
          RGBColor[1, 0.9, 0.8]], 
         Cell[
          StyleData["Comment", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Suggestion"], 
          CellFrameLabels -> {{Inherited, Inherited}, {Inherited, 
             Cell[
              BoxData[
               TagBox[
                GridBox[{{
                   ButtonBox[
                   "\"  Insert  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`ReplaceWithSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    ContentPadding -> False, Appearance -> Automatic, Method -> 
                    "Queued"], 
                   ButtonBox[
                   "\"  Stet  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; DocuTools`StetSuggestion[]), 
                    Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "    ", 
                   ButtonBox[
                   "\"  Next  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindNextSuggestion[]), Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], 
                   ButtonBox[
                   "\"  Previous  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindPreviousSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "\"\""}}, 
                 AutoDelete -> False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
                "Grid"]], ShowStringCharacters -> False, Background -> 
              None]}}, Background -> RGBColor[1, 0.8, 0.8]], 
         Cell[
          StyleData["Suggestion", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Tentative"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[
             0.30000000000000016`, 0.6000000000000003, 0.7000000000000003], 
            "Thickness" -> 5}, Evaluatable -> False, CellFrameMargins -> 4, 
          StyleMenuListing -> None, Background -> 
          RGBColor[0.8500000000000003, 0.9500000000000003, 1]], 
         Cell[
          StyleData["Tentative", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["WebOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.91, 0.92, 0.9], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.91, 0.92, 0.86]], 
         Cell[
          StyleData["WebOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Lockdown"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.8, 0.5, 0.4], "Thickness" -> 3}, Evaluatable -> 
       False, StyleMenuListing -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["IndexField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["IndexField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExplanationField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["ExplanationField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EnglishHighlight"], FontFamily -> "WolframCodeSans"], 
         Cell[
          StyleData["EnglishHighlight", "Printout"]]}, Open]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth :> Infinity, TextAlignment -> Left, 
       LineSpacing -> {0.6, 1}, AutoQuoteCharacters -> {}, 
       PasteAutoQuoteCharacters -> {}, StyleMenuListing -> None, FontFamily -> 
       "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth :> Infinity, 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Link", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (Function[
             t, NotebookFind[t, "Notes", All, CellStyle]; 
              NotebookFind[
               t, "NotesSection", All, CellStyle, AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Crosslink"], 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               
               NotebookLocate[#2, "OpenInNewWindow" -> 
                CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None,
             Method -> "Queued"}], 
         Cell[
          StyleData["Crosslink", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeLink"], 
          ButtonBoxOptions -> {
           Appearance -> None, ButtonFunction :> (Documentation`HelpLookup[
              Part[#, 1]]& ), ButtonSource -> ButtonContents, Evaluator -> 
            Automatic}], 
         Cell[
          StyleData["CodeLink", "Printout"]]}, Open]], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 0, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 0, FontFamily -> 
       "Source Sans Pro", FontSize -> Inherited 0.95], 
      Cell[
       StyleData["NoLabel"], 
       GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, ShowCellLabel -> 
       False], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariable"], FontFamily -> "Times", FontSize -> 
          Inherited 1.05, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariable", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariableLrg"], FontFamily -> "Times", FontSize -> 
          Inherited 1.1, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariableLrg", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "WolframCodeSans", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "WolframCodeSans", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {0.5, 3}}, 
               ImageMargins -> {{2, 2}, {1, 1}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Open]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Specialized for Klopper", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9, {3.7114709033696413`*^9, 
         3.711470909048764*^9}, {3.73531219927332*^9, 3.735312227736931*^9}, {
         3.745680245296091*^9, 3.7456802496393538`*^9}, {3.745930022124992*^9,
          3.7459300236362534`*^9}, {3.746546663993486*^9, 
         3.7465466650968523`*^9}}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {2, 32}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> "Italic", 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 14}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], LineSpacing -> {1.3, 1., 2.}, 
          MenuSortingValue -> 10010, MenuCommandKey :> "1", FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"], 
          CellMargins -> {{99, Inherited}, {2, 12}}, StripStyleOnPaste -> 
          True, DefaultFormatType -> DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           LanguageCategory -> "Formula", ScriptLevel -> 0, 
          SingleLetterItalics -> True, MenuSortingValue -> 1700, FontFamily -> 
          "Baskerville", FontSize -> 16, FontWeight -> "Regular", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[0.2], 
          UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}], 
              "DisplayFormulaEquationNumber"]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered", MenuSortingValue -> 
          1710, FontFamily -> "Baskerville", FontSize -> 16, FontWeight -> 
          "Regular", FontSlant -> "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       StyleData["InitializationCell"], Background -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Print"], CellMargins -> {{99, 10}, {4, 4}}, FontSize -> 
          15], 
         Cell[
          StyleData["Print", "Presentation"], 
          CellMargins -> {{100, Inherited}, {1.5 Inherited, 1.5 Inherited}}], 
         
         Cell[
          StyleData["Print", "SlideShow"], 
          CellMargins -> {{
            0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.01 
             FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {8, 15}}, 
          FontSize -> 18], 
         Cell[
          StyleData["Print", "Condensed"], 
          CellMargins -> {{18, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "Printout"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "PrintoutGray"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            RGBColor[0.8, 0.043, 0.008]], CellMargins -> {{81, 10}, {4, 8}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            GrayLevel[0.2]], 
          CellMargins -> {{80, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemParagraph"], CellMargins -> {{81, 10}, {4, 1}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["ItemParagraph", "Printout"], 
          CellMargins -> {{80, Inherited}, {Inherited, 0.5 Inherited}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemNumbered"], CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontWeight -> "Bold"], 
          CellMargins -> {{85, 10}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "ItemNumbered", 
          CounterAssignments -> {{"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> 1630, FontFamily -> 
          "Source Sans Pro", FontSize -> 15], 
         Cell[
          StyleData["ItemNumbered", "Printout"], 
          CellMargins -> {{90, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteItem"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontSize -> 12, FontWeight -> 
            Bold, FontColor -> GrayLevel[0.25]], 
          CellMargins -> {{93, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, CellFrameLabelMargins -> 4, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          CounterIncrements -> "ItemNumbered", MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNoteItem", "Printout"], 
          CellMargins -> {{93, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Epigraph"], CellMargins -> {{100, 78}, {6, 24}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, TextAlignment -> Left, Hyphenation -> 
          True, HyphenationOptions -> {"HyphenationMinLengths" -> {3, 5}}, 
          LineSpacing -> {1, 2}, TabSpacings -> {1.2, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontWeight -> "Plain", FontSlant -> 
          "Plain"], 
         Cell[
          StyleData["Epigraph", "Printout", StyleDefinitions -> None]]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EpigraphAuthor"], CellMargins -> {{125, 100}, {12, 12}}, 
          TextAlignment -> Left, LineSpacing -> {1, 2}, 
          ParagraphIndent -> -17, TabSpacings -> {1.5, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontTracking -> -0.05], 
         Cell[
          StyleData["EpigraphAuthor", "Printout", StyleDefinitions -> None]]},
         Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ReferenceSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ReferenceSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Reference"], CellDingbat -> Cell[
            TextData[{
              CounterBox["Reference"]}], "SR", FontSize -> 13, 
            CellSize -> {30, Inherited}, TextAlignment -> Right], 
          CellMargins -> {{80, 10}, {3, 4}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, 
          CellChangeTimes -> {{3.7385995432110577`*^9, 3.738599549834622*^9}},
           LineSpacing -> {1, 2}, ParagraphIndent -> -8, 
          TabSpacings -> {0.7, 2.5}, CounterIncrements -> "Reference", 
          MenuSortingValue -> 1870, FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["Reference", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{66, 10}, {3, 4}}, TabSpacings -> {1.2, 2.5}]}, 
        Open]]}, Closed]]}, Visible -> False, FrontEndVersion -> 
  "12.2 for Mac OS X x86 (64-bit) (December 12, 2020)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"e021fa9d-8611-4acd-ba75-df8a32ac5374"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "C:3"->{
  Cell[580, 22, 382, 9, 113, "Section",ExpressionUUID->"e13c5211-6608-4dfa-a2a3-b4ecc531ac72",
   CounterAssignments->{{"Section", 2}, {"Subsection", 2}, {"Subsubsection", 2}, {"Exercise", 2}},
   CellTags->"C:3",
   CellID->1397384692]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"C:3", 250514, 5951}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 382, 9, 113, "Section",ExpressionUUID->"e13c5211-6608-4dfa-a2a3-b4ecc531ac72",
 CounterAssignments->{{"Section", 2}, {"Subsection", 2}, {"Subsubsection", 2}, {"Exercise", 2}},
 CellTags->"C:3",
 CellID->1397384692],
Cell[965, 33, 469, 11, 88, "Text",ExpressionUUID->"9ec3f099-7716-4eff-a4ab-ca00913f2236",
 CellID->1261610270],
Cell[1437, 46, 605, 10, 88, "Text",ExpressionUUID->"07d6ddb9-73f7-4b57-bb92-8f74bad84257",
 CellID->1777761059]
}, Open  ]],
Cell[CellGroupData[{
Cell[2079, 61, 219, 3, 57, "Subsection",ExpressionUUID->"bc2ce47e-5695-4ba4-85cb-21248dd623d2",
 CellID->890137902],
Cell[2301, 66, 847, 13, 138, "Text",ExpressionUUID->"f2f40288-daa2-411b-8421-220049974e43",
 CellID->1176633912],
Cell[CellGroupData[{
Cell[3173, 83, 641, 18, 32, "ItemNumbered",ExpressionUUID->"ede83636-449c-4d42-ab97-9085f31d1e8c",
 CellID->1656737408],
Cell[3817, 103, 535, 11, 32, "ItemNumbered",ExpressionUUID->"00856b78-e840-454c-b60d-6036ee61b068",
 CellID->512649254]
}, Open  ]],
Cell[4367, 117, 538, 8, 63, "Text",ExpressionUUID->"6098a51b-068c-4d47-bb06-6dc7d629469e",
 CellID->391620214],
Cell[4908, 127, 496, 8, 88, "Text",ExpressionUUID->"4b2a7547-0038-49b2-b224-7d7700c2639c",
 CellID->2071042290],
Cell[CellGroupData[{
Cell[5429, 139, 209, 3, 55, "Subsubsection",ExpressionUUID->"0ca856bc-b363-4ebf-be7a-e5da2bb18962",
 CellID->1592817454],
Cell[5641, 144, 1693, 28, 238, "Text",ExpressionUUID->"8d5b0d84-2e5d-42c6-84f3-675d6772a1f3",
 CellID->2099289523],
Cell[7337, 174, 1105, 21, 113, "Text",ExpressionUUID->"74bf92dd-e2e5-433b-b6b9-56d8ae070211",
 CellID->1750176498]
}, Open  ]],
Cell[CellGroupData[{
Cell[8479, 200, 225, 3, 55, "Subsubsection",ExpressionUUID->"675c4b66-92d8-4f0f-9fad-ded5b693bc82",
 CellID->862205497],
Cell[8707, 205, 743, 13, 37, "CodeCaption",ExpressionUUID->"86692462-d09a-4df3-ae4c-d15a3400b99c",
 CellID->1132888927],
Cell[CellGroupData[{
Cell[9475, 222, 437, 9, 29, "Input",ExpressionUUID->"ae41e8ab-03b4-4728-9a34-4b37d2d2a9d0",
 CellID->1739760727],
Cell[9915, 233, 444, 9, 40, "Output",ExpressionUUID->"17bb7e99-8bda-4b42-8ddb-c096afdcf6a6",
 CellID->846622092]
}, Open  ]],
Cell[10374, 245, 1106, 20, 113, "Text",ExpressionUUID->"15b880e1-b8f1-4e69-a8fa-3af28d0d80b4",
 CellID->1437664982],
Cell[11483, 267, 635, 10, 88, "Text",ExpressionUUID->"9f2bc6e9-fdba-4bc8-b2b3-242252eb0954",
 CellID->1496840077],
Cell[12121, 279, 389, 6, 37, "CodeCaption",ExpressionUUID->"d7b1f78d-45aa-485c-90d6-7c54f97865bd",
 CellID->1767733181],
Cell[CellGroupData[{
Cell[12535, 289, 250, 4, 29, "Input",ExpressionUUID->"5ecb97ef-7a6b-4090-aead-209e215a159b",
 CellID->645349003],
Cell[12788, 295, 306, 7, 40, "Output",ExpressionUUID->"109ec80c-7400-4015-bff9-988bc875483c",
 CellID->2098338869]
}, Open  ]],
Cell[13109, 305, 771, 16, 63, "Text",ExpressionUUID->"e1f5bbcd-931f-443f-804f-8b8ef93687cc",
 CellID->1408799405]
}, Open  ]],
Cell[CellGroupData[{
Cell[13917, 326, 202, 3, 55, "Subsubsection",ExpressionUUID->"c2c49437-f244-41b1-8ecf-b42a14a96b9b",
 CellID->1923527635],
Cell[14122, 331, 487, 13, 37, "CodeCaption",ExpressionUUID->"d68f9d1e-c2fc-41a4-82ad-674d42361699",
 CellID->1684391660],
Cell[CellGroupData[{
Cell[14634, 348, 372, 8, 29, "Input",ExpressionUUID->"6b00df46-e7fe-4662-9f83-c99d7e247be6",
 CellID->1902442557],
Cell[15009, 358, 329, 7, 40, "Output",ExpressionUUID->"e72b37b3-e458-43b3-896e-c35dbed50bfe",
 CellID->804920249]
}, Open  ]],
Cell[15353, 368, 1598, 39, 163, "Text",ExpressionUUID->"8635c076-e3c7-4326-9be8-402ed2c4f2e2",
 CellID->655840147],
Cell[16954, 409, 713, 16, 37, "CodeCaption",ExpressionUUID->"9fcf9447-170e-4ab5-b069-e720797dd990",
 PageBreakAbove->True,
 CellID->265226226],
Cell[CellGroupData[{
Cell[17692, 429, 231, 4, 29, "Input",ExpressionUUID->"89719a46-a31b-4145-bc33-a97f5ba0703e",
 CellID->31015232],
Cell[17926, 435, 196, 3, 40, "Output",ExpressionUUID->"7d4f75cd-ea0a-4daa-b0a2-94bb79a0075d",
 CellID->1295132490]
}, Open  ]],
Cell[18137, 441, 469, 10, 37, "CodeCaption",ExpressionUUID->"b38d4b79-c6c5-415a-ba7f-a290ac6dd2ae",
 CellID->31600184],
Cell[CellGroupData[{
Cell[18631, 455, 256, 5, 29, "Input",ExpressionUUID->"f31e63ce-2866-4ced-ab1d-cb84bb8744d3",
 CellID->16492371],
Cell[18890, 462, 197, 3, 40, "Output",ExpressionUUID->"c7133c17-b966-42a3-abdc-b160a0f2218f",
 CellID->397513438]
}, Open  ]],
Cell[19102, 468, 317, 8, 38, "Text",ExpressionUUID->"72b71f44-c6fb-43e7-a64d-3d75563a07d3",
 CellID->525909639],
Cell[19422, 478, 1239, 23, 113, "Text",ExpressionUUID->"934a0679-fc5e-422b-96b5-3f550decc1e0",
 CellID->525071160],
Cell[20664, 503, 382, 5, 37, "CodeCaption",ExpressionUUID->"d362218c-3b91-4bba-8c8b-0e78bb76588f",
 CellID->685340947],
Cell[CellGroupData[{
Cell[21071, 512, 224, 4, 29, "Input",ExpressionUUID->"e3e76c3d-dab5-4d51-af02-a4b77665cd1d",
 CellID->183621007],
Cell[21298, 518, 197, 3, 40, "Output",ExpressionUUID->"6461675e-301e-4ac0-8870-185c0d2b5ea6",
 CellID->186726649]
}, Open  ]],
Cell[21510, 524, 378, 5, 37, "CodeCaption",ExpressionUUID->"d7888a45-4b92-471a-a7ae-8db1d50c8a80",
 CellID->119047235],
Cell[CellGroupData[{
Cell[21913, 533, 221, 4, 29, "Input",ExpressionUUID->"fa25d783-8229-497f-8923-50e2d0d1b0c3",
 CellID->539934307],
Cell[22137, 539, 196, 3, 40, "Output",ExpressionUUID->"85709621-f5d2-4d4f-b5d8-97dcc2784f71",
 CellID->841181476]
}, Open  ]],
Cell[22348, 545, 449, 9, 37, "CodeCaption",ExpressionUUID->"4f90c401-4311-479e-9a86-18ba8c8c8f47",
 CellID->15187266],
Cell[CellGroupData[{
Cell[22822, 558, 245, 5, 29, "Input",ExpressionUUID->"e9948f0e-ad2f-4389-bbc5-9bba70d6c94f",
 CellID->2335321],
Cell[23070, 565, 198, 3, 40, "Output",ExpressionUUID->"07ad7964-c725-4ffa-82de-e6edc4895293",
 CellID->852218931]
}, Open  ]],
Cell[23283, 571, 796, 21, 88, "Text",ExpressionUUID->"b6d3a359-94a1-436e-b233-23d2380db427",
 CellID->316965284],
Cell[24082, 594, 492, 10, 37, "CodeCaption",ExpressionUUID->"c5b99961-5009-444e-aa70-12aa43700831",
 CellID->355944966],
Cell[CellGroupData[{
Cell[24599, 608, 229, 4, 29, "Input",ExpressionUUID->"d7729c99-d933-4821-91cb-8f846176b6f6",
 CellID->761846243],
Cell[24831, 614, 227, 4, 40, "Output",ExpressionUUID->"87259ca6-c83b-4b7f-b81d-f34945851cc5",
 CellID->1675131474]
}, Open  ]],
Cell[25073, 621, 563, 11, 37, "CodeCaption",ExpressionUUID->"602cb161-df2a-4844-b362-5cb7f311bc7e",
 CellID->427400363],
Cell[CellGroupData[{
Cell[25661, 636, 217, 4, 29, "Input",ExpressionUUID->"8b0f0689-44bc-4293-a9f6-839c6dd22827",
 CellID->63912589],
Cell[25881, 642, 194, 3, 40, "Output",ExpressionUUID->"a879ac56-ea30-43c4-87b1-a80a0fb05772",
 CellID->424071348]
}, Open  ]],
Cell[26090, 648, 1576, 35, 138, "Text",ExpressionUUID->"75c4517b-2c4e-46a4-99fd-5ebd92f5eac8",
 CellID->104671427],
Cell[27669, 685, 195, 2, 37, "CodeCaption",ExpressionUUID->"f5832416-7190-49de-9b5c-4acebb1a6314",
 CellID->577359980],
Cell[CellGroupData[{
Cell[27889, 691, 216, 4, 29, "Input",ExpressionUUID->"f7337dcd-73bb-43b1-b489-f2ef3d1b6eef",
 CellID->160938468],
Cell[28108, 697, 228, 4, 40, "Output",ExpressionUUID->"16082b5f-67ce-4b54-94e5-00b6833126e1",
 CellID->2016405090]
}, Open  ]],
Cell[28351, 704, 293, 8, 38, "Text",ExpressionUUID->"c360c095-83b8-4734-a29d-5b4fa635790e",
 CellID->275632639]
}, Open  ]],
Cell[CellGroupData[{
Cell[28681, 717, 280, 3, 55, "Subsubsection",ExpressionUUID->"6eafdb1c-8ba6-427c-afd4-50c938bf8600",
 CellID->694058349],
Cell[28964, 722, 758, 12, 63, "Text",ExpressionUUID->"890243cf-609c-4179-b3c9-764b4b3121aa",
 CellID->2054984786],
Cell[29725, 736, 478, 9, 37, "CodeCaption",ExpressionUUID->"1724cf29-2ff9-4edd-9a25-d0c115a16dd0",
 CellID->149803601],
Cell[CellGroupData[{
Cell[30228, 749, 273, 5, 29, "Input",ExpressionUUID->"70b683da-e884-4fa6-8456-dda2ff2e0b5c",
 CellID->2068892239],
Cell[30504, 756, 325, 7, 40, "Output",ExpressionUUID->"107f7c8b-0edf-4f71-8a73-feb11b90288a",
 CellID->280914323]
}, Open  ]],
Cell[30844, 766, 615, 10, 63, "Text",ExpressionUUID->"08b88633-9ac8-45dc-bab9-8c2908b6758a",
 CellID->711722051],
Cell[31462, 778, 509, 11, 37, "CodeCaption",ExpressionUUID->"d0b7a73d-404e-446c-a5f1-904864b18665",
 CellID->428597367],
Cell[CellGroupData[{
Cell[31996, 793, 269, 5, 29, "Input",ExpressionUUID->"65f34ee3-5048-41ec-8db0-41dc982c9e91",
 CellID->1517454332],
Cell[32268, 800, 326, 7, 40, "Output",ExpressionUUID->"3940656e-f37d-4b6c-808c-65316556b8a5",
 CellID->1157970555]
}, Open  ]],
Cell[32609, 810, 1089, 19, 139, "Text",ExpressionUUID->"b23798f8-18b4-4b37-b9f9-87213c7fc22b",
 CellID->1415545780],
Cell[33701, 831, 331, 4, 37, "CodeCaption",ExpressionUUID->"d6c8f0fa-d4a3-44f1-9a83-66afe4290378",
 CellID->1254082994],
Cell[CellGroupData[{
Cell[34057, 839, 278, 5, 29, "Input",ExpressionUUID->"e41b1b2f-78c9-4612-aaa8-1c6452113b1d",
 CellID->1771149749],
Cell[34338, 846, 327, 7, 43, "Output",ExpressionUUID->"01e15cdd-4057-464b-a6fb-ec943635b69e",
 CellID->1514308771]
}, Open  ]],
Cell[34680, 856, 623, 10, 88, "Text",ExpressionUUID->"6c1e7f96-c274-4fa9-bbe5-6132b18081b7",
 CellID->383797465],
Cell[35306, 868, 254, 4, 37, "CodeCaption",ExpressionUUID->"29bfebc1-9d0d-4849-b94b-daa45ec01766",
 CellID->1590602314],
Cell[CellGroupData[{
Cell[35585, 876, 255, 5, 29, "Input",ExpressionUUID->"8cc2a4a1-3d5c-4964-a91e-7d060261a178",
 CellID->321934162],
Cell[35843, 883, 330, 7, 40, "Output",ExpressionUUID->"c8968e99-5586-4f82-b4bc-a61b25c08b3e",
 CellID->1158813600]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36222, 896, 250, 4, 55, "Subsubsection",ExpressionUUID->"70856f29-ca32-4880-8ffd-e325db52a1e2",
 PageBreakAbove->True,
 CellID->427267616],
Cell[36475, 902, 1204, 26, 88, "Text",ExpressionUUID->"defce31a-d1c1-4fa7-ad1d-62d1012dd7d4",
 CellID->2048990191],
Cell[37682, 930, 311, 4, 37, "CodeCaption",ExpressionUUID->"dde86163-a63d-45c4-b5dc-12959d24a7f5",
 CellID->330376845],
Cell[CellGroupData[{
Cell[38018, 938, 330, 7, 29, "Input",ExpressionUUID->"ac1dfa08-5750-4e5c-be37-50a856437bc0",
 CellID->1581341515],
Cell[38351, 947, 440, 11, 40, "Output",ExpressionUUID->"a28d6b5a-6d0d-4eb0-9894-0a72f250db3f",
 CellID->650980557]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38852, 965, 171, 2, 57, "Subsection",ExpressionUUID->"8fb41a92-0f79-4fcb-a812-b5f21985b635",
 CellID->955668172],
Cell[39026, 969, 750, 11, 113, "Text",ExpressionUUID->"3e2c7203-84ba-49f0-8a08-c5018d45ad94",
 CellID->884770891],
Cell[39779, 982, 302, 9, 54, "DisplayFormula",ExpressionUUID->"f70082c2-e4fc-44ff-ac45-d8c17e067818",
 CellID->1167593209],
Cell[40084, 993, 873, 16, 88, "Text",ExpressionUUID->"9a194d3b-bae3-457e-8c9d-38e12348f214",
 CellID->33497377],
Cell[40960, 1011, 312, 8, 37, "CodeCaption",ExpressionUUID->"4da7eaa7-03d1-4c72-8a36-2d2d933a03ae",
 CellID->216047554],
Cell[CellGroupData[{
Cell[41297, 1023, 424, 11, 29, "Input",ExpressionUUID->"fa82acd4-902a-4504-96d1-893bd7ac01e0",
 CellID->349699725],
Cell[41724, 1036, 459, 11, 40, "Output",ExpressionUUID->"e059b69f-f0c4-4c5f-901d-712bc2f7fe1f",
 CellID->1748523681]
}, Open  ]],
Cell[42198, 1050, 567, 10, 88, "Text",ExpressionUUID->"40a7f073-b21e-4432-baaa-5d0f6c7c2be1",
 CellID->314154751],
Cell[42768, 1062, 974, 16, 88, "Text",ExpressionUUID->"49e7f9ab-4290-4ccd-ab4b-5ffe78d619b3",
 CellID->731805509],
Cell[43745, 1080, 445, 13, 37, "CodeCaption",ExpressionUUID->"2ac945f8-5894-4f1d-a8d9-377d0f9ac77a",
 CellID->816343394],
Cell[CellGroupData[{
Cell[44215, 1097, 287, 5, 29, "Input",ExpressionUUID->"a278cb8a-7a6f-4feb-a142-0200e56e8338",
 CellID->1159046616],
Cell[44505, 1104, 683, 19, 57, "Output",ExpressionUUID->"1f52344a-c529-4794-bdb7-b62e2eeb6e89",
 CellID->1271281019]
}, Open  ]],
Cell[45203, 1126, 501, 9, 32, "CodeCaption",ExpressionUUID->"f6f9dba9-f952-488b-b702-83367a89ed12",
 PageBreakAbove->True,
 CellID->884860518],
Cell[CellGroupData[{
Cell[45729, 1139, 382, 6, 29, "Input",ExpressionUUID->"31a8b4bc-d920-4905-84ec-7fa488ab1ad2",
 CellID->1735216604],
Cell[46114, 1147, 729, 19, 57, "Output",ExpressionUUID->"4d53444d-97e0-482e-9cd0-a70634c74223",
 CellID->1105282330]
}, Open  ]],
Cell[46858, 1169, 345, 4, 37, "CodeCaption",ExpressionUUID->"0d027a53-4979-4c95-9220-c064508177d3",
 CellID->757925017],
Cell[CellGroupData[{
Cell[47228, 1177, 313, 5, 29, "Input",ExpressionUUID->"7abe4af4-0070-4b87-9755-f3b8de3c994c",
 CellID->1535090383],
Cell[47544, 1184, 730, 19, 57, "Output",ExpressionUUID->"5b3a9cb9-8d3a-4eff-a335-7e35c2c68751",
 CellID->746573760]
}, Open  ]],
Cell[48289, 1206, 729, 16, 88, "Text",ExpressionUUID->"d9664a32-7473-4575-a089-b418163e3454",
 CellID->120358242],
Cell[49021, 1224, 405, 5, 37, "CodeCaption",ExpressionUUID->"bbb2a3b5-a4f8-41a6-af41-8ed7c33e0604",
 CellID->511598552],
Cell[CellGroupData[{
Cell[49451, 1233, 249, 5, 29, "Input",ExpressionUUID->"1bd5ac03-0594-4835-902c-ba1c7e7c40d4",
 CellID->296195294],
Cell[49703, 1240, 340, 9, 40, "Output",ExpressionUUID->"a23885ad-0ddb-4d78-8cbd-92633dbd378a",
 CellID->2065718546]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[50092, 1255, 243, 4, 57, "Subsection",ExpressionUUID->"6c27edc1-a8dd-4287-b12d-1722128e43a1",
 CellID->675494573],
Cell[50338, 1261, 1155, 21, 113, "Text",ExpressionUUID->"a6b718f9-995f-4c82-ae1e-98aa4be4ec9a",
 InitializationCell->True,
 CellID->1438730369],
Cell[51496, 1284, 1287, 30, 164, "Text",ExpressionUUID->"7a69bff5-d379-4139-abb9-dc46e90fb192",
 CellID->136117311],
Cell[52786, 1316, 485, 8, 37, "CodeCaption",ExpressionUUID->"e1574714-8270-4a3f-9e00-6d4d615c6cd9",
 CellID->75446563],
Cell[CellGroupData[{
Cell[53296, 1328, 538, 12, 29, "Input",ExpressionUUID->"c704a606-db69-4b39-aa2c-0e1dc14781c7",
 CellID->2076158683],
Cell[53837, 1342, 351, 8, 40, "Output",ExpressionUUID->"21f33a2f-106e-4f2a-bd0a-38a4967721a8",
 CellID->163481573]
}, Open  ]],
Cell[54203, 1353, 570, 12, 64, "Text",ExpressionUUID->"456e2520-a0ab-4b83-add5-ae8045fd7d32",
 CellID->148162651],
Cell[54776, 1367, 533, 7, 37, "CodeCaption",ExpressionUUID->"1a8eb419-13f9-41a0-8e2f-af5d3af58dd8",
 CellID->437282718],
Cell[CellGroupData[{
Cell[55334, 1378, 296, 7, 29, "Input",ExpressionUUID->"56be93cb-e63f-42a0-9a48-dc33df01109a",
 CellID->265909620],
Cell[55633, 1387, 361, 8, 35, "Output",ExpressionUUID->"55dcbc2a-198d-47cc-8a09-973137363ec7",
 CellID->1003212898]
}, Open  ]],
Cell[56009, 1398, 236, 3, 38, "Text",ExpressionUUID->"7ee1c2de-d510-4754-a6f0-2d54b88efc6a",
 PageBreakAbove->True,
 CellID->416832771],
Cell[56248, 1403, 510, 6, 37, "CodeCaption",ExpressionUUID->"2395795f-df26-4044-874b-015e69efa676",
 CellID->298044940],
Cell[CellGroupData[{
Cell[56783, 1413, 321, 7, 29, "Input",ExpressionUUID->"60e73008-3971-46f9-98fe-36aeed754ea4",
 CellID->449329642],
Cell[57107, 1422, 386, 8, 40, "Output",ExpressionUUID->"ad741057-c32a-4b8f-a196-53fa25c0cdcc",
 CellID->1105064089]
}, Open  ]],
Cell[57508, 1433, 212, 2, 38, "Text",ExpressionUUID->"71d3f5f9-1869-4455-98ef-42fdfe4d1045",
 CellID->352701977],
Cell[57723, 1437, 486, 6, 37, "CodeCaption",ExpressionUUID->"7b761daf-7845-4c5e-98f0-f5c9add064bc",
 CellID->306444229],
Cell[CellGroupData[{
Cell[58234, 1447, 341, 8, 29, "Input",ExpressionUUID->"6d2f4fe8-1de4-46fd-ba7e-077dc3f8ffc4",
 CellID->189634114],
Cell[58578, 1457, 325, 7, 40, "Output",ExpressionUUID->"33edb437-2cf3-4b8a-82c6-49027e53f945",
 CellID->1373564567]
}, Open  ]],
Cell[58918, 1467, 1522, 36, 117, "Text",ExpressionUUID->"07115bc6-9644-4d83-8cda-a2fe1ee88dad",
 CellID->43001309],
Cell[60443, 1505, 424, 11, 37, "CodeCaption",ExpressionUUID->"54fe8d43-e11d-4238-8b9b-c473a44bf775",
 CellID->213763186],
Cell[CellGroupData[{
Cell[60892, 1520, 481, 11, 29, "Input",ExpressionUUID->"acb3fb07-ce39-4974-9feb-d476fed66270",
 CellID->1168494971],
Cell[61376, 1533, 293, 6, 40, "Output",ExpressionUUID->"0ada5eb5-7cc7-4c5a-8f18-744fe8cff52a",
 CellID->50472319]
}, Open  ]],
Cell[61684, 1542, 2802, 64, 247, "Text",ExpressionUUID->"e818c775-61e6-4202-af8c-054150f17931",
 CellID->2022399558],
Cell[64489, 1608, 768, 14, 37, "CodeCaption",ExpressionUUID->"b282b8bf-54ac-454f-bffc-4cd008842c0e",
 CellID->98206590],
Cell[CellGroupData[{
Cell[65282, 1626, 781, 16, 29, "Input",ExpressionUUID->"4060eb99-13df-44b1-bbd4-7866e578af8b",
 CellID->433268949],
Cell[66066, 1644, 738, 18, 40, "Output",ExpressionUUID->"c90f6e35-95a8-48d2-8ef0-93c95aa123f0",
 CellID->32224868]
}, Open  ]],
Cell[66819, 1665, 1825, 52, 67, "Text",ExpressionUUID->"34ef9b04-c83a-42ba-ac9d-bb83c862e9fb",
 CellID->213854862],
Cell[68647, 1719, 496, 11, 38, "Text",ExpressionUUID->"06c51ab5-89ac-42ee-aef3-d1eab4c39754",
 CellID->1395799009]
}, Open  ]],
Cell[CellGroupData[{
Cell[69180, 1735, 302, 5, 52, "Subsection",ExpressionUUID->"fc1bc442-6f43-4255-9301-0783f3faef20",
 PageBreakAbove->True,
 CellID->82584435],
Cell[69485, 1742, 1433, 25, 188, "Text",ExpressionUUID->"e4bf0bff-a077-4720-b83c-5de41dcde910",
 CellID->722163083],
Cell[70921, 1769, 512, 11, 37, "CodeCaption",ExpressionUUID->"1ac7a278-dc79-4383-8355-7ebc814d31e1",
 CellID->1964846784],
Cell[CellGroupData[{
Cell[71458, 1784, 274, 4, 29, "Input",ExpressionUUID->"656b0b80-085e-464b-83b7-a340bec2a0a0",
 CellID->918184561],
Cell[71735, 1790, 304, 7, 40, "Output",ExpressionUUID->"e2325406-e269-4e7b-85fd-1b75a7520fb3",
 CellID->437477432]
}, Open  ]],
Cell[72054, 1800, 501, 8, 88, "Text",ExpressionUUID->"81f91e3a-3979-4f4d-8e5a-5d2b1a18c9b8",
 CellID->16264016],
Cell[72558, 1810, 233, 3, 37, "CodeCaption",ExpressionUUID->"0ae1dc8f-5ff0-4bdf-addd-2b19db10e904",
 CellID->618893743],
Cell[CellGroupData[{
Cell[72816, 1817, 276, 6, 29, "Input",ExpressionUUID->"c379a331-32cc-45b3-b1d9-08d401fbb515",
 CellID->806540824],
Cell[73095, 1825, 217, 4, 40, "Output",ExpressionUUID->"a39b14f6-9701-4cd4-b670-e4959dd7553f",
 CellID->1846675943]
}, Open  ]],
Cell[73327, 1832, 189, 2, 38, "Text",ExpressionUUID->"a11ae196-1954-45e4-8a16-33b9075e73b2",
 CellID->107084649],
Cell[73519, 1836, 236, 3, 37, "CodeCaption",ExpressionUUID->"7c613ee7-1b17-4658-b4e4-230ab0a953d3",
 CellID->180399557],
Cell[CellGroupData[{
Cell[73780, 1843, 279, 6, 29, "Input",ExpressionUUID->"eac82336-6e1d-4af6-8b5d-b8431c9f2c48",
 CellID->1209951394],
Cell[74062, 1851, 235, 4, 40, "Output",ExpressionUUID->"3e147346-2217-4969-a020-66a6df3dcbc9",
 CellID->1648907557]
}, Open  ]],
Cell[74312, 1858, 1430, 36, 94, "Text",ExpressionUUID->"b25b47b4-e03a-437b-a8f4-984e4020c219",
 CellID->1524256067],
Cell[75745, 1896, 389, 5, 37, "CodeCaption",ExpressionUUID->"e426db1f-27e4-4be7-afb8-6c1e54999423",
 CellID->839293006],
Cell[CellGroupData[{
Cell[76159, 1905, 344, 6, 29, "Input",ExpressionUUID->"8dea1273-d23e-4b0b-8919-91638c918652",
 CellID->1560745284],
Cell[76506, 1913, 239, 4, 40, "Output",ExpressionUUID->"e17d0a4b-ecb6-4518-88b0-97750e19861d",
 CellID->2060329611]
}, Open  ]],
Cell[76760, 1920, 1044, 19, 114, "Text",ExpressionUUID->"0f5b78c1-302a-42ce-8408-66dfdb801385",
 CellID->1316985479],
Cell[77807, 1941, 198, 2, 37, "CodeCaption",ExpressionUUID->"59ff2bd7-80ca-4f35-b56a-de730932ee01",
 CellID->331136608],
Cell[CellGroupData[{
Cell[78030, 1947, 284, 5, 29, "Input",ExpressionUUID->"3c8a7afc-2514-44ca-881c-b1788a149776",
 CellID->460995924],
Cell[78317, 1954, 237, 4, 40, "Output",ExpressionUUID->"6a131174-0e64-4760-91cd-6f51d146250f",
 CellID->1933447849]
}, Open  ]],
Cell[78569, 1961, 751, 14, 63, "Text",ExpressionUUID->"d6b46333-4302-4397-89a2-d85b61890abd",
 PageBreakAbove->True,
 CellID->399378628],
Cell[79323, 1977, 455, 10, 37, "CodeCaption",ExpressionUUID->"412765a5-51ba-440a-aa1d-737876b28453",
 CellID->1470203921],
Cell[CellGroupData[{
Cell[79803, 1991, 227, 4, 29, "Input",ExpressionUUID->"448a7e74-2823-4b58-86bf-97575743954a",
 CellID->966462749],
Cell[80033, 1997, 598, 16, 40, "Output",ExpressionUUID->"cea4e90e-0c6e-4d42-880e-7932ab0a248d",
 CellID->1882935386]
}, Open  ]],
Cell[80646, 2016, 294, 4, 37, "CodeCaption",ExpressionUUID->"a303853f-002d-4921-96e6-2da156f931a4",
 CellID->1906429292],
Cell[CellGroupData[{
Cell[80965, 2024, 259, 5, 29, "Input",ExpressionUUID->"c66094b6-2cec-46bd-a53d-ceed32f542af",
 CellID->295170369],
Cell[81227, 2031, 770, 22, 117, "Output",ExpressionUUID->"43dff31d-ac46-4e89-afa1-524fc5ef6b1e",
 CellID->1176010310]
}, Open  ]],
Cell[82012, 2056, 344, 4, 37, "CodeCaption",ExpressionUUID->"7f61c000-ecc5-4d12-8cf1-0e3d5f596a20",
 CellID->689390384],
Cell[CellGroupData[{
Cell[82381, 2064, 347, 6, 29, "Input",ExpressionUUID->"6250cb3f-f537-451e-a38d-894610b0b7f7",
 CellID->1770390207],
Cell[82731, 2072, 275, 6, 40, "Output",ExpressionUUID->"5ddf5efc-526c-454d-a477-8fe89e2c35a6",
 CellID->1913276829]
}, Open  ]],
Cell[83021, 2081, 1292, 20, 188, "Text",ExpressionUUID->"2abce069-3497-4a80-975c-c3004288c764",
 CellID->598134374],
Cell[84316, 2103, 588, 9, 66, "CodeCaption",ExpressionUUID->"2581380a-a529-45c3-a04f-d1eaabc960ad",
 CellID->473472211],
Cell[CellGroupData[{
Cell[84929, 2116, 416, 7, 29, "Input",ExpressionUUID->"39d4454e-7561-4ca1-884b-fc4f5867030d",
 CellID->446546551],
Cell[85348, 2125, 216, 4, 40, "Output",ExpressionUUID->"7b91a3d2-01a3-4f55-9c77-d29c424a9cc1",
 CellID->23534825]
}, Open  ]],
Cell[85579, 2132, 862, 17, 89, "Text",ExpressionUUID->"7857e98e-728b-4fe4-87c0-7c82f1746cd8",
 CellID->820756450],
Cell[86444, 2151, 621, 10, 66, "CodeCaption",ExpressionUUID->"e965cb13-23b4-46b1-b461-05222c84578f",
 CellID->1166190469],
Cell[CellGroupData[{
Cell[87090, 2165, 442, 7, 29, "Input",ExpressionUUID->"83ec7c73-487e-44df-b658-e1492894a9f0",
 CellID->854376435],
Cell[87535, 2174, 298, 7, 40, "Output",ExpressionUUID->"b00453ab-bc41-42c7-8504-6f7164e9a35a",
 CellID->412812727]
}, Open  ]],
Cell[87848, 2184, 987, 21, 63, "Text",ExpressionUUID->"683224aa-f5fa-44ad-b350-ce76dd2b419d",
 PageBreakAbove->True,
 CellID->1816560023],
Cell[88838, 2207, 579, 15, 37, "CodeCaption",ExpressionUUID->"33f31649-6913-4a87-9432-86ca294fc19c",
 CellID->149297162],
Cell[CellGroupData[{
Cell[89442, 2226, 415, 7, 29, "Input",ExpressionUUID->"a6dedef1-597c-4950-9cd2-8a0d1038f486",
 CellID->258471199],
Cell[89860, 2235, 323, 7, 40, "Output",ExpressionUUID->"545a324a-d1e2-437f-8995-edda9098595b",
 CellID->1771322879]
}, Open  ]],
Cell[90198, 2245, 533, 8, 63, "Text",ExpressionUUID->"42fe21fe-e6ce-4078-8707-79f30ea8d13d",
 CellID->999722292],
Cell[90734, 2255, 567, 9, 66, "CodeCaption",ExpressionUUID->"0fb2aaed-f277-4960-a2b4-7ce087d7c400",
 CellID->420507516],
Cell[CellGroupData[{
Cell[91326, 2268, 416, 8, 29, "Input",ExpressionUUID->"af096c98-2376-4d3e-aa84-9bfad4906859",
 CellID->906852107],
Cell[91745, 2278, 277, 6, 40, "Output",ExpressionUUID->"624c40d0-ed1d-4ad0-ba45-823a5c141148",
 CellID->57828992]
}, Open  ]],
Cell[92037, 2287, 621, 12, 63, "Text",ExpressionUUID->"e79869ab-8253-4a95-ba14-9e72c7bbcf56",
 CellID->1185877168],
Cell[92661, 2301, 596, 9, 66, "CodeCaption",ExpressionUUID->"45fddff0-1ae4-42ef-b33f-d78be43dc54c",
 CellID->241834769],
Cell[CellGroupData[{
Cell[93282, 2314, 442, 10, 29, "Input",ExpressionUUID->"77200e8c-521d-4e3c-822c-509498d42674",
 CellID->502985276],
Cell[93727, 2326, 266, 6, 40, "Output",ExpressionUUID->"afd374d8-aa68-4bab-9c9b-3398a931fa48",
 CellID->1269260100]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[94042, 2338, 234, 3, 57, "Subsection",ExpressionUUID->"18532cdc-959f-4935-a689-7fbc164d5754",
 CellID->1310767211],
Cell[94279, 2343, 954, 18, 88, "Text",ExpressionUUID->"06466b8d-36d2-473a-8144-ba52114decc0",
 CellID->1177264351],
Cell[95236, 2363, 394, 10, 37, "CodeCaption",ExpressionUUID->"fb8def20-ec40-4460-a8c4-6d0c5d167fa7",
 CellID->1515107446],
Cell[CellGroupData[{
Cell[95655, 2377, 226, 4, 29, "Input",ExpressionUUID->"b0cdcd71-1e07-4735-8886-9b5133bd5ecd",
 CellID->678848326],
Cell[95884, 2383, 305, 7, 40, "Output",ExpressionUUID->"0d83b327-4c7e-46f7-93f3-c9099ef8ae95",
 CellID->1499435049]
}, Open  ]],
Cell[96204, 2393, 499, 11, 37, "CodeCaption",ExpressionUUID->"a52e12d6-c60f-4ba3-a8e9-9bf6013d60f7",
 CellID->528456400],
Cell[CellGroupData[{
Cell[96728, 2408, 331, 6, 29, "Input",ExpressionUUID->"3bd8bb43-6fde-4b99-a4be-4808afd89388",
 CellID->217209853],
Cell[97062, 2416, 216, 4, 40, "Output",ExpressionUUID->"83df9f62-d88e-4a30-9f04-454116041e69",
 CellID->284270998]
}, Open  ]],
Cell[97293, 2423, 593, 13, 38, "Text",ExpressionUUID->"0e281c41-adad-4532-be1c-13616f270381",
 PageBreakAbove->True,
 CellID->2117634305],
Cell[97889, 2438, 530, 11, 37, "CodeCaption",ExpressionUUID->"418c3ef4-438a-4cbc-92de-c9a9b741aecd",
 CellID->833282404],
Cell[CellGroupData[{
Cell[98444, 2453, 230, 4, 29, "Input",ExpressionUUID->"35abbb66-6641-4180-99cc-e6c6793ec46a",
 CellID->1450247492],
Cell[98677, 2459, 600, 16, 40, "Output",ExpressionUUID->"5e48d64c-55f5-45f0-b981-9a332a3b4d55",
 CellID->1739032458]
}, Open  ]],
Cell[CellGroupData[{
Cell[99314, 2480, 232, 4, 29, "Input",ExpressionUUID->"1490e206-66d6-4124-ad36-c9c144cdec0c",
 CellID->688870368],
Cell[99549, 2486, 241, 4, 40, "Output",ExpressionUUID->"4adeffa2-2fd0-4d4c-95d3-7541b147e571",
 CellID->666085936]
}, Open  ]],
Cell[99805, 2493, 302, 5, 38, "Text",ExpressionUUID->"7b92dc2b-0f7d-4016-a624-7f20648175fb",
 CellID->1125472484],
Cell[100110, 2500, 1164, 21, 88, "Text",ExpressionUUID->"f14c1e91-8344-41e3-b5f3-7e51d8c48e58",
 CellID->780075812],
Cell[101277, 2523, 370, 5, 37, "CodeCaption",ExpressionUUID->"3fd7c2c0-8331-4c1c-9ad7-ec640fb31c6f",
 CellID->346507349],
Cell[CellGroupData[{
Cell[101672, 2532, 1204, 38, 29, "Input",ExpressionUUID->"3588865c-003b-4e38-b488-07d5269c37b9",
 CellID->275741712],
Cell[102879, 2572, 1115, 36, 40, "Output",ExpressionUUID->"6a8eeef0-d713-4231-87f9-a7b990271bbb",
 CellID->74074541]
}, Open  ]],
Cell[104009, 2611, 329, 4, 37, "CodeCaption",ExpressionUUID->"ea03e624-8367-4208-800a-407e9297830d",
 CellID->564384831],
Cell[CellGroupData[{
Cell[104363, 2619, 333, 6, 29, "Input",ExpressionUUID->"1711a30c-481e-4726-8012-dcebf68bdf33",
 CellID->1924649204],
Cell[104699, 2627, 243, 4, 40, "Output",ExpressionUUID->"6c6487d9-9de0-492e-a07b-ea9ad0f2ef57",
 CellID->1577778974]
}, Open  ]],
Cell[104957, 2634, 329, 4, 38, "Text",ExpressionUUID->"b75fb5ff-518a-4a1d-9271-4a21758afc7b",
 CellID->711449915],
Cell[105289, 2640, 461, 7, 37, "CodeCaption",ExpressionUUID->"c3b013f9-3e07-4415-8a3a-9e3e295fe1f2",
 CellID->149774909],
Cell[CellGroupData[{
Cell[105775, 2651, 280, 5, 29, "Input",ExpressionUUID->"6faf4d20-37ce-481e-bbaa-22bf37d57c79",
 CellID->1449222407],
Cell[106058, 2658, 5612, 162, 223, "Output",ExpressionUUID->"94f0d5ec-c22d-4292-9127-f2cd06ddf455",
 CellID->603142862]
}, Open  ]],
Cell[111685, 2823, 1260, 24, 114, "Text",ExpressionUUID->"250b06a2-b73d-4e13-ae8c-8f98762fe45e",
 CellID->535161521],
Cell[112948, 2849, 344, 5, 37, "CodeCaption",ExpressionUUID->"40280a23-28ce-4c3d-b5ee-05045ea141cc",
 PageBreakAbove->True,
 CellID->798169811],
Cell[CellGroupData[{
Cell[113317, 2858, 351, 6, 29, "Input",ExpressionUUID->"0dedf459-4ac2-4585-9d23-e240665fa94a",
 CellID->715077577],
Cell[113671, 2866, 240, 4, 40, "Output",ExpressionUUID->"9524d97f-687f-4d6a-bf70-37648f2e75da",
 CellID->899267794]
}, Open  ]],
Cell[113926, 2873, 1275, 27, 114, "Text",ExpressionUUID->"e4cc6584-f51a-4db3-903c-02e911717722",
 CellID->1077154262],
Cell[115204, 2902, 445, 10, 37, "CodeCaption",ExpressionUUID->"aa4ed038-90e3-4ce1-81cb-d5986be697ba",
 CellID->444537224],
Cell[CellGroupData[{
Cell[115674, 2916, 285, 5, 29, "Input",ExpressionUUID->"f84bd8f6-3ed8-4efb-9b93-4d09fc6d41a9",
 CellID->904911756],
Cell[115962, 2923, 452, 9, 40, "Output",ExpressionUUID->"581947f5-2315-4a80-8c9a-8197f856893e",
 CellID->3906172]
}, Open  ]],
Cell[116429, 2935, 574, 13, 63, "Text",ExpressionUUID->"f5771b0b-7622-4fde-a1f8-dc9a0bf95ee9",
 CellID->412882155],
Cell[117006, 2950, 393, 6, 37, "CodeCaption",ExpressionUUID->"582912c6-c874-4f52-a099-7f81447e62cb",
 CellID->790715628],
Cell[CellGroupData[{
Cell[117424, 2960, 342, 6, 29, "Input",ExpressionUUID->"f21ed69f-f52e-4bab-a763-98512c27ca48",
 CellID->796709554],
Cell[117769, 2968, 220, 4, 40, "Output",ExpressionUUID->"581cc729-7e76-44a5-8634-6ef82e2579d7",
 CellID->1226523394]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[118038, 2978, 341, 4, 57, "Subsection",ExpressionUUID->"a770e73d-a34e-4f68-afc2-140310f07b03",
 CellID->1626406724],
Cell[118382, 2984, 1299, 24, 113, "Text",ExpressionUUID->"5c684947-d42d-4360-8f9b-2330f7c3c4fb",
 CellID->1845951252],
Cell[119684, 3010, 349, 9, 37, "CodeCaption",ExpressionUUID->"637611fb-ebfe-423d-bc27-7e2146470994",
 CellID->206444155],
Cell[CellGroupData[{
Cell[120058, 3023, 226, 4, 29, "Input",ExpressionUUID->"d46cc6e8-e0fe-4df1-987f-5871a1ec94ca",
 CellID->1723344177],
Cell[120287, 3029, 279, 6, 40, "Output",ExpressionUUID->"d720b73b-8b98-4f41-8099-c3f8a4ed4248",
 CellID->483155405]
}, Open  ]],
Cell[120581, 3038, 460, 10, 37, "CodeCaption",ExpressionUUID->"7c19c57d-ba1b-4f75-828a-6001398e4a21",
 CellID->1520823180],
Cell[CellGroupData[{
Cell[121066, 3052, 376, 7, 29, "Input",ExpressionUUID->"f2931652-f035-40d0-bac1-cfdb639d2acf",
 CellID->1630310558],
Cell[121445, 3061, 381, 8, 40, "Output",ExpressionUUID->"5459b302-daab-419f-9e6c-e46cd8eca129",
 CellID->757222528]
}, Open  ]],
Cell[121841, 3072, 713, 13, 37, "CodeCaption",ExpressionUUID->"a87d99dd-7b40-40e4-9aa7-8492af217212",
 CellID->545581921],
Cell[CellGroupData[{
Cell[122579, 3089, 201, 3, 29, "Input",ExpressionUUID->"370be3d4-50d5-47d1-b9d4-6cc0b600b993",
 CellID->1987657204],
Cell[122783, 3094, 306, 7, 40, "Output",ExpressionUUID->"e04a5edd-7bb0-48c9-b685-c00dffcb4232",
 CellID->650935974]
}, Open  ]],
Cell[123104, 3104, 581, 13, 63, "Text",ExpressionUUID->"f57b4359-8f1c-415c-b004-0a90ad65935a",
 PageBreakAbove->True,
 CellID->431623092],
Cell[123688, 3119, 381, 9, 37, "CodeCaption",ExpressionUUID->"49babbfe-489f-4503-97fc-70c333d57b2b",
 CellID->89547678],
Cell[CellGroupData[{
Cell[124094, 3132, 306, 6, 29, "Input",ExpressionUUID->"72bd3337-765d-4e87-b45e-b43139a9bc22",
 CellID->131065750],
Cell[124403, 3140, 337, 8, 40, "Output",ExpressionUUID->"4a90f4a2-8856-4e7f-ade5-df1569a5ca8a",
 CellID->999217200]
}, Open  ]],
Cell[CellGroupData[{
Cell[124777, 3153, 199, 3, 29, "Input",ExpressionUUID->"1dfc325a-e159-4717-84be-c98229b41bc6",
 CellID->1068322581],
Cell[124979, 3158, 343, 8, 40, "Output",ExpressionUUID->"e022d7a0-3244-4ec5-aee4-add2f6d572fd",
 CellID->521360860]
}, Open  ]],
Cell[125337, 3169, 541, 8, 113, "Text",ExpressionUUID->"01dbb2b3-109f-4798-ac0e-5f347c713014",
 CellID->48280919],
Cell[125881, 3179, 948, 16, 138, "Text",ExpressionUUID->"8602c2fd-cfdd-4187-86fa-c99cb5274939",
 CellID->704672186],
Cell[126832, 3197, 678, 16, 64, "Text",ExpressionUUID->"39b54084-b11a-4632-bee6-6dbe0eba513b",
 CellID->53116897],
Cell[127513, 3215, 486, 9, 37, "CodeCaption",ExpressionUUID->"b536a907-a7b7-4240-8a0b-20926fc3d755",
 CellID->1529974374],
Cell[CellGroupData[{
Cell[128024, 3228, 294, 5, 29, "Input",ExpressionUUID->"d6376119-c5eb-4d08-84e9-8066872f599a",
 CellID->915164175],
Cell[128321, 3235, 220, 4, 40, "Output",ExpressionUUID->"f424fe7d-60a1-4643-9643-d966d484088b",
 CellID->778694260]
}, Open  ]],
Cell[128556, 3242, 785, 16, 89, "Text",ExpressionUUID->"f944847e-d988-4ba7-bf44-912fe4642966",
 CellID->153943211],
Cell[129344, 3260, 491, 9, 37, "CodeCaption",ExpressionUUID->"60446ac4-dd21-471e-8638-258940fdaa17",
 CellID->1753236289],
Cell[CellGroupData[{
Cell[129860, 3273, 315, 6, 29, "Input",ExpressionUUID->"f43be3e6-720d-481b-b046-1bfe57f529af",
 CellID->246140459],
Cell[130178, 3281, 219, 4, 40, "Output",ExpressionUUID->"ac1e06ae-b2da-4a21-8194-a0d9dd0d7836",
 CellID->749083002]
}, Open  ]],
Cell[130412, 3288, 1994, 50, 143, "Text",ExpressionUUID->"cbd8c043-80f9-461f-8d32-6ceee579837f",
 CellID->1175517480],
Cell[132409, 3340, 761, 16, 62, "Text",ExpressionUUID->"d7a54b47-5d4a-450f-99fe-6b8e62f58d03",
 PageBreakAbove->True,
 InitializationCell->True,
 CellID->72733960],
Cell[133173, 3358, 419, 10, 36, "CodeCaption",ExpressionUUID->"caa92eba-4ed5-48ee-a49e-54febf6cd432",
 CellID->521470577],
Cell[CellGroupData[{
Cell[133617, 3372, 337, 8, 30, "Input",ExpressionUUID->"01ce54ad-f43d-4d0d-9b15-e6d63b984e69",
 CellID->925381945],
Cell[133957, 3382, 353, 7, 41, "Output",ExpressionUUID->"41a27eb9-de4b-4c6c-8e26-a13bd8d48fb7",
 CellID->1288875900]
}, Open  ]],
Cell[134325, 3392, 455, 10, 37, "CodeCaption",ExpressionUUID->"9f1cd74a-53c8-4b57-91c8-98f3ac2691d4",
 CellID->601984031],
Cell[CellGroupData[{
Cell[134805, 3406, 408, 8, 29, "Input",ExpressionUUID->"bfd0bbbf-940d-43ff-a338-b3a648e4910c",
 CellID->817778041],
Cell[135216, 3416, 359, 8, 40, "Output",ExpressionUUID->"31f75199-61fe-43d0-ad5f-fe6df37db8d1",
 CellID->469704011]
}, Open  ]],
Cell[135590, 3427, 312, 4, 37, "CodeCaption",ExpressionUUID->"9ee38b4e-f408-4294-a347-c172411949cc",
 CellID->2008428110],
Cell[CellGroupData[{
Cell[135927, 3435, 230, 4, 29, "Input",ExpressionUUID->"1418ee42-5a07-43a0-b3f1-ec987966a0eb",
 CellID->500194287],
Cell[136160, 3441, 370, 8, 40, "Output",ExpressionUUID->"21f1bf87-ff8a-4f23-8d73-7964f7446cfd",
 CellID->165426505]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[136579, 3455, 242, 3, 57, "Subsection",ExpressionUUID->"c0d0a88e-257e-4c87-ab48-fc6d15c4f160",
 CellID->502424813],
Cell[136824, 3460, 1120, 19, 138, "Text",ExpressionUUID->"676de3e5-4a88-402f-8d80-f75cee64135d",
 CellID->348132087],
Cell[137947, 3481, 411, 7, 37, "CodeCaption",ExpressionUUID->"71bd9648-b057-4f8d-9335-8e708c22e671",
 CellID->1310531781],
Cell[CellGroupData[{
Cell[138383, 3492, 667, 12, 54, "Input",ExpressionUUID->"b57894df-3b6f-45ca-9560-f96969f37307",
 CellID->723876709],
Cell[139053, 3506, 622, 11, 65, "Output",ExpressionUUID->"b100e7fa-f849-4c12-b9c9-c1ce88d5df11",
 CellID->1479430317]
}, Open  ]],
Cell[139690, 3520, 1919, 44, 170, "Text",ExpressionUUID->"93752a6a-2f84-4759-9abc-6ccb04274377",
 CellID->1640815672],
Cell[141612, 3566, 993, 17, 68, "CodeCaption",ExpressionUUID->"cca1ce84-2139-4a3b-befb-2765f5e0bad9",
 PageBreakAbove->True,
 CellID->1351488177],
Cell[CellGroupData[{
Cell[142630, 3587, 588, 12, 29, "Input",ExpressionUUID->"f8cc6735-0dbd-4fad-9af8-d8d1e41397ec",
 CellID->439151463],
Cell[143221, 3601, 375, 8, 40, "Output",ExpressionUUID->"6d970419-beb1-4055-b813-4f57a3a39e1a",
 CellID->1219672853]
}, Open  ]],
Cell[143611, 3612, 405, 9, 39, "Text",ExpressionUUID->"be8d4c3f-9e98-48d4-a5d1-89943f258819",
 CellID->1082804118],
Cell[144019, 3623, 820, 15, 63, "Text",ExpressionUUID->"70eb9f4b-8d0d-47de-8800-50a85363bd8b",
 CellID->912386548],
Cell[144842, 3640, 428, 5, 37, "CodeCaption",ExpressionUUID->"e6516669-0f9e-4a5c-9406-e563940feebe",
 CellID->1447472656],
Cell[CellGroupData[{
Cell[145295, 3649, 978, 17, 150, "Input",ExpressionUUID->"c7982b3c-a806-42d1-944a-3efe8ed89024",
 CellID->361137086],
Cell[146276, 3668, 904, 15, 137, "Output",ExpressionUUID->"19f57d57-68a4-481f-9478-897f1f890cef",
 CellID->1310229756]
}, Open  ]],
Cell[147195, 3686, 535, 10, 63, "Text",ExpressionUUID->"98dad1c6-1103-4c79-9fae-c429d8a62572",
 CellID->1219672247],
Cell[147733, 3698, 589, 15, 37, "CodeCaption",ExpressionUUID->"4ca8a021-26ce-40bc-84a5-4b1f767ff277",
 CellID->1300044714],
Cell[CellGroupData[{
Cell[148347, 3717, 559, 12, 29, "Input",ExpressionUUID->"f66b7515-aa3c-493e-82a1-58e325cd7772",
 CellID->1599814578],
Cell[148909, 3731, 412, 8, 40, "Output",ExpressionUUID->"67628bb8-dbec-4749-8ab2-db1595695700",
 CellID->734192754]
}, Open  ]],
Cell[149336, 3742, 814, 12, 138, "Text",ExpressionUUID->"0d41a9de-754e-45f4-b522-c78cf8ac4af8",
 CellID->358146904],
Cell[150153, 3756, 800, 16, 88, "Text",ExpressionUUID->"a4da01d7-2a7e-4b91-8d97-2ef46f93060a",
 CellID->2125836634],
Cell[150956, 3774, 283, 4, 37, "CodeCaption",ExpressionUUID->"a92fb277-0b71-4431-875a-5b690c1adf5e",
 CellID->1250872499],
Cell[CellGroupData[{
Cell[151264, 3782, 366, 7, 29, "Input",ExpressionUUID->"a507ecff-cde7-4882-9923-fbc729c1f2da",
 CellID->589907810],
Cell[151633, 3791, 370, 9, 40, "Output",ExpressionUUID->"b10c8300-52b5-43dd-9a90-3afbdd327696",
 CellID->136580816]
}, Open  ]],
Cell[152018, 3803, 636, 18, 39, "Text",ExpressionUUID->"009e36b3-1b66-4258-8c9e-610fbb65d1ce",
 PageBreakAbove->True,
 CellID->1648354604],
Cell[152657, 3823, 593, 11, 63, "Text",ExpressionUUID->"19fcae7b-5dfb-4822-bce4-56e494aea66b",
 CellID->1356783128],
Cell[CellGroupData[{
Cell[153275, 3838, 185, 4, 70, "ExerciseSection",ExpressionUUID->"ae89b352-2115-458a-bdf4-cc58c9b78ec7",
 CellID->1969701267],
Cell[153463, 3844, 499, 13, 30, "Exercise",ExpressionUUID->"43b6179a-82ab-4377-900b-9e99512c8df0",
 CellID->513209901],
Cell[153965, 3859, 592, 13, 44, "Exercise",ExpressionUUID->"e78876f3-e5ad-461b-88db-0ba158e8738c",
 CellID->2040268941],
Cell[154560, 3874, 477, 14, 25, "Exercise",ExpressionUUID->"192dcbc3-a7ac-4599-8d6a-207e8307b4fd",
 CellID->809918388],
Cell[155040, 3890, 551, 15, 25, "Exercise",ExpressionUUID->"72ed5838-78d7-40db-9c23-ea2496babb57",
 CellID->1703760825],
Cell[155594, 3907, 808, 22, 45, "Exercise",ExpressionUUID->"249ae6aa-e18c-4ddc-a036-72b097f7612e",
 CellID->2032224541],
Cell[156405, 3931, 864, 24, 25, "Exercise",ExpressionUUID->"2f9ed6d1-8cdc-4f74-aa9b-1bb3daf4d93e",
 CellID->2004325695],
Cell[157272, 3957, 2225, 49, 44, "Exercise",ExpressionUUID->"ebf9aa0c-9425-4d8e-b603-312dbdbd8a81",
 CellID->1190261921],
Cell[159500, 4008, 438, 11, 25, "Exercise",ExpressionUUID->"ac2724dd-56d2-4400-8372-e6326d3a19d1",
 CellID->1252693244],
Cell[159941, 4021, 992, 25, 44, "Exercise",ExpressionUUID->"66e16d5e-f85c-4703-a20b-01cac09af03c",
 CellID->1331898665],
Cell[160936, 4048, 756, 19, 44, "Exercise",ExpressionUUID->"5763cc2c-d101-4673-b2d1-4b51eebaac1b",
 CellID->1900617830],
Cell[161695, 4069, 677, 16, 25, "Exercise",ExpressionUUID->"8e4b4391-f12d-4100-9c7d-5c3c62cd031f",
 CellID->156189696],
Cell[162375, 4087, 724, 16, 25, "Exercise",ExpressionUUID->"295cf33a-49c5-4389-94bc-120b5dd89ce2",
 CellID->1450589640]
}, Open  ]],
Cell[CellGroupData[{
Cell[163136, 4108, 121, 1, 100, "MoreExploreSection",ExpressionUUID->"60356ba7-655c-44b0-a60b-5f0aabf6eca6",
 CellID->2111815718],
Cell[163260, 4111, 1113, 25, 49, "MoreExplore",ExpressionUUID->"39297a7e-57b9-4e07-9291-a7427361d3f4",
 CellID->26626102],
Cell[164376, 4138, 1797, 43, 49, "MoreExplore",ExpressionUUID->"65fae1be-b491-4b5c-a87e-321a5794bb9b",
 CellID->716471692]
}, Open  ]]
}, Open  ]]
}
]
*)

