(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    397081,       7544]
NotebookOptionsPosition[    302317,       5581]
NotebookOutlinePosition[    386647,       7341]
CellTagsIndexPosition[    386579,       7336]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Data Types", "SectionInline",ExpressionUUID->
   "910ef620-2a47-49e1-acc1-2cac31701780"],
  $Line = 0; Null]], "Section",
 CounterAssignments->{{"Section", 4}, {"Subsection", 4}, {
   "Subsubsection", 4}, {"Exercise", 4}, {"Question", 4}},
 CellTags->"C:5",
 CellLabel->"In[44]:=",
 CellID->818845388,ExpressionUUID->"9ef2bc15-6f86-4c5b-bae1-cb5587fb303a"],

Cell[TextData[{
 "In this chapter, we start our journey into proper statistics and data \
analysis. The journey begins by classifying data point values as specific \
types. The ability to do this underlies an important decision: ",
 StyleBox["what statistical test to use when analysing data",
  FontSlant->"Italic"],
 ". Without knowing what type of data each variable represents, we cannot \
make this decision."
}], "Text",
 CellChangeTimes->{{3.7528941352799587`*^9, 3.7528941820658092`*^9}, {
   3.752894273010105*^9, 3.752894280892581*^9}, 3.754221480115511*^9, {
   3.7542215444379425`*^9, 3.754221558862385*^9}},
 CellID->374170624,ExpressionUUID->"4c5fa1e7-521a-4b62-9486-e271aad14096"],

Cell["\<\
We will also expand on our knowledge of Dataset objects by importing an \
actual data file in the form of a spreadsheet. The file used in this text \
consists of simulated health-care data and does not contain any data on \
actual people.\
\>", "Text",
 CellChangeTimes->{
  3.7528941451132383`*^9, {3.7528942032181883`*^9, 3.752894206717224*^9}, 
   3.754221575544053*^9, 3.7542216249219904`*^9, 3.7542222839951544`*^9},
 CellID->29680916,ExpressionUUID->"e85f91b5-563d-4718-8cfe-01870c575f0d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data", "Subsection",
 CellChangeTimes->{{3.752894232340911*^9, 3.7528942330753284`*^9}},
 CellID->724768940,ExpressionUUID->"a33c2583-2efa-4755-854a-dde7c41055ba"],

Cell["\<\
Measurements taken during an experiment are termed data point values. Each \
data point value belongs to a variable. Some examples of variables are \
length, age, species, luminosity, distance, concentration, price, and choice \
in a survey question. These are represented as columns in a data file. For \
each subject in a research project, we will have data point values entered \
for each of these variables, represented as a row in a data file.\
\>", "Text",
 CellChangeTimes->{
  3.7528942412996783`*^9, {3.7528943412500143`*^9, 3.7528943551932907`*^9}, 
   3.7528943883502393`*^9, {3.754221567983297*^9, 3.754221586857184*^9}, {
   3.754221617428241*^9, 3.754221640203518*^9}},
 CellID->822645814,ExpressionUUID->"4e1290a0-212b-44b3-9d9f-c64c208f4423"],

Cell[TextData[{
 "In the previous chapter, we took a look at how a Dataset object is created. \
While creating our own data can be useful, it is much more common to have \
data already entered into a data file. In the code on the next page, we \
import a spreadsheet file from a simulated research project. The import will \
create a Dataset object similar to the one we created manually. Spreadsheets \
and other files that we may wish to import with the Wolfram Language can \
reside anywhere on your hard drive or even on the internet. In many cases, it \
is good practice to have the data file located in the same folder (directory) \
as the Wolfram Language file (notebook) in which we are working. This negates \
the need to type in a long path to the file in question. This is the \
convention used in this text. Once a notebook is saved locally, we can use \
the ",
 ButtonBox["NotebookDirectory",
  BaseStyle->"Link"],
 " function to print the folder (directory) name in which it is stored to the \
screen."
}], "Text",
 CellChangeTimes->{
  3.7528942507757215`*^9, {3.752894397270754*^9, 3.752894453172385*^9}, {
   3.7542215680273013`*^9, 3.754221568096308*^9}, {3.7542216174752455`*^9, 
   3.754221665980096*^9}, {3.7542224705551543`*^9, 3.754222498143154*^9}, {
   3.7542225692081547`*^9, 3.7542225881851544`*^9}, 3.7542226392881546`*^9, 
   3.7542348891006556`*^9, {3.762716729967752*^9, 3.762716733047661*^9}, 
   3.815755412119915*^9, 3.8157555016807623`*^9},
 CellID->77775309,ExpressionUUID->"87c34026-41e7-4e95-880f-d26cdb6dbfa6"],

Cell["Print the notebook directory to the screen:", "CodeCaption",
 CellChangeTimes->{{3.7542227076751547`*^9, 3.754222713058154*^9}},
 CellID->457685436,ExpressionUUID->"d7be9857-5c41-4c2c-b25c-3ce88c0c0aec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NotebookDirectory", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7528945154176145`*^9, 3.7528945211839046`*^9}},
 CellLabel->"In[1]:=",
 CellID->165639971,ExpressionUUID->"1507149a-846e-449a-91c9-7cfd21f69fa8"],

Cell[BoxData["\<\"/Users/todda/Desktop/\"\>"], "Output",
 CellChangeTimes->{
  3.752894549903595*^9, {3.809780920202032*^9, 3.809780926479607*^9}, 
   3.8123087655397863`*^9},
 CellLabel->"Out[1]=",
 CellID->1812554174,ExpressionUUID->"4136e409-2b78-44a1-9e10-7ab6dba36fc9"]
}, Open  ]],

Cell[TextData[{
 "We need to go one step further and set the current folder (directory) that \
contains our notebook and data files as the active folder (directory). This \
is accomplished with the ",
 ButtonBox["SetDirectory",
  BaseStyle->"Link"],
 " function. We pass the ",
 ButtonBox["NotebookDirectory",
  BaseStyle->"Link"],
 " function as an argument."
}], "Text",
 CellChangeTimes->{{3.7528945746985455`*^9, 3.752894589869235*^9}, {
  3.754221568106309*^9, 3.7542215681173105`*^9}, {3.754221617557254*^9, 
  3.754221617567255*^9}, {3.754221670196517*^9, 3.7542216737238703`*^9}, {
  3.7542227777921543`*^9, 3.7542228225031548`*^9}, {3.7542349338936553`*^9, 
  3.754234943804655*^9}},
 CellID->42729138,ExpressionUUID->"b2d85e5c-95aa-4d1e-8b09-dd0d256f2115"],

Cell["Set the active working directory:", "CodeCaption",
 CellChangeTimes->{{3.7542228613621545`*^9, 3.7542228654421544`*^9}},
 CellID->102680392,ExpressionUUID->"34e8f702-9585-4b15-88e9-ba55daa40c44"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"NotebookDirectory", "[", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7528946159234214`*^9, 3.752894628465271*^9}},
 CellLabel->"In[2]:=",
 CellID->20072638,ExpressionUUID->"e02c383b-7333-473e-8c3d-5575e4e81f44"],

Cell[BoxData["\<\"/Users/todda/Desktop\"\>"], "Output",
 CellChangeTimes->{
  3.752894549903595*^9, {3.809780920202032*^9, 3.809780926479607*^9}, 
   3.812308765547349*^9},
 CellLabel->"Out[2]=",
 CellID->1542469723,ExpressionUUID->"149a8a24-c5fe-4864-bbe6-99ff037baedf"]
}, Open  ]],

Cell[TextData[{
 "When we now import a file, we do not need to type its complete path \
(address) on our system drive. Setting the active folder is not strictly \
necessary. The Wolfram Language makes it easy to browse for a file on your \
local system by opening a ",
 StyleBox["File Browser", "MenuName",
  FontSize->14],
 " button as soon as you start to enter the argument for the ",
 ButtonBox["SemanticImport",
  BaseStyle->"Link"],
 " function."
}], "Text",
 CellChangeTimes->{{3.752894653616331*^9, 3.7528946666685376`*^9}, {
   3.75289491669763*^9, 3.752895045809573*^9}, {3.754221568127311*^9, 
   3.754221568155314*^9}, {3.7542216175772557`*^9, 3.754221617605259*^9}, {
   3.7542216771562133`*^9, 3.7542216823407316`*^9}, {3.754223169353154*^9, 
   3.7542231897121544`*^9}, {3.754236041524474*^9, 3.754236041834505*^9}, 
   3.7627174920207*^9, {3.8123037297504473`*^9, 3.812303730358786*^9}},
 CellID->59949281,ExpressionUUID->"550369a6-2a29-4913-9bec-9fc8b1430e0b"],

Cell["\<\
Clicking the button will open your system\[CloseCurlyQuote]s drive browser \
and you can navigate to the file:\
\>", "CodeCaption",
 CellChangeTimes->{{3.752894653616331*^9, 3.7528946666685376`*^9}, {
   3.75289491669763*^9, 3.752895045809573*^9}, {3.754221568127311*^9, 
   3.754221568155314*^9}, {3.7542216175772557`*^9, 3.754221617605259*^9}, {
   3.7542216771562133`*^9, 3.7542216823407316`*^9}, {3.754223169353154*^9, 
   3.7542231897121544`*^9}, {3.754236041524474*^9, 3.754236041834505*^9}, 
   3.7627174920207*^9, {3.8123037297504473`*^9, 3.812303737677471*^9}, {
   3.815755538621565*^9, 3.8157555401414347`*^9}},
 CellID->544190477,ExpressionUUID->"da31f50f-9a92-4689-b48c-843ffb45a950"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvetTVWn752cleZGX+RfyPvh6qqZS6ItUaqoesGpSiWiZqZFWfzP6a6ZL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    "], {{0, 764}, {862, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> ColorProfileData[CompressedData["
1:eJyVlwdUE1sax+9MeqMFIiAl9Ca9BZASeiiCdLARkhBCCSEhINiVhwo+UVRE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      "], "RGB", "XYZ"], Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->{449.80859375, Automatic},
  ImageSizeRaw->{862, 764},
  PlotRange->{{0, 862}, {0, 764}}]], "Picture",
 CellChangeTimes->{3.765649647224118*^9},
 CellID->885015780,ExpressionUUID->"8d5f3925-19f5-444d-b8ff-22d530384122"],

Cell[TextData[{
 "The following code imports a comma-separated value (",
 Cell[BoxData[
  FormBox[
   RowBox[{".", "csv"}], TraditionalForm]], "InlineCodeText",ExpressionUUID->
  "d5504ec8-e191-4f40-8db1-70e839e5f5e1"],
 "), spreadsheet file. These files can be created in common spreadsheet \
software. While most of the programs save the spreadsheet file in a \
proprietary format, such as ",
 Cell[BoxData[
  FormBox[
   RowBox[{".", "xlsx"}], TraditionalForm]], "InlineCodeText",ExpressionUUID->
  "4e9799ea-d58f-4bb6-a6be-c646f5187824"],
 " in the case of Microsoft Excel, they all provide the ability to choose the \
",
 Cell[BoxData[
  FormBox[
   RowBox[{".", "csv"}], TraditionalForm]], "InlineCodeText",ExpressionUUID->
  "869453dd-00d9-46cc-b3d9-be0bd581b3a5"],
 " file format when saving. We use the ",
 ButtonBox["SemanticImport",
  BaseStyle->"Link"],
 " function and pass the file name and extension as a string inside of \
quotation marks. We will store this imported spreadsheet in the computer \
variable called ",
 Cell[BoxData[
 "data"], "InlineCodeText",ExpressionUUID->
  "3b9ec311-596f-41cd-b993-31852f37a284"],
 "."
}], "Text",
 CellChangeTimes->{{3.752894677028879*^9, 3.7528948281188464`*^9}, {
   3.7542215239898977`*^9, 3.7542215377262716`*^9}, {3.754221568166315*^9, 
   3.7542215681763163`*^9}, {3.7542216176152596`*^9, 
   3.7542216176262608`*^9}, {3.7542216863161287`*^9, 
   3.7542216896924667`*^9}, {3.754224540611891*^9, 3.7542245776728907`*^9}, {
   3.762717529991922*^9, 3.762717554136093*^9}, 3.809781024333552*^9, 
   3.809781064179411*^9, {3.8157556410011168`*^9, 3.815755670390238*^9}, {
   3.8157557505944843`*^9, 3.8157557852557173`*^9}},
 CellID->29982804,ExpressionUUID->"c2c8b893-e238-4f87-baa9-ce599be5a90c"],

Cell["\<\
We can now omit the complete path to the file. The semicolon suppresses the \
output:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7542246198378906`*^9, 3.7542246407648907`*^9}},
 CellID->22671240,ExpressionUUID->"9f0a53de-4eb7-46c0-a3d8-0aa7384ef5c7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"SemanticImport", "[", "\"\<Variables.csv\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7528948721017513`*^9, 3.752894901308883*^9}},
 CellLabel->"In[3]:=",
 CellID->100546392,ExpressionUUID->"27f7da97-31ff-4a69-b81a-4dceab289dea"],

Cell[TextData[{
 "As we noted in the previous chapter, we can use the ",
 ButtonBox["Head",
  BaseStyle->"Link"],
 " function to look at the object type that was created when we imported the \
spreadsheet file."
}], "Text",
 CellChangeTimes->{{3.7528950666618185`*^9, 3.752895072757105*^9}, {
  3.754224814074891*^9, 3.754224827666891*^9}},
 CellID->1224815,ExpressionUUID->"6b49952b-b07b-4919-9f28-1cd395eae856"],

Cell[TextData[{
 "Look at what type of object was stored in the computer variable ",
 Cell[BoxData[
 "data"], "InlineCode",ExpressionUUID->"d8725297-3eaa-4161-be05-38d13f318e53"],
 " when we imported the ",
 Cell[BoxData[
  FormBox[
   RowBox[{".", "csv"}], TraditionalForm]], "InlineCode",ExpressionUUID->
  "0369d137-23dd-4b86-86b6-ffb39a9ebe62"],
 " spreadsheet file: "
}], "CodeCaption",
 CellChangeTimes->{{3.7542248873828907`*^9, 3.754224931798891*^9}, 
   3.7627177942151537`*^9, 3.8097810801683702`*^9},
 CellID->358198085,ExpressionUUID->"0839639b-3e02-496c-99d5-3ec935bf95e1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "data", "]"}]], "Input",
 CellChangeTimes->{{3.7528950980571876`*^9, 3.7528951004324265`*^9}},
 CellLabel->"In[4]:=",
 CellID->230878426,ExpressionUUID->"7ddbc88e-6420-47ce-850c-f8a914c9abf0"],

Cell[BoxData["Dataset"], "Output",
 CellChangeTimes->{3.752895100917044*^9, 3.812308765730721*^9},
 CellLabel->"Out[4]=",
 CellID->2013531524,ExpressionUUID->"7d3d04d6-5ccb-4763-bac3-212d1666bcb3"]
}, Open  ]],

Cell["\<\
While you can open the data file in your favorite spreadsheet program, we can \
also take a look at it right in the notebook using the indexing syntax, with \
which we are now very familiar. Let\[CloseCurlyQuote]s look at the first five \
rows.\
\>", "Text",
 CellChangeTimes->{{3.752895124483653*^9, 3.752895131832652*^9}, 
   3.7542215377372723`*^9, 3.754221568185317*^9, 3.754221617636262*^9, 
   3.754221692148712*^9, 3.754224961090891*^9},
 CellID->187380056,ExpressionUUID->"78f567b8-3bbb-4f46-983b-d37eca834b77"],

Cell["View the first five rows:", "CodeCaption",
 CellChangeTimes->{{3.754224967154891*^9, 3.7542249699698906`*^9}},
 CellID->453746082,ExpressionUUID->"0c36cbf2-b379-4b24-b97f-8ed702a6e8bb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "\[LeftDoubleBracket]", 
  RowBox[{";;", "5"}], "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.7528951616103086`*^9, 3.7528951678172283`*^9}},
 CellLabel->"In[5]:=",
 CellID->134474493,ExpressionUUID->"e9971e73-5b79-40e9-b82e-2a98ad192031"],

Cell[BoxData[
 TagBox[
  TagBox[
   DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = 
    Association["InitialData" -> {
       Association[
       "Age" -> 77, "Logistics" -> 
        "Immediate Surgical intervention(then Ward / ICU / HCU)", "Temp" -> 
        37.4, "InsulinDependentDiabetic" -> "No", "SurveyQuestion1" -> 5], 
       Association[
       "Age" -> 64, "Logistics" -> "Admit to Ward for Care", "Temp" -> 38., 
        "InsulinDependentDiabetic" -> "No", "SurveyQuestion1" -> 1], 
       Association[
       "Age" -> 87, "Logistics" -> "Admit to Ward for Care", "Temp" -> 38.5, 
        "InsulinDependentDiabetic" -> "No", "SurveyQuestion1" -> 1], 
       Association[
       "Age" -> 70, "Logistics" -> "Admit to Ward for Care", "Temp" -> 38.2, 
        "InsulinDependentDiabetic" -> "No", "SurveyQuestion1" -> 2], 
       Association[
       "Age" -> 85, "Logistics" -> "Admit to Ward for Care", "Temp" -> 38.1, 
        "InsulinDependentDiabetic" -> "No", "SurveyQuestion1" -> 3]}, 
     "InitialShape" -> TypeSystem`PackageScope`HeaderShape[
       Association[{All, "Age"} -> 1, {All, "Logistics"} -> 1, {All, "Temp"} -> 
        1, {All, "InsulinDependentDiabetic"} -> 1, {All, "SurveyQuestion1"} -> 
        1], 
       TypeSystem`PackageScope`Limited[
        TypeSystem`PackageScope`ColumnShape[
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`RowShape[
           Association[
           "Age" -> TypeSystem`PackageScope`AtomShape[34], "Logistics" -> 
            TypeSystem`PackageScope`AtomShape[486.], "Temp" -> 
            TypeSystem`PackageScope`AtomShape[60], "InsulinDependentDiabetic" -> 
            TypeSystem`PackageScope`AtomShape[27.], "SurveyQuestion1" -> 
            TypeSystem`PackageScope`AtomShape[34]]], 
          DirectedInfinity[1], 5, {All}]], 5, 
        DirectedInfinity[1], {}]], "InitialType" -> TypeSystem`Vector[
       TypeSystem`Struct[{
        "Age", "Logistics", "Temp", "InsulinDependentDiabetic", 
         "SurveyQuestion1"}, {
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[
          TypeSystem`Enumeration[
          "Admit to Ward for Care", 
           "Immediate Surgical intervention(then Ward / ICU / HCU)"]], 
         TypeSystem`Atom[Real], 
         TypeSystem`Atom[
          TypeSystem`Enumeration["No"]], 
         TypeSystem`Atom[Integer]}], 5], "Meta" -> 
     Association["ID" -> 79796412152750], "RowTarget" -> 20, "ColumnTarget" -> 
     10, "Shape" -> TypeSystem`PackageScope`HeaderShape[
       Association[{All, "Age"} -> 1, {All, "Logistics"} -> 1, {All, "Temp"} -> 
        1, {All, "InsulinDependentDiabetic"} -> 1, {All, "SurveyQuestion1"} -> 
        1], 
       TypeSystem`PackageScope`Limited[
        TypeSystem`PackageScope`ColumnShape[
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`RowShape[
           Association[
           "Age" -> TypeSystem`PackageScope`AtomShape[34], "Logistics" -> 
            TypeSystem`PackageScope`AtomShape[486.], "Temp" -> 
            TypeSystem`PackageScope`AtomShape[60], "InsulinDependentDiabetic" -> 
            TypeSystem`PackageScope`AtomShape[27.], "SurveyQuestion1" -> 
            TypeSystem`PackageScope`AtomShape[34]]], 
          DirectedInfinity[1], 5, {All}]], 5, 
        DirectedInfinity[1], {}]], "Type" -> TypeSystem`Vector[
       TypeSystem`Struct[{
        "Age", "Logistics", "Temp", "InsulinDependentDiabetic", 
         "SurveyQuestion1"}, {
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[
          TypeSystem`Enumeration[
          "Admit to Ward for Care", 
           "Immediate Surgical intervention(then Ward / ICU / HCU)"]], 
         TypeSystem`Atom[Real], 
         TypeSystem`Atom[
          TypeSystem`Enumeration["No"]], 
         TypeSystem`Atom[Integer]}], 5], "Path" -> {}, "BaseIndices" -> {}, 
     "DisplayedRowCount" -> 5, "DisplayedColumnCount" -> 5, "DataRowCount" -> 
     5, "DataColumnCount" -> 5, "SortPaths" -> {}, "SortDirections" -> {}, 
     "HiddenItemsMap" -> Null, "UpdateType" -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`$outputID$$, 
    TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
    TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
    DynamicModule[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
        Style[
         Grid[{{
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["Age", 
                  Style[
                  "Age", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "Age"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "Age"}, "ColumnHeader", True], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["Logistics", 
                  Style[
                  "Logistics", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "Logistics"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "Logistics"}, "ColumnHeader", True], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["Temp", 
                  Style[
                  "Temp", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "Temp"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "Temp"}, "ColumnHeader", True], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["InsulinDependentDiabetic", 
                  Style[
                  "InsulinDependentDiabetic", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "InsulinDependentDiabetic"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "InsulinDependentDiabetic"}, "ColumnHeader", True], 
               "Mouse"], ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["SurveyQuestion1", 
                  Style[
                  "SurveyQuestion1", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "SurveyQuestion1"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "SurveyQuestion1"}, "ColumnHeader", True], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}]}, {
            Item[
             Pane[
              Annotation[
               RawBoxes["77"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["Age"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
              "Immediate Surgical intervention(then Ward / ICU / HCU)", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["Logistics"]}, "Item", False], "Mouse"], 
              ImageSize -> {{486., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["37.4"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["Temp"]}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["InsulinDependentDiabetic"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["5"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["SurveyQuestion1"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               RawBoxes["64"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["Age"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Admit to Ward for Care", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["Logistics"]}, "Item", False], "Mouse"], 
              ImageSize -> {{486., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["38.0"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["Temp"]}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["InsulinDependentDiabetic"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["1"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["SurveyQuestion1"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               RawBoxes["87"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["Age"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Admit to Ward for Care", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["Logistics"]}, "Item", False], "Mouse"], 
              ImageSize -> {{486., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["38.5"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["Temp"]}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["InsulinDependentDiabetic"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["1"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["SurveyQuestion1"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               RawBoxes["70"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["Age"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Admit to Ward for Care", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["Logistics"]}, "Item", False], "Mouse"], 
              ImageSize -> {{486., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["38.2"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["Temp"]}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["InsulinDependentDiabetic"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["2"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["SurveyQuestion1"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               RawBoxes["85"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["Age"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Admit to Ward for Care", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["Logistics"]}, "Item", False], "Mouse"], 
              ImageSize -> {{486., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["38.1"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["Temp"]}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["InsulinDependentDiabetic"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["3"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["SurveyQuestion1"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}}, 
          BaseStyle -> {
           ContextMenu -> 
            Dynamic[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
              Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                 TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu, True, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger = 
                 TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                 Block[{TypeSystem`NestedGrid`PackagePrivate`$globalScrollPos = \
{TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                   
                   With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Show ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Hide ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic]}]]]]], FontFamily -> 
            "Verdana", FontSize -> 12}, Spacings -> {0, 0}, Alignment -> Left,
           Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
          BaseStyle -> {FontFamily -> "Verdana", FontSize -> 12}], 
         LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> False, 
         ShowAutoStyles -> False]], 
      TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
     Dynamic[
      TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
         Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
         Module[{
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
           TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
           TypeSystem`NestedGrid`PackagePrivate`datasetData[
            TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
             TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
             TypeSystem`NestedGrid`PackagePrivate`renderGrid[
             TypeSystem`NestedGrid`PackagePrivate`$state$$, 
              TypeSystem`NestedGrid`PackagePrivate`$path$$, 
              TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
              TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
             TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
            Not[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
            TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
       TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
       TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
         FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
         TypeSystem`SparseGrid[
          TypeSystem`H["(data no longer present)"]], 
         If[GeneralUtilities`$DebugMode, 
          Row[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid, "  ", 
            TypeSystem`NestedGrid`PackagePrivate`formatState[
            TypeSystem`NestedGrid`PackagePrivate`$state$$, 
             TypeSystem`NestedGrid`PackagePrivate`$path$$, 
             TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
             TypeSystem`NestedGrid`PackagePrivate`$hPos$$]}], 
          TypeSystem`NestedGrid`PackagePrivate`renderedGrid]]], 
      TrackedSymbols :> {
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
     DynamicModuleValues :> {}], 
    TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
     TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
      TypeSystem`PackageScope`SubViewPathbar[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, 
       TypeSystem`NestedGrid`PackagePrivate`updateState[
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$path$$, 
        TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
        TypeSystem`NestedGrid`PackagePrivate`localHold[
        TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
     TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
    TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
     Framed[
      Dynamic[
       Replace[
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
        TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
           Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
           Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
            Blank[]]] :> (
          Increment[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
           TypeSystem`NestedGrid`PackagePrivate`path$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
           TypeSystem`NestedGrid`PackagePrivate`pathType$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
           TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
           TypeSystem`NestedGrid`PackagePrivate`localHold[
            TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
          TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
           TypeSystem`NestedGrid`PackagePrivate`path$, 
            TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
         Spacer[10], Blank[] :> Spacer[10]}], 
       TrackedSymbols :> {
        TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], FrameStyle -> 
      None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> Top, 
      ImageSize -> {Automatic, 15}], FontSize -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
    DynamicWrapperBox[
     DynamicBox[ToBoxes[
       Dataset`DatasetContent[
       2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
        "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], "State" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], "VPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], "HPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], "TopBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], "BottomBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
        Hold[
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
      ImageSizeCache->{780., {89.8837890625, 97.1162109375}},
      TrackedSymbols:>{
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
     TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
     MouseAnnotation[],
     ImageSizeCache->{780., {89.8837890625, 97.1162109375}}],
    BaseStyle->{LineBreakWithin -> False},
    DynamicModuleValues:>{},
    Initialization:>
     Block[{$ContextPath = $ContextPath}, Needs["TypeSystem`"]; 
      Needs["Dataset`"]; 
      TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = CreateUUID[]],
    UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Dataset`InterpretDataset[1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 PageWidth:>800,
 CellChangeTimes->{3.7528951691764917`*^9, 3.812308765762691*^9},
 CellLabel->"Out[5]=",
 CellID->1377014442,ExpressionUUID->"88b59776-4f6e-4875-a10b-5321a48aa193"]
}, Open  ]],

Cell["\<\
Most datasets are too large to view comfortably at once, and so it is useful \
to find their dimensions.\
\>", "Text",
 CellChangeTimes->{{3.7528951847984557`*^9, 3.752895204824868*^9}, 
   3.754221537751274*^9, 3.754221568197318*^9, 3.7542216176472626`*^9, 
   3.754221694748972*^9, {3.754225004775891*^9, 3.754225027807891*^9}, 
   3.80978112254712*^9, {3.815755914253208*^9, 3.8157559292457943`*^9}},
 CellID->37485402,ExpressionUUID->"4d4476bb-09ae-4223-b6cc-775cd971ffb9"],

Cell["\<\
Determine the number of rows and columns in the Dataset object:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7542250358308907`*^9, 3.7542250444058905`*^9}},
 CellID->227762743,ExpressionUUID->"c997e725-c80d-4348-837f-22e877eff77b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "data", "]"}]], "Input",
 CellChangeTimes->{{3.7528952332098045`*^9, 3.7528952376501856`*^9}},
 CellLabel->"In[6]:=",
 CellID->54482967,ExpressionUUID->"860642e5-d780-4ede-a27c-4abaa7cc1d8b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"597", ",", "5"}], "}"}]], "Output",
 CellChangeTimes->{3.7528952379469833`*^9, 3.8123087658402443`*^9},
 CellLabel->"Out[6]=",
 CellID->50462975,ExpressionUUID->"482059e3-751b-4135-84cd-eedee426d825"]
}, Open  ]],

Cell["\<\
Note that there are 597 rows of data representing the data point values \
collected for 597 subjects and that these data point values represent eight \
variables.\
\>", "Text",
 CellChangeTimes->{{3.752895255595049*^9, 3.752895269312453*^9}, 
   3.754221537775276*^9, 3.75422156821632*^9, 3.7542216176662645`*^9, {
   3.754221697445242*^9, 3.754221697636261*^9}, {3.754225124473891*^9, 
   3.754225135544891*^9}, {3.763996968973484*^9, 3.763996971961626*^9}},
 CellID->145583533,ExpressionUUID->"390b52e2-fe0c-4732-8f8b-67351eb12cea"],

Cell[TextData[{
 "The column headers are each appropriately named for a variable. We have ",
 StyleBox["Age",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Logistics",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Temp",
  FontSlant->"Italic"],
 ", ",
 StyleBox["InsulinDependentDiabetic",
  FontSlant->"Italic"],
 ", ",
 StyleBox["HB",
  FontSlant->"Italic"],
 ", ",
 StyleBox["TreatmentGroup",
  FontSlant->"Italic"],
 ", ",
 StyleBox["SurveyQuestion1",
  FontSlant->"Italic"],
 ", and ",
 StyleBox["Improvement",
  FontSlant->"Italic"],
 ". You will note that there are no spaces or other special characters in the \
variable names. This was done intentionally when the spreadsheet file was \
created and makes it easier when we write Wolfram Language code for analysis. \
It is a good idea to save the names in a similar format when collecting data."
}], "Text",
 CellChangeTimes->{
  3.752895301910675*^9, {3.7528954925028267`*^9, 3.752895502345519*^9}, {
   3.752895556960087*^9, 3.752895575108163*^9}, {3.7542215377872777`*^9, 
   3.7542215378192806`*^9}, {3.754221568226321*^9, 3.754221568254324*^9}, {
   3.754221617677266*^9, 3.754221617706269*^9}, {3.754221700518549*^9, 
   3.7542217099734945`*^9}, {3.754225913786889*^9, 3.754225914106889*^9}, 
   3.763997055153635*^9, 3.809781189290779*^9},
 CellID->365003618,ExpressionUUID->"ff08f653-232e-41be-99fa-d7f8af13211b"],

Cell["\<\
Each row, then, represents the data point values for each of the variables \
entered for a particular participant in the research project. We can take a \
look at the first row of the object to familiarize ourselves with the data. \
The first participant is 77 years of age, was immediately operated on, had a \
temperature of 37.4 degrees Celsius, did not have insulin-dependent diabetes \
mellitus, had an HB value of 9.2, fell in treatment group I, answered the \
value 5 for the first question on a survey given to all participants, and \
showed zero improvement (more on this last column later). We can print this \
to the screen. Remember that the Wolfram Language will transpose this single \
row view into column format for display purposes.\
\>", "Text",
 CellChangeTimes->{{3.7528953330954027`*^9, 3.752895454768481*^9}, {
  3.754221537830282*^9, 3.754221537872286*^9}, {3.754221568266325*^9, 
  3.7542215683033285`*^9}, {3.7542216177182703`*^9, 3.7542216177562733`*^9}, {
  3.7542217150219994`*^9, 3.7542217232228193`*^9}, {3.7542366849846487`*^9, 
  3.7542367177896485`*^9}},
 CellID->279225871,ExpressionUUID->"cd177fd9-0057-4bee-90c6-99e17c0fcf7a"],

Cell["Look at the first row of data:", "CodeCaption",
 CellChangeTimes->{{3.754226447129889*^9, 3.754226450394889*^9}},
 CellID->31689805,ExpressionUUID->"3226ab38-7cef-4ff8-90af-6c251dd15ed5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "\[LeftDoubleBracket]", "1", 
  "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.752895472643278*^9, 3.752895476136759*^9}},
 CellLabel->"In[7]:=",
 CellID->454746449,ExpressionUUID->"203b8180-e7fc-4d40-9b9f-1bb596a1e0eb"],

Cell[BoxData[
 TagBox[
  TagBox[
   DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = 
    Association[
    "InitialData" -> 
     Association[
      "Age" -> 77, "Logistics" -> 
       "Immediate Surgical intervention(then Ward / ICU / HCU)", "Temp" -> 
       37.4, "InsulinDependentDiabetic" -> "No", "SurveyQuestion1" -> 5], 
     "InitialShape" -> TypeSystem`PackageScope`DocumentShape[
       Association[{"Age"} -> 
        TypeSystem`PackageScope`AtomShape[34], {"Logistics"} -> 
        TypeSystem`PackageScope`AtomShape[480.00000000000006`], {"Temp"} -> 
        TypeSystem`PackageScope`AtomShape[60], {"InsulinDependentDiabetic"} -> 
        TypeSystem`PackageScope`AtomShape[28.800000000000004`], {
         "SurveyQuestion1"} -> TypeSystem`PackageScope`AtomShape[34]], 1], 
     "InitialType" -> 
     TypeSystem`Struct[{
       "Age", "Logistics", "Temp", "InsulinDependentDiabetic", 
        "SurveyQuestion1"}, {
        TypeSystem`Atom[Integer], 
        TypeSystem`Atom[String], 
        TypeSystem`Atom[Real], 
        TypeSystem`Atom[String], 
        TypeSystem`Atom[Integer]}], "Meta" -> 
     Association["ID" -> 79800707120046], "RowTarget" -> 20, "ColumnTarget" -> 
     10, "Shape" -> TypeSystem`PackageScope`DocumentShape[
       Association[{"Age"} -> 
        TypeSystem`PackageScope`AtomShape[34], {"Logistics"} -> 
        TypeSystem`PackageScope`AtomShape[480.00000000000006`], {"Temp"} -> 
        TypeSystem`PackageScope`AtomShape[60], {"InsulinDependentDiabetic"} -> 
        TypeSystem`PackageScope`AtomShape[28.800000000000004`], {
         "SurveyQuestion1"} -> TypeSystem`PackageScope`AtomShape[34]], 1], 
     "Type" -> TypeSystem`Struct[{
       "Age", "Logistics", "Temp", "InsulinDependentDiabetic", 
        "SurveyQuestion1"}, {
        TypeSystem`Atom[Integer], 
        TypeSystem`Atom[String], 
        TypeSystem`Atom[Real], 
        TypeSystem`Atom[String], 
        TypeSystem`Atom[Integer]}], "Path" -> {}, "BaseIndices" -> {}, 
     "DisplayedRowCount" -> 20, "DisplayedColumnCount" -> 10, "DataRowCount" -> 
     5, "DataColumnCount" -> 1, "SortPaths" -> {}, "SortDirections" -> {}, 
     "HiddenItemsMap" -> Null, "UpdateType" -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`$outputID$$, 
    TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
    TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
    DynamicModule[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
        Style[
         Grid[{{
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["Age", 
                  Style[
                  "Age", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["Age"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["Age"]}, "ColumnHeader", False], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["77"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["Age"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["Logistics", 
                  Style[
                  "Logistics", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["Logistics"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["Logistics"]}, "ColumnHeader", False], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
              "Immediate Surgical intervention(then Ward / ICU / HCU)", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["Logistics"]}, "Item", False], "Mouse"], 
              ImageSize -> {{480.00000000000006`, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["Temp", 
                  Style[
                  "Temp", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["Temp"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["Temp"]}, "ColumnHeader", False], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["37.4"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["Temp"]}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["InsulinDependentDiabetic", 
                  Style[
                  "InsulinDependentDiabetic", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["InsulinDependentDiabetic"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["InsulinDependentDiabetic"]}, "ColumnHeader", False], 
               "Mouse"], ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["InsulinDependentDiabetic"]}, "Item", False], "Mouse"], 
              ImageSize -> {{28.800000000000004`, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["SurveyQuestion1", 
                  Style[
                  "SurveyQuestion1", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["SurveyQuestion1"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["SurveyQuestion1"]}, "ColumnHeader", False], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["5"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["SurveyQuestion1"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}}, 
          BaseStyle -> {
           ContextMenu -> 
            Dynamic[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
              Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                 TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu, True, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger = 
                 TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                 Block[{TypeSystem`NestedGrid`PackagePrivate`$globalScrollPos = \
{TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                   
                   With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Show ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Hide ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic]}]]]]], FontFamily -> 
            "Verdana", FontSize -> 12}, Spacings -> {0, 0}, Alignment -> Left,
           Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
          BaseStyle -> {FontFamily -> "Verdana", FontSize -> 12}], 
         LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> False, 
         ShowAutoStyles -> False]], 
      TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
     Dynamic[
      TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
         Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
         Module[{
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
           TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
           TypeSystem`NestedGrid`PackagePrivate`datasetData[
            TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
             TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
             TypeSystem`NestedGrid`PackagePrivate`renderGrid[
             TypeSystem`NestedGrid`PackagePrivate`$state$$, 
              TypeSystem`NestedGrid`PackagePrivate`$path$$, 
              TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
              TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
             TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
            Not[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
            TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
       TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
       TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
         FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
         TypeSystem`SparseGrid[
          TypeSystem`H["(data no longer present)"]], 
         If[GeneralUtilities`$DebugMode, 
          Row[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid, "  ", 
            TypeSystem`NestedGrid`PackagePrivate`formatState[
            TypeSystem`NestedGrid`PackagePrivate`$state$$, 
             TypeSystem`NestedGrid`PackagePrivate`$path$$, 
             TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
             TypeSystem`NestedGrid`PackagePrivate`$hPos$$]}], 
          TypeSystem`NestedGrid`PackagePrivate`renderedGrid]]], 
      TrackedSymbols :> {
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
     DynamicModuleValues :> {}], 
    TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
     TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
      TypeSystem`PackageScope`SubViewPathbar[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, 
       TypeSystem`NestedGrid`PackagePrivate`updateState[
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$path$$, 
        TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
        TypeSystem`NestedGrid`PackagePrivate`localHold[
        TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
     TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
    TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
     Framed[
      Dynamic[
       Replace[
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
        TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
           Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
           Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
            Blank[]]] :> (
          Increment[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
           TypeSystem`NestedGrid`PackagePrivate`path$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
           TypeSystem`NestedGrid`PackagePrivate`pathType$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
           TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
           TypeSystem`NestedGrid`PackagePrivate`localHold[
            TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
          TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
           TypeSystem`NestedGrid`PackagePrivate`path$, 
            TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
         Spacer[10], Blank[] :> Spacer[10]}], 
       TrackedSymbols :> {
        TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], FrameStyle -> 
      None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> Top, 
      ImageSize -> {Automatic, 15}], FontSize -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
    DynamicWrapperBox[
     DynamicBox[ToBoxes[
       Dataset`DatasetContent[
       2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
        "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], "State" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], "VPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], "HPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], "TopBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], "BottomBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
        Hold[
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
      ImageSizeCache->{673., {77.3837890625, 84.6162109375}},
      TrackedSymbols:>{
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
     TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
     MouseAnnotation[],
     ImageSizeCache->{673., {77.3837890625, 84.6162109375}}],
    BaseStyle->{LineBreakWithin -> False},
    DynamicModuleValues:>{},
    Initialization:>
     Block[{$ContextPath = $ContextPath}, Needs["TypeSystem`"]; 
      Needs["Dataset`"]; 
      TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = CreateUUID[]],
    UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Dataset`InterpretDataset[1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 PageWidth:>800,
 CellChangeTimes->{3.7528954768867316`*^9, 3.8123087658664513`*^9},
 CellLabel->"Out[7]=",
 CellID->2022663907,ExpressionUUID->"5b079a3b-ece0-49af-a89f-f8439729ed05"]
}, Open  ]],

Cell[TextData[{
 "This row versus column format is ideal for working with data and analyzing \
it using the Wolfram Language. For the sake of clarity, we will keep to the \
term ",
 StyleBox["variable",
  FontSlant->"Italic"],
 " and call each entry a ",
 StyleBox["data point value",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.752895521350217*^9, 3.7528955430010815`*^9}, 
   3.7542215378832874`*^9, 3.75422156831433*^9, 3.754221617767275*^9, 
   3.754221726255122*^9},
 CellID->134809566,ExpressionUUID->"48673f77-c9cd-477e-9587-8dbebba6a1c0"],

Cell[TextData[{
 "You will notice that all the data point values for the ",
 StyleBox["Age",
  FontSlant->"Italic"],
 " variable are integer values. The data point values for the ",
 StyleBox["Logistics",
  FontSlant->"Italic"],
 " variable are words (strings). There are only a few unique ones, though, \
such as ",
 StyleBox["Admit to Ward for Care",
  FontSlant->"Italic"],
 " and ",
 StyleBox["Immediate Surgical intervention(then Ward",
  FontSlant->"Italic"],
 "/",
 StyleBox["ICU",
  FontSlant->"Italic"],
 "/",
 StyleBox["HCU)",
  FontSlant->"Italic"],
 ". We can all agree that numbers and words are different types of data."
}], "Text",
 CellChangeTimes->{{3.752895605455886*^9, 3.752895628656494*^9}, {
   3.752895697352249*^9, 3.752895727671675*^9}, {3.7542215379032893`*^9, 
   3.754221537923291*^9}, {3.754221568330332*^9, 3.754221568349334*^9}, {
   3.7542216177832766`*^9, 3.7542216178022785`*^9}, {3.754221729063403*^9, 
   3.7542217374872456`*^9}, {3.809781230966764*^9, 3.809781239262401*^9}, 
   3.812373857438836*^9},
 CellID->401584441,ExpressionUUID->"0e45ff64-2ef0-4835-a8ae-b5e76dd45e77"],

Cell[TextData[{
 "If we have words (strings) as data point values, we can count the number of \
each specific entry. The ",
 ButtonBox["Counts",
  BaseStyle->"Link"],
 " function will count the number of unique entries found in the specified \
column, regardless of text or value."
}], "Text",
 CellChangeTimes->{
  3.752895701732217*^9, {3.752895744509923*^9, 3.7528957955691023`*^9}, {
   3.7528958322946167`*^9, 3.752895833179553*^9}, 3.7542215379342923`*^9, 
   3.7542215683603344`*^9, 3.754221617812279*^9, 3.754221742951792*^9, {
   3.7542268990447855`*^9, 3.754226908604741*^9}, {3.812373915190604*^9, 
   3.812373940912445*^9}},
 CellID->251966793,ExpressionUUID->"fa7e6341-c74f-4222-8164-3b7f4dad2a75"],

Cell[TextData[{
 "Count the number of unique entries found in the ",
 StyleBox["Logistics",
  FontSlant->"Italic"],
 " column:"
}], "CodeCaption",
 CellChangeTimes->{{3.754226915125393*^9, 3.754226927276608*^9}},
 CellID->584868914,ExpressionUUID->"10d35054-ca50-4c5b-ad59-04d22365ec54"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"Counts", ",", "\"\<Logistics\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.7528958137516575`*^9, 3.7528958204741073`*^9}},
 CellLabel->"In[8]:=",
 CellID->72281429,ExpressionUUID->"326f2f64-ab7f-422c-8514-39b0f9b7523c"],

Cell[BoxData[
 TagBox[
  TagBox[
   DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = 
    Association[
    "InitialData" -> 
     Association[
      "Immediate Surgical intervention(then Ward / ICU / HCU)" -> 98, 
       "Admit to Ward for Care" -> 362, "Admit to ICU / HCU for Care" -> 26, 
       "Consultation only (leave in original ward)" -> 111], "InitialShape" -> 
     TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`ColumnShape[
        TypeSystem`PackageScope`KeyValueShape[
         TypeSystem`PackageScope`AtomShape[486.], 
         TypeSystem`PackageScope`AtomShape[34]]], 4, 
       DirectedInfinity[1], {}], "InitialType" -> TypeSystem`Assoc[
       TypeSystem`Atom[
        TypeSystem`Enumeration[
        "Admit to ICU / HCU for Care", "Admit to Ward for Care", 
         "Consultation only (leave in original ward)", 
         "Immediate Surgical intervention(then Ward / ICU / HCU)"]], 
       TypeSystem`Atom[Integer], 4], "Meta" -> 
     Association["ID" -> 79805002087342], "RowTarget" -> 20, "ColumnTarget" -> 
     10, "Shape" -> TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`ColumnShape[
        TypeSystem`PackageScope`KeyValueShape[
         TypeSystem`PackageScope`AtomShape[486.], 
         TypeSystem`PackageScope`AtomShape[34]]], 4, 
       DirectedInfinity[1], {}], "Type" -> TypeSystem`Assoc[
       TypeSystem`Atom[
        TypeSystem`Enumeration[
        "Admit to ICU / HCU for Care", "Admit to Ward for Care", 
         "Consultation only (leave in original ward)", 
         "Immediate Surgical intervention(then Ward / ICU / HCU)"]], 
       TypeSystem`Atom[Integer], 4], "Path" -> {}, "BaseIndices" -> {}, 
     "DisplayedRowCount" -> 4, "DisplayedColumnCount" -> 1, "DataRowCount" -> 
     4, "DataColumnCount" -> 1, "SortPaths" -> {}, "SortDirections" -> {}, 
     "HiddenItemsMap" -> Null, "UpdateType" -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`$outputID$$, 
    TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
    TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
    DynamicModule[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
        Style[
         Grid[{{
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover[
                 "Immediate Surgical intervention(then Ward / ICU / HCU)", 
                  Style[
                  "Immediate Surgical intervention(then Ward / ICU / HCU)", 
                   FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key[
                   "Immediate Surgical intervention(then Ward / ICU / HCU)"]},
                   1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key[
                 "Immediate Surgical intervention(then Ward / ICU / HCU)"]}, 
                "RowHeader", False], "Mouse"], 
              ImageSize -> {{486., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["98"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key[
                 "Immediate Surgical intervention(then Ward / ICU / HCU)"]}, 
                "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["Admit to Ward for Care", 
                  Style[
                  "Admit to Ward for Care", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["Admit to Ward for Care"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["Admit to Ward for Care"]}, "RowHeader", False], 
               "Mouse"], ImageSize -> {{486., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["362"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["Admit to Ward for Care"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["Admit to ICU / HCU for Care", 
                  Style[
                  "Admit to ICU / HCU for Care", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["Admit to ICU / HCU for Care"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["Admit to ICU / HCU for Care"]}, "RowHeader", False], 
               "Mouse"], ImageSize -> {{486., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["26"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["Admit to ICU / HCU for Care"]}, "Item", False], 
               "Mouse"], ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["Consultation only (leave in original ward)", 
                  Style[
                  "Consultation only (leave in original ward)", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["Consultation only (leave in original ward)"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["Consultation only (leave in original ward)"]}, 
                "RowHeader", False], "Mouse"], 
              ImageSize -> {{486., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["111"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["Consultation only (leave in original ward)"]}, "Item", 
                False], "Mouse"], ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}}, 
          BaseStyle -> {
           ContextMenu -> 
            Dynamic[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
              Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                 TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu, True, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger = 
                 TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                 Block[{TypeSystem`NestedGrid`PackagePrivate`$globalScrollPos = \
{TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                   
                   With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Show ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Hide ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic]}]]]]], FontFamily -> 
            "Verdana", FontSize -> 12}, Spacings -> {0, 0}, Alignment -> Left,
           Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
          BaseStyle -> {FontFamily -> "Verdana", FontSize -> 12}], 
         LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> False, 
         ShowAutoStyles -> False]], 
      TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
     Dynamic[
      TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
         Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
         Module[{
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
           TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
           TypeSystem`NestedGrid`PackagePrivate`datasetData[
            TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
             TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
             TypeSystem`NestedGrid`PackagePrivate`renderGrid[
             TypeSystem`NestedGrid`PackagePrivate`$state$$, 
              TypeSystem`NestedGrid`PackagePrivate`$path$$, 
              TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
              TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
             TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
            Not[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
            TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
       TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
       TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
         FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
         TypeSystem`SparseGrid[
          TypeSystem`H["(data no longer present)"]], 
         If[GeneralUtilities`$DebugMode, 
          Row[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid, "  ", 
            TypeSystem`NestedGrid`PackagePrivate`formatState[
            TypeSystem`NestedGrid`PackagePrivate`$state$$, 
             TypeSystem`NestedGrid`PackagePrivate`$path$$, 
             TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
             TypeSystem`NestedGrid`PackagePrivate`$hPos$$]}], 
          TypeSystem`NestedGrid`PackagePrivate`renderedGrid]]], 
      TrackedSymbols :> {
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
     DynamicModuleValues :> {}], 
    TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
     TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
      TypeSystem`PackageScope`SubViewPathbar[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, 
       TypeSystem`NestedGrid`PackagePrivate`updateState[
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$path$$, 
        TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
        TypeSystem`NestedGrid`PackagePrivate`localHold[
        TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
     TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
    TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
     Framed[
      Dynamic[
       Replace[
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
        TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
           Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
           Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
            Blank[]]] :> (
          Increment[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
           TypeSystem`NestedGrid`PackagePrivate`path$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
           TypeSystem`NestedGrid`PackagePrivate`pathType$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
           TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
           TypeSystem`NestedGrid`PackagePrivate`localHold[
            TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
          TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
           TypeSystem`NestedGrid`PackagePrivate`path$, 
            TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
         Spacer[10], Blank[] :> Spacer[10]}], 
       TrackedSymbols :> {
        TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], FrameStyle -> 
      None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> Top, 
      ImageSize -> {Automatic, 15}], FontSize -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
    DynamicWrapperBox[
     DynamicBox[ToBoxes[
       Dataset`DatasetContent[
       2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
        "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], "State" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], "VPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], "HPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], "TopBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], "BottomBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
        Hold[
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
      ImageSizeCache->{557., {64.8837890625, 72.1162109375}},
      TrackedSymbols:>{
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
     TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
     MouseAnnotation[],
     ImageSizeCache->{557., {64.8837890625, 72.1162109375}}],
    BaseStyle->{LineBreakWithin -> False},
    DynamicModuleValues:>{},
    Initialization:>
     Block[{$ContextPath = $ContextPath}, Needs["TypeSystem`"]; 
      Needs["Dataset`"]; 
      TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = CreateUUID[]],
    UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Dataset`InterpretDataset[1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.7528958209119706`*^9, 3.8123087659468403`*^9},
 CellLabel->"Out[8]=",
 CellID->1680082457,ExpressionUUID->"009aafec-5c23-4fd1-a616-8095c5b69ba1"]
}, Open  ]],

Cell[TextData[{
 "In this instance, we note that there are four unique data point values for \
the ",
 StyleBox["Logistics",
  FontSlant->"Italic"],
 " variable, and we can see how many times each occurs in the Dataset object. \
This is referred to as the frequency of each unique data point value."
}], "Text",
 CellChangeTimes->{{3.752895836596735*^9, 3.7528958986099463`*^9}, 
   3.754221537946294*^9, 3.7542215683703356`*^9, 3.7542216178232803`*^9, 
   3.754221745999097*^9, {3.7542270049203715`*^9, 3.754227014353315*^9}, 
   3.809781406094226*^9},
 CellID->79074759,ExpressionUUID->"c160b39b-c82a-4be6-917e-91a0505fa00c"],

Cell[TextData[{
 "The sample space of the variable is a set of all possible values within \
that variable. The sample space for ",
 StyleBox["Age",
  FontSlant->"Italic"],
 ", for instance, will be integer values between and including the minimum \
and maximum values. The specific age value for each subject is drawn from \
that sample space. In this case, for our data, age is represented as whole \
numbers above 0."
}], "Text",
 CellChangeTimes->{{3.752895925729761*^9, 3.7528959483328524`*^9}, {
   3.754221537961295*^9, 3.7542215379792967`*^9}, {3.7542215683803368`*^9, 
   3.754221568395338*^9}, {3.7542216178332815`*^9, 3.754221617848283*^9}, {
   3.7542217487683735`*^9, 3.7542217520156984`*^9}, {3.7542270282337027`*^9, 
   3.7542270426591454`*^9}, {3.754237247680649*^9, 3.7542372648636484`*^9}, 
   3.809781425217609*^9, {3.809781474101903*^9, 3.809781474617093*^9}},
 CellID->101800540,ExpressionUUID->"982d2149-85cf-40d2-bbb5-92161a6e77a4"],

Cell[TextData[{
 "Pass two functions to the ",
 Cell[BoxData["data"], "InlineCode",
  ShowStringCharacters->False,ExpressionUUID->
  "80bc2487-161d-4657-9c93-820b132fdf3c"],
 " computer variable:"
}], "CodeCaption",
 CellChangeTimes->{{3.7542270592348022`*^9, 3.754227071099989*^9}, 
   3.7542372741506486`*^9, 3.7542373948946486`*^9},
 CellID->653032168,ExpressionUUID->"40c4064c-8fe1-405a-8396-f075342c83eb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Min", ",", "Max"}], "}"}], ",", "\"\<Age\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.7528960234920483`*^9, 3.752896035774826*^9}},
 CellLabel->"In[9]:=",
 CellID->619799585,ExpressionUUID->"7e1b430a-e1c5-4b6a-b0c1-18b0beaf8e06"],

Cell[BoxData[
 TagBox[
  TagBox[
   DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = 
    Association[
    "InitialData" -> {18, 90}, "InitialShape" -> 
     TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`ColumnShape[
        TypeSystem`PackageScope`AtomShape[34]], 2, 
       DirectedInfinity[1], {}], "InitialType" -> TypeSystem`Vector[
       TypeSystem`Atom[Integer], 2], "Meta" -> 
     Association["ID" -> 79809297054638], "RowTarget" -> 20, "ColumnTarget" -> 
     10, "Shape" -> TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`ColumnShape[
        TypeSystem`PackageScope`AtomShape[34]], 2, 
       DirectedInfinity[1], {}], "Type" -> TypeSystem`Vector[
       TypeSystem`Atom[Integer], 2], "Path" -> {}, "BaseIndices" -> {}, 
     "DisplayedRowCount" -> 2, "DisplayedColumnCount" -> 1, "DataRowCount" -> 
     2, "DataColumnCount" -> 1, "SortPaths" -> {}, "SortDirections" -> {}, 
     "HiddenItemsMap" -> Null, "UpdateType" -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`$outputID$$, 
    TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
    TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
    DynamicModule[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
        Style[
         Grid[{{
            Item[
             Pane[
              Annotation[
               RawBoxes["18"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1}, 
                "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               RawBoxes["90"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2}, 
                "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}}, 
          BaseStyle -> {
           ContextMenu -> 
            Dynamic[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
              Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                 TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu, True, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger = 
                 TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                 Block[{TypeSystem`NestedGrid`PackagePrivate`$globalScrollPos = \
{TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                   
                   With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Show ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Hide ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic]}]]]]], FontFamily -> 
            "Verdana", FontSize -> 12}, Spacings -> {0, 0}, Alignment -> Left,
           Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
          BaseStyle -> {FontFamily -> "Verdana", FontSize -> 12}], 
         LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> False, 
         ShowAutoStyles -> False]], 
      TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
     Dynamic[
      TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
         Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
         Module[{
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
           TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
           TypeSystem`NestedGrid`PackagePrivate`datasetData[
            TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
             TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
             TypeSystem`NestedGrid`PackagePrivate`renderGrid[
             TypeSystem`NestedGrid`PackagePrivate`$state$$, 
              TypeSystem`NestedGrid`PackagePrivate`$path$$, 
              TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
              TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
             TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
            Not[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
            TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
       TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
       TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
         FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
         TypeSystem`SparseGrid[
          TypeSystem`H["(data no longer present)"]], 
         If[GeneralUtilities`$DebugMode, 
          Row[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid, "  ", 
            TypeSystem`NestedGrid`PackagePrivate`formatState[
            TypeSystem`NestedGrid`PackagePrivate`$state$$, 
             TypeSystem`NestedGrid`PackagePrivate`$path$$, 
             TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
             TypeSystem`NestedGrid`PackagePrivate`$hPos$$]}], 
          TypeSystem`NestedGrid`PackagePrivate`renderedGrid]]], 
      TrackedSymbols :> {
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
     DynamicModuleValues :> {}], 
    TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
     TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
      TypeSystem`PackageScope`SubViewPathbar[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, 
       TypeSystem`NestedGrid`PackagePrivate`updateState[
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$path$$, 
        TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
        TypeSystem`NestedGrid`PackagePrivate`localHold[
        TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
     TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
    TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
     Framed[
      Dynamic[
       Replace[
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
        TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
           Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
           Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
            Blank[]]] :> (
          Increment[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
           TypeSystem`NestedGrid`PackagePrivate`path$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
           TypeSystem`NestedGrid`PackagePrivate`pathType$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
           TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
           TypeSystem`NestedGrid`PackagePrivate`localHold[
            TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
          TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
           TypeSystem`NestedGrid`PackagePrivate`path$, 
            TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
         Spacer[10], Blank[] :> Spacer[10]}], 
       TrackedSymbols :> {
        TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], FrameStyle -> 
      None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> Top, 
      ImageSize -> {Automatic, 15}], FontSize -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
    DynamicWrapperBox[
     DynamicBox[ToBoxes[
       Dataset`DatasetContent[
       2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
        "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], "State" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], "VPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], "HPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], "TopBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], "BottomBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
        Hold[
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
      ImageSizeCache->{63., {39.8837890625, 47.1162109375}},
      TrackedSymbols:>{
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
     TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
     MouseAnnotation[],
     ImageSizeCache->{63., {39.8837890625, 47.1162109375}}],
    BaseStyle->{LineBreakWithin -> False},
    DynamicModuleValues:>{},
    Initialization:>
     Block[{$ContextPath = $ContextPath}, Needs["TypeSystem`"]; 
      Needs["Dataset`"]; 
      TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = CreateUUID[]],
    UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Dataset`InterpretDataset[1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.7528960361185155`*^9, 3.8123087660245237`*^9},
 CellLabel->"Out[9]=",
 CellID->506179199,ExpressionUUID->"f2723797-0792-4595-b4b4-43bae757ea40"]
}, Open  ]],

Cell[TextData[{
 "This code expresses the minimum (",
 ButtonBox["Min",
  BaseStyle->"Link"],
 ") and maximum (",
 ButtonBox["Max",
  BaseStyle->"Link"],
 ") values for the ",
 StyleBox["Age",
  FontSlant->"Italic"],
 " column."
}], "Text",
 CellChangeTimes->{{3.754227084852364*^9, 3.754227175856886*^9}},
 CellID->627195121,ExpressionUUID->"4ab94045-d6f5-4c2c-aa8f-1ebb778ab706"],

Cell[TextData[{
 "The important thing to note in the code above is the fact that the type of \
data point values that exist for a variable are different. The ",
 StyleBox["Logistics",
  FontSlant->"Italic"],
 " column has strings (called categories) in its sample space and the ",
 StyleBox["Age",
  FontSlant->"Italic"],
 " column has integers (called numerical values) in its sample space."
}], "Text",
 CellChangeTimes->{{3.7528960587554693`*^9, 3.752896083314051*^9}, 
   3.754221537989298*^9, 3.7542215684053392`*^9, 3.754221617858284*^9, 
   3.754221757975294*^9, 3.7542273669078856`*^9, {3.7542374619051266`*^9, 
   3.7542374727442102`*^9}},
 CellID->755378940,ExpressionUUID->"6c1e08b0-a557-484a-bf39-9850a8122b87"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data Types", "Subsection",
 CellChangeTimes->{{3.752896091561369*^9, 3.7528960937022247`*^9}, {
  3.754227406271886*^9, 3.7542274069448853`*^9}},
 CellID->247485778,ExpressionUUID->"37ff3390-a654-47e2-a69b-79446299d4af"],

Cell[TextData[{
 "As mentioned, you will have noticed that all of the data point values for a \
variable are similar. We had words and numbers. Each of these have a type \
name. This allows us a classification system for variables. Our example of \
integers and strings allows us our first classification of data types, namely \
",
 StyleBox["numerical",
  FontSlant->"Italic"],
 " and ",
 StyleBox["categorical",
  FontSlant->"Italic"],
 " data types."
}], "Text",
 CellChangeTimes->{{3.7528961254297576`*^9, 3.7528961468743916`*^9}, {
  3.754221538018301*^9, 3.7542215380573044`*^9}, {3.75422156841534*^9, 
  3.7542215684533443`*^9}, {3.754221617869285*^9, 3.754221617906289*^9}, {
  3.7542217611836147`*^9, 3.7542217722087173`*^9}, {3.7542376018791227`*^9, 
  3.754237623040239*^9}},
 CellID->703976491,ExpressionUUID->"6f55ddd8-1094-428d-ba15-47a4e9e68f3d"],

Cell[CellGroupData[{

Cell["Numerical Data Types", "Subsubsection",
 CellChangeTimes->{{3.7528961785839386`*^9, 3.752896182613978*^9}, {
  3.7542274090648856`*^9, 3.7542274111838856`*^9}},
 CellID->505708953,ExpressionUUID->"235cb9d5-0f7f-4e17-9ef7-6730651f18fb"],

Cell[TextData[{
 "As the term implies, a numerical data type consists of numbers. If we \
consider the ",
 StyleBox["Age",
  FontSlant->"Italic"],
 " variable, its data point values are indeed numbers and the variable can be \
classified as numerical."
}], "Text",
 CellChangeTimes->{
  3.7528962097548475`*^9, 3.7542215380663056`*^9, 3.7542215684633446`*^9, 
   3.75422161791529*^9, 3.754221774895986*^9, {3.7542274403038855`*^9, 
   3.7542274410068855`*^9}},
 CellID->201367951,ExpressionUUID->"5176f5be-429d-4a15-8ec0-e27b1a8a3943"],

Cell["\<\
Here is another example of a numerical variable that shows the minimum and \
maximum temperature values:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7542274780918856`*^9, 3.7542275064268856`*^9}},
 CellID->163231021,ExpressionUUID->"342b5092-99cc-4cc0-be34-53ee4e5f8042"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Min", ",", "Max"}], "}"}], ",", "\"\<Temp\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.752896263577613*^9, 3.752896294585278*^9}},
 CellLabel->"In[10]:=",
 CellID->189537907,ExpressionUUID->"8fdd5bfb-f74c-40d8-91b4-bb5c25acb31a"],

Cell[BoxData[
 TagBox[
  TagBox[
   DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = 
    Association[
    "InitialData" -> {35.8, 39.9}, "InitialShape" -> 
     TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`ColumnShape[
        TypeSystem`PackageScope`AtomShape[60]], 2, 
       DirectedInfinity[1], {}], "InitialType" -> TypeSystem`Vector[
       TypeSystem`Atom[Real], 2], "Meta" -> 
     Association["ID" -> 79813592021934], "RowTarget" -> 20, "ColumnTarget" -> 
     10, "Shape" -> TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`ColumnShape[
        TypeSystem`PackageScope`AtomShape[60]], 2, 
       DirectedInfinity[1], {}], "Type" -> TypeSystem`Vector[
       TypeSystem`Atom[Real], 2], "Path" -> {}, "BaseIndices" -> {}, 
     "DisplayedRowCount" -> 2, "DisplayedColumnCount" -> 1, "DataRowCount" -> 
     2, "DataColumnCount" -> 1, "SortPaths" -> {}, "SortDirections" -> {}, 
     "HiddenItemsMap" -> Null, "UpdateType" -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`$outputID$$, 
    TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
    TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
    DynamicModule[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
        Style[
         Grid[{{
            Item[
             Pane[
              Annotation[
               RawBoxes["35.8"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1}, 
                "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               RawBoxes["39.9"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2}, 
                "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}}, 
          BaseStyle -> {
           ContextMenu -> 
            Dynamic[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
              Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                 TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu, True, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger = 
                 TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                 Block[{TypeSystem`NestedGrid`PackagePrivate`$globalScrollPos = \
{TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                   
                   With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Show ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Hide ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic]}]]]]], FontFamily -> 
            "Verdana", FontSize -> 12}, Spacings -> {0, 0}, Alignment -> Left,
           Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
          BaseStyle -> {FontFamily -> "Verdana", FontSize -> 12}], 
         LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> False, 
         ShowAutoStyles -> False]], 
      TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
     Dynamic[
      TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
         Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
         Module[{
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
           TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
           TypeSystem`NestedGrid`PackagePrivate`datasetData[
            TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
             TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
             TypeSystem`NestedGrid`PackagePrivate`renderGrid[
             TypeSystem`NestedGrid`PackagePrivate`$state$$, 
              TypeSystem`NestedGrid`PackagePrivate`$path$$, 
              TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
              TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
             TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
            Not[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
            TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
       TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
       TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
         FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
         TypeSystem`SparseGrid[
          TypeSystem`H["(data no longer present)"]], 
         If[GeneralUtilities`$DebugMode, 
          Row[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid, "  ", 
            TypeSystem`NestedGrid`PackagePrivate`formatState[
            TypeSystem`NestedGrid`PackagePrivate`$state$$, 
             TypeSystem`NestedGrid`PackagePrivate`$path$$, 
             TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
             TypeSystem`NestedGrid`PackagePrivate`$hPos$$]}], 
          TypeSystem`NestedGrid`PackagePrivate`renderedGrid]]], 
      TrackedSymbols :> {
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
     DynamicModuleValues :> {}], 
    TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
     TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
      TypeSystem`PackageScope`SubViewPathbar[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, 
       TypeSystem`NestedGrid`PackagePrivate`updateState[
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$path$$, 
        TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
        TypeSystem`NestedGrid`PackagePrivate`localHold[
        TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
     TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
    TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
     Framed[
      Dynamic[
       Replace[
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
        TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
           Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
           Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
            Blank[]]] :> (
          Increment[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
           TypeSystem`NestedGrid`PackagePrivate`path$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
           TypeSystem`NestedGrid`PackagePrivate`pathType$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
           TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
           TypeSystem`NestedGrid`PackagePrivate`localHold[
            TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
          TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
           TypeSystem`NestedGrid`PackagePrivate`path$, 
            TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
         Spacer[10], Blank[] :> Spacer[10]}], 
       TrackedSymbols :> {
        TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], FrameStyle -> 
      None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> Top, 
      ImageSize -> {Automatic, 15}], FontSize -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
    DynamicWrapperBox[
     DynamicBox[ToBoxes[
       Dataset`DatasetContent[
       2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
        "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], "State" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], "VPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], "HPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], "TopBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], "BottomBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
        Hold[
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
      ImageSizeCache->{89., {39.8837890625, 47.1162109375}},
      TrackedSymbols:>{
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
     TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
     MouseAnnotation[],
     ImageSizeCache->{89., {39.8837890625, 47.1162109375}}],
    BaseStyle->{LineBreakWithin -> False},
    DynamicModuleValues:>{},
    Initialization:>
     Block[{$ContextPath = $ContextPath}, Needs["TypeSystem`"]; 
      Needs["Dataset`"]; 
      TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = CreateUUID[]],
    UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Dataset`InterpretDataset[1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.7528962951964397`*^9, 3.81230876608983*^9},
 CellLabel->"Out[10]=",
 CellID->516554827,ExpressionUUID->"5a7e3fc6-79a6-4b85-a17c-c06b0ae3ad0d"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["Temp",
  FontSlant->"Italic"],
 " variable is also numerical, but there is a difference, though. Consider \
the age value of zero. It certainly exists and refers to birth or the first \
year of life. A patient who is 40 years old is twice as old as one who is 20 \
years old. The same cannot be said for a temperature measured in degrees \
Celsius or Fahrenheit. Neither contain a true zero. We might say that it is 0\
\[Degree]C or 0\[Degree]F outside, but true zero only exists for the Kelvin \
scale. Whereas an age of zero refers to the absence of age, a temperature of \
0\[Degree]C or 0\[Degree]F does not infer the absence of temperature. This \
means that we cannot say that a temperature of 80\[Degree]C is twice as warm \
as 40\[Degree]F."
}], "Text",
 CellChangeTimes->{{3.7528963093604984`*^9, 3.7528964277285423`*^9}, {
   3.754221538080307*^9, 3.754221538184317*^9}, {3.754221568474346*^9, 
   3.7542215685773563`*^9}, {3.754221617927291*^9, 3.754221618028301*^9}, {
   3.7542217780583024`*^9, 3.7542218047139673`*^9}, {3.754227565606886*^9, 
   3.7542275667108855`*^9}, {3.7542276599938855`*^9, 3.7542276719688854`*^9}, 
   3.7542277046548853`*^9, {3.754227801061886*^9, 3.754227821733886*^9}, {
   3.7542280770038853`*^9, 3.7542280850038853`*^9}, {3.7542281179538856`*^9, 
   3.7542281605198855`*^9}, {3.7542284982108855`*^9, 
   3.7542285124208856`*^9}, {3.7542286295008855`*^9, 
   3.7542286315918856`*^9}, {3.7542286793398857`*^9, 3.7542286796268854`*^9}},
 CellID->44059808,ExpressionUUID->"69c78d6e-4164-4e6c-be96-e3799993083f"],

Cell[TextData[{
 "Temperature is therefore classified as ",
 StyleBox["interval-type",
  FontSlant->"Italic"],
 " numerical data and age would be an example of ",
 StyleBox["ratio-type",
  FontSlant->"Italic"],
 " numerical data. The majority of numerical data types that you will come \
across will be ratio-type, and it is common to simply refer to the term ",
 StyleBox["numerical data",
  FontSlant->"Italic"],
 " when dealing with numbers."
}], "Text",
 CellChangeTimes->{3.7528964510988607`*^9, 3.7542215381933184`*^9, 
  3.7542215685873575`*^9, 3.754221618038302*^9, 3.7542218085303493`*^9, 
  3.7542281863818855`*^9},
 CellID->27610436,ExpressionUUID->"72c81c9d-5006-49f7-aaf8-d7904aba9ec5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Categorical Data Types", "Subsubsection",
 CellChangeTimes->{{3.752896460396988*^9, 3.7528964688532543`*^9}, {
  3.7542288087178855`*^9, 3.754228810455886*^9}},
 CellID->604861761,ExpressionUUID->"0d32cea3-7bde-4d6e-9ecb-92ca105fcb97"],

Cell[TextData[{
 "The ",
 StyleBox["Logistics",
  FontSlant->"Italic"],
 " variable is an example of a categorical data type. The data point values \
are words. Note also that we cannot put these in any proper order. Think of \
variables such as ",
 StyleBox["Organism",
  FontSlant->"Italic"],
 ",",
 StyleBox[" Breed (of Animal)",
  FontSlant->"Italic"],
 ",",
 StyleBox[" Soil Type",
  FontSlant->"Italic"],
 ", etc., for which the data point values are drawn from a sample space that \
is usually expressed as words or characters. Other than by some form of \
mental interpretation, we cannot put the data point values for these \
variables in an order as we can do with numbers. We might order them \
alphabetically, by size of the breed, or by other means, but for statistical \
purposes, they cannot be ordered. The term for this data type is",
 StyleBox[" nominal",
  FontSlant->"Italic"],
 " categorical."
}], "Text",
 CellChangeTimes->{{3.752896481294771*^9, 3.7528965309929895`*^9}, {
   3.7542215382073193`*^9, 3.754221538252324*^9}, {3.7542215685973587`*^9, 
   3.754221568643363*^9}, {3.7542216180483027`*^9, 3.7542216180953074`*^9}, {
   3.754221811329629*^9, 3.754221825459042*^9}, {3.7542288296478853`*^9, 
   3.7542288303838854`*^9}, {3.7542302461735573`*^9, 3.7542302625841985`*^9}, 
   3.815756087445709*^9},
 CellID->241490288,ExpressionUUID->"36f23643-cda4-4bfc-a724-dbda0776a0ce"],

Cell[TextData[{
 "The ",
 StyleBox["Improvement",
  FontSlant->"Italic"],
 " column\[CloseCurlyQuote]s data point values are commonly seen in data \
files, where categorical variables as expressed as numbers. Researchers may \
choose to enter numbers as placeholders for actual data point values. In this \
example, 0 might refer to ",
 StyleBox["no improvement",
  FontSlant->"Italic"],
 " and 1 might refer to ",
 StyleBox["improvement",
  FontSlant->"Italic"],
 ". It is important to know the meaning of the data point values when doing \
statistical analysis. In the code below, we express the unique data point \
values that make up the sample space of the ",
 StyleBox["Improvement",
  FontSlant->"Italic"],
 " variable and count how many times each appears. It is important to clearly \
understand that the variable type is not numerical."
}], "Text",
 CellChangeTimes->{{3.7528965477964163`*^9, 3.7528965653333864`*^9}, {
  3.7542215382623253`*^9, 3.754221538302329*^9}, {3.754221568654364*^9, 
  3.754221568694368*^9}, {3.754221618106309*^9, 3.7542216181453123`*^9}, {
  3.754221828292325*^9, 3.754221840661562*^9}, {3.754230319331873*^9, 
  3.754230348067746*^9}},
 CellID->76674588,ExpressionUUID->"7ca1a9c9-d51d-4c6e-a369-3a8f1a8c807f"],

Cell[TextData[{
 "Express the unique data point values in the ",
 StyleBox["Improvement",
  FontSlant->"Italic"],
 " column and their counts:"
}], "CodeCaption",
 CellChangeTimes->{{3.754230363250264*^9, 3.7542303734822874`*^9}},
 CellID->18059349,ExpressionUUID->"6bcc0739-4e5c-4dfa-acba-4badd2bf160f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"Counts", ",", "\"\<Improvement\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.7528966325589523`*^9, 3.7528966431200542`*^9}},
 CellLabel->"In[11]:=",
 CellID->305991790,ExpressionUUID->"2861f759-352c-40d2-8877-5a07007577ac"],

Cell[BoxData[
 TemplateBox[{
   TagBox[
    DynamicModuleBox[{
     TypeSystem`NestedGrid`PackagePrivate`$state$$ = 
      Data`UnorderedAssociation[
       "DisplayedRowCount" -> 20, "RowCount" -> 2, "Length" -> 2, 
        "InitialType" -> TypeSystem`Assoc[
          TypeSystem`Atom[Integer], 
          TypeSystem`Atom[Integer], 2], "DisplayedColumnCount" -> 20, 
        "DataRowCount" -> 0, "Shape" -> TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`ColumnShape[
           TypeSystem`PackageScope`KeyValueShape[
            TypeSystem`PackageScope`AtomShape[34], 
            TypeSystem`PackageScope`AtomShape[34]]], 2, {}], 
        "DataColumnCount" -> 0, "InitialData" -> 
        TypeSystem`PackageScope`CacheHandle[1881115859], "Type" -> 
        TypeSystem`Assoc[
          TypeSystem`Atom[Integer], 
          TypeSystem`Atom[Integer], 2], "HandleQ" -> True, "Meta" -> {}, 
        "RowTarget" -> 20, "Data" -> 
        TypeSystem`PackageScope`CacheHandle[1881115859]], 
      TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
      TypeSystem`NestedGrid`PackagePrivate`$pos$$ = 1, 
      TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
      DynamicModule[{
        TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
           Style[
            Grid[{{
               Item[
                Pane[
                 Annotation[
                  EventHandler[
                   MouseAppearance[
                    Mouseover[
                    RawBoxes["0"], 
                    Style[
                    RawBoxes["0"], FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                   TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$pos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 113078960][{
                    Key[0]}]], 
                  TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[113078960][
                   GeneralUtilities`Slice[
                    Key[0]]], "Mouse"], ImageSize -> {{34, Full}, Automatic}],
                 Background -> GrayLevel[0.95], 
                Alignment -> {Left, Baseline}], 
               Pane[
                Annotation[
                 RawBoxes["301"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[113078960][
                  GeneralUtilities`Slice[
                   Key[0]]], "Mouse"], ImageSize -> {{34, Full}, Automatic}, 
                Alignment -> {Left, Baseline}]}, {
               Item[
                Pane[
                 Annotation[
                  EventHandler[
                   MouseAppearance[
                    Mouseover[
                    RawBoxes["1"], 
                    Style[
                    RawBoxes["1"], FontColor -> 
                    RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                   TypeSystem`NestedGrid`PackagePrivate`updateState[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$pos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 113078960][{
                    Key[1]}]], 
                  TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[113078960][
                   GeneralUtilities`Slice[
                    Key[1]]], "Mouse"], ImageSize -> {{34, Full}, Automatic}],
                 Background -> GrayLevel[0.95], 
                Alignment -> {Left, Baseline}], 
               Pane[
                Annotation[
                 RawBoxes["296"], 
                 TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[113078960][
                  GeneralUtilities`Slice[
                   Key[1]]], "Mouse"], ImageSize -> {{34, Full}, Automatic}, 
                Alignment -> {Left, Baseline}]}}, BaseStyle -> {ContextMenu -> {
                 MenuItem["Copy position to clipboard", 
                  KernelExecute[
                   TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                   TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                  MenuEvaluator -> Automatic], 
                 MenuItem["Copy data to clipboard", 
                  KernelExecute[
                   TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                   TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                  MenuEvaluator -> Automatic], Delimiter, 
                 MenuItem["Paste position in new cell", 
                  KernelExecute[
                   TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                   TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                  MenuEvaluator -> Automatic], 
                 MenuItem["Paste data in new cell", 
                  KernelExecute[
                   TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                   TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                  MenuEvaluator -> Automatic]}, FontFamily -> "Verdana", 
               FontSize -> 12}, Alignment -> Left, RowMinHeight -> 1.5, 
             Dividers -> All, FrameStyle -> GrayLevel[0.85], 
             BaseStyle -> {FontFamily -> "Verdana", FontSize -> 12}], 
            LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> False,
             ShowAutoStyles -> False]], 
         TypeSystem`NestedGrid`PackagePrivate`initialQ = True, 
         TypeSystem`NestedGrid`PackagePrivate`self = $Failed}, 
        Dynamic[
         TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
         TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
            Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
            
            Module[{TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
              TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
              TypeSystem`NestedGrid`PackagePrivate`LookupCacheValue[
                TypeSystem`NestedGrid`PackagePrivate`$state$$["Data"]]}, 
             TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = 
              If[TypeSystem`NestedGrid`PackagePrivate`tmpData$ === 
                TypeSystem`NestedGrid`PackagePrivate`$NotCached, 
                TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
                TypeSystem`NestedGrid`PackagePrivate`renderGrid[
                TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                 TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                 TypeSystem`NestedGrid`PackagePrivate`$pos$$, 
                 TypeSystem`NestedGrid`PackagePrivate`$grid$$, 113078960][
                TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
               Not[
                FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
               TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
               TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
          TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
          TypeSystem`NestedGrid`PackagePrivate`$pos$$; If[
            FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
            TypeSystem`SparseGrid[
             TypeSystem`H["(data no longer present)"]], 
            If[GeneralUtilities`$DebugMode, 
             Row[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid, "  ", 
               TypeSystem`NestedGrid`PackagePrivate`formatState[
               TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                TypeSystem`NestedGrid`PackagePrivate`$pos$$]}], 
             TypeSystem`NestedGrid`PackagePrivate`renderedGrid]]], 
         TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$pos$$}], 
        DynamicModuleValues :> {}], 
      TypeSystem`NestedGrid`PackagePrivate`$posCell$$, 
      TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
        TypeSystem`NestedGrid`PackagePrivate`alignBar[
        TypeSystem`NestedGrid`PackagePrivate`$state$$][
         TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
          TypeSystem`PackageScope`Pathbar[
          TypeSystem`NestedGrid`PackagePrivate`$path$$, 
           TypeSystem`NestedGrid`PackagePrivate`updateState[
           TypeSystem`NestedGrid`PackagePrivate`$state$$, 
            TypeSystem`NestedGrid`PackagePrivate`$path$$, 
            TypeSystem`NestedGrid`PackagePrivate`$pos$$, 
            TypeSystem`NestedGrid`PackagePrivate`$grid$$, 113078960]]]], 
        TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
      TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Framed[
        Dynamic[
         Replace[
          MouseAnnotation[Null], {
          TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[113078960][Null] -> 
           "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[113078960][
             Pattern[TypeSystem`NestedGrid`PackagePrivate`path, 
              Blank[]]] :> (
            TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
             TypeSystem`NestedGrid`PackagePrivate`path; 
            TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
             TypeSystem`NestedGrid`PackagePrivate`path, 
              TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
           Spacer[10], Blank[] :> Spacer[10]}], TrackedSymbols :> {}], 
        FrameStyle -> None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> 
        Top, ImageSize -> {Automatic, 14}]}, 
     DynamicBox[
      ToBoxes[
       Column[
        If[TypeSystem`NestedGrid`PackagePrivate`$path$$ == {}, {
          TypeSystem`NestedGrid`PackagePrivate`displayScrollBar[
          TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
           TypeSystem`NestedGrid`PackagePrivate`$state$$, 
           TypeSystem`NestedGrid`PackagePrivate`$pos$$], 
          TypeSystem`NestedGrid`PackagePrivate`onDesktopShow[
           TypeSystem`NestedGrid`PackagePrivate`alignBar[
           TypeSystem`NestedGrid`PackagePrivate`$state$$][
           TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$]]}, {
         TypeSystem`NestedGrid`PackagePrivate`$topBar$$, 
          TypeSystem`NestedGrid`PackagePrivate`displayScrollBar[
          TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
           TypeSystem`NestedGrid`PackagePrivate`$state$$, 
           TypeSystem`NestedGrid`PackagePrivate`$pos$$], 
          TypeSystem`NestedGrid`PackagePrivate`onDesktopShow[
           TypeSystem`NestedGrid`PackagePrivate`alignBar[
           TypeSystem`NestedGrid`PackagePrivate`$state$$][
           TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$]]}], Spacings -> 
        If[TypeSystem`NestedGrid`PackagePrivate`$path$$ == {}, 
          0, {{}, {0, 0.05, 0}}]], StandardForm], 
      ImageSizeCache -> {88., {30.3837890625, 37.6162109375}}, 
      TrackedSymbols :> {
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
     BaseStyle -> {LineBreakWithin -> False}, Deinitialization :> 
     TypeSystem`NestedGrid`PackagePrivate`deleteState[
      TypeSystem`NestedGrid`PackagePrivate`$state$$], 
     DynamicModuleValues :> {}, Initialization :> 
     Block[{$ContextPath = $ContextPath}, 
       Needs["TypeSystem`"]]], Deploy, DefaultBaseStyle -> "Deploy"]},
  "CopyTag",
  DisplayFunction->(#& ),
  InterpretationFunction->("Dataset[<>]"& )]], "Output",
 CellChangeTimes->{3.752896643510672*^9},
 CellLabel->"Out[11]=",
 CellID->382897054,ExpressionUUID->"f96633b7-a9dd-4035-9ac7-95348875567b"]
}, Open  ]],

Cell[TextData[{
 "It is just as important to understand that although the ",
 StyleBox["Improvement",
  FontSlant->"Italic"],
 " variable was expressed in terms of numbers, there is no order to them. One \
may follow zero in our natural counting system, but these values represented \
ideas, i.e. improvement and no improvement. There is no order to these data \
point values. "
}], "Text",
 CellChangeTimes->{{3.752896660598268*^9, 3.7528967013606243`*^9}, {
  3.75422153831133*^9, 3.7542215383203306`*^9}, {3.754221568704369*^9, 
  3.7542215687133703`*^9}, {3.754221618156314*^9, 3.7542216181653147`*^9}, {
  3.754221843386834*^9, 3.754221846203116*^9}},
 CellID->5281963,ExpressionUUID->"1d0f9f92-6a56-470c-8dd4-82e0e7396872"],

Cell[TextData[{
 "For ordered categorical variables, we have the ",
 StyleBox["ordinal",
  FontSlant->"Italic"],
 " categorical data type. Consider the ",
 StyleBox["SurveyQuestion1",
  FontSlant->"Italic"],
 " variable. Let\[CloseCurlyQuote]s assume the question was, \
\[OpenCurlyDoubleQuote]Rate how much you enjoyed the airline food,\
\[CloseCurlyDoubleQuote] with 1 referring to ",
 StyleBox["not so tasty",
  FontSlant->"Italic"],
 " all the way to 5 for ",
 StyleBox["gourmet meal",
  FontSlant->"Italic"],
 ". Be careful. Although these are numbers and we can order them (hence \
ordinal categorical), they do not represent actual numbers. For one, there is \
no fixed difference between them. We cannot imply that the difference in \
taste between values 1 and 2 is the same as between 3 and 4. Neither can we \
say that someone who chose 4 found the food twice as tasty as someone who \
chose 2. Strictly speaking then, we cannot represent this data with a mean \
value. We may be able to calculate a mean, but how do we interpret a result \
such as 2.4? How tasty is airline food if it is rated as 2.4?"
}], "Text",
 CellChangeTimes->{{3.752896703154943*^9, 3.7528967324176273`*^9}, {
  3.75289676729881*^9, 3.7528967856685543`*^9}, {3.752896840461645*^9, 
  3.752896842711862*^9}, {3.7542215383323317`*^9, 3.7542215384273415`*^9}, {
  3.7542215687253714`*^9, 3.754221568824381*^9}, {3.7542216181773157`*^9, 
  3.7542216182743254`*^9}, {3.7542218492374196`*^9, 3.754221877989294*^9}, {
  3.754230463428281*^9, 3.7542305884477816`*^9}, {3.7542378405329857`*^9, 
  3.7542378439043226`*^9}},
 CellID->312462959,ExpressionUUID->"e38d76d9-5cf8-49b1-8bf9-70d689c15b81"],

Cell["\<\
Now that we have a good classification system for the data type for our \
variables, we can choose an appropriate statistical test when we do our \
analysis. There is one more classification system for numerical data types \
that we should look at first though.\
\>", "Text",
 CellChangeTimes->{{3.752896864562712*^9, 3.752896877709424*^9}, 
   3.7542215384363422`*^9, 3.754221568834382*^9, 3.7542216182843266`*^9, 
   3.754221881133609*^9, 3.7542306028432207`*^9, {3.754237911843116*^9, 
   3.7542379149804296`*^9}},
 CellID->668839495,ExpressionUUID->"5f498f06-dfe4-4ec6-bdce-1ff1aea5d82b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discrete and Continuous Data Types", "Subsubsection",
 CellChangeTimes->{{3.7528968908975067`*^9, 3.7528968974897814`*^9}, {
  3.754230605339471*^9, 3.754230609011838*^9}},
 CellID->363650283,ExpressionUUID->"dca8b8fb-324b-486a-8c7a-226d18d03c8e"],

Cell[TextData[{
 "Numerical data types can either be ",
 StyleBox["discrete",
  FontSlant->"Italic"],
 " or ",
 StyleBox["continuous",
  FontSlant->"Italic"],
 ". Let\[CloseCurlyQuote]s have a look at the ",
 StyleBox["Age",
  FontSlant->"Italic"],
 " variable again. The sample space comes from integers, which are discrete \
values. The number 46.8 is a decimal value and not an integer. We know, \
though, that years can be broken down into weeks, days, hours, and so on, so \
it makes sense to say that the mean age was 46.5 years. ",
 StyleBox["Age",
  FontSlant->"Italic"],
 ", in this case, is then a ",
 StyleBox["continuous",
  FontSlant->"Italic"],
 " numerical variable. The same goes for currency (dollars, euros, and \
pounds). We might have a smallest value for any given currency on earth, but \
for banks to keep proper track of interest rates, very small decimal values \
might have to be used."
}], "Text",
 CellChangeTimes->{{3.7528969076413956`*^9, 3.7528969643515086`*^9}, {
  3.7542215384463434`*^9, 3.7542215385143504`*^9}, {3.754221568846383*^9, 
  3.7542215689183903`*^9}, {3.7542216182943277`*^9, 3.754221618364334*^9}, {
  3.7542218835828533`*^9, 3.7542219000224977`*^9}, {3.754221960024497*^9, 
  3.7542219633858333`*^9}, {3.754233374165963*^9, 3.754233431984744*^9}, {
  3.7542334640259485`*^9, 3.75423349174872*^9}},
 CellID->540373563,ExpressionUUID->"717dc0ce-0371-43aa-bd5f-b2e72cb6e709"],

Cell[TextData[{
 "When data point values can absolutely only take certain numerical values, \
we refer to them as being ",
 StyleBox["discrete",
  FontSlant->"Italic"],
 " numerical. As a very simple example, we can look at the roll of a die. For \
a normal six-sided die, the value that lands face up can only be an integer \
value from one through six."
}], "Text",
 CellChangeTimes->{{3.7528969832683287`*^9, 3.752897010561695*^9}, {
   3.754221538524351*^9, 3.754221538533352*^9}, {3.7542215689283915`*^9, 
   3.7542215689363923`*^9}, {3.7542216183743353`*^9, 3.754221618383336*^9}, 
   3.754221956929188*^9, {3.754233555005045*^9, 3.754233559829528*^9}},
 CellID->133100691,ExpressionUUID->"1733cf91-cabd-4720-821b-42e919b20afd"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox["Exercises",
  $Line = 0; Null]], "ExerciseSection",
 CellLabel->"In[12]:=",
 CellID->1969701267,ExpressionUUID->"f600381e-12c8-446f-84e1-966c889a36a8"],

Cell[TextData[{
 "Calculate the number of unique data point values in the ",
 StyleBox["InsulinDependentDiabetic",
  FontSlant->"Italic"],
 " column in the dataset used in this chapter."
}], "Exercise",
 CellChangeTimes->{{3.7262286590360723`*^9, 3.72622873894293*^9}, {
   3.7262287716961455`*^9, 3.7262287754399443`*^9}, {3.726228865544318*^9, 
   3.7262288824469132`*^9}, {3.7262290096722617`*^9, 
   3.7262290542473125`*^9}, {3.7262295602878523`*^9, 3.726229562391164*^9}, 
   3.726842073467464*^9, {3.726842199040183*^9, 3.726842199141012*^9}, {
   3.7477659616730633`*^9, 3.74776596922626*^9}, {3.747766013016721*^9, 
   3.7477660144880943`*^9}, {3.752557757913641*^9, 3.7525577734935055`*^9}, {
   3.7528971012862883`*^9, 3.7528971184191046`*^9}},
 CellID->340070963,ExpressionUUID->"4bda6ef6-0ea7-433c-9ec1-1b83ab276312"],

Cell[TextData[{
 "Calculate the number of unique data point values in the ",
 StyleBox["SurveyQuestion1",
  FontSlant->"Italic"],
 " column."
}], "Exercise",
 CellChangeTimes->{{3.7262286590360723`*^9, 3.72622873894293*^9}, {
   3.7262287716961455`*^9, 3.7262287754399443`*^9}, {3.726228865544318*^9, 
   3.7262288824469132`*^9}, {3.7262290096722617`*^9, 
   3.7262290542473125`*^9}, {3.7262295602878523`*^9, 3.726229562391164*^9}, 
   3.726842073467464*^9, {3.726842199040183*^9, 3.726842199141012*^9}, {
   3.7477659616730633`*^9, 3.74776596922626*^9}, {3.747766013016721*^9, 
   3.7477660144880943`*^9}, {3.752557757913641*^9, 3.7525577734935055`*^9}, {
   3.7528971012862883`*^9, 3.7528971369071627`*^9}},
 CellID->677423780,ExpressionUUID->"ff7fc687-fbae-4a3b-a988-ce1b990a8c0e"],

Cell[TextData[{
 "What data type would you consider the ",
 StyleBox["TreatmentGroup",
  FontSlant->"Italic"],
 " variable to be?"
}], "Exercise",
 CellChangeTimes->{{3.7262286590360723`*^9, 3.72622873894293*^9}, {
   3.7262287716961455`*^9, 3.7262287754399443`*^9}, {3.726228865544318*^9, 
   3.7262288824469132`*^9}, {3.7262290096722617`*^9, 
   3.7262290542473125`*^9}, {3.7262295602878523`*^9, 3.726229562391164*^9}, 
   3.726842073467464*^9, {3.726842199040183*^9, 3.726842199141012*^9}, {
   3.7477659616730633`*^9, 3.74776596922626*^9}, {3.747766013016721*^9, 
   3.7477660144880943`*^9}, {3.752557757913641*^9, 3.7525577734935055`*^9}, {
   3.7528971012862883`*^9, 3.7528971184191046`*^9}, 3.7528971511019535`*^9},
 CellID->24631262,ExpressionUUID->"6d6e5419-7ea7-4c64-b8fa-04076e0e087e"],

Cell[TextData[{
 "What data type would you consider the ",
 StyleBox["HB",
  FontSlant->"Italic"],
 " column to to be?"
}], "Exercise",
 CellChangeTimes->{{3.7262286590360723`*^9, 3.72622873894293*^9}, {
   3.7262287716961455`*^9, 3.7262287754399443`*^9}, {3.726228865544318*^9, 
   3.7262288824469132`*^9}, {3.7262290096722617`*^9, 
   3.7262290542473125`*^9}, {3.7262295602878523`*^9, 3.726229562391164*^9}, 
   3.726842073467464*^9, {3.726842199040183*^9, 3.726842199141012*^9}, {
   3.7477659616730633`*^9, 3.74776596922626*^9}, {3.747766013016721*^9, 
   3.7477660144880943`*^9}, {3.752557757913641*^9, 3.7525577734935055`*^9}, {
   3.7528971012862883`*^9, 3.7528971184191046`*^9}, 3.75289715794671*^9},
 CellID->130652255,ExpressionUUID->"6ef94fbc-fd3d-428c-9e95-249c1353f0f1"],

Cell[TextData[{
 "Calculate the minimum and maximum values in the ",
 StyleBox["HB",
  FontSlant->"Italic"],
 " column."
}], "Exercise",
 CellChangeTimes->{{3.7262286590360723`*^9, 3.72622873894293*^9}, {
   3.7262287716961455`*^9, 3.7262287754399443`*^9}, {3.726228865544318*^9, 
   3.7262288824469132`*^9}, {3.7262290096722617`*^9, 
   3.7262290542473125`*^9}, {3.7262295602878523`*^9, 3.726229562391164*^9}, 
   3.726842073467464*^9, {3.726842199040183*^9, 3.726842199141012*^9}, {
   3.7477659616730633`*^9, 3.74776596922626*^9}, {3.747766013016721*^9, 
   3.7477660144880943`*^9}, {3.752557757913641*^9, 3.7525577734935055`*^9}, {
   3.7528971012862883`*^9, 3.7528971184191046`*^9}, 3.7528971651350374`*^9},
 CellID->82859634,ExpressionUUID->"64d5d98b-d21b-415a-bf91-46f040738cb2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tech Notes", "TechNoteSection",
 CellID->874797650,ExpressionUUID->"c107ca51-3d99-4140-8159-4f02e20fd555"],

Cell["\<\
The semicolon suppresses output to the screen and is often used in larger \
blocks of code to eliminate unnecessary lines of output.\
\>", "TechNote",
 CellChangeTimes->{{3.651515120816633*^9, 3.651515125814807*^9}, 
   3.6515155174947033`*^9, 3.762717702497916*^9, 3.815756132131422*^9},
 CellID->173252925,ExpressionUUID->"f453ce65-e5d8-4d01-8a08-1c4645ec365b"],

Cell["\<\
When more than one argument is passed, it needs to be represented as a list. \
\>", "TechNote",
 CellChangeTimes->{{3.651515120816633*^9, 3.651515125814807*^9}, 
   3.6515155174947033`*^9, 3.762717702497916*^9, 3.76287733994162*^9},
 CellID->1859864436,ExpressionUUID->"2ac1abe6-efef-4583-a05b-733ad0609c1a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 CellID->2111815718,ExpressionUUID->"553f0b24-382b-4c77-bc6b-afe5564b4a14"],

Cell[TextData[{
 StyleBox[ButtonBox["For more information, try the Computation with \
Structured Datasets guide page ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/guide/\
ComputationWithStructuredDatasets.html"], None},
  ButtonNote->
   "https://reference.wolfram.com/language/guide/\
ComputationWithStructuredDatasets.html"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/StructuredDatasets",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolfr.am/StructuredDatasets"], None},
  ButtonNote->"http://wolfr.am/StructuredDatasets"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{
  3.746269404508712*^9, {3.7462857234063983`*^9, 3.746285751218179*^9}, {
   3.7462858072927856`*^9, 3.746285809571014*^9}, {3.757099714283596*^9, 
   3.757099720243217*^9}},
 CellID->26626102,ExpressionUUID->"71eacf8b-6d7d-4bb2-b526-e04ddc255d26"],

Cell[TextData[{
 StyleBox[ButtonBox["For an advanced application, try N. M. Abbassi\
\[CloseCurlyQuote]s Wolfram Demonstration on continuous- to discrete-time \
fourier transforms ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
FromContinuousToDiscreteTimeFourierTransformBySamplingMethod/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
FromContinuousToDiscreteTimeFourierTransformBySamplingMethod/"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/TimeFourierTransform",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolfr.am/TimeFourierTransform"], None},
  ButtonNote->"http://wolfr.am/TimeFourierTransform"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{
  3.746269404508712*^9, {3.7462857234063983`*^9, 3.746285751218179*^9}, {
   3.7462858072927856`*^9, 3.746285809571014*^9}, {3.757099714283596*^9, 
   3.757099720243217*^9}},
 CellID->1135722941,ExpressionUUID->"a36da43f-ea7a-4307-a5f4-4e903595d189"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->False,
Saveable->False,
WindowSize->{808, 911},
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{"\[ThinSpace]", "\[ThinSpace]", 
          StyleBox[
          "Introduction to Statistics\t\t\t\t\t\nwith the Wolfram Language", 
           LineSpacing -> {1, 1}, FontFamily -> "Source Sans Pro", FontSize -> 
           24, FontColor -> GrayLevel[1]], "\[ThinSpace]"}, 
         "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {65, 75}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"04-Klopper-WorkingWithData.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"04-Klopper-WorkingWithData.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> GrayLevel[0.2], Evaluator -> Automatic, 
                  Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Chapter 4\"", TooltipDelay -> 0.15, 
              LabelStyle -> "TextStyling"], 
             Annotation[#, "Chapter 4", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"06-Klopper-DescriptiveStatistics.nb", ""},
                     FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"06-Klopper-DescriptiveStatistics.nb", ""},
                     FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  GrayLevel[0.2], Evaluator -> Automatic, Method -> 
                  "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Chapter 6\"", TooltipDelay -> 0.15, 
              LabelStyle -> "TextStyling"], 
             Annotation[#, "Chapter 6", "Tooltip"]& ]}, "RowWithSeparators"], 
          Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> GrayLevel[0.2], 
             ImageSize -> {35, 30}, Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> RGBColor[0.12, 0.18, 0.26], 
             ImageSize -> {35, 30}, Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "1 | Introduction" :> 
          NotebookLocate[{"01-Klopper-IntroDataAnalysis.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "2 | Evaluating Basic Math" :> 
          NotebookLocate[{"02-Klopper-BasicMath.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "3 | Collections" :> 
          NotebookLocate[{"03-Klopper-Collections.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "4 | Working with Datasets" :> 
          NotebookLocate[{"04-Klopper-WorkingWithData.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "5 | Data Types" :> 
          NotebookLocate[{"05-Klopper-DataTypes.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "6 | Simple Descriptive Statistics" :> 
          NotebookLocate[{"06-Klopper-DescriptiveStatistics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "7 | Visualizing Data" :> 
          NotebookLocate[{"07-Klopper-VisualizingData.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "8 | Distributions" :> 
          NotebookLocate[{"08-Klopper-Distributions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "9 | Hypothesis Testing" :> 
          NotebookLocate[{"09-Klopper-HypothesisTesting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10 | Parametric Tests, Comparing Means" :> 
          NotebookLocate[{"10-Klopper-ParametricTests.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "11 | Correlation" :> 
          NotebookLocate[{"11-Klopper-Correlation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "12 | Linear Regression" :> 
          NotebookLocate[{"12-Klopper-LinearRegression.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "13 | Comparing Categorical Variables" :> 
          NotebookLocate[{"13-Klopper-ComparingCategoricalVariables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "14 | Nonparametric Tests" :> 
          NotebookLocate[{"14-Klopper-NonparametricTests.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "15 | A Research Project Demonstration" :> 
          NotebookLocate[{"15-Klopper-ResearchProject.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> RGBColor[0.12, 0.18, 0.26], 
   CellMargins -> {{0, 0}, {0, -1}}, CellFrameMargins -> {{27, 0}, {1, 7}}, 
   Background -> RGBColor[0.12, 0.18, 0.26], CellTags -> 
   "DockedCellLogoCell"], 
  Cell["JUAN H. KLOPPER", "Text", FontFamily -> "Source Sans Pro", FontWeight -> 
   "Light", FontSize -> 15, CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> 
   False, CellMargins -> {{0, 0}, {-1, -1}}, 
   CellFrameMargins -> {{27, 0}, {2, 4}}, CellFrameColor -> 
   RGBColor[1., 0.7, 0.1], FontTracking -> "Extended", FontColor -> 
   GrayLevel[1], Background -> RGBColor[0.9, 0.4, 0.], CellTags -> 
   "DockedCellLogoCell"]},
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    Introduction to Statistics with the Wolfram Language", "Header"]}],
     "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], 
   None, None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["  |  Data Types", "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 34}, {Inherited, Inherited}}]}},
ShowAutoSpellCheck->False,
FrontEndVersion->"12.2 for Mac OS X x86 (64-bit) (December 12, 2020)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> 
       "Source San Pro", FontSize -> 8, FontWeight -> "Plain", FontSlant -> 
       "Plain", FontColor -> GrayLevel[0.45]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Source San Pro", FontSize -> 
       8, FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth :> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, 
       AutoStyleOptions -> {
        "FormattingErrorTooltips" -> False, "HighlightComments" -> False, 
         "HighlightEmphasizedSyntaxErrors" -> False, 
         "HighlightExcessArguments" -> False, "HighlightFormattingErrors" -> 
         False, "HighlightGlobalToLocalScopeConflicts" -> False, 
         "HighlightGraphicsCompatibilityProblems" -> False, 
         "HighlightLocalScopeConflicts" -> False, "HighlightMissingArguments" -> 
         False, "HighlightNoKernelPresent" -> False, 
         "HighlightOrderOfEvaluationConflicts" -> False, "HighlightStrings" -> 
         True, "HighlightSymbolContexts" -> False, "HighlightSymbolShadowing" -> 
         False, "HighlightSyntaxErrors" -> False, "HighlightUndefinedSymbols" -> 
         False, "HighlightUnknownOptions" -> False, 
         "HighlightUnwantedAssignments" -> False}, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey :> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Open]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey :> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey :> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 64}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["GrayPointSix"], FontColor -> GrayLevel[0.6]], 
         Cell[
          StyleData["GrayPointSix", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, DefaultNewCellStyle -> 
          "ExerciseInput", CounterIncrements -> "Exercise", MenuSortingValue -> 
          10020, MenuCommandKey :> "2", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth :> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, DefaultReturnCreatedCellStyle -> 
          "Answer", CounterIncrements -> "Question", MenuSortingValue -> 
          10030, MenuCommandKey :> "3", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth :> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, ReturnCreatesNewCell -> True, 
          DefaultReturnCreatedCellStyle -> "Question", 
          LineSpacing -> {1.125, 1., 2.}, MenuSortingValue -> 10032, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          ReturnCreatesNewCell -> True, CellFrameLabelMargins -> 3, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 12}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Baskerville", FontSize -> 
          18, FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Italic", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", StripStyleOnPaste -> True, PageBreakWithin -> False, 
          GroupPageBreakWithin -> False, GeneratedCell -> True, 
          CellAutoOverwrite -> True, ShowCellLabel -> False, 
          DefaultFormatType -> DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221]], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, 
          GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, 
          ShowCellLabel -> False, SpanMaxSize -> 1, FontSize -> 14], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Comment"], FontFamily -> "Verdana", FontSize -> 13, 
          FontColor -> RGBColor[0.3, 0.3, 0.2], Background -> 
          RGBColor[1, 0.9, 0.8]], 
         Cell[
          StyleData["Comment", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Suggestion"], 
          CellFrameLabels -> {{Inherited, Inherited}, {Inherited, 
             Cell[
              BoxData[
               TagBox[
                GridBox[{{
                   ButtonBox[
                   "\"  Insert  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`ReplaceWithSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    ContentPadding -> False, Appearance -> Automatic, Method -> 
                    "Queued"], 
                   ButtonBox[
                   "\"  Stet  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; DocuTools`StetSuggestion[]), 
                    Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "    ", 
                   ButtonBox[
                   "\"  Next  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindNextSuggestion[]), Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], 
                   ButtonBox[
                   "\"  Previous  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindPreviousSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "\"\""}}, 
                 AutoDelete -> False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
                "Grid"]], ShowStringCharacters -> False, Background -> 
              None]}}, Background -> RGBColor[1, 0.8, 0.8]], 
         Cell[
          StyleData["Suggestion", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Tentative"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[
             0.30000000000000016`, 0.6000000000000003, 0.7000000000000003], 
            "Thickness" -> 5}, Evaluatable -> False, CellFrameMargins -> 4, 
          StyleMenuListing -> None, Background -> 
          RGBColor[0.8500000000000003, 0.9500000000000003, 1]], 
         Cell[
          StyleData["Tentative", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["WebOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.91, 0.92, 0.9], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.91, 0.92, 0.86]], 
         Cell[
          StyleData["WebOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Lockdown"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.8, 0.5, 0.4], "Thickness" -> 3}, Evaluatable -> 
       False, StyleMenuListing -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["IndexField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["IndexField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExplanationField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["ExplanationField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EnglishHighlight"], FontFamily -> "WolframCodeSans"], 
         Cell[
          StyleData["EnglishHighlight", "Printout"]]}, Open]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth :> Infinity, TextAlignment -> Left, 
       LineSpacing -> {0.6, 1}, AutoQuoteCharacters -> {}, 
       PasteAutoQuoteCharacters -> {}, StyleMenuListing -> None, FontFamily -> 
       "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth :> Infinity, 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Link", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (Function[
             t, NotebookFind[t, "Notes", All, CellStyle]; 
              NotebookFind[
               t, "NotesSection", All, CellStyle, AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Crosslink"], 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               
               NotebookLocate[#2, "OpenInNewWindow" -> 
                CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None,
             Method -> "Queued"}], 
         Cell[
          StyleData["Crosslink", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeLink"], 
          ButtonBoxOptions -> {
           Appearance -> None, ButtonFunction :> (Documentation`HelpLookup[
              Part[#, 1]]& ), ButtonSource -> ButtonContents, Evaluator -> 
            Automatic}], 
         Cell[
          StyleData["CodeLink", "Printout"]]}, Open]], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 0, FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 0, FontFamily -> 
       "Source Sans Pro", FontSize -> Inherited 0.95], 
      Cell[
       StyleData["NoLabel"], 
       GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, ShowCellLabel -> 
       False], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariable"], FontFamily -> "Times", FontSize -> 
          Inherited 1.05, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariable", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariableLrg"], FontFamily -> "Times", FontSize -> 
          Inherited 1.1, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariableLrg", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "WolframCodeSans", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "WolframCodeSans", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {0.5, 3}}, 
               ImageMargins -> {{2, 2}, {1, 1}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Open]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Specialized for Klopper", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9, {3.7114709033696413`*^9, 
         3.711470909048764*^9}, {3.73531219927332*^9, 3.735312227736931*^9}, {
         3.745680245296091*^9, 3.7456802496393538`*^9}, {3.745930022124992*^9,
          3.7459300236362534`*^9}, {3.746546663993486*^9, 
         3.7465466650968523`*^9}}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {2, 32}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> "Italic", 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 14}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], LineSpacing -> {1.3, 1., 2.}, 
          MenuSortingValue -> 10010, MenuCommandKey :> "1", FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"], 
          CellMargins -> {{99, Inherited}, {2, 12}}, StripStyleOnPaste -> 
          True, DefaultFormatType -> DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           LanguageCategory -> "Formula", ScriptLevel -> 0, 
          SingleLetterItalics -> True, MenuSortingValue -> 1700, FontFamily -> 
          "Baskerville", FontSize -> 16, FontWeight -> "Regular", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[0.2], 
          UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}], 
              "DisplayFormulaEquationNumber"]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered", MenuSortingValue -> 
          1710, FontFamily -> "Baskerville", FontSize -> 16, FontWeight -> 
          "Regular", FontSlant -> "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       StyleData["InitializationCell"], Background -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Print"], CellMargins -> {{99, 10}, {4, 4}}, FontSize -> 
          15], 
         Cell[
          StyleData["Print", "Presentation"], 
          CellMargins -> {{100, Inherited}, {1.5 Inherited, 1.5 Inherited}}], 
         Cell[
          StyleData["Print", "SlideShow"], 
          CellMargins -> {{
            0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.01 
             FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {8, 15}}, 
          FontSize -> 18], 
         Cell[
          StyleData["Print", "Condensed"], 
          CellMargins -> {{18, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "Printout"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "PrintoutGray"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            RGBColor[0.8, 0.043, 0.008]], CellMargins -> {{81, 10}, {4, 8}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            GrayLevel[0.2]], 
          CellMargins -> {{80, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemParagraph"], CellMargins -> {{81, 10}, {4, 1}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["ItemParagraph", "Printout"], 
          CellMargins -> {{80, Inherited}, {Inherited, 0.5 Inherited}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemNumbered"], CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontWeight -> "Bold"], 
          CellMargins -> {{85, 10}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "ItemNumbered", 
          CounterAssignments -> {{"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> 1630, FontFamily -> 
          "Source Sans Pro", FontSize -> 15], 
         Cell[
          StyleData["ItemNumbered", "Printout"], 
          CellMargins -> {{90, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteItem"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontSize -> 12, FontWeight -> 
            Bold, FontColor -> GrayLevel[0.25]], 
          CellMargins -> {{93, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, CellFrameLabelMargins -> 4, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          CounterIncrements -> "ItemNumbered", MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNoteItem", "Printout"], 
          CellMargins -> {{93, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Epigraph"], CellMargins -> {{100, 78}, {6, 24}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, TextAlignment -> Left, Hyphenation -> 
          True, HyphenationOptions -> {"HyphenationMinLengths" -> {3, 5}}, 
          LineSpacing -> {1, 2}, TabSpacings -> {1.2, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontWeight -> "Plain", FontSlant -> 
          "Plain"], 
         Cell[
          StyleData["Epigraph", "Printout", StyleDefinitions -> None]]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EpigraphAuthor"], CellMargins -> {{125, 100}, {12, 12}}, 
          TextAlignment -> Left, LineSpacing -> {1, 2}, 
          ParagraphIndent -> -17, TabSpacings -> {1.5, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontTracking -> -0.05], 
         Cell[
          StyleData["EpigraphAuthor", "Printout", StyleDefinitions -> None]]},
         Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ReferenceSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ReferenceSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Reference"], CellDingbat -> Cell[
            TextData[{
              CounterBox["Reference"]}], "SR", FontSize -> 13, 
            CellSize -> {30, Inherited}, TextAlignment -> Right], 
          CellMargins -> {{80, 10}, {3, 4}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, 
          CellChangeTimes -> {{3.7385995432110577`*^9, 3.738599549834622*^9}},
           LineSpacing -> {1, 2}, ParagraphIndent -> -8, 
          TabSpacings -> {0.7, 2.5}, CounterIncrements -> "Reference", 
          MenuSortingValue -> 1870, FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["Reference", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{66, 10}, {3, 4}}, TabSpacings -> {1.2, 2.5}]}, 
        Open]]}, Closed]]}, Visible -> False, FrontEndVersion -> 
  "12.2 for Mac OS X x86 (64-bit) (December 12, 2020)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"87cb1175-391a-43c3-b058-03fffa040899"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "C:5"->{
  Cell[580, 22, 398, 9, 113, "Section",ExpressionUUID->"9ef2bc15-6f86-4c5b-bae1-cb5587fb303a",
   CounterAssignments->{{"Section", 4}, {"Subsection", 4}, {"Subsubsection", 4}, {"Exercise", 4}, {"Question", 4}},
   CellTags->"C:5",
   CellID->818845388]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"C:5", 386301, 7328}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 398, 9, 113, "Section",ExpressionUUID->"9ef2bc15-6f86-4c5b-bae1-cb5587fb303a",
 CounterAssignments->{{"Section", 4}, {"Subsection", 4}, {"Subsubsection", 4}, {"Exercise", 4}, {"Question", 4}},
 CellTags->"C:5",
 CellID->818845388],
Cell[981, 33, 695, 12, 113, "Text",ExpressionUUID->"4c5fa1e7-521a-4b62-9486-e271aad14096",
 CellID->374170624],
Cell[1679, 47, 505, 9, 88, "Text",ExpressionUUID->"e85f91b5-563d-4718-8cfe-01870c575f0d",
 CellID->29680916]
}, Open  ]],
Cell[CellGroupData[{
Cell[2221, 61, 169, 2, 57, "Subsection",ExpressionUUID->"a33c2583-2efa-4755-854a-dde7c41055ba",
 CellID->724768940],
Cell[2393, 65, 768, 12, 163, "Text",ExpressionUUID->"4e1290a0-212b-44b3-9d9f-c64c208f4423",
 CellID->822645814],
Cell[3164, 79, 1549, 25, 313, "Text",ExpressionUUID->"87c34026-41e7-4e95-880f-d26cdb6dbfa6",
 CellID->77775309],
Cell[4716, 106, 209, 2, 37, "CodeCaption",ExpressionUUID->"d7be9857-5c41-4c2c-b25c-3ce88c0c0aec",
 CellID->457685436],
Cell[CellGroupData[{
Cell[4950, 112, 233, 4, 29, "Input",ExpressionUUID->"1507149a-846e-449a-91c9-7cfd21f69fa8",
 CellID->165639971],
Cell[5186, 118, 274, 5, 40, "Output",ExpressionUUID->"4136e409-2b78-44a1-9e10-7ab6dba36fc9",
 CellID->1812554174]
}, Open  ]],
Cell[5475, 126, 766, 16, 88, "Text",ExpressionUUID->"b2d85e5c-95aa-4d1e-8b09-dd0d256f2115",
 CellID->42729138],
Cell[6244, 144, 201, 2, 37, "CodeCaption",ExpressionUUID->"34e8f702-9585-4b15-88e9-ba55daa40c44",
 CellID->102680392],
Cell[CellGroupData[{
Cell[6470, 150, 269, 5, 29, "Input",ExpressionUUID->"e02c383b-7333-473e-8c3d-5575e4e81f44",
 CellID->20072638],
Cell[6742, 157, 271, 5, 40, "Output",ExpressionUUID->"149a8a24-c5fe-4864-bbe6-99ff037baedf",
 CellID->1542469723]
}, Open  ]],
Cell[7028, 165, 977, 18, 138, "Text",ExpressionUUID->"550369a6-2a29-4913-9bec-9fc8b1430e0b",
 CellID->59949281],
Cell[8008, 185, 707, 11, 37, "CodeCaption",ExpressionUUID->"da31f50f-9a92-4689-b48c-843ffb45a950",
 CellID->544190477],
Cell[8718, 198, 98599, 1622, 419, "Picture",ExpressionUUID->"8d5f3925-19f5-444d-b8ff-22d530384122",
 CellID->885015780],
Cell[107320, 1822, 1755, 38, 188, "Text",ExpressionUUID->"c2c8b893-e238-4f87-baa9-ce599be5a90c",
 CellID->29982804],
Cell[109078, 1862, 260, 5, 37, "CodeCaption",ExpressionUUID->"9f0a53de-4eb7-46c0-a3d8-0aa7384ef5c7",
 CellID->22671240],
Cell[109341, 1869, 301, 7, 29, "Input",ExpressionUUID->"27f7da97-31ff-4a69-b81a-4dceab289dea",
 CellID->100546392],
Cell[109645, 1878, 413, 9, 63, "Text",ExpressionUUID->"6b49952b-b07b-4919-9f28-1cd395eae856",
 CellID->1224815],
Cell[110061, 1889, 586, 13, 66, "CodeCaption",ExpressionUUID->"0839639b-3e02-496c-99d5-3ec935bf95e1",
 CellID->358198085],
Cell[CellGroupData[{
Cell[110672, 1906, 228, 4, 29, "Input",ExpressionUUID->"7ddbc88e-6420-47ce-850c-f8a914c9abf0",
 CellID->230878426],
Cell[110903, 1912, 197, 3, 40, "Output",ExpressionUUID->"7d3d04d6-5ccb-4763-bac3-212d1666bcb3",
 CellID->2013531524]
}, Open  ]],
Cell[111115, 1918, 529, 9, 88, "Text",ExpressionUUID->"78f567b8-3bbb-4f46-983b-d37eca834b77",
 CellID->187380056],
Cell[111647, 1929, 191, 2, 37, "CodeCaption",ExpressionUUID->"0c36cbf2-b379-4b24-b97f-8ed702a6e8bb",
 CellID->453746082],
Cell[CellGroupData[{
Cell[111863, 1935, 283, 5, 29, "Input",ExpressionUUID->"e9971e73-5b79-40e9-b82e-2a98ad192031",
 CellID->134474493],
Cell[112149, 1942, 43192, 813, 211, "Output",ExpressionUUID->"88b59776-4f6e-4875-a10b-5321a48aa193",
 CellID->1377014442]
}, Open  ]],
Cell[155356, 2758, 487, 8, 63, "Text",ExpressionUUID->"4d4476bb-09ae-4223-b6cc-775cd971ffb9",
 CellID->37485402],
Cell[155846, 2768, 239, 4, 37, "CodeCaption",ExpressionUUID->"c997e725-c80d-4348-837f-22e877eff77b",
 CellID->227762743],
Cell[CellGroupData[{
Cell[156110, 2776, 233, 4, 29, "Input",ExpressionUUID->"860642e5-d780-4ede-a27c-4abaa7cc1d8b",
 CellID->54482967],
Cell[156346, 2782, 240, 5, 40, "Output",ExpressionUUID->"482059e3-751b-4135-84cd-eedee426d825",
 CellID->50462975]
}, Open  ]],
Cell[156601, 2790, 544, 9, 63, "Text",ExpressionUUID->"390b52e2-fe0c-4732-8f8b-67351eb12cea",
 CellID->145583533],
Cell[157148, 2801, 1372, 37, 163, "Text",ExpressionUUID->"ff08f653-232e-41be-99fa-d7f8af13211b",
 CellID->365003618],
Cell[158523, 2840, 1172, 17, 238, "Text",ExpressionUUID->"cd177fd9-0057-4bee-90c6-99e17c0fcf7a",
 CellID->279225871],
Cell[159698, 2859, 193, 2, 37, "CodeCaption",ExpressionUUID->"3226ab38-7cef-4ff8-90af-6c251dd15ed5",
 CellID->31689805],
Cell[CellGroupData[{
Cell[159916, 2865, 263, 5, 29, "Input",ExpressionUUID->"203b8180-e7fc-4d40-9b9f-1bb596a1e0eb",
 CellID->454746449],
Cell[160182, 2872, 31204, 563, 185, "Output",ExpressionUUID->"5b079a3b-ece0-49af-a89f-f8439729ed05",
 CellID->2022663907]
}, Open  ]],
Cell[191401, 3438, 565, 14, 88, "Text",ExpressionUUID->"48673f77-c9cd-477e-9587-8dbebba6a1c0",
 CellID->134809566],
Cell[191969, 3454, 1113, 28, 138, "Text",ExpressionUUID->"0e45ff64-2ef0-4835-a8ae-b5e76dd45e77",
 CellID->401584441],
Cell[193085, 3484, 711, 14, 88, "Text",ExpressionUUID->"fa7e6341-c74f-4222-8164-3b7f4dad2a75",
 CellID->251966793],
Cell[193799, 3500, 287, 7, 37, "CodeCaption",ExpressionUUID->"10d35054-ca50-4c5b-ad59-04d22365ec54",
 CellID->584868914],
Cell[CellGroupData[{
Cell[194111, 3511, 268, 5, 29, "Input",ExpressionUUID->"326f2f64-ab7f-422c-8514-39b0f9b7523c",
 CellID->72281429],
Cell[194382, 3518, 29517, 527, 161, "Output",ExpressionUUID->"009aafec-5c23-4fd1-a616-8095c5b69ba1",
 CellID->1680082457]
}, Open  ]],
Cell[223914, 4048, 627, 12, 88, "Text",ExpressionUUID->"c160b39b-c82a-4be6-917e-91a0505fa00c",
 CellID->79074759],
Cell[224544, 4062, 954, 16, 138, "Text",ExpressionUUID->"982d2149-85cf-40d2-bbb5-92161a6e77a4",
 CellID->101800540],
Cell[225501, 4080, 410, 9, 37, "CodeCaption",ExpressionUUID->"40c4064c-8fe1-405a-8396-f075342c83eb",
 CellID->653032168],
Cell[CellGroupData[{
Cell[225936, 4093, 309, 7, 29, "Input",ExpressionUUID->"7e1b430a-e1c5-4b6a-b0c1-18b0beaf8e06",
 CellID->619799585],
Cell[226248, 4102, 20849, 366, 111, "Output",ExpressionUUID->"f2723797-0792-4595-b4b4-43bae757ea40",
 CellID->506179199]
}, Open  ]],
Cell[247112, 4471, 381, 13, 63, "Text",ExpressionUUID->"4ab94045-d6f5-4c2c-aa8f-1ebb778ab706",
 CellID->627195121],
Cell[247496, 4486, 723, 14, 113, "Text",ExpressionUUID->"6c1e08b0-a557-484a-bf39-9850a8122b87",
 CellID->755378940]
}, Open  ]],
Cell[CellGroupData[{
Cell[248256, 4505, 226, 3, 57, "Subsection",ExpressionUUID->"37ff3390-a654-47e2-a69b-79446299d4af",
 CellID->247485778],
Cell[248485, 4510, 861, 18, 113, "Text",ExpressionUUID->"6f55ddd8-1094-428d-ba15-47a4e9e68f3d",
 CellID->703976491],
Cell[CellGroupData[{
Cell[249371, 4532, 241, 3, 55, "Subsubsection",ExpressionUUID->"235cb9d5-0f7f-4e17-9ef7-6730651f18fb",
 CellID->505708953],
Cell[249615, 4537, 535, 12, 88, "Text",ExpressionUUID->"5176f5be-429d-4a15-8ec0-e27b1a8a3943",
 CellID->201367951],
Cell[250153, 4551, 280, 5, 66, "CodeCaption",ExpressionUUID->"342b5092-99cc-4cc0-be34-53ee4e5f8042",
 CellID->163231021],
Cell[CellGroupData[{
Cell[250458, 4560, 309, 7, 29, "Input",ExpressionUUID->"8fdd5bfb-f74c-40d8-91b4-bb5c25acb31a",
 CellID->189537907],
Cell[250770, 4569, 20849, 366, 111, "Output",ExpressionUUID->"5a7e3fc6-79a6-4b85-a17c-c06b0ae3ad0d",
 CellID->516554827]
}, Open  ]],
Cell[271634, 4938, 1585, 25, 213, "Text",ExpressionUUID->"69c78d6e-4164-4e6c-be96-e3799993083f",
 CellID->44059808],
Cell[273222, 4965, 699, 16, 113, "Text",ExpressionUUID->"72c81c9d-5006-49f7-aaf8-d7904aba9ec5",
 CellID->27610436]
}, Open  ]],
Cell[CellGroupData[{
Cell[273958, 4986, 241, 3, 55, "Subsubsection",ExpressionUUID->"0d32cea3-7bde-4d6e-9ecb-92ca105fcb97",
 CellID->604861761],
Cell[274202, 4991, 1403, 31, 213, "Text",ExpressionUUID->"36f23643-cda4-4bfc-a724-dbda0776a0ce",
 CellID->241490288],
Cell[275608, 5024, 1248, 26, 213, "Text",ExpressionUUID->"7ca1a9c9-d51d-4c6e-a369-3a8f1a8c807f",
 CellID->76674588],
Cell[276859, 5052, 303, 7, 37, "CodeCaption",ExpressionUUID->"6bcc0739-4e5c-4dfa-acba-4badd2bf160f",
 CellID->18059349],
Cell[CellGroupData[{
Cell[277187, 5063, 272, 5, 29, "Input",ExpressionUUID->"2861f759-352c-40d2-8877-5a07007577ac",
 CellID->305991790],
Cell[277462, 5070, 11990, 222, 91, "Output",ExpressionUUID->"f96633b7-a9dd-4035-9ac7-95348875567b",
 CellID->382897054]
}, Open  ]],
Cell[289467, 5295, 729, 13, 113, "Text",ExpressionUUID->"1d0f9f92-6a56-470c-8dd4-82e0e7396872",
 CellID->5281963],
Cell[290199, 5310, 1674, 31, 288, "Text",ExpressionUUID->"e38d76d9-5cf8-49b1-8bf9-70d689c15b81",
 CellID->312462959],
Cell[291876, 5343, 602, 10, 88, "Text",ExpressionUUID->"5f498f06-dfe4-4ec6-bdce-1ff1aea5d82b",
 CellID->668839495]
}, Open  ]],
Cell[CellGroupData[{
Cell[292515, 5358, 253, 3, 55, "Subsubsection",ExpressionUUID->"dca8b8fb-324b-486a-8c7a-226d18d03c8e",
 CellID->363650283],
Cell[292771, 5363, 1421, 30, 213, "Text",ExpressionUUID->"717dc0ce-0371-43aa-bd5f-b2e72cb6e709",
 CellID->540373563],
Cell[294195, 5395, 734, 13, 113, "Text",ExpressionUUID->"1733cf91-cabd-4720-821b-42e919b20afd",
 CellID->133100691],
Cell[CellGroupData[{
Cell[294954, 5412, 185, 4, 71, "ExerciseSection",ExpressionUUID->"f600381e-12c8-446f-84e1-966c889a36a8",
 CellID->1969701267],
Cell[295142, 5418, 829, 14, 49, "Exercise",ExpressionUUID->"4bda6ef6-0ea7-433c-9ec1-1b83ab276312",
 CellID->340070963],
Cell[295974, 5434, 784, 14, 26, "Exercise",ExpressionUUID->"ff7fc687-fbae-4a3b-a988-ce1b990a8c0e",
 CellID->677423780],
Cell[296761, 5450, 796, 14, 26, "Exercise",ExpressionUUID->"6d6e5419-7ea7-4c64-b8fa-04076e0e087e",
 CellID->24631262],
Cell[297560, 5466, 783, 14, 26, "Exercise",ExpressionUUID->"6ef94fbc-fd3d-428c-9e95-249c1353f0f1",
 CellID->130652255],
Cell[298346, 5482, 786, 14, 26, "Exercise",ExpressionUUID->"64d5d98b-d21b-415a-bf91-46f040738cb2",
 CellID->82859634]
}, Open  ]],
Cell[CellGroupData[{
Cell[299169, 5501, 112, 1, 70, "TechNoteSection",ExpressionUUID->"c107ca51-3d99-4140-8159-4f02e20fd555",
 CellID->874797650],
Cell[299284, 5504, 373, 6, 54, "TechNote",ExpressionUUID->"f453ce65-e5d8-4d01-8a08-1c4645ec365b",
 CellID->173252925],
Cell[299660, 5512, 318, 5, 30, "TechNote",ExpressionUUID->"2ac1abe6-efef-4583-a05b-733ad0609c1a",
 CellID->1859864436]
}, Open  ]],
Cell[CellGroupData[{
Cell[300015, 5522, 121, 1, 100, "MoreExploreSection",ExpressionUUID->"553f0b24-382b-4c77-bc6b-afe5564b4a14",
 CellID->2111815718],
Cell[300139, 5525, 1020, 24, 49, "MoreExplore",ExpressionUUID->"71eacf8b-6d7d-4bb2-b526-e04ddc255d26",
 CellID->26626102],
Cell[301162, 5551, 1115, 25, 49, "MoreExplore",ExpressionUUID->"a36da43f-ea7a-4307-a5f4-4e903595d189",
 CellID->1135722941]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

