(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    399608,       8606]
NotebookOptionsPosition[    289370,       6331]
NotebookOutlinePosition[    373998,       8109]
CellTagsIndexPosition[    373930,       8104]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Distributions", "SectionInline",ExpressionUUID->
   "741fb465-dc20-4fdf-bb8c-07d29fef7af9"],
  $Line = 0; Null]], "Section",
 CounterAssignments->{{"Section", 7}, {"Subsection", 7}, {
   "Subsubsection", 7}, {"Exercise", 7}},
 CellTags->"C:8",
 CellLabel->"In[1]:=",
 CellID->868451339,ExpressionUUID->"0886596a-110a-4bf9-a26d-e53e7705e582"],

Cell[TextData[{
 "In Chapter 6, we saw how easy it is to generate simulated data with the \
Wolfram Language using functions such as ",
 ButtonBox["RandomInteger",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["RandomChoice",
  BaseStyle->"Link"],
 ". In this chapter, we will expand on this creation of data point values for \
variables, but in doing so, we will investigate the patterns of frequency \
that such values can take. These patterns are called ",
 StyleBox["distributions",
  FontSlant->"Italic"],
 ". The most common is the normal distribution, with its bell-shaped \
frequency curve."
}], "Text",
 CellChangeTimes->{{3.7646088991570306`*^9, 3.7646089057080307`*^9}, {
  3.76492887214286*^9, 3.7649288765681133`*^9}},
 CellID->121416020,ExpressionUUID->"bd9e37e8-db2e-4461-9e75-90c26174fd70"],

Cell[TextData[{
 "It is important to distinguish early on between the patterns that the \
frequency of actual data point values take and the pattern that statistics \
take. In this sense, we are using the term ",
 StyleBox["statistic",
  FontSlant->"Italic"],
 " as some value that we calculate from data. These include values such as \
the mean, median, and standard deviation. Given the calculation of many mean \
values, we will note that they also form a frequency pattern, called a ",
 StyleBox["sampling distribution",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.7646089666860304`*^9, 3.7646089689510307`*^9}, {
  3.764928913509226*^9, 3.7649289151493196`*^9}},
 CellID->92426958,ExpressionUUID->"2cd93a65-051a-495f-8bfd-efa9d863f8d4"],

Cell["\<\
In the case of actual data point values for numerical variables, we find \
discrete and continuous distributions in line with discrete and continuous \
numerical data types.\
\>", "Text",
 CellChangeTimes->{{3.7646089863810306`*^9, 3.7646089966440306`*^9}, 
   3.815838162080865*^9},
 CellID->246767786,ExpressionUUID->"e6d4bc07-fbc5-4ace-b89b-706d9e38e83c"],

Cell["\<\
In this chapter, we will learn about the most common examples of discrete, \
continuous, and sampling distributions.\
\>", "Text",
 CellID->110691724,ExpressionUUID->"c450ee7b-e094-4ca0-89bb-f6691c30a668"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discrete Uniform Distribution", "Subsection",
 CellChangeTimes->{{3.7646090463130302`*^9, 3.7646090492560306`*^9}},
 CellID->423276631,ExpressionUUID->"3362b275-7303-4e50-ab97-902d22e13473"],

Cell[TextData[{
 "When we used the ",
 ButtonBox["RandomInteger",
  BaseStyle->"Link"],
 " function, we were actually drawing random values from a domain, where \
every value in the sample space had an equal likelihood of being selected."
}], "Text",
 CellChangeTimes->{3.7646104283880305`*^9},
 CellID->59887565,ExpressionUUID->"e2b720c9-dcdb-4a12-8077-6430d096ce88"],

Cell["\<\
As an example, think for a moment about rolling a six-sided die. Each of the \
six sides has an equal likelihood of landing face up. If we roll the die \
multiple times, we can count how many times each value ends face up, that is, \
the frequency with which each value appears.\
\>", "Text",
 CellChangeTimes->{{3.7646091133580303`*^9, 3.7646091271170306`*^9}, {
  3.7646105044540305`*^9, 3.7646105323250303`*^9}, {3.7649291746211605`*^9, 
  3.764929176156248*^9}},
 CellID->351417190,ExpressionUUID->"286d9c1b-994e-408b-b6c6-82978d0fd116"],

Cell[TextData[{
 "We can simulate this using the Wolfram Language by using the ",
 ButtonBox["RandomInteger",
  BaseStyle->"Link"],
 " function to simulate ",
 Cell[BoxData[
  FormBox["10000", TraditionalForm]],ExpressionUUID->
  "48a52489-46bc-4566-bbb7-ee9d246fb622"],
 " rolls of a die and store the results in the computer variable ",
 Cell[BoxData[
 "die"], "InlineCodeText",ExpressionUUID->
  "63066403-7655-42e3-acf1-c7be09f2bd57"],
 ", using a semicolon to suppress the output. "
}], "Text",
 CellChangeTimes->{{3.764609163140031*^9, 3.7646091772030306`*^9}, {
  3.764675127047208*^9, 3.764675134764208*^9}},
 CellID->21548066,ExpressionUUID->"24bde6b6-4bdd-4f03-95a5-3d49e613bcf2"],

Cell[TextData[{
 "Use the ",
 ButtonBox["SeedRandom",
  BaseStyle->"Link"],
 " function for reproducibility:"
}], "CodeCaption",
 CellChangeTimes->{{3.7646093152670307`*^9, 3.764609315930031*^9}},
 CellID->1433940191,ExpressionUUID->"d6fc1308-9599-4e1b-89a5-c8b7b514023e"],

Cell[BoxData[{
 RowBox[{"SeedRandom", "[", "123", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"die", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", "10000"}], "]"}]}], 
  ";"}]}], "Input",
 CellLabel->"In[1]:=",
 CellID->560069374,ExpressionUUID->"0c54cfff-be73-44fe-91e5-8fbcb191ac3e"],

Cell[TextData[{
 "It is important to note that a variable will retain the information \
assigned to it until it is overwritten or cleared using the ",
 ButtonBox["Clear",
  BaseStyle->"Link"],
 " function. Keep in mind that either option will affect the results of all \
computations that use the variable if they are rerun. This is a useful \
function, especially if you are running more than one notebook at a time and \
are using similar computer variable names."
}], "Text",
 CellChangeTimes->{{3.7646096352430305`*^9, 3.7646096402810307`*^9}, {
   3.7646098609980307`*^9, 3.7646098618930306`*^9}, {3.764610205411031*^9, 
   3.764610209015031*^9}, 3.7646106501130304`*^9, 3.810401556714951*^9, 
   3.815838186673422*^9},
 CellID->42765712,ExpressionUUID->"60559197-742d-4fdf-a85b-4bd98790a36e"],

Cell[TextData[{
 "Clear the contents of the ",
 Cell[BoxData[
 "die"], "InlineCode",ExpressionUUID->
  "d871055b-245c-41f6-b00c-a6f6e9812e26"],
 " computer variable:"
}], "CodeCaption",
 CellChangeTimes->{{3.7646098812260303`*^9, 3.7646098817120304`*^9}, 
   3.7646099121570306`*^9, {3.7646099448370304`*^9, 3.7646100228000307`*^9}, 
   3.7646101690170307`*^9, {3.7649298723410683`*^9, 3.7649298744921913`*^9}},
 CellID->632037609,ExpressionUUID->"18e6fdf9-ef68-4eb9-8007-04af753aeb0e"],

Cell[BoxData[
 RowBox[{"Clear", "[", "die", "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->161192109,ExpressionUUID->"5f6cbcec-29ed-42e5-af1e-ab7d419faea3"],

Cell[TextData[{
 "The ",
 ButtonBox["RandomVariate",
  BaseStyle->"Link"],
 " function takes a particular distribution with its parameters as the first \
argument and the number of random data point values required as second \
argument. The distribution that we are interested in is the discrete uniform \
distribution. Its parameters are the minimum and maximum values. (Note that \
the ",
 ButtonBox["RandomInteger",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["RandomChoice",
  BaseStyle->"Link"],
 " functions use the discrete uniform distribution. If you consult the ",
 ButtonBox["Documentation Center",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/"], None},
  ButtonNote->"https://reference.wolfram.com/language/"],
 ", you will note that the values can also be weighted.)"
}], "Text",
 CellChangeTimes->{{3.7646111420590305`*^9, 3.764611142357031*^9}, {
  3.7646782407195635`*^9, 3.7646782808255734`*^9}, {3.764678362936784*^9, 
  3.764678362939784*^9}},
 CellID->118392862,ExpressionUUID->"1617dbc8-b1f8-4998-a972-c532b21b4dab"],

Cell[TextData[{
 "Simulate a new experiment rolling a fair die ",
 Cell[BoxData[
  FormBox["10000", TraditionalForm]],ExpressionUUID->
  "f7508471-40ce-4101-88e7-b25fe78fe53f"],
 " times:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7646781966981616`*^9, {3.764678370308521*^9, 3.7646783846199517`*^9}},
 CellID->20933067,ExpressionUUID->"27a413c4-e99c-44e1-a778-9af770514824"],

Cell[BoxData[{
 RowBox[{"SeedRandom", "[", "123", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"die", "=", 
   RowBox[{"RandomVariate", "[", 
    RowBox[{
     RowBox[{"DiscreteUniformDistribution", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6"}], "}"}], "]"}], ",", "10000"}], "]"}]}], 
  ";"}]}], "Input",
 CellLabel->"In[4]:=",
 CellID->272051126,ExpressionUUID->"456d11f9-3015-4e68-8c8c-33a4a12be9bb"],

Cell[TextData[{
 "We can use use the ",
 ButtonBox["Tally",
  BaseStyle->"Link"],
 " function to count the occurrences of each value. It returns a nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object of names (in this case, the values 1 through 6) and the frequency \
count of each of these. To return the frequencies in the order one through \
six, we can use the ",
 ButtonBox["SortBy",
  BaseStyle->"Link"],
 " function. Its first argument is the nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object we are creating, and the second argument is the element in the \
nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object that we are interested in sorting. Since the nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " that the ",
 ButtonBox["Tally",
  BaseStyle->"Link"],
 " function returns has the die face value first and then the count, we will \
use the ",
 ButtonBox["First",
  BaseStyle->"Link"],
 " function. We will store the results in the ",
 Cell[BoxData[
 "dieCounts"], "InlineCodeText",ExpressionUUID->
  "5d51009c-2dec-4253-ae67-043737ea9107"],
 " computer variable."
}], "Text",
 CellChangeTimes->{{3.7646784394164305`*^9, 3.7646785036108494`*^9}, {
   3.7646795521856966`*^9, 3.7646795562831063`*^9}, {3.7649303589969034`*^9, 
   3.76493035999196*^9}, {3.7649323174619207`*^9, 3.7649323283825455`*^9}, 
   3.8158381995687304`*^9},
 CellID->512262468,ExpressionUUID->"76b84c60-76ef-462b-a330-21822b0d1a1c"],

Cell["\<\
The first element in the nested list is the value being counted and the \
second is the actual count:\
\>", "CodeCaption",
 CellID->463522401,ExpressionUUID->"a5989c47-ae26-4a37-81c6-5b6b772d6be9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dieCounts", "=", 
  RowBox[{"SortBy", "[", 
   RowBox[{
    RowBox[{"Tally", "[", "die", "]"}], ",", "First"}], "]"}]}]], "Input",
 CellLabel->"In[6]:=",
 CellID->290980916,ExpressionUUID->"f0af3271-46b6-4994-9886-e8bc463cc343"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1622"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1682"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1661"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1653"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1642"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "1740"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.810385807545225*^9, 3.812733465803*^9},
 CellLabel->"Out[6]=",
 CellID->694336830,ExpressionUUID->"04b76eb6-4fa6-4be7-a81a-7ae05b23c60d"]
}, Open  ]],

Cell[TextData[{
 "The ",
 ButtonBox["Counts",
  BaseStyle->"Link"],
 " function can also be used. We learned that it returns an ",
 ButtonBox["Association",
  BaseStyle->"Link"],
 " object, associating each name with a count:"
}], "CodeCaption",
 CellID->68494916,ExpressionUUID->"192de5f8-49f8-40ef-ae3b-28816e05439a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Counts", "[", "die", "]"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->432683771,ExpressionUUID->"0ea37773-e5fb-4418-92cf-0fb84284f31c"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"4", "\[Rule]", "1653"}], ",", 
   RowBox[{"6", "\[Rule]", "1740"}], ",", 
   RowBox[{"2", "\[Rule]", "1682"}], ",", 
   RowBox[{"3", "\[Rule]", "1661"}], ",", 
   RowBox[{"1", "\[Rule]", "1622"}], ",", 
   RowBox[{"5", "\[Rule]", "1642"}]}], "\[RightAssociation]"}]], "Output",
 CellChangeTimes->{3.8103858075611477`*^9, 3.812733465818924*^9},
 CellLabel->"Out[7]=",
 CellID->292964012,ExpressionUUID->"976c2e07-924b-4504-b2a4-fcb71d4dfc03"]
}, Open  ]],

Cell[TextData[{
 "Using indexing, we can collate all the second elements in each nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object element in the ",
 Cell[BoxData[
 "dieCounts"], "InlineCodeText",ExpressionUUID->
  "aa358ac8-9a61-4b0c-a69e-cbaaeeee7aa0"],
 " computer variable."
}], "Text",
 CellID->85046672,ExpressionUUID->"9eedb627-fb58-4a00-a2df-e7f15a811936"],

Cell[TextData[{
 "Store the results in the ",
 Cell[BoxData[
 "counts"], "InlineCode",ExpressionUUID->
  "49eb0820-ba5f-450f-9398-6c14434ace47"],
 " computer variable:"
}], "CodeCaption",
 CellChangeTimes->{{3.7646785971572037`*^9, 3.7646785990053883`*^9}},
 CellID->28627986,ExpressionUUID->"e9827bd8-5098-41c9-bcc4-4c786f696ab6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"counts", "=", 
  RowBox[{"dieCounts", "\[LeftDoubleBracket]", 
   RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}]}]], "Input",
 CellLabel->"In[8]:=",
 CellID->3381550,ExpressionUUID->"29f1bd2f-573a-4bac-9b12-6dfd3f638533"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1622", ",", "1682", ",", "1661", ",", "1653", ",", "1642", ",", "1740"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.810385807566513*^9, 3.812733465824842*^9},
 CellLabel->"Out[8]=",
 CellID->1813630760,ExpressionUUID->"95c97f7c-3f9b-4e1c-b7d7-e98e452e8d18"]
}, Open  ]],

Cell["We can do the same with the die face values.", "Text",
 CellChangeTimes->{{3.764678675400027*^9, 3.7646786820886955`*^9}},
 CellID->145482982,ExpressionUUID->"67ec5424-8db6-4c7e-8d2c-c9eb79716141"],

Cell[TextData[{
 "Store the die face values in the computer variable ",
 Cell[BoxData[
 "faceValue"], "InlineCode",ExpressionUUID->
  "ab0107f1-7ccf-4f73-b35b-1c7529edbd46"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.764678687265213*^9, 3.76467869733722*^9}},
 CellID->233614204,ExpressionUUID->"a673fcfb-6de4-4151-b6e3-e5ed4978d75f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"faceValue", "=", 
  RowBox[{"dieCounts", "\[LeftDoubleBracket]", 
   RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}]], "Input",
 CellLabel->"In[9]:=",
 CellID->116867700,ExpressionUUID->"322a93de-4d04-42aa-91e1-1c48a1cece20"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.810385807582265*^9, 3.8127334658403883`*^9},
 CellLabel->"Out[9]=",
 CellID->309297802,ExpressionUUID->"b73fd4b7-204a-4853-9eb9-fa2b6a2783d8"]
}, Open  ]],

Cell["\<\
We can create a bar chart showing how many times each of these six values \
ended face up. A bar chart shows the number of specific values of a discrete \
or categorical variable.\
\>", "Text",
 CellChangeTimes->{{3.7649309485726247`*^9, 3.764930948868642*^9}},
 CellID->501766448,ExpressionUUID->"54b484cd-e0b9-487f-9611-f103eb4bdd2a"],

Cell["Create a bar chart to show the frequency count:", "CodeCaption",
 CellChangeTimes->{{3.7646787150889955`*^9, 3.7646787154980364`*^9}},
 CellID->271148052,ExpressionUUID->"2023b3f7-e269-4d75-81cb-0af6d9017644"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BarChart", "[", 
  RowBox[{"counts", ",", 
   RowBox[{"ChartLabels", "\[Rule]", "faceValue"}]}], "]"}]], "Input",
 CellLabel->"In[10]:=",
 CellID->291559845,ExpressionUUID->"2e2c52e8-af6a-4e7f-a3f3-47b67158cae6"],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], 
    PointBox[{{0.43075018208302984`, 0.}, {6.451201747997087, 0.}}]}, {{}, 
    {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
     0.6579999999999999], Thickness[Small]}], 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.6579999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{0.5487982520029133, 0.}, {1.4512017479970867`, 
             1622.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{33.67592331050067, 
            102.40901179588033`}, {-123.95067364959291`, 
            135.69811066745015`}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1622]& ,
         TagBoxNote->"1622"],
        StyleBox["1622", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1622, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.6579999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{1.5487982520029133`, 0.}, {2.4512017479970867`, 
             1682.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{109.28853871843145`, 
            178.0216272038111}, {-133.53694187340463`, 135.69811066745015`}}],
          
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1682]& ,
         TagBoxNote->"1682"],
        StyleBox["1682", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1682, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.6579999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{2.5487982520029133`, 0.}, {3.4512017479970867`, 
             1661.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{184.90115412636226`, 
            253.6342426117419}, {-130.18174799507054`, 135.69811066745015`}}],
          
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1661]& ,
         TagBoxNote->"1661"],
        StyleBox["1661", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1661, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.6579999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{3.5487982520029133`, 0.}, {4.451201747997087, 
             1653.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{260.51376953429303`, 
            329.2468580196727}, {-128.9035788985623, 135.69811066745015`}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1653]& ,
         TagBoxNote->"1653"],
        StyleBox["1653", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1653, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.6579999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{4.548798252002913, 0.}, {5.451201747997087, 1642.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{336.1263849422238, 
            404.85947342760346`}, {-127.1460963908635, 135.69811066745015`}}],
          
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1642]& ,
         TagBoxNote->"1642"],
        StyleBox["1642", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1642, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[
      0.6579999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{5.548798252002913, 0.}, {6.451201747997087, 1740.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{411.73900035015464`, 
            480.47208883553424`}, {-142.80366782308928`, 
            135.69811066745015`}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1740]& ,
         TagBoxNote->"1740"],
        StyleBox["1740", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1740, {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, {}, {}, 
   StyleBox[{
     {Thickness[Tiny], 
      LineBox[{{0.43075018208302984`, 0.}, {6.5716107793153675`, 0.}}], 
      StyleBox[{}, "GraphicsLabel",
       StripOnInput->False]}, 
     StyleBox[{
       {Thickness[Tiny], 
        LineBox[{{0.5487982520029133, 0.}, 
          Offset[{-1.102182119232618*^-15, -6.}, {0.5487982520029133, 0.}]}], 
        LineBox[{{6.451201747997087, 0.}, 
          Offset[{-1.102182119232618*^-15, -6.}, {6.451201747997087, 
           0.}]}], {{}, {}, {}, {}, {}, {}, {
          LineBox[{{1.4512017479970867`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {1.4512017479970867`, 
             0.}]}], LineBox[{{1.5487982520029133`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {1.5487982520029133`, 
             0.}]}], LineBox[{{2.4512017479970867`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {2.4512017479970867`, 
             0.}]}], LineBox[{{2.5487982520029133`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {2.5487982520029133`, 
             0.}]}], LineBox[{{3.4512017479970867`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {3.4512017479970867`, 
             0.}]}], LineBox[{{3.5487982520029133`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {3.5487982520029133`, 
             0.}]}], LineBox[{{4.451201747997087, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {4.451201747997087, 0.}]}],
           LineBox[{{4.548798252002913, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {4.548798252002913, 0.}]}],
           LineBox[{{5.451201747997087, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {5.451201747997087, 0.}]}],
           LineBox[{{5.548798252002913, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {5.548798252002913, 
             0.}]}]}, {}}}, 
       StyleBox[
        {Thickness[Tiny], 
         InsetBox["1", Offset[{0, -2}, {1., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["2", Offset[{0, -2}, {2., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["3", Offset[{0, -2}, {3., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["4", Offset[{0, -2}, {4., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["5", Offset[{0, -2}, {5., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["6", Offset[{0, -2}, {6., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}]}, 
        "GraphicsLabel",
        StripOnInput->False]}, "GraphicsTicks",
      StripOnInput->False]}, "GraphicsAxes",
    StripOnInput->False,
    Antialiasing->False]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.43075018208302984`, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{500., Automatic},
  PlotRange->{{All, All}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{3.8103858077683*^9, 3.812733466086031*^9},
 CellLabel->"Out[10]=",
 CellID->1457732474,ExpressionUUID->"3deb0380-8549-4bb1-8c2f-68a9497ddf33"]
}, Open  ]],

Cell[TextData[{
 "Notice the pattern that this chart shows us. All six values are (nearly) \
equally likely. When we count the occurrences of an event and plot it in this \
way, we refer to it as a ",
 StyleBox["frequency distribution",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.7646787348679733`*^9, 3.764678753005787*^9}, {
  3.7646793172922096`*^9, 3.7646793184273233`*^9}, {3.776942349288489*^9, 
  3.77694237567092*^9}, {3.815838232128076*^9, 3.815838232287916*^9}},
 CellID->812740575,ExpressionUUID->"18f55d5f-1d54-4218-bb87-ecc35a28f0a2"],

Cell[TextData[{
 "We can use this very simple example to start to develop our intuition about \
probabilities and ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "0dc4025a-d836-4d91-bb3b-89a1145b4366"],
 "-values. We develop this intuition around the concept of area, as in the \
area of a rectangle or the area under a curve."
}], "Text",
 CellChangeTimes->{{3.7769423942292633`*^9, 3.7769423955098886`*^9}, {
  3.7769424605509353`*^9, 3.776942489910425*^9}, {3.7769427160662303`*^9, 
  3.7769427392811413`*^9}},
 CellID->25356097,ExpressionUUID->"1f3af079-f43a-4a5f-971a-640c43f2e44c"],

Cell[TextData[{
 "From the frequency distribution, we can develop a relative frequency \
distribution. This is done by dividing each of the counts by the total number \
of cases, ",
 Cell[BoxData[
  FormBox["10000", TraditionalForm]],ExpressionUUID->
  "97095aef-36b9-44f7-a708-9e5558cb1072"],
 ", in this example. We are now expressing each outcome as a fraction of the \
whole, which must sum to ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "ac226186-25c6-4710-b339-d921d8816b07"],
 "."
}], "Text",
 CellChangeTimes->{{3.776942727606394*^9, 3.7769428330589314`*^9}, {
   3.776942867899704*^9, 3.776942873988426*^9}, {3.8104007734643917`*^9, 
   3.810400788987874*^9}, 3.81583825305639*^9},
 CellID->104697398,ExpressionUUID->"a46323dd-7248-46db-aea4-6bc957f1746d"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
 "\"\<\!\(\*ButtonBox[\"Probability\",BaseStyle->\"CodeLink\"]\)\>\""], 
  "InlineCodeText",ExpressionUUID->"ccd2dee4-3263-4b1d-ad87-07fc72c40dfe"],
 " argument in the ",
 ButtonBox["Histogram",
  BaseStyle->"Link"],
 " function allows us to visualize this relative frequency distribution. The \
Wolfram Language will assume a total of six bins. Look at the value on the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "bd0324ba-b3bb-4aba-81d8-986b51d4b05a"],
 " axis. If you run this in your own notebook, you can hover over each \
rectangle. "
}], "Text",
 CellChangeTimes->{{3.764679746795092*^9, 3.7646797499664574`*^9}, {
   3.7646802769704227`*^9, 3.7646802771214075`*^9}, 3.76493146110294*^9, {
   3.776942894628224*^9, 3.7769429733368144`*^9}, {3.815838343377215*^9, 
   3.8158383825692997`*^9}},
 CellID->267213650,ExpressionUUID->"4c8ab552-0d59-42a2-82a5-e006ff64976d"],

Cell[TextData[{
 "Create a histogram of probabilities. ",
 ButtonBox["Automatic",
  BaseStyle->"Link"],
 " will order the ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula",ExpressionUUID->
  "48875432-7230-4f4c-8c4d-385982c7573f"],
 " axis values:"
}], "CodeCaption",
 CellChangeTimes->{{3.7646797972100067`*^9, 3.7646798294425592`*^9}, 
   3.7646798931008253`*^9},
 CellID->93797649,ExpressionUUID->"41380cdf-e21e-45a9-a201-0518968b0f52"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"die", ",", "Automatic", ",", "\"\<Probability\>\""}], 
  "]"}]], "Input",
 CellLabel->"In[11]:=",
 CellID->598609423,ExpressionUUID->"655d7f98-0b21-487b-a5f1-49e4f001d726"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.644], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.644], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{0.5, 0}, {1.5, 0.1622}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{30.98298638911129, 
           108.42453963170536`}, {-124.14555360502925`, 134.00903218818848`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.1622]& ,
        TagBoxNote->"0.1622"],
       StyleBox["0.1622`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.1622, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{1.5, 0}, {2.5, 0.1682}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{107.92453963170536`, 
           185.36609287429943`}, {-133.676549380364, 134.00903218818848`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.1682]& ,
        TagBoxNote->"0.1682"],
       StyleBox["0.1682`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.1682, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{2.5, 0}, {3.5, 0.1661}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{184.86609287429943`, 
           262.30764611689347`}, {-130.34070085899685`, 134.00903218818848`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.1661]& ,
        TagBoxNote->"0.1661"],
       StyleBox["0.1661`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.1661, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{3.5, 0}, {4.5, 0.1653}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{261.80764611689347`, 
           339.24919935948753`}, {-129.06990142228557`, 134.00903218818848`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.1653]& ,
        TagBoxNote->"0.1653"],
       StyleBox["0.1653`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.1653, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{4.5, 0}, {5.5, 0.1642}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{338.74919935948753`, 
           416.1907526020816}, {-127.32255219680752`, 134.00903218818848`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.1642]& ,
        TagBoxNote->"0.1642"],
       StyleBox["0.1642`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.1642, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{5.5, 0}, {6.5, 0.174}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{415.6907526020816, 
           493.13230584467567`}, {-142.889845296521, 134.00903218818848`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.174]& ,
        TagBoxNote->"0.174"],
       StyleBox["0.174`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.174, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.38, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{504., Automatic},
  PlotRange->{{0.5, 6.5}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7769429836931486`*^9, 3.7769429974972315`*^9}, 
   3.810385807941249*^9, 3.812733466150218*^9},
 CellLabel->"Out[11]=",
 CellID->1616245542,ExpressionUUID->"a791dcef-ce64-4696-a62f-f3c2ada85cd6"]
}, Open  ]],

Cell[TextData[{
 "We now have a probability of rolling each of the six discrete values. \
Hovering over the bar representing 6, we see the probability, or ",
 StyleBox["p",
  FontSlant->"Italic"],
 "-value, of 0.174."
}], "Text",
 CellChangeTimes->{{3.764680228321288*^9, 3.7646802285432663`*^9}, {
   3.764680714698807*^9, 3.764680760472807*^9}, {3.7649314935817976`*^9, 
   3.76493149484487*^9}, {3.7769380244159184`*^9, 3.7769380395721865`*^9}, {
   3.7769430109622517`*^9, 3.7769430489825387`*^9}, {3.776943192069145*^9, 
   3.7769432180217524`*^9}, 3.8104007929735413`*^9, 3.8127307650336113`*^9},
 CellID->84680248,ExpressionUUID->"9e1b4946-2d4b-4bec-b955-a8c1921b0185"],

Cell[TextData[{
 "One way of understanding probability (and later ",
 StyleBox["p",
  FontSlant->"Italic"],
 "-values) is to consider area. In the case of the previous visualizations, \
the area of a rectangle. Since we are dealing with a discrete variable (which \
cannot be divided), we consider the width of the base of the rectangles as \
equal to ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "7163596c-b39d-4849-92f9-060645e4c365"],
 ". The height is given by the relative frequency. Since the area for a \
rectangle is base times height, we have used the area of each rectangle as \
the probability of our random variable taking on a specific value."
}], "Text",
 CellChangeTimes->{{3.7769461444126654`*^9, 3.7769464662388825`*^9}, {
  3.810400795088107*^9, 3.810400798406217*^9}, {3.815838506535819*^9, 
  3.815838515671565*^9}},
 CellID->635034296,ExpressionUUID->"cafa9afa-f5a9-40cf-8e6e-f17286deaa07"],

Cell[TextData[{
 "What we are trying to represent here, though, is called a probability mass \
function, a function that gives the probability that a discrete random \
variable is equal to a stated value. The term mass is used for discrete \
variables. Later in this chapter, we will introduce the probability density \
function (PDF) for continuous variables. The Wolfram Language ",
 ButtonBox["PDF",
  BaseStyle->"Link"],
 " function is used in both cases."
}], "Text",
 CellChangeTimes->{{3.776943067154936*^9, 3.77694313617168*^9}, {
   3.7769431724027586`*^9, 3.776943180819233*^9}, 3.7769432314538145`*^9, {
   3.7769433621218777`*^9, 3.776943364558359*^9}, {3.776943449510298*^9, 
   3.7769434865033426`*^9}, {3.7769462908563204`*^9, 3.776946292214634*^9}, {
   3.776946519178294*^9, 3.776946528919022*^9}, {3.810400799597172*^9, 
   3.8104008016336937`*^9}, 3.812731128614112*^9, {3.815838551639703*^9, 
   3.8158385680633087`*^9}, {3.815844645637315*^9, 3.8158446517961693`*^9}, {
   3.816450834403344*^9, 3.816450835743473*^9}},
 CellID->65808809,ExpressionUUID->"bb6414b3-2c90-4019-bf1e-81526fc562bf"],

Cell[TextData[{
 "With every discrete value having an equal probability of being selected at \
random. our probability mass function is an example of a discrete uniform \
distribution (which is why we used ",
 ButtonBox["DiscreteUniformDistribution",
  BaseStyle->"Link"],
 " to create the random variable in the first place). If you roll a fair die \
and it lands with a 5 facing up, you could state that the probability of \
having rolled a 5 is ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "6"], TraditionalForm]],ExpressionUUID->
  "dd781549-e24b-467a-85c2-4e9e54931bac"],
 ", the same as for any of the other values."
}], "Text",
 CellChangeTimes->{{3.7646810331138067`*^9, 3.7646810476158066`*^9}, 
   3.764931589445281*^9, {3.776937948682115*^9, 3.776937950447362*^9}, {
   3.776938067425387*^9, 3.776938070246773*^9}, {3.776943247655485*^9, 
   3.7769433357155333`*^9}, {3.77694338218423*^9, 3.7769434212438517`*^9}, {
   3.7769435568691525`*^9, 3.77694356306015*^9}, {3.776946854253894*^9, 
   3.7769469124134417`*^9}, 3.812731221642661*^9, {3.8158385936397*^9, 
   3.815838613729837*^9}, 3.815838733279654*^9},
 CellID->166011649,ExpressionUUID->"b7807492-4da4-49a0-a4b3-d6e1d25f0b93"],

Cell[TextData[{
 "Use the ",
 ButtonBox["PDF",
  BaseStyle->"Link"],
 " function to look at the probability mass function of the discrete uniform \
distribution with a sample space of values ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "1d4d08cf-d362-47c3-817b-47a9af462dc5"],
 " through ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "a591a545-1f6d-47eb-8440-d785323629d8"],
 ". The ",
 ButtonBox["DiscreteUniformDistribution",
  BaseStyle->"Link"],
 " function takes a List object as argument, representing the minimum and \
maximum value that the random variable can take. The second argument for the ",
 ButtonBox["PDF",
  BaseStyle->"Link"],
 " function is ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "950e1820-00d0-45da-9724-277097ed5485"],
 ", representing the actual value that the variable takes."
}], "Text",
 CellChangeTimes->{{3.77694361093611*^9, 3.776943761984377*^9}, {
  3.7769437975458117`*^9, 3.7769438342267275`*^9}, {3.8104008027488728`*^9, 
  3.810400803794201*^9}, {3.812731379026141*^9, 3.81273140062921*^9}, {
  3.815838646759848*^9, 3.815838646975402*^9}},
 CellID->442486879,ExpressionUUID->"306441d9-ea1a-4212-996e-5b1aec24039e"],

Cell["Show the discrete uniform distribution\[CloseCurlyQuote]s PDF:", \
"CodeCaption",
 CellChangeTimes->{{3.764681231965807*^9, 3.764681271260807*^9}, {
   3.7646818174460435`*^9, 3.764681828206195*^9}, {3.7646818596124754`*^9, 
   3.764681861827918*^9}, 3.815838723025544*^9, {3.8164508603512278`*^9, 
   3.816450860727162*^9}},
 CellID->457704754,ExpressionUUID->"3b295b0b-3462-412b-a3ce-7b4263f6e0c6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PDF", "[", 
  RowBox[{
   RowBox[{"DiscreteUniformDistribution", "[", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}], "]"}], ",", "k"}], "]"}]], "Input",
 CellLabel->"In[12]:=",
 CellID->363357430,ExpressionUUID->"0d5ebf6f-5023-4225-8edc-16544ea419c2"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {
        FractionBox["1", 
         RowBox[{"1", "-", "a", "+", "b"}]], 
        RowBox[{"a", "\[LessEqual]", "k", "\[LessEqual]", "b"}]},
       {"0", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}},
      Selectable->True]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False,
  StripWrapperBoxes->True]], "Output",
 CellChangeTimes->{3.810385807949243*^9, 3.812733466158774*^9},
 CellLabel->"Out[12]=",
 CellID->718173491,ExpressionUUID->"e7be430d-4f43-436b-a3ef-b51b566ffeb7"]
}, Open  ]],

Cell[TextData[{
 "This formula states that given any number ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]], "InlineMath",ExpressionUUID->
  "9254710d-8664-473b-82ad-1a3c4c545d07"],
 " in the closed interval ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]], "InlineMath",ExpressionUUID->
  "c6c8a1a6-ec13-473a-a66b-181fe215cb07"],
 ", ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]], "InlineMath",ExpressionUUID->
  "e426a80e-1c18-4f6b-a5ca-4803fdd73332"],
 ", the likelihood of ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]], "InlineMath",ExpressionUUID->
  "2385ec18-a05c-48ce-9ee2-b8e7d1b86174"],
 " being selected at random can be found using the expression below."
}], "Text",
 CellChangeTimes->{
  3.7646814711528068`*^9, {3.7646815175168066`*^9, 3.7646816018278065`*^9}, {
   3.7646843939257984`*^9, 3.7646844093857985`*^9}, {3.774197291677855*^9, 
   3.7741972951320343`*^9}, {3.7769438861371713`*^9, 3.7769439146977882`*^9}},
 
 CellID->441068988,ExpressionUUID->"497abdc4-d489-462e-8ac7-cb08e72018d3"],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{"1", "-", "a", "+", "b"}]], TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{3.7646939040513797`*^9},
 CellID->788329313,ExpressionUUID->"a275f34c-2607-430f-b756-678f46afb854"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s look at the probability of rolling a ",
 Cell[BoxData[
  FormBox["5", TraditionalForm]],ExpressionUUID->
  "23c76748-83c5-44d5-a8ac-4d687032c8dc"],
 " then:"
}], "CodeCaption",
 CellChangeTimes->{{3.7769441083908186`*^9, 3.7769441246496897`*^9}, {
  3.812731544417664*^9, 3.812731545361376*^9}},
 CellID->11885163,ExpressionUUID->"cfdc7245-8391-47b0-a145-63ca1047d03a"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"1", "-", "1", "+", "6"}],
  FractionLine->0.2]], "Input",
 CellLabel->"In[13]:=",
 CellID->114856603,ExpressionUUID->"00976e7e-8386-473a-8622-dd96d0f60180"],

Cell[BoxData[
 FractionBox["1", "6",
  FractionLine->0.2]], "Output",
 CellChangeTimes->{3.810385807964447*^9, 3.812733466174705*^9},
 CellLabel->"Out[13]=",
 CellID->1483767097,ExpressionUUID->"1fb613e6-1646-4900-a82c-1e343cca1311"]
}, Open  ]],

Cell[TextData[{
 "Use the ",
 ButtonBox["PDF",
  BaseStyle->"Link"],
 " function to show the probability of our random variable taking on a value \
of 5:"
}], "CodeCaption",
 CellChangeTimes->{{3.764681231965807*^9, 3.764681271260807*^9}, {
   3.7646818174460435`*^9, 3.764681828206195*^9}, {3.7646818596124754`*^9, 
   3.764681861827918*^9}, {3.776938706019014*^9, 3.7769387275477095`*^9}, {
   3.776944163338211*^9, 3.7769441773308334`*^9}, 3.815838968751319*^9},
 CellID->56358650,ExpressionUUID->"4ebcb57e-2c54-442d-9066-6111713ddc9d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PDF", "[", 
  RowBox[{
   RowBox[{"DiscreteUniformDistribution", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "6"}], "}"}], "]"}], ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.7769386787522383`*^9, 3.776938693365425*^9}, {
  3.776944179376405*^9, 3.7769441797722993`*^9}},
 CellLabel->"In[14]:=",
 CellID->301633926,ExpressionUUID->"b11b5f36-3d57-4e1d-baf0-3ddbd112ca4d"],

Cell[BoxData[
 FractionBox["1", "6",
  FractionLine->0.2]], "Output",
 CellChangeTimes->{3.776938693568494*^9, 3.7769441800994496`*^9, 
  3.81038580796992*^9, 3.812733466180258*^9},
 CellLabel->"Out[14]=",
 CellID->1093490315,ExpressionUUID->"affd3e6a-3a43-4eeb-b93e-ae55fdb3f75e"]
}, Open  ]],

Cell[TextData[{
 "For our die experiment, we could use the ",
 ButtonBox["DiscretePlot",
  BaseStyle->"Link"],
 " function to show the probability of each of the six values."
}], "Text",
 CellChangeTimes->{{3.7769439282335863`*^9, 3.776944019685055*^9}, 
   3.7769441895910926`*^9, {3.8127315981241827`*^9, 3.812731610881299*^9}},
 CellID->325844190,ExpressionUUID->"688c3467-bc23-44e5-8832-5beb03c94a2d"],

Cell[TextData[{
 ButtonBox["DiscretePlot",
  BaseStyle->"Link"],
 " is used to show data that has no connective data between points:"
}], "CodeCaption",
 CellChangeTimes->{{3.812731655177017*^9, 3.812731657960742*^9}},
 CellID->235290855,ExpressionUUID->"2cdce688-417b-4e7f-a2bf-494095dabceb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiscretePlot", "[", 
  RowBox[{
   RowBox[{"PDF", "[", 
    RowBox[{
     RowBox[{"DiscreteUniformDistribution", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6"}], "}"}], "]"}], ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "1", ",", "6"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0.2"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7769383886577406`*^9, 3.7769384329699154`*^9}, {
  3.7769385007868075`*^9, 3.776938571344554*^9}, {3.7769439788612356`*^9, 
  3.7769439826999683`*^9}},
 CellLabel->"In[15]:=",
 CellID->121014798,ExpressionUUID->"d2acc071-7ee5-471b-b3ba-64a602202eba"],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     TagBox[{
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.012833333333333334`], AbsoluteThickness[1.6], Opacity[0.2], 
        LineBox[{},
         VertexColors->None]}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.012833333333333334`], AbsoluteThickness[1.6], Opacity[0.2], 
        LineBox[{{{1., 0.16666666666666666`}, {1., 0}}, {{2., 
           0.16666666666666666`}, {2., 0}}, {{3., 0.16666666666666666`}, {
           3., 0}}, {{4., 0.16666666666666666`}, {4., 0}}, {{5., 
           0.16666666666666666`}, {5., 0}}, {{6., 0.16666666666666666`}, {
           6., 0}}},
         VertexColors->None]}},
      Annotation[#, "Charting`Private`Tag$23108#1"]& ]}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], {}, 
      PointBox[{{1., 0.16666666666666666`}, {2., 0.16666666666666666`}, {3., 
       0.16666666666666666`}, {4., 0.16666666666666666`}, {5., 
       0.16666666666666666`}, {6., 0.16666666666666666`}}], {}},
     Annotation[#, "Charting`Private`Tag$23108#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "MessagesHead" -> DiscretePlot, "AxisPadding" -> Scaled[0.02], 
    "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05]},
  PlotRange->{{0, 6.}, {0, 0.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.776938421036868*^9, 3.776938433768289*^9}, 
   3.776938503497364*^9, {3.77693855030235*^9, 3.7769385721918716`*^9}, 
   3.776943985582259*^9, 3.810385808023522*^9, 3.812733466212455*^9},
 CellLabel->"Out[15]=",
 CellID->126673179,ExpressionUUID->"c1b75137-b2b9-44f4-bd8d-8f0835a4754d"]
}, Open  ]],

Cell[TextData[{
 "Hence, values outside of these bounds (the ",
 ButtonBox["True",
  BaseStyle->"Link"],
 " in the PDF above) have a zero probability of occurring. For example, we \
cannot roll a 7 or a 1.5."
}], "Text",
 CellChangeTimes->{
  3.764681719064807*^9, {3.7646820068639193`*^9, 3.764682034755497*^9}, {
   3.7769440450412455`*^9, 3.7769440474358916`*^9}, {3.812732306799386*^9, 
   3.8127323199979486`*^9}, 3.815838943455598*^9},
 CellID->202718110,ExpressionUUID->"02e3178d-4438-4d21-a0b0-027a32b823f2"],

Cell["\<\
Show that the PDF for the uniform discrete distribution of 7 is 0:\
\>", "CodeCaption",
 CellChangeTimes->{{3.764681231965807*^9, 3.764681271260807*^9}, {
  3.7646818174460435`*^9, 3.764681828206195*^9}, {3.7646818596124754`*^9, 
  3.764681861827918*^9}, {3.776938277024288*^9, 3.776938336477361*^9}, {
  3.7769387325337577`*^9, 3.776938732783777*^9}, {3.8158390395032043`*^9, 
  3.8158390516062927`*^9}},
 CellID->447508593,ExpressionUUID->"8f88888d-00f4-41da-b6b3-cfcde9a6faf5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PDF", "[", 
  RowBox[{
   RowBox[{"DiscreteUniformDistribution", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "6"}], "}"}], "]"}], ",", "7"}], "]"}]], "Input",
 CellChangeTimes->{{3.776938232753339*^9, 3.7769382594700994`*^9}},
 CellLabel->"In[16]:=",
 CellID->487766923,ExpressionUUID->"6c15c425-3cd1-4c50-bdae-12f479a73edc"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7769382461903725`*^9, 3.7769382597384996`*^9}, 
   3.810385808030487*^9, 3.81273346621978*^9},
 CellLabel->"Out[16]=",
 CellID->839825276,ExpressionUUID->"2ff12806-55e8-4023-8da5-be0851cc5e5e"]
}, Open  ]],

Cell[TextData[{
 "We can also use the ",
 ButtonBox["Probability",
  BaseStyle->"Link"],
 " function. It looks more like what we are trying to achieve in this \
equation."
}], "Text",
 CellChangeTimes->{{3.7769387849838457`*^9, 3.776938844315403*^9}, {
   3.7769389781422048`*^9, 3.7769390715496283`*^9}, {3.776944212461872*^9, 
   3.776944241351609*^9}, 3.810400804852392*^9, {3.810402835919681*^9, 
   3.8104028873853903`*^9}, 3.812732337400543*^9, 3.8158391731853437`*^9, {
   3.816451655710451*^9, 3.816451656021912*^9}},
 CellID->72720277,ExpressionUUID->"a079c9b9-118c-49d7-88ef-57bd3e6748dd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["P",
    FontSlant->"Italic"], 
   RowBox[{"(", 
    RowBox[{
     StyleBox["x",
      FontSlant->"Italic"], "=", 
     RowBox[{"3", "|", 
      RowBox[{
      "Discrete", " ", "uniform", " ", "distribution", " ", "for", " ", 
       StyleBox["x",
        FontSlant->"Italic"], " ", "being", " ", "1", " ", "through", " ", 
       "6"}]}]}], ")"}]}], "=", 
  FractionBox["1", "6"]}]], "DisplayFormula",
 CellChangeTimes->{{3.7769388565322294`*^9, 3.776938907065132*^9}, 
   3.8164516656060467`*^9},
 CellID->707922722,ExpressionUUID->"2c5dfd42-ce23-4359-bd73-45b5e6bc8a6f"],

Cell[TextData[{
 "It states that the probability of our random value taking on a value of ",
 Cell[BoxData[
  FormBox["3", TraditionalForm]],ExpressionUUID->
  "9deb54f4-936c-42a7-ba0a-ccdda901831f"],
 " given a discrete uniform distribution with minimum value of ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "5928e102-77c7-4098-9c62-c769f3e71ed4"],
 " and maximum value of ",
 Cell[BoxData[
  FormBox["6", TraditionalForm]],ExpressionUUID->
  "ecdcde2d-cbd4-4f12-9d53-2c64feca9313"],
 " is ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "6",
    FractionLine->0.2], TraditionalForm]], "InlineMath",ExpressionUUID->
  "8f25113f-c4fb-4d90-be75-9b30f75f500e"],
 "\[NegativeThinSpace]."
}], "Text",
 CellChangeTimes->{{3.7769442543917356`*^9, 3.7769443070430574`*^9}, 
   3.776944337771042*^9, 3.8158392765987797`*^9, {3.815839371527463*^9, 
   3.8158393767126703`*^9}, {3.8158394143333807`*^9, 3.815839418902382*^9}},
 CellID->42081074,ExpressionUUID->"7efb3094-5c21-4f8e-9ae5-2561aef4edc3"],

Cell[TextData[{
 "Use the ",
 ButtonBox["Probability",
  BaseStyle->"Link"],
 " function (note the use of ",
 Cell[BoxData[
  TemplateBox[{"esc"},
   "Key0"]], "InlineCodeText",ExpressionUUID->
  "5301d007-d81f-4ecb-92b6-4d4de0f30e8d"],
 " dist ",
 Cell[BoxData[
  TemplateBox[{"esc"},
   "Key0"]], "InlineCodeText",ExpressionUUID->
  "81784d6c-f2b5-41e5-b15c-cc284207404e"],
 " to create the ",
 Cell[BoxData[
  FormBox["\[Distributed]", TraditionalForm]], "InlineCode",
  FormatType->"TraditionalForm",ExpressionUUID->
  "bb621dea-f64e-418e-ba0e-45f42cb358ad"],
 " symbol):"
}], "CodeCaption",
 CellChangeTimes->{{3.764681231965807*^9, 3.764681271260807*^9}, {
   3.7646818174460435`*^9, 3.764681828206195*^9}, {3.7646818596124754`*^9, 
   3.764681861827918*^9}, {3.7769391276698885`*^9, 3.7769391642964106`*^9}, {
   3.815839449238058*^9, 3.8158394665760803`*^9}, {3.8158394981921797`*^9, 
   3.815839499630965*^9}, 3.815839540375147*^9},
 CellID->50329074,ExpressionUUID->"88e888b9-86cd-4fc0-ac0c-f3bca7d5f3a2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Probability", "[", 
  RowBox[{
   RowBox[{"x", "\[Equal]", "3"}], ",", 
   RowBox[{"x", "\[Distributed]", 
    RowBox[{"DiscreteUniformDistribution", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7769389155503693`*^9, 3.7769389190004025`*^9}, {
  3.776939077916579*^9, 3.776939111107803*^9}},
 CellLabel->"In[17]:=",
 CellID->358956926,ExpressionUUID->"dc1bf21a-bc4b-4e76-a9a3-43c6b28d87f1"],

Cell[BoxData[
 FractionBox["1", "6",
  FractionLine->0.2]], "Output",
 CellChangeTimes->{3.776939112160234*^9, 3.810385808065063*^9, 
  3.812733466268341*^9},
 CellLabel->"Out[17]=",
 CellID->1680885648,ExpressionUUID->"a341cfb6-5526-4ddb-9c96-5363d7a89b68"]
}, Open  ]],

Cell[TextData[{
 "This brings us to a very important point. The sum of all the probabilities \
must equal 1. This represents 100%. Given a collectively exhaustive, mutually \
exclusive list of outcomes, the probability of any such outcome occurring is \
in the interval ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{"0", ",", " ", "1"}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "fa42d425-1005-43b2-9deb-c699d6d3db53"],
 "], and they must all sum to 1. We cannot have a 101% probability of an \
outcome or a ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "3"}], TraditionalForm]],ExpressionUUID->
  "8c382413-b3ab-467b-a521-89bdca7493a4"],
 "% probability of an outcome."
}], "Text",
 CellChangeTimes->{{3.7646843641047983`*^9, 3.764684376150798*^9}, 
   3.7646844303557982`*^9, {3.7769443561399*^9, 3.7769444142116203`*^9}},
 CellID->670304900,ExpressionUUID->"5e35ba84-0f07-4535-8261-71dcf903f616"],

Cell["\<\
That is it for the uniform discrete distribution. Next up, we look at the \
normal distribution.\
\>", "Text",
 CellChangeTimes->{{3.7769444357569714`*^9, 3.7769444394520874`*^9}},
 CellID->106598390,ExpressionUUID->"b1dccd45-3330-49b4-81c8-28583a689031"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normal Distribution", "Subsection",
 CellID->176638570,ExpressionUUID->"884b6122-2959-434e-aa0c-00f62de4c588"],

Cell["\<\
Most of us are familiar with the normal distribution. When plotted, the PDF \
for the normal distribution has a bell shape. It is also known by other \
names, such as the Gaussian distribution or the Laplace\[Dash]Gauss \
distribution. \
\>", "Text",
 CellChangeTimes->{
  3.7646845168147984`*^9, {3.7769451231257014`*^9, 3.7769452412265463`*^9}, {
   3.7769452819935427`*^9, 3.776945293080907*^9}, {3.776945989494562*^9, 
   3.776946004298357*^9}, 3.810400805908873*^9, {3.815841097626444*^9, 
   3.8158411319462843`*^9}, {3.815844772420246*^9, 3.815844772699884*^9}},
 CellID->9186485,ExpressionUUID->"983ff0e2-ba0e-4741-8478-8313393bafad"],

Cell["\<\
The normal distribution is useful in statistical analysis because of the \
central limit theorem, for which we will develop some intuition here.\
\>", "Text",
 CellChangeTimes->{{3.776945243925325*^9, 3.7769452788120265`*^9}, {
  3.7769453107676425`*^9, 3.7769453287519317`*^9}},
 CellID->101398934,ExpressionUUID->"18b1a59d-2392-4d52-8f99-d98572c83e45"],

Cell["\<\
We return to our die experiment, but this time, we roll a pair of dice and \
add the values that land face up. From experience, you might know that you \
are unlikely to roll two sixes, resulting in a sum of 12. You are just as \
unlikely to roll two ones, that is, a total of 2. It is much more likely to \
roll a total of 7 since we can make up 7 in so many ways. There are six ways, \
in fact: 1 and 6; 2 and 5; 3 and 4; 4 and 3; 5 and 2; and 6 and 1 for each \
respective die.\
\>", "Text",
 CellChangeTimes->{{3.764684555020798*^9, 3.7646846598147984`*^9}, {
   3.7646848231977983`*^9, 3.7646848598747983`*^9}, 3.764697363139368*^9, {
   3.7649320623103275`*^9, 3.7649320709898233`*^9}, {3.7769453405363855`*^9, 
   3.77694540099442*^9}},
 CellID->809766297,ExpressionUUID->"ff7bbe12-b0f1-431d-abd9-027ff76218e5"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s create a computer variable called ",
 Cell[BoxData[
 "dice"], "InlineCodeText",ExpressionUUID->
  "40afa5d3-deab-4edf-beb0-1d51f67539aa"],
 " that simulates rolling a pair of dice ",
 Cell[BoxData[
  FormBox["10000", TraditionalForm]],ExpressionUUID->
  "a60ef162-b301-4e2f-9681-52cfd8b1aebd"],
 " times and then look at the first 10 rolls using indexing."
}], "Text",
 CellChangeTimes->{{3.7646879216332073`*^9, 3.764687959120956*^9}},
 CellID->424553395,ExpressionUUID->"821c4209-5ebd-4b4d-af7b-fa8bca15466c"],

Cell[TextData[{
 "Roll two dice ",
 Cell[BoxData[
  FormBox["10000", TraditionalForm]], "InlineMath",ExpressionUUID->
  "e70d361a-a0ed-45c3-9f1f-de6f8c72e4a6"],
 " times:"
}], "CodeCaption",
 CellChangeTimes->{{3.7646879639454384`*^9, 3.7646879709581394`*^9}},
 CellID->221200766,ExpressionUUID->"ff654f3b-6968-48bd-9dbb-ec1059c4ea4f"],

Cell[BoxData[{
 RowBox[{"SeedRandom", "[", "123", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dice", "=", 
   RowBox[{"RandomVariate", "[", 
    RowBox[{
     RowBox[{"DiscreteUniformDistribution", "[", 
      RowBox[{"{", 
       RowBox[{"1", ",", "6"}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"10000", ",", "2"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[18]:=",
 CellID->204048059,ExpressionUUID->"20f452e1-5645-46d5-bfb7-05450c36cbb0"],

Cell["The first 10 rolls:", "CodeCaption",
 CellID->341591163,ExpressionUUID->"fc8dc9f6-a008-4601-9e6e-f550b29996f3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dice", "\[LeftDoubleBracket]", 
  RowBox[{";;", "10"}], "\[RightDoubleBracket]"}]], "Input",
 CellLabel->"In[20]:=",
 CellID->9767186,ExpressionUUID->"db0fc70c-b8d3-453a-a112-76f8f62cfecb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "6"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.810385808084467*^9, 3.812733466291149*^9},
 CellLabel->"Out[20]=",
 CellID->557299292,ExpressionUUID->"02a33678-742d-439d-b046-6a670c6154ad"]
}, Open  ]],

Cell[TextData[{
 "We can add all of the elements of the nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object (pairs of rolls) using the notation below and assign it to the \
computer variable ",
 Cell[BoxData[
 "totals"], "InlineCodeText",ExpressionUUID->
  "c1a4d9e0-fdd6-46a0-9483-8be6de1ea3d7"],
 ". We use the ",
 ButtonBox["@@@",
  BaseStyle->"Link",
  ButtonData->"Apply"],
 " symbol notation. It conveniently adds up the elements in nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " objects when used in combination with the ",
 ButtonBox["Plus",
  BaseStyle->"Link"],
 " function."
}], "Text",
 CellChangeTimes->{{3.7646879844914927`*^9, 3.7646880409991426`*^9}, {
   3.7646883860956492`*^9, 3.7646883929503345`*^9}, 3.764688436351674*^9, {
   3.76493213736362*^9, 3.764932140056774*^9}, {3.7769454563354845`*^9, 
   3.7769454607875776`*^9}},
 CellID->323136105,ExpressionUUID->"95e1924a-6c8f-4d84-881d-96e4abb807ea"],

Cell[TextData[{
 ButtonBox["@@@",
  BaseStyle->"Link",
  ButtonData->"Prefix"],
 " is shorthand notation for adding values in a nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object:"
}], "CodeCaption",
 CellChangeTimes->{{3.8127324507434673`*^9, 3.812732455064825*^9}, {
  3.8190176005908537`*^9, 3.819017612701067*^9}},
 CellID->360363996,ExpressionUUID->"5d267ca5-75a8-46d7-bb59-4b09c5875896"],

Cell[BoxData[
 RowBox[{
  RowBox[{"totals", "=", 
   RowBox[{"Plus", "@@@", "dice"}]}], ";"}]], "Input",
 CellLabel->"In[21]:=",
 CellID->685161560,ExpressionUUID->"6df83146-552a-4bc1-ae95-e8af8bf36749"],

Cell["\<\
If we print out the first 10 totals, we note that they are indeed the sum of \
each of the rolls above.\
\>", "Text",
 CellID->503533385,ExpressionUUID->"12dc2748-64fb-4670-b46a-00e3bd09b162"],

Cell["The first 10 totals:", "CodeCaption",
 CellID->114027062,ExpressionUUID->"643bceba-8673-40d6-8d5b-4dc5508e62e1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"totals", "\[LeftDoubleBracket]", 
  RowBox[{";;", "10"}], "\[RightDoubleBracket]"}]], "Input",
 CellLabel->"In[22]:=",
 CellID->17588274,ExpressionUUID->"fc08a091-575c-4744-9056-3cdd7220db86"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "10", ",", "5", ",", "7", ",", "4", ",", "6", ",", "7", ",", "3", ",", "9", 
   ",", "6", ",", "11"}], "}"}]], "Output",
 CellChangeTimes->{3.776945494563276*^9, 3.810385808103221*^9, 
  3.8127334663004313`*^9},
 CellLabel->"Out[22]=",
 CellID->1353016077,ExpressionUUID->"6f3e449f-d0e3-4045-9851-f3ae95ecd961"]
}, Open  ]],

Cell[TextData[{
 "We can add up the occurrences of each addition using the ",
 ButtonBox["Tally",
  BaseStyle->"Link"],
 " function. We can also sort them from 2 through 12 using the ",
 ButtonBox["SortBy",
  BaseStyle->"Link"],
 " function."
}], "Text",
 CellChangeTimes->{{3.764932245631812*^9, 3.764932248453974*^9}, {
  3.7769455098423877`*^9, 3.776945511765242*^9}},
 CellID->116133576,ExpressionUUID->"1374f829-0819-439f-adc4-e908b3892260"],

Cell["Count and sort the totals:", "CodeCaption",
 CellChangeTimes->{{3.764932257236476*^9, 3.764932260555666*^9}},
 CellID->20798786,ExpressionUUID->"a6a89e3c-cde9-408b-aace-dab7901f3ec7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SortBy", "[", 
  RowBox[{
   RowBox[{"Tally", "[", "totals", "]"}], ",", "First"}], "]"}]], "Input",
 CellLabel->"In[23]:=",
 CellID->65285777,ExpressionUUID->"4d70202b-3a8c-4bde-baec-c536074a536a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "243"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "547"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "825"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "1119"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "1362"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "1710"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "1394"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "1086"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "841"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11", ",", "594"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", "279"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.776945516507557*^9, 3.810385808108738*^9, 
  3.812733466316679*^9},
 CellLabel->"Out[23]=",
 CellID->436868056,ExpressionUUID->"320eb533-37ba-4eeb-afab-1941a009550b"]
}, Open  ]],

Cell[TextData[{
 "Each nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object contains two elements. The first is the sum of the two dice and the \
second is how many times that value appeared in our ",
 Cell[BoxData[
  FormBox["10000", TraditionalForm]],ExpressionUUID->
  "00c40d76-8c7f-42db-b821-2b996d50727f"],
 " rolls."
}], "Text",
 CellID->6035978,ExpressionUUID->"5584a7d9-3f26-400d-bc12-6ddd4d1c380b"],

Cell[TextData[{
 "Below we create a list of all the occurrences using indexing from the ",
 ButtonBox["Tally",
  BaseStyle->"Link"],
 " function."
}], "Text",
 CellChangeTimes->{{3.764688925291563*^9, 3.76468893536357*^9}, {
  3.764690251921818*^9, 3.764690261238022*^9}},
 CellID->235025413,ExpressionUUID->"3df2d35e-9084-4b9f-9ca1-4e7dfbcbaad7"],

Cell[TextData[{
 "Clear the ",
 Cell[BoxData[
 "counts"], "InlineCode",ExpressionUUID->
  "12ba51b7-d369-4dc4-9067-03323f01f3f2"],
 " variable that we used previously:"
}], "CodeCaption",
 CellChangeTimes->{{3.7646887832293587`*^9, 3.764688871385173*^9}, {
  3.764688905698604*^9, 3.764688905873622*^9}, {3.7646893586058903`*^9, 
  3.764689388022832*^9}, {3.7646900142341456`*^9, 3.764690022490668*^9}, {
  3.7646900592446384`*^9, 3.764690069409588*^9}, {3.764932471805749*^9, 
  3.7649324771560545`*^9}},
 CellID->229700914,ExpressionUUID->"8ddca30a-4f6c-4204-8043-cff6ef8afa48"],

Cell[BoxData[
 RowBox[{"Clear", "[", "counts", "]"}]], "Input",
 CellLabel->"In[24]:=",
 CellID->605933267,ExpressionUUID->"b6ae380b-47b1-42b3-bade-874d96254f0d"],

Cell[TextData[{
 "Save just the counts in a computer variable called ",
 Cell[BoxData[
 "counts"], "InlineCode",ExpressionUUID->
  "bceed234-0de7-43e1-822d-1476f34c3031"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.764689276952726*^9, 3.7646892836183925`*^9}, {
  3.764689372344264*^9, 3.7646893831903486`*^9}, {3.7646900884828644`*^9, 
  3.764690105900637*^9}, {3.7646908650523796`*^9, 3.7646908654353795`*^9}},
 CellID->12130739,ExpressionUUID->"781ab363-0380-4c9e-a445-2f0c3d3e29a9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"counts", "=", 
  RowBox[{
   RowBox[{"SortBy", "[", 
    RowBox[{
     RowBox[{"Tally", "[", "totals", "]"}], ",", "First"}], "]"}], 
   "\[LeftDoubleBracket]", 
   RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}]}]], "Input",
 CellLabel->"In[25]:=",
 CellID->546476866,ExpressionUUID->"b311d61a-6391-4bd4-a084-7d2fd8692973"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "243", ",", "547", ",", "825", ",", "1119", ",", "1362", ",", "1710", ",", 
   "1394", ",", "1086", ",", "841", ",", "594", ",", "279"}], "}"}]], "Output",\

 CellChangeTimes->{3.77694556747798*^9, 3.810385808117358*^9, 
  3.812733466336274*^9},
 CellLabel->"Out[25]=",
 CellID->194828099,ExpressionUUID->"1e786f4f-2427-4c26-92cb-f6beaa6f63fb"]
}, Open  ]],

Cell["\<\
Here is the unsurprising frequency chart, a nice symmetrically shaped curve.\
\>", "Text",
 CellChangeTimes->{{3.7646911029983797`*^9, 3.7646911045823793`*^9}, {
   3.7769455845269394`*^9, 3.776945593874938*^9}, 3.815841170306896*^9},
 CellID->73923205,ExpressionUUID->"91758e09-7c3b-4606-a346-00c20ed1b08c"],

Cell["Make a bar chart with manually created labels:", "CodeCaption",
 CellChangeTimes->{{3.7646910661363797`*^9, 3.76469108604838*^9}},
 CellID->443292433,ExpressionUUID->"5f37f94d-48d8-46a1-88d2-fd79b03ea4a6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BarChart", "[", 
  RowBox[{"counts", ",", 
   RowBox[{"ChartLabels", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", ",", 
      "9", ",", "10", ",", "11", ",", "12"}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[26]:=",
 CellID->587048772,ExpressionUUID->"5827e516-8ec2-425e-83b7-11a9291a1bd3"],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], 
    PointBox[{{0.332737030411449, 0.}, {11.44929131691207, 0.}}]}, {{}, 
    {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.623], 
     Thickness[Small]}], 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.623], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{0.5507086830879317, 0.}, {1.4492913169120683`, 
             243.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{33.43111950662618, 69.71881545250304}, {
            92.74163753597844, 131.66366881370155`}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 243]& ,
         TagBoxNote->"243"],
        StyleBox["243", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[243, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.623], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{1.5507086830879317`, 0.}, {2.4492913169120683`, 
             547.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{73.25794744516939, 109.54564339104626`}, {
            44.67456960006146, 131.66366881370155`}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 547]& ,
         TagBoxNote->"547"],
        StyleBox["547", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[547, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.623], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{2.5507086830879317`, 0.}, {3.4492913169120683`, 
             825.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{113.0847753837126, 149.37247132958947`}, {
            0.7185008955057981, 131.66366881370155`}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 825]& ,
         TagBoxNote->"825"],
        StyleBox["825", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[825, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.623], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{3.5507086830879317`, 0.}, {4.449291316912069, 
             1119.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{152.91160332225581`, 
            189.1992992681327}, {-45.767413489887616`, 131.66366881370155`}}],
          
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1119]& ,
         TagBoxNote->"1119"],
        StyleBox["1119", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1119, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.623], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{4.550708683087932, 0.}, {5.449291316912069, 1362.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{192.73843126079905`, 
            229.0261272066759}, {-84.18944476761072, 131.66366881370155`}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1362]& ,
         TagBoxNote->"1362"],
        StyleBox["1362", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1362, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.623], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{5.550708683087932, 0.}, {6.449291316912069, 1710.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{232.56525919934225`, 
            268.8529551452191}, {-139.21358832583147`, 131.66366881370155`}}],
          
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1710]& ,
         TagBoxNote->"1710"],
        StyleBox["1710", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1710, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.623], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{6.550708683087932, 0.}, {7.449291316912069, 1394.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{272.3920871378855, 
            308.67978308376235`}, {-89.2491361292862, 131.66366881370155`}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1394]& ,
         TagBoxNote->"1394"],
        StyleBox["1394", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1394, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.623], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{7.550708683087932, 0.}, {8.449291316912069, 1086.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{312.21891507642863`, 
            348.5066110223055}, {-40.54960677315978, 131.66366881370155`}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 1086]& ,
         TagBoxNote->"1086"],
        StyleBox["1086", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1086, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.623], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{8.550708683087933, 0.}, {9.44929131691207, 841.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{352.0457430149719, 
            388.33343896084887`}, {-1.8113447853319542`, 
            131.66366881370155`}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 841]& ,
         TagBoxNote->"841"],
        StyleBox["841", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[841, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.623], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{9.550708683087933, 0.}, {10.44929131691207, 594.}, 
             "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{391.87257095351515`, 428.160266899392}, {
            37.243147912600605`, 131.66366881370155`}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 594]& ,
         TagBoxNote->"594"],
        StyleBox["594", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[594, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.623], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            
            RectangleBox[{10.550708683087933`, 0.}, {11.44929131691207, 279.},
              "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{431.6993988920583, 467.9870948379353}, {
            87.04948475409353, 131.66366881370155`}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 279]& ,
         TagBoxNote->"279"],
        StyleBox["279", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[279, {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, {}, {}, 
   StyleBox[{
     {Thickness[Tiny], 
      LineBox[{{0.332737030411449, 0.}, {11.67162240264208, 0.}}], 
      StyleBox[{}, "GraphicsLabel",
       StripOnInput->False]}, 
     StyleBox[{
       {Thickness[Tiny], 
        LineBox[{{0.5507086830879317, 0.}, 
          Offset[{-1.102182119232618*^-15, -6.}, {0.5507086830879317, 0.}]}], 
        LineBox[{{11.449291316912069`, 0.}, 
          Offset[{-1.102182119232618*^-15, -6.}, {11.449291316912069`, 
           0.}]}], {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {
          LineBox[{{1.4492913169120683`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {1.4492913169120683`, 
             0.}]}], LineBox[{{1.5507086830879317`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {1.5507086830879317`, 
             0.}]}], LineBox[{{2.4492913169120683`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {2.4492913169120683`, 
             0.}]}], LineBox[{{2.5507086830879317`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {2.5507086830879317`, 
             0.}]}], LineBox[{{3.4492913169120683`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {3.4492913169120683`, 
             0.}]}], LineBox[{{3.5507086830879317`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {3.5507086830879317`, 
             0.}]}], LineBox[{{4.449291316912069, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {4.449291316912069, 0.}]}],
           LineBox[{{4.550708683087931, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {4.550708683087931, 0.}]}],
           LineBox[{{5.449291316912069, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {5.449291316912069, 0.}]}],
           LineBox[{{5.550708683087931, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {5.550708683087931, 0.}]}],
           LineBox[{{6.449291316912069, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {6.449291316912069, 0.}]}],
           LineBox[{{6.550708683087931, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {6.550708683087931, 0.}]}],
           LineBox[{{7.449291316912069, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {7.449291316912069, 0.}]}],
           LineBox[{{7.550708683087931, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {7.550708683087931, 0.}]}],
           LineBox[{{8.449291316912069, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {8.449291316912069, 0.}]}],
           LineBox[{{8.550708683087931, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {8.550708683087931, 0.}]}],
           LineBox[{{9.449291316912069, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {9.449291316912069, 0.}]}],
           LineBox[{{9.550708683087931, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {9.550708683087931, 0.}]}],
           LineBox[{{10.449291316912069`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {10.449291316912069`, 
             0.}]}], LineBox[{{10.550708683087931`, 0.}, 
            Offset[{-7.347880794884119*^-16, -4.}, {10.550708683087931`, 
             0.}]}]}, {}}}, 
       StyleBox[
        {Thickness[Tiny], 
         InsetBox["2", Offset[{0, -2}, {1., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["3", Offset[{0, -2}, {2., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["4", Offset[{0, -2}, {3., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["5", Offset[{0, -2}, {4., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["6", Offset[{0, -2}, {5., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["7", Offset[{0, -2}, {6., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["8", Offset[{0, -2}, {7., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["9", Offset[{0, -2}, {8., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["10", Offset[{0, -2}, {9., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["11", Offset[{0, -2}, {10., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}], 
         InsetBox["12", Offset[{0, -2}, {11., 0.}], 
          ImageScaled[{Rational[1, 2], 1}], Automatic, {1, 0}]}, 
        "GraphicsLabel",
        StripOnInput->False]}, "GraphicsTicks",
      StripOnInput->False]}, "GraphicsAxes",
    StripOnInput->False,
    Antialiasing->False]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.332737030411449, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{487., Automatic},
  PlotRange->{{All, All}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{3.810385808190701*^9, 3.812733466386261*^9},
 CellLabel->"Out[26]=",
 CellID->1710781865,ExpressionUUID->"c57fa3fd-d332-4f82-a598-e81f92cedb44"]
}, Open  ]],

Cell[TextData[{
 "Next we create a histogram and use the ",
 Cell[BoxData[
 "\"\<Probability\>\""], "InlineCodeText",ExpressionUUID->
  "46b1a633-7322-40dc-8d34-99c250060e27"],
 " option. It counts the occurrences of each of the added values, 1 through \
12, and divides by ",
 Cell[BoxData[
  FormBox["10000", TraditionalForm]],ExpressionUUID->
  "65a5b112-9568-4cbd-a3ad-92b85d5d58d3"],
 " as we mentioned previously. If you run this in your own notebook, you can \
hover over each rectangle. It will give you the probability of rolling that \
value."
}], "Text",
 CellChangeTimes->{{3.7646912091533794`*^9, 3.7646912142883797`*^9}, {
   3.7646912889913797`*^9, 3.7646913678733797`*^9}, 3.7646914034943795`*^9, {
   3.76469143881238*^9, 3.7646914419393797`*^9}, {3.7646919839803796`*^9, 
   3.7646920115863795`*^9}, {3.776945637133312*^9, 3.776945655801385*^9}},
 CellID->35287596,ExpressionUUID->"86818888-39c4-44bb-be57-fa51c49d3f99"],

Cell[TextData[{
 "Create a ",
 ButtonBox["Histogram",
  BaseStyle->"Link"],
 " of the probability of each value:"
}], "CodeCaption",
 CellChangeTimes->{{3.764932660453539*^9, 3.7649327106494102`*^9}},
 CellID->428124550,ExpressionUUID->"c2746e20-cf11-4c46-959d-216a4644b5f4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"totals", ",", "Automatic", ",", "\"\<Probability\>\""}], 
  "]"}]], "Input",
 CellLabel->"In[27]:=",
 CellID->413488752,ExpressionUUID->"6fe02e4b-920a-4f9b-9f90-54e428cdfca9"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.609], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.609], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{1.5, 0}, {2.5, 0.0243}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{31.079063250600477`, 73.9838962078754}, {
           95.85337081648649, 136.03982336600524`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.0243]& ,
        TagBoxNote->"0.0243"],
       StyleBox["0.0243`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0243, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{2.5, 0}, {3.5, 0.0547}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{73.4838962078754, 116.38872916515032`}, {
           46.20447544589511, 136.03982336600524`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.0547]& ,
        TagBoxNote->"0.0547"],
       StyleBox["0.0547`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0547, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{3.5, 0}, {4.5, 0.0825}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{115.88872916515032`, 158.79356212242521`}, {
           0.8018671793674912, 136.03982336600524`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.0825]& ,
        TagBoxNote->"0.0825"],
       StyleBox["0.0825`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0825, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{4.5, 0}, {5.5, 0.1119}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{158.29356212242521`, 
           201.19839507970013`}, {-47.21384084350706, 136.03982336600524`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.1119]& ,
        TagBoxNote->"0.1119"],
       StyleBox["0.1119`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.1119, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{5.5, 0}, {6.5, 0.1362}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{200.69839507970013`, 
           243.60322803697505`}, {-86.9002933930258, 136.03982336600524`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.1362]& ,
        TagBoxNote->"0.1362"],
       StyleBox["0.1362`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.1362, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{6.5, 0}, {7.5, 0.171}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{243.10322803697505`, 
           286.00806099424994`}, {-143.73521309357125`, 136.03982336600524`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.171]& ,
        TagBoxNote->"0.171"],
       StyleBox["0.171`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.171, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{7.5, 0}, {8.5, 0.1394}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{285.50806099424994`, 
           328.4128939515249}, {-92.12649290571963, 136.03982336600524`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.1394]& ,
        TagBoxNote->"0.1394"],
       StyleBox["0.1394`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.1394, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{8.5, 0}, {9.5, 0.1086}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{327.9128939515249, 
           370.8177269087998}, {-41.824322596041554`, 136.03982336600524`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.1086]& ,
        TagBoxNote->"0.1086"],
       StyleBox["0.1086`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.1086, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{9.5, 0}, {10.5, 0.0841}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{370.3177269087998, 
           413.2225598660747}, {-1.811232576979421, 136.03982336600524`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.0841]& ,
        TagBoxNote->"0.0841"],
       StyleBox["0.0841`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0841, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{10.5, 0}, {11.5, 0.0594}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{412.7225598660747, 455.6273928233496}, {
           38.528494911626055`, 136.03982336600524`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.0594]& ,
        TagBoxNote->"0.0594"],
       StyleBox["0.0594`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0594, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{11.5, 0}, {12.5, 0.0279}, "RoundingRadius" -> 0]},
          ImageSizeCache->{{455.1273928233496, 498.0322257806245}, {
           89.97389636470592, 136.03982336600524`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 0.0279]& ,
        TagBoxNote->"0.0279"],
       StyleBox["0.0279`", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0279, {}], 
       "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
  
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1.28, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{509., Automatic},
  PlotRange->{{1.5, 12.5}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.810385808252574*^9, 3.812733466425926*^9},
 CellLabel->"Out[27]=",
 CellID->452255372,ExpressionUUID->"5abc6229-4ffb-4e64-8254-b7f4181814a1"]
}, Open  ]],

Cell["\<\
Note that it also makes sense to ask what the probability is of rolling a 10 \
or greater (or similar question). In this case, we simply add the \
probabilities for the values 10, 11, and 12.\
\>", "Text",
 CellChangeTimes->{{3.7646920415303793`*^9, 3.7646920643433795`*^9}, 
   3.7646921513633795`*^9, 3.7741975728286047`*^9, {3.7769456709907675`*^9, 
   3.7769456718843765`*^9}, {3.7769457040787687`*^9, 3.776945729109868*^9}, {
   3.776945829456544*^9, 3.7769458466096144`*^9}},
 CellID->255990457,ExpressionUUID->"a427a724-75b4-4dfc-9c65-77a0ebc0a704"],

Cell["\<\
In real-life experiments, we would not be rolling dice and our numerical data \
types will usually be continuous. Let\[CloseCurlyQuote]s imagine a variable \
whose data point values in the population follow a normal distribution.\
\>", "Text",
 CellChangeTimes->{{3.7646922906913795`*^9, 3.7646923128493795`*^9}, 
   3.776945885623329*^9},
 CellID->481178091,ExpressionUUID->"96721d91-e496-436a-979d-bec3cd6496b8"],

Cell[TextData[{
 "If we calculate a mean of a variable for a whole population, we call that \
mean a ",
 StyleBox["parameter",
  FontSlant->"Italic"],
 " of the population. If we now take a sample of a few individuals from that \
population and measure the mean of the same variable (for our sample only), \
we call that mean a ",
 StyleBox["statistic",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.776945929992613*^9, 3.7769459327691946`*^9}},
 CellID->626562882,ExpressionUUID->"c74e671a-2f55-468c-8c1d-0079336e1139"],

Cell["\<\
The latter scenario is of course the norm. It is hardly ever possible to get \
detailed information from a whole population. Instead, we take a random \
sample from a population. Let\[CloseCurlyQuote]s take a closer look at a \
variable for which the set of data point values for the whole population is \
known and, in fact, normally distributed. We will assume that this variable \
has the following parameters: a mean of 100 and a standard deviation of 20. \
The first thing we will do is plot the PDF.\
\>", "Text",
 CellChangeTimes->{{3.7646924875373793`*^9, 3.7646925189343796`*^9}, {
  3.7646926262803793`*^9, 3.7646926453333797`*^9}, {3.816451697942061*^9, 
  3.816451698245921*^9}},
 CellID->110580635,ExpressionUUID->"4d77b44a-ebff-438c-b1f3-2847a18c322c"],

Cell["\<\
The 100 and the 20 indicate a mean of 100 and a standard deviation of 20:\
\>", "CodeCaption",
 CellID->2067965092,ExpressionUUID->"b8833092-062b-4f41-9777-43437a3284f8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"PDF", "[", 
    RowBox[{
     RowBox[{"NormalDistribution", "[", 
      RowBox[{"100", ",", "20"}], "]"}], ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "20", ",", "180"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellLabel->"In[28]:=",
 CellID->173557031,ExpressionUUID->"d53b0196-4e1c-4789-a0de-7f623be58046"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJw1mnk4Vd8X/02pzEWDFJL0Mc+zzlrmOTP3XkNc914yDxWV0iiUTLciGZIm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    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1WWcFVUYwOFl6ZZOgaVbSqTEABRFGqRBke6WULpDBaW7W1JQ6RCkUUJB
WrqlpASfAx+e33n/Z+buvTszdzeqcftq7SIjIiKikS/y5Zo38uVcyJzHut5m
FmtN62rSmR84VtG8hGR6ur5AKT2ZSHt19B0+0AtIbK+v3sGr+gv+pqCexnlK
6klEc25t/Q/l9XwS2eujfyG97sU5Cuip/E0JPTH8Es6tZbnN+3oeCe311ttJ
p3tyltf0FM5RXE/gOR/rW7xnnksCr/9SbyOt7sEZ8uvJnKWYHs8zauov2Eoa
3Z3T5NOTOMMbehz/UUP3Ygup9eecIq+eyGmK6rE8pbruyWZS6W6cJI+ewCle
19/xhGq6B5tIqbtygtx6PCcpor/lMVV1dzaSQnfhL3LpcZygsB7DI6roz9lA
ct2Z4+TUY/mLQno0D6msu7GeZLoTx8ihv+M4BfU3/Esl3ZV1JNUd+ZPs+luO
UUB/zQMq6i78TBLdgT/Ipj+iMz/xir32HCWrrkAnfiSxvXYcCd8BnZkoMpGR
DHxIR9aSyHltOcyr4dmnA2tIaK8Nh0ivx/Anr+mvuE953Z4fSKBb83v4zun7
4XObF5PUszha/0F+PYp7vK9vUs48h/jOa6crm78nhV6t45tb8RtpdQ3rqjA7
fi/87uaM5grWRSQxfxOupTnKXDVcd+tyayrrUcdyWteE3zv8/QjX0jrSepf3
HM+t15kzW6uF+2xdYU1tveF4LutancFaNtwn62xrPGvbcK/MmcyVrEtJbl4V
rlW4nuZ41pYcJI396taVYXbsbrhP5oW8or/WVczLSKmP6LzmEdyhnL5OGfMs
4jqnjV5JXN2CA+Gz6684TB49nH8oq6/xrnkmcby+tV5BHN2c/eHa6VEcCtdH
D+M2ZXQrlhNbN2Nf+KzhZ9KSZcSy15S94d6G7134LoXvR3jmw7PNO7Tge2I6
rwl7SKzfpjlLiWHvM3aTSL9FM5YQ3V5jdpFQj+T3cM/0UG5RWjdlMZH6U34l
gR7Bb+EZ0UO4yZu6CYuIpj9hZ3hm9XAOkkMP5gal9GcsjIh48Y+qETvC8yGH
cYDsehDXKakbs4DnNLT3S7iX5qHsJ5seyDVK6E+ZzzMa2Nse7p15CPvIqgdw
leL6E+bxH/XtbSO2eTB7yaL7c4ViuhFzeUo9e1uJZR7EHjLrflzmDX013D/z
jPBzPUMN9RyeUNfeFmKaB7KbKN2XSxTVV8I9Nk8P7+P1DfRsHlPH3mZimAew
i0y6Dxd5XV8Oz4F5Wngfr6+vZ/GI2vY2Ed3cn1/JqHtzgSL6EqXNU8P7eH09
PZOH1LK3MdqLf9UR/dhJBv0l5ymsL/KmeUp4HyfW1TP4l4/tbeB/ZNMGWw==

         "]]]}, {}, {}}, {{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl1mW4VFUYgNGLgDQIKN2tSDdSUtISCijdIQIS0lLSoXSHdEkK0t3dSEpI
g4SUAuLajz8W+3v3nGGGmX3uJW3jdtXbRoqIiMj6VkREWDf5oybPzTP5ksge
m2qvKDd0Hv4w9yIVe3RfXBaxWdfihfkn6hDFA9PsFeOmzst183ekZq/uF16H
Lbo2f5tnUZeonj/dXnFu6XzcMPcmDft0//A6bNVf8I95NvV42/Nn2CvBbZ2f
m+Y+pGW//j68Dtv0l7w0z6E+0Tx/pr2PuaMLcMvcl3Qc0APC67Bd1+GVeS4N
KMhte/1Iz0E9MPy97NB1eW2eR0MKccdefzJwSA8iOjt1Pf41z6cRhblr73sy
clgPJga7dH3emBfQmI+4Z28AmTiihxCT3bpBOAgstDShCPf1QDJzVA8lFnt0
QyKxSDelKH/qQWThmB5GbPbqRrzFYt2MYjzQg3mf43o4cdinGxOZJbo5xYnL
fntNiMLPugUliMcBe02JylLdko95h/gkICHv8h4HXdeMt1mmW1GSRByy15xo
LNetKcVDPYQPOKFHkJjDugXRWaG/Ct+dM/STLsldXZpH5qFk5aQeSRKO6JbE
YKVuE75Lz5+lS3FPl+GxeRgfciq8V9csM1flh/Bv1QvNFfhLJ9UrzTVIqo9a
WxGTFB5bbV0VPhPzz+Yq4f4yr7N+Hc6HeXY4Y9bS4d63/hq+M+v98N6tK8IZ
sVYP94Z1Q/h8rGU9/pd5eDjTOps1pXVNOCPW0+Gzsy4PZ9JaLdyb1vXWH8N3
Zl5krhh+ZpjXWp/YT2ZeZf6MZPqYtTWx+CV8tx5fav6UtuHM6jnmMvypP+GJ
eQTZOaNHhfPhusW6Ek91co6bvyI2q3U7yvFUjyQHv+nRpOCEbkMc1uj2lCcl
J8NnSlx+1d9QgVSkJg1pSUd6ToX3TzzW6g5UJAOn7bXjHdbpjlQiI2fstSc+
63UnKvMsnBFyclaPIRO/6W9IwAbdmSo8D98DuTinx5KZs7oDCdmov+VTXuhR
5Oa8HkcWzumOvMsm3YWq/K1Hk4cLejzvc1534j02665U4x89hrxc1BP4gAu6
M4nYortRnZd6LPm4pCeSlYv6WxKzVXenBq/0OPLzu57Eh1zSXUjCNt2Dz3it
x1OAy3oy2fhddw33G9t1Tz7nXz2BglzRU8jOZd0tnGV26F7Edhbn6rI80DV5
Y55IIa7qqeTgiu5Ocnbq74jj+fP0JzzUtQi/rCfpwlyT08jJVd0j/Dxgl+5N
XNfO1+V4pGsTyd5k/RF/6Onk4pruGe5tdus+xHPtAl2ex/qL8PL2pugiXNcz
SGhvia7Ms3DP6V/Mn5PevDHS//9Pye2x/wBKOAX6
         "]]},
       Annotation[#, "Charting`Private`Tag$23349#1"]& ]}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{20., 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{439., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotRange->{{20, 180}, {0., 0.019947110239004025`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.810385808378602*^9, 3.8127334665529757`*^9},
 CellLabel->"Out[28]=",
 CellID->1111410471,ExpressionUUID->"a6bc52c1-2dce-4e97-bb85-2ea0b21d03fb"]
}, Open  ]],

Cell[TextData[{
 "Note that it is a probability density curve. We should be able to calculate \
the area under the curve to calculate a probability. The obvious problem is, \
how? We are dealing with a continuous, numerical data type. If we were to \
create thin rectangles, they will have a base that, by definition, can be \
divided into two and so on to infinity. The number of values that a \
continuous numerical variable can take is, therefore, theoretically infinite. \
In our die rolling experiment, we divided each of the six values that our \
variable could take by ",
 Cell[BoxData[
  FormBox["6", TraditionalForm]],ExpressionUUID->
  "738bf8fa-4c99-40ab-ae25-0b5544480df4"],
 ". Now, though, we have to divide by infinity. Dividing by in infinity \
results in a ",
 Cell[BoxData[
  FormBox["0", TraditionalForm]],ExpressionUUID->
  "6e06a3db-f4c9-4987-b026-037f232dfe15"],
 ". This gives us a ",
 Cell[BoxData[
  FormBox["0", TraditionalForm]],ExpressionUUID->
  "4fd231b3-d3c5-4ae7-bef2-0e4ff83d393d"],
 " probability for any given value that a random continuous variable can take."
}], "Text",
 CellChangeTimes->{
  3.7646927524733796`*^9, 3.7646973674823675`*^9, {3.7769396331236167`*^9, 
   3.7769397058987155`*^9}, {3.776939752025447*^9, 3.776939896548941*^9}, 
   3.7769460521404176`*^9, {3.776946600406839*^9, 3.776946668571426*^9}, {
   3.810400806989564*^9, 3.8104008091385727`*^9}, {3.812732611302796*^9, 
   3.812732611846447*^9}, {3.815841189850635*^9, 3.815841212467105*^9}, {
   3.81584128364297*^9, 3.8158412851150837`*^9}},
 CellID->65942760,ExpressionUUID->"b820b9ae-945e-441e-b990-6e70076d664e"],

Cell[TextData[{
 "So, the probability of a random variable taking on a single value is ",
 Cell[BoxData[
  FormBox["0", TraditionalForm]],ExpressionUUID->
  "8b5d9479-fb84-421f-aeb0-eb02479f99fa"],
 ". Instead, it makes more sense to ask about the probability that a variable \
takes on a value in an interval. More commonly, we will ask what the \
probability of selecting a value larger than or smaller than a specified \
value is. We will do just that in Chapter 10."
}], "Text",
 CellChangeTimes->{{3.76469281154838*^9, 3.7646928288443794`*^9}, {
   3.764695116469493*^9, 3.764695122046051*^9}, 3.7646973716263676`*^9, {
   3.776939492021202*^9, 3.776939543826708*^9}, {3.7769399121963687`*^9, 
   3.7769399562390966`*^9}, {3.776940026484831*^9, 3.776940037036724*^9}, {
   3.776940094866367*^9, 3.776940113752048*^9}, 3.8127326283912992`*^9},
 CellID->77913434,ExpressionUUID->"af0cc840-3ce2-4df3-90c0-dd9b9f06d637"],

Cell[TextData[{
 "Note that the ",
 ButtonBox["NormalDistribution",
  BaseStyle->"Link"],
 " function in the Wolfram Language takes two arguments: the first is the \
mean and the second is the standard deviation. These two parameters are \
sufficient to specify the normal probability density function. We can use the \
",
 ButtonBox["Mean",
  BaseStyle->"Link"],
 ", ",
 ButtonBox["StandardDeviation",
  BaseStyle->"Link"],
 ", and ",
 ButtonBox["Variance",
  BaseStyle->"Link"],
 " functions to examine this. In the next example, we use the symbol ",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "02a117e9-a267-4bf0-be37-fc2fa4d15910"],
 " to indicate mean and ",
 Cell[BoxData[
  FormBox["\[Sigma]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "8eca0204-a942-4351-a052-f99c9dcd0def"],
 " to indicate standard deviation. In general though, remember that we use ",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "092f5a3e-7cb5-482c-9f02-19c4ce6ee36e"],
 " for the population mean and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["x", "_"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "3a67e337-6cf3-41ab-9edf-129f06abd38a"],
 " for a sample mean."
}], "Text",
 CellChangeTimes->{{3.7646938262883797`*^9, 3.7646938280593796`*^9}, {
   3.76469395960038*^9, 3.7646939639673796`*^9}, {3.7646943060806417`*^9, 
   3.7646943131697683`*^9}, 3.7646946873845887`*^9, {3.77694019653296*^9, 
   3.776940206960278*^9}, 3.812732652795768*^9},
 CellID->78729036,ExpressionUUID->"38c02f3a-b7c6-44db-b04f-a52d05480a1e"],

Cell[TextData[{
 "Calculate the mean of a normal distribution with a mean of ",
 Cell[BoxData[
 "\[Mu]"], "InlineCode",ExpressionUUID->
  "b8c79081-6217-4cbc-b349-322a09d929b0"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.764694672779128*^9, 3.7646946732091713`*^9}, {
  3.76469470739559*^9, 3.7646947135952096`*^9}},
 CellID->5861944,ExpressionUUID->"864c6688-48ae-4178-9b46-5329b9338309"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mean", "[", 
  RowBox[{"NormalDistribution", "[", 
   RowBox[{"\[Mu]", ",", "\[Sigma]"}], "]"}], "]"}]], "Input",
 CellLabel->"In[29]:=",
 CellID->870478265,ExpressionUUID->"66b8a011-0bbe-4654-aedb-3e48c33b7678"],

Cell[BoxData["\[Mu]"], "Output",
 CellChangeTimes->{3.810385808385118*^9, 3.812733466670507*^9},
 CellLabel->"Out[29]=",
 CellID->663024491,ExpressionUUID->"52c20f32-af5c-468d-8e13-cc85a539cb43"]
}, Open  ]],

Cell[TextData[{
 "Calculate the standard deviation of a normal distribution with a standard \
deviation of ",
 Cell[BoxData[
 "\[Sigma]"], "InlineCode",ExpressionUUID->
  "72a7b91f-4389-4936-80d3-184e4cc8216d"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7646947175806084`*^9, 3.7646947180846586`*^9}},
 CellID->352163608,ExpressionUUID->"dd031c78-8285-47b1-9c54-735cea3966ac"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardDeviation", "[", 
  RowBox[{"NormalDistribution", "[", 
   RowBox[{"\[Mu]", ",", "\[Sigma]"}], "]"}], "]"}]], "Input",
 CellLabel->"In[30]:=",
 CellID->187026937,ExpressionUUID->"a19f3dbb-7fb8-45cc-bdcc-68d9756b5b6e"],

Cell[BoxData["\[Sigma]"], "Output",
 CellChangeTimes->{3.810385808399663*^9, 3.812733466676324*^9},
 CellLabel->"Out[30]=",
 CellID->159975954,ExpressionUUID->"c2a89b84-4dd8-4940-81dd-92c69b9a168e"]
}, Open  ]],

Cell["Note that the variance is the standard deviation squared:", \
"CodeCaption",
 CellID->304094515,ExpressionUUID->"75455245-43c8-410b-ad5b-e4cdc7e92d9b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Variance", "[", 
  RowBox[{"NormalDistribution", "[", 
   RowBox[{"\[Mu]", ",", "\[Sigma]"}], "]"}], "]"}]], "Input",
 CellLabel->"In[31]:=",
 CellID->212033964,ExpressionUUID->"87208d07-6d1d-409d-b7d6-99c20bb3290c"],

Cell[BoxData[
 SuperscriptBox["\[Sigma]", "2"]], "Output",
 CellChangeTimes->{3.810385808405905*^9, 3.812733466681777*^9},
 CellLabel->"Out[31]=",
 CellID->66332834,ExpressionUUID->"8a0bb011-55a0-4813-b235-81a96bf655bc"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["standard normal distribution",
  FontSlant->"Italic"],
 " is a special version of the normal distribution where the mean is 0 and \
the standard deviation is 1. When we omit the arguments for the ",
 ButtonBox["NormalDistribution",
  BaseStyle->"Link"],
 " function, the Wolfram Language assumes these values."
}], "Text",
 CellChangeTimes->{3.815841310539207*^9},
 CellID->7551058,ExpressionUUID->"87c7429a-0f7a-4884-ac46-b0c757a41885"],

Cell["Find the mean of the standard normal distribution:", "CodeCaption",
 CellChangeTimes->{{3.7646947696228123`*^9, 3.76469477460631*^9}},
 CellID->620488064,ExpressionUUID->"fa8f09cf-ba31-4d85-b6a1-a484fce908fc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mean", "[", 
  RowBox[{"NormalDistribution", "[", "]"}], "]"}]], "Input",
 CellLabel->"In[32]:=",
 CellID->38546484,ExpressionUUID->"3cd7fc8c-51d2-426b-94ad-518306efdf62"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.810385808493289*^9, 3.812733466699801*^9},
 CellLabel->"Out[32]=",
 CellID->311928245,ExpressionUUID->"4411e701-adaf-4437-82dc-9b065090886b"]
}, Open  ]],

Cell["\<\
Find the standard deviation of the standard normal distribution:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7646947768715367`*^9, 3.764694779542804*^9}},
 CellID->524249967,ExpressionUUID->"bb58ad06-8618-4922-bc29-f08a59267189"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardDeviation", "[", 
  RowBox[{"NormalDistribution", "[", "]"}], "]"}]], "Input",
 CellLabel->"In[33]:=",
 CellID->645924666,ExpressionUUID->"06fa7ad5-16ae-49f3-b894-f91556af3d89"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.8103858084982862`*^9, 3.812733466705508*^9},
 CellLabel->"Out[33]=",
 CellID->570431388,ExpressionUUID->"6b2455c9-f16f-48fd-9a2d-debe5177241f"]
}, Open  ]],

Cell["\<\
The expression for the PDF of the normal distribution is shown below.\
\>", "Text",
 CellChangeTimes->{{3.7649319448136063`*^9, 3.764931946379696*^9}, {
   3.764933150462566*^9, 3.7649331516046314`*^9}, {3.7769402772706785`*^9, 
   3.77694028068775*^9}, 3.810402921634907*^9, 3.812732785462266*^9, 
   3.812732872246003*^9, 3.81584136673993*^9, {3.815844888616084*^9, 
   3.815844890779879*^9}},
 CellID->661582274,ExpressionUUID->"67cab8c3-d33f-405f-933e-3dab23ce5505"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    SqrtBox[
     RowBox[{"2", 
      SuperscriptBox["\[Pi]\[Sigma]", "2"]}]]], 
   SuperscriptBox["e", 
    FractionBox[
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "\[Mu]"}], ")"}], "2"]}], 
     RowBox[{"2", 
      SuperscriptBox["\[Sigma]", "2"]}]]]}], 
  TraditionalForm]], "DisplayFormula",
 CellID->556501683,ExpressionUUID->"e3f1a68f-19ed-42c0-8fdb-8f630378bd34"],

Cell[TextData[{
 "We can use the Wolfram Language function ",
 ButtonBox["PDF",
  BaseStyle->"Link"],
 " to show this equation:"
}], "CodeCaption",
 CellChangeTimes->{{3.7646948220040493`*^9, 3.764694822530102*^9}},
 CellID->980144212,ExpressionUUID->"ee849cd1-020a-481c-87df-a757950ee6d7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PDF", "[", 
  RowBox[{
   RowBox[{"NormalDistribution", "[", 
    RowBox[{"\[Mu]", ",", "\[Sigma]"}], "]"}], ",", "x"}], "]"}]], "Input",
 CellLabel->"In[34]:=",
 CellID->174264330,ExpressionUUID->"8315f5d3-7c0a-49e4-bb79-a2a26d1b61c1"],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "\[Mu]"}], ")"}], "2"], 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Sigma]", "2"]}]]}]], 
  RowBox[{
   SqrtBox[
    RowBox[{"2", " ", "\[Pi]"}]], " ", "\[Sigma]"}]]], "Output",
 CellChangeTimes->{3.8103858085128593`*^9, 3.8127334667211237`*^9},
 CellLabel->"Out[34]=",
 CellID->873337908,ExpressionUUID->"e8c355a3-24f7-468d-982c-89d5e51c6bd6"]
}, Open  ]],

Cell[TextData[{
 "For the standard normal distribution we can omit the ",
 Cell[BoxData[
 "\[Mu]"], "InlineCode",ExpressionUUID->
  "08845544-1364-4286-ab06-4b0131e827ed"],
 " and ",
 Cell[BoxData[
 "\[Sigma]"], "InlineCode",ExpressionUUID->
  "f9ac034f-f21d-4f19-88a7-dae965c15cd5"],
 " terms:"
}], "CodeCaption",
 CellChangeTimes->{{3.774198551290846*^9, 3.774198551554575*^9}},
 CellID->172762918,ExpressionUUID->"7e6bdbc6-97d9-405b-8f40-29e557caba63"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PDF", "[", 
  RowBox[{
   RowBox[{"NormalDistribution", "[", "]"}], ",", "x"}], "]"}]], "Input",
 CellLabel->"In[35]:=",
 CellID->737053995,ExpressionUUID->"6ad97a81-09f7-468d-87ad-4b958d8fa283"],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox["x", "2"], "2"]}]], 
  SqrtBox[
   RowBox[{"2", " ", "\[Pi]"}]]]], "Output",
 CellChangeTimes->{3.810385808518106*^9, 3.812733466727024*^9},
 CellLabel->"Out[35]=",
 CellID->139492511,ExpressionUUID->"95023a44-8efc-4668-800d-ef6d1eecf32e"]
}, Open  ]],

Cell["\<\
Next, we plot the standard normal distribution by making use of its formula.\
\>", "Text",
 CellChangeTimes->{{3.7646950103788853`*^9, 3.7646950194327908`*^9}, {
  3.7769404336918125`*^9, 3.776940437140216*^9}, {3.812732986767219*^9, 
  3.812732987590919*^9}},
 CellID->27864696,ExpressionUUID->"4554bcf7-6028-43ee-b332-b73e267ff453"],

Cell[TextData[{
 "We specify a domain of ",
 Cell[BoxData[
  RowBox[{"-", "6"}]], "InlineCode",ExpressionUUID->
  "23cafa65-0598-4396-83ff-ddf915d46b4c"],
 " to ",
 Cell[BoxData[
 "6"], "InlineCode",ExpressionUUID->"ad3a6425-ed43-4693-8d70-21b238d668cb"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7646949690167494`*^9, 3.7646949701198597`*^9}, {
  3.7646950145443015`*^9, 3.7646950264424915`*^9}},
 CellID->320680758,ExpressionUUID->"b73dbb20-2cbf-41ac-9e5b-be4531731121"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     SqrtBox[
      RowBox[{"2", "*", "\[Pi]", "*", 
       SuperscriptBox["1", "2"]}]]], "*", 
    RowBox[{"Exp", "[", 
     FractionBox[
      RowBox[{"-", 
       RowBox[{"(", 
        SuperscriptBox["x", "2"], ")"}]}], 
      RowBox[{"2", "*", 
       SuperscriptBox["1", "2"]}]], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellLabel->"In[36]:=",
 CellID->6843162,ExpressionUUID->"400a5ce8-265b-4fab-b248-2712bcdc9ff2"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJw1m3k0Vt/7v83z8MwPKoo3IUrRIOy9ixAlkZkoCoVUSEimzESKDClkKhmS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    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1WWYVlUUQOFxUEpAEBRBuru7u7u7G6S7uxskVRQMsLuREAxApEulBATF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         "]]]}, {}, {}}, {{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl12WYVVUfQPGhU0G6uxSlu0G6lO7u7u4wCSVUGqRBEElBQumUVrpTCemO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         "]]},
       Annotation[#, "Charting`Private`Tag$24565#1"]& ]}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{518., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotRange->{{-6, 6}, {0., 0.39894211025341036`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.810385808573106*^9, 3.8127334667511663`*^9},
 CellLabel->"Out[36]=",
 CellID->1545973500,ExpressionUUID->"c838c854-e61b-469c-83dd-3a605747c04e"]
}, Open  ]],

Cell[TextData[{
 "This is exactly the same as using the ",
 ButtonBox["NormalDistribution",
  BaseStyle->"Link"],
 " function:"
}], "CodeCaption",
 CellID->24949686,ExpressionUUID->"a0b85c5f-2843-4444-b53b-a62ff1f8def6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"PDF", "[", 
    RowBox[{
     RowBox[{"NormalDistribution", "[", "]"}], ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", 
     RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellLabel->"In[37]:=",
 CellID->135139084,ExpressionUUID->"3055636b-b501-4500-a8f8-b1755c844ea7"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJw1m3k0F873/+378tq8Xqgo3hVSKVqEmSlCiWTPXilkSYWE7NmJyJYUspUs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    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1WWYVlUUQOFxUEpAEBRBuru7u7u7G6S7uxskVRQMsLuREAxApEulBATF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         "]]]}, {}, {}}, {{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl12WYVVUfQPGhU0G6uxSlu0G6lO7u7u4wCSVUGqRBEElBQumUVrpTCemO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         "]]},
       Annotation[#, "Charting`Private`Tag$24610#1"]& ]}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{522., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotRange->{{-6, 6}, {0., 0.39894211025341036`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.810385808730515*^9, 3.812733466900751*^9},
 CellLabel->"Out[37]=",
 CellID->771969447,ExpressionUUID->"eef744ae-b90a-4260-bb76-50234397e418"]
}, Open  ]],

Cell[TextData[{
 "Now that we have a good understanding of the normal distribution, we can \
simulate an experiment by taking samples for the measurement of a variable \
from a population in which the variable is normally distributed. Let\
\[CloseCurlyQuote]s imagine that the variable has a mean of 100 and a \
standard deviation of 20 in the population. We will take 60 samples at random \
from this population for our experiment and store it in the computer variable \
",
 Cell[BoxData[
 "sampleVariable"], "InlineCodeText",ExpressionUUID->
  "f4871b60-9b75-4e06-91d0-b1d03ba0192b"],
 "."
}], "Text",
 CellChangeTimes->{{3.7649332147982454`*^9, 3.7649332156602945`*^9}, {
  3.776940537617327*^9, 3.776940538370526*^9}, {3.776940638329314*^9, 
  3.7769406697053275`*^9}},
 CellID->246688181,ExpressionUUID->"65f2d309-e85f-4ce3-a0eb-935b05ebdb26"],

Cell["\<\
Create a random sample of 60 cases from a normal distribution of 100 and a \
standard deviation of 20:\
\>", "CodeCaption",
 CellChangeTimes->{{3.764933445636449*^9, 3.7649334460134706`*^9}},
 CellID->292014550,ExpressionUUID->"32daa0d4-cbc9-4d3d-859b-812f01a0365c"],

Cell[BoxData[{
 RowBox[{"SeedRandom", "[", "123", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sampleVariable", "=", 
   RowBox[{"RandomVariate", "[", 
    RowBox[{
     RowBox[{"NormalDistribution", "[", 
      RowBox[{"100", ",", "20"}], "]"}], ",", "60"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7769405418052454`*^9, 3.776940542385928*^9}},
 CellLabel->"In[38]:=",
 CellID->405256362,ExpressionUUID->"08fed267-ae67-43fd-85d4-0c7ce8a9fac9"],

Cell["\<\
Your experiment will have a sample taken from a larger population. For the \
instance above, let\[CloseCurlyQuote]s see what the random sample mean and \
standard deviation are.\
\>", "Text",
 CellChangeTimes->{{3.764933489045932*^9, 3.764933489748972*^9}},
 CellID->278236021,ExpressionUUID->"1ce682eb-c3d7-4f62-91ec-cdaa200d8ffe"],

Cell["The mean of the random sample:", "CodeCaption",
 CellID->886510950,ExpressionUUID->"05266939-7452-4cfe-b2f6-284338c52809"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mean", "[", "sampleVariable", "]"}]], "Input",
 CellChangeTimes->{{3.776940555916267*^9, 3.776940566971386*^9}},
 CellLabel->"In[40]:=",
 CellID->213084500,ExpressionUUID->"99c7bf86-d245-4871-9bbe-0d32179684fa"],

Cell[BoxData["97.10438222070262`"], "Output",
 CellChangeTimes->{{3.776940557155498*^9, 3.776940567152171*^9}, 
   3.8103858087435083`*^9, 3.8127334669249773`*^9},
 CellLabel->"Out[40]=",
 CellID->1229398312,ExpressionUUID->"423a0db1-e3ab-4290-a3d5-e4fb10ef4bf4"]
}, Open  ]],

Cell["The standard deviation of the random sample:", "CodeCaption",
 CellID->122167763,ExpressionUUID->"852a95ce-1d23-45e8-b6ef-17f896b1aa36"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardDeviation", "[", "sampleVariable", "]"}]], "Input",
 CellChangeTimes->{{3.7769405715192366`*^9, 3.776940572004397*^9}},
 CellLabel->"In[41]:=",
 CellID->14691677,ExpressionUUID->"ce31a765-48d1-4ee0-99be-f1b279ea3acc"],

Cell[BoxData["19.97205940814186`"], "Output",
 CellChangeTimes->{3.7769405724466147`*^9, 3.810385808748452*^9, 
  3.812733466930354*^9},
 CellLabel->"Out[41]=",
 CellID->1557261997,ExpressionUUID->"506f4202-f5e5-4a36-80fa-68a4ec9ac020"]
}, Open  ]],

Cell["\<\
These values are close to 100 and 20. The question is, how close?  As we \
learn about inferential statistics in the coming chapters, we will learn to \
express how different a statistic is from a stated value or how different two \
statistics for the same variable are between two groups.\
\>", "Text",
 CellChangeTimes->{{3.7769407556634207`*^9, 3.7769409008104525`*^9}, 
   3.815841430730789*^9},
 CellID->59054695,ExpressionUUID->"86b2c6b6-5642-4b63-bb26-16c9e08cde47"],

Cell["\<\
Taking samples from populations and exploring and comparing different \
statistics for the variables under consideration are at the heart of \
inferential statistics. This is how we investigate our research questions. \
For example, we might randomly divide a sample taken from a larger population \
into two groups. One group receives an intervention and the other not. We \
then measure a variable for each subject in the two groups and compare the \
statistics for that variable between them. One of the most common statistics \
that we compare is the mean.\
\>", "Text",
 CellChangeTimes->{
  3.7646957696383677`*^9, 3.7646973755783677`*^9, {3.776940909670809*^9, 
   3.776941084327927*^9}, {3.7769411577265573`*^9, 3.776941189365973*^9}, {
   3.810400810510725*^9, 3.810400812055187*^9}, 3.812732992998951*^9, {
   3.815841444474186*^9, 3.815841460098034*^9}},
 CellID->69466243,ExpressionUUID->"d01c9023-587d-4850-94cb-e113c5acae8f"],

Cell[TextData[{
 "An important lesson to take from this chapter, is that we base our \
assumption on the distribution of the variable in the underlying population. \
When it comes to common tests, such as the Student ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath",ExpressionUUID->
  "7f93cf9e-b08d-4cc8-ab6d-12b6cfa56608"],
 " test, we must be sure of this assumption or else we will get inaccurate \
and misleading results. Different tests must be used for different \
distributions."
}], "Text",
 CellChangeTimes->{{3.764695921575368*^9, 3.764695949635368*^9}, {
  3.7769412024602118`*^9, 3.776941210880517*^9}, {3.81584158933041*^9, 
  3.815841591809539*^9}},
 CellID->517737602,ExpressionUUID->"b734d4aa-10a7-4188-bfef-7e4ee1fda31f"],

Cell[TextData[{
 "One obvious problem is that we do not often have data from a whole \
population. We have to make a calculated guess as to what it is. One of the \
distributions that will come to our rescue is the ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath",ExpressionUUID->
  "c5a8bc3b-048c-4085-8a1d-fe888466f5cc"],
 " distribution."
}], "Text",
 CellChangeTimes->{
  3.764695968714368*^9, {3.776941238180621*^9, 3.7769412635004425`*^9}, 
   3.815841611402548*^9},
 CellID->107113048,ExpressionUUID->"4ce3f8c0-d0b6-4d5c-b7e6-15984e8fbf4c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath",ExpressionUUID->
  "ae02afd0-d518-45a9-921b-f4ff3f189f25"],
 " Distribution"
}], "Subsection",
 CellChangeTimes->{3.8158416569952793`*^9},
 CellID->7223967,ExpressionUUID->"fc1d4b11-eaa7-45c6-880b-c4128eba85e0"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath",ExpressionUUID->
  "fad786f6-dde4-44d9-b2f5-88defc0aedc2"],
 " distribution is a commonly used distribution and is the basis for the \
Student ",
 StyleBox["t",
  FontSlant->"Italic"],
 " test. It is used when the variance of a variable in a population is \
unknown, as well as when the sample size is small."
}], "Text",
 CellChangeTimes->{{3.764696034583368*^9, 3.764696034735368*^9}, {
   3.7646963784863677`*^9, 3.764696380837368*^9}, {3.7646967092893677`*^9, 
   3.764696715226368*^9}, 3.764697379450368*^9, 3.7769413685271425`*^9, {
   3.7769414595249834`*^9, 3.776941583122121*^9}, 3.810400812091626*^9, {
   3.8158416775783653`*^9, 3.815841680449423*^9}},
 CellID->25724162,ExpressionUUID->"154ae898-9dcb-4d7b-b66d-c8ab8b44731c"],

Cell[TextData[{
 "The ",
 StyleBox["t",
  FontSlant->"Italic"],
 " distribution is dependent on a value known as ",
 StyleBox["degrees of freedom",
  FontSlant->"Italic"],
 ". Think of degrees of freedom in the following way. You have three numbers \
and their mean is 10. For the mean to remain 10, two of the values can \
fluctuate wildly, but this fixes the third. There are two degrees of freedom \
in this example, that is, three total elements in a single group. The degrees \
of freedom is simply calculated as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"3", "-", "1"}], "=", "2"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"86866709-f017-4ad3-b474-d9e734cb3aad"],
 "."
}], "Text",
 CellChangeTimes->{{3.7769415870743823`*^9, 3.776941603754483*^9}, {
  3.8158417399385843`*^9, 3.8158417431533203`*^9}},
 CellID->344467047,ExpressionUUID->"7868c78b-4019-41af-ad6e-0a8d600fc5cd"],

Cell[TextData[{
 "For a given value for degrees of freedom, ",
 Cell[BoxData[
  FormBox["\[Nu]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "647da008-76a2-4978-a5fe-b58c0183f62f"],
 ", the PDF of the ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath",ExpressionUUID->
  "4cdb0c4f-0c74-4d8a-a7e5-70ba0397ea2f"],
 " distribution is as follows."
}], "Text",
 CellChangeTimes->{{3.764933630517023*^9, 3.764933639108515*^9}, {
  3.776941675462282*^9, 3.776941678444269*^9}, {3.815844946843816*^9, 
  3.815844947099535*^9}},
 CellID->118445582,ExpressionUUID->"2db32e10-4126-46bf-9783-289d0499d959"],

Cell[TextData[{
 "Use the Wolfram Language to write the PDF of the ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath",ExpressionUUID->
  "223c6b86-bde5-412c-8840-137fdb997dcc"],
 " distribution:"
}], "CodeCaption",
 CellChangeTimes->{{3.7646968982623677`*^9, 3.7646969240153675`*^9}, {
  3.7649336123889866`*^9, 3.7649336258127546`*^9}, {3.815844986140417*^9, 
  3.815844986379485*^9}},
 CellID->243432671,ExpressionUUID->"853e36e7-dabe-4566-97b7-9d10a085a666"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PDF", "[", 
  RowBox[{
   RowBox[{"StudentTDistribution", "[", "\[Nu]", "]"}], ",", "x"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.776941685779663*^9, 3.7769416881542983`*^9}},
 CellLabel->"In[42]:=",
 CellID->401279574,ExpressionUUID->"b12dc92a-8c66-49f4-94a7-d43eaaa7a5f6"],

Cell[BoxData[
 FractionBox[
  SuperscriptBox[
   RowBox[{"(", 
    FractionBox["\[Nu]", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", "\[Nu]"}]], ")"}], 
   FractionBox[
    RowBox[{"1", "+", "\[Nu]"}], "2"]], 
  RowBox[{
   SqrtBox["\[Nu]"], " ", 
   RowBox[{"Beta", "[", 
    RowBox[{
     FractionBox["\[Nu]", "2"], ",", 
     FractionBox["1", "2"]}], "]"}]}]]], "Output",
 CellChangeTimes->{3.7769416913118505`*^9, 3.81038580876455*^9, 
  3.8127334669354353`*^9},
 CellLabel->"Out[42]=",
 CellID->1519177590,ExpressionUUID->"c7af818b-0b7d-4418-84eb-9c4fbfbc9d89"]
}, Open  ]],

Cell["\<\
In the example below, we create two curves, one with 2 and one with 30 \
degrees of freedom:\
\>", "CodeCaption",
 CellChangeTimes->{{3.764696947643368*^9, 3.7646969514823675`*^9}, {
  3.7649336537583528`*^9, 3.764933654436392*^9}},
 CellID->245061752,ExpressionUUID->"eeacc90c-4bfd-4e27-9e24-3107a7606623"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"PDF", "[", 
       RowBox[{
        RowBox[{"StudentTDistribution", "[", "\[Nu]", "]"}], ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Nu]", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "30"}], "}"}]}], "}"}]}], "]"}], "//", 
    "Evaluate"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellLabel->"In[43]:=",
 CellID->191060932,ExpressionUUID->"896b53c7-7d58-45aa-840e-9b5cf55a1ac5"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx12nkwVv8f+H37vl52FSJLWmyRJdfrJMkSUkJCKiVSdtmSfd9C9qwRJbss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    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1WW0VVUUBtBHd4MS0oIIBmFLo4SCgdLdHSpdgkqX0t3dKN3doXSKhNjd
7VyDH3Os9a29z7njvrf3uPmbd6nZOXFCQkIibie6Uw8nTUg4Qkn9LYMhXKE4
AzjDDWtF1B4cY4Z8hQL6rhygoTyEA6SV67OGEnJxHuYhGjCY/aSxXo/VPCjX
5x32kdqsLqt4QK7H2+wllVkdVlJMrstb7CGlWW1WUFSuwyB2k8KsFsu5X67N
QHaR3OxVllFErsWb7CSZ2Sss5T55OpfJL3dhfzwrD2AHSeWaLKGwPI1L5JM7
sy/eJ/dnO0nkl1lMIXkqF8krd2JvvE/uxzYSyy+xiHvlKVwgj9yRPfE+uS9b
4/8tv8hCCsqTOU9uuQO7431yH7Yk3DkgL7CAAuIkznGP3J5d8T65N5v5jxpm
88mvn8hZcsnt2Bnvk3uxiX+pbjaPfPoJnCGn3JYd1JB7spF/eN5sLnn14zlN
DrkN26ku92ADf/Oc2RzyxLN0Zz1/Uc18NrnjO8VeurGOP6lqbRa59OM4RXa5
NduoJl+jkP4NDkeVi6q9OMEH8h9U0c8kZ9wBtT+nuR5nVr0QZ4ruHOW9uAPq
pTj3XKMPH/KRtevqQM5xN1dpxVaqWr+pDuZy3Ck+oW88y8fWb6iDOB9nJ2a8
zqGoccfUi3E/6Mlx3o+7oJ7ld31ldQY54k6r/TgVnyUXVrtxhHflYmpvTsZ3
kO9SW7KFKvJVCupf42BUeS2/8aw8nez6sZwkm9yCzVSWu7KGX3nGbFr8XeJz
4nm6sJpfqGRtKtliL51Zxc9UNJ9CVv0YTpBVbs4mKsmdWMlPVDCbTBb9aI6T
RW7GRirKHVnBj5Q3m0Rm/SiOkVluygYqyB1Yzg+UM5tIJv1IjpJJbsJ6ysvt
Wcb3lDWbQEb9CI6QUW7MOsrJ7VjKd5QxG08G/XAOk0FuFGeXsnJblvAtpc3G
kV4/jEOklxvG+aCM3IbFfMPTcZZJpx/KQdLJDVhLabk1i/iap+K8kDaepRUL
+YonzceSJvbRkgV8yRPmY0gd+2jBfL7gcfPRpIp9NGcen/OY+ShSxj6aMZfP
eNR8JCliH02Zw20eMR9B8thHE2bzKaXMh5Ms9tGYWdyipPkw/NQmJCF+h0vR
iJncpIT1ofwPbaXqlw==
         "]]]}, {}, 
      {RGBColor[0.880722, 0.611041, 0.142051], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1WWYVVUAhtHL0N3dSGPQ3d0dAipKd3eKoHRLK93dDWKCrWCQBt3d6dqP
P9Zz9vfee2YG58w1a+seDbtHRSKRaJxzOO9wKEYkcphU9jeub3CARdEjkVyu
O0jrPIfMzhuY57236ak95COtkp3UeSqp7RX01A5RVfuRt7SU9lxu0UN7wId6
RTuJ8xRS2cvpEX4mqmg/0FJLYadxnk0mez1ztJt01+4zWqtgJ3aeTEp7GeEf
/zWVte9poSW3Z3ODbto9Runl7UTOk0hhL6Wb9hWVtO9oriWzZ3GdrtpdPtDL
2QmdJ5LcXkJX7Usqat/yppbUTu08i4z2OmZq1+ii3WGkVtZO4DyBZPZiumhf
UEE7TDMtif0xV+ms3eZ9vYwd33k8ScPvl87a55TXDtFUS2zP4AqdtFuM0Evb
8ZzHkcReSCftIOW0b2iiJbKnc5mO2k2G66XsuM5jSWwvoKP2GWW1r2msJbSn
cYkO2g2G6SXtOM5jSGR/SgftAGW0r2ikJbCncpH22nWG6iXs2OFZJaH9Ce21
/ZTWvqShFt+ewgXaadcYohe3Y4VnlQT2fNpp+yilfUEDLZ49Ofxt0Va7ymC9
mB0zPJvED39DtNX2UlL7nPpaXHtS1P9/n220KwzSi9oxwrNJPHsubbQ9lNAO
Uk+LY0/kLK21ywzUi4TNboprn1FXj21P4AzvaZcYoBcOm10U0w5QR49lj+df
3tUu0l8vFDY7Kartp7Ye0x7HP7TSLtBPLxg2Oyii7aOWHsMey9+8o52nr14g
bLZTWNtLTT26HUU08vM22yjk9T3U8J6IPYa/wuvaOfqEzzr7LbZSUNtNdf2l
z8VUzjPJYK/lI+85Hd6vnaW39rodPfy9Ezd8DtFSm2dndd7EFruAvYtq9gtf
e6FzTuft4fPQOZ/rHj52Tu+6hg/d95rrvvCshufD9ZXw9TgVPkdc87ArfM/w
+3Q949rL9bXwORd+PvaHv5XwfLpmZytR4e/FNS+7GRmen/DsMJsW7n/VdW94
zryWxXUjm/XcrjvJr++kqvNz/6YFzjmct4XPaOcZpHNezWj3zbezha/BSbuF
/S897VfD7y98ThHbnkVzbRNvaDuooj3zfUZpJ2iu/UMPPZ/9Jht5XdtOZf2p
93+gHQ+va3/TPfy77WZsCP+NtW1U0p94/2MekcdrTVkf/lt4fSsVveeh13Jr
TVhHPn0LFbz2wGsjtWPh62t/0U3PZTdmLXm1zZTX73v/+9qf4Xtpp+mq57Qb
sYY82ibK6fe8f4T2R/j+2im66DnsSPicJlb4/wcNtdXh96VtpKx21/3Dtd/D
z6OdpHN4LuyXDLdjhueQBvYqcmkbKKPdcf8w7bfw82kn6BSeS/sFw+wY9gzq
2yvJqa2ntHbb/UO1ozTUjtNRz2Y/Z6gd3Z5OPXsFObR1lNJuuX+IdoQG2jE6
6FntZwyxo+xp1LWXk11bS0ntpvsHa79SX/uT9noW+ymD7Wj2VOrYy3hFW0MJ
7Yb7B2m/UE/7g3Z6ZvsJg+yIPYXa9lKyaasprl13/0DtZ+pqv9NWz2Q/ZqD9
kslaLXsJWe1VFNOuuX+A9hN1tN9oo2e0HzHAfsEkraa9mCz2SopqV93fX/uR
2tpRWusZ7If0t58zUathLyKzvYIi2hX3J3eeTlp7Ff285wdqaUd4T0tvP6Cf
/YwJWnV7IZns5RTWLvt6fbXvqan9yrt6Ovs+fe2njNeq2QvIaC+jkHbJ/X20
76ih/UIrPa19jz72E8ZpVe1PyWAvpaB20f3JnKeRxl5Jb+/5luraz7yjpbHv
0tt+zFitiv0J6e0lFNAu+Hq9tMNU037ibT21fYde9iPGaJXDZyLp7MXk1/4D
IAVx9A==
         "]]]}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl1WOYnVcUBtBMbKsNJ7Ztp3EysW23sV23Sa3YTlPHtlEzTW276dpPf6y7
97vPzHPvfOecuYmDxieNS0iWLNlNL1Hv9lKZj/XL6UtVkpOClNxjvQo39Svo
RzVSca95VT7Rr6Q/1UnNfebV+FS/igHUIA33m1fnM/1qBlKTtDxgXoPP9WsY
RC3S8aB5Tb7Qr2UwtUnPQ+a1+FK/jiHUIQMPm9fmK/16hlKXjCw1r8PX+g0M
ox7Pm/UmEyfjWZGJZXJdvtFvZDj12W3Wh8yciudGZh6R6/GtfhMjaMALZn3J
wul4lmThUbk+3+k3M5KGvGjWj6yciedLVh6TG/C9fgujaMRLZv3Jxtl45mTj
cbkhP+i3MprGvGw2gOyci30gO0/IjfhRv40xNOEVs4Hk4HzsDTl4Um7MT/rt
jKUpr5oNIicXYr/IyVNyE37W72AczcjF0+ZN+UW/k/E0Jzd5eMZaM37V72IC
LXjNbDC5uBj7T16elZvzW+wvEzkpT6Qo78kt2aMfQm4uyRfV6ZRlqXxGnUQJ
PpSvqLOowG3yc2oLftdfV+eyW39enUpp3mIhd5qfisr7FOMN5nMjZtYvqzPj
vSjPOyyOe8sd1veqQ+Pzk4fXmcdHXLZ+SZ3BB5TjbRaxzNpZdTIleZMF8Xvm
V9XZVOR2ebnakj/i7HJBP40y3CWfjkrxeB+5Ffv0w8jLlbgL5GNFfG7+jHPN
JFqTnwKstNaKv+IcM5k2FGSVeWv+jjPLFNqy32x4PH+uxj2iEKvlNvwTZ5ap
tOOA2Yj427gW94jCrJHb8m+cWabRnoNmI8nH9bhHJLJWbsetOHdMpwOHzEaR
P/Yj7hFFWCe3J/4B71Fm0JHD8mgKxP7HPaIo6+UOJLBXnkknjshjKBj7FveI
YmyQO5KcffIskjgqj6VQnL24WxRno9yJFOyXZ9OZY3J8WRSO8xJ3jRJskpNI
yQF5Dl04Lo8nMc5n3DVKslnuTCoOynPpSim2mHUhNYfkeXSjNFvNupKGw/J8
ulOGbWbdSMsReQE9KMt2s+6k46i8kJ6UY4dZD9JzTF5EL8qz06wnGTguL6Y3
FahIJSqzy3ovMnJCXkIfTsgTKMK78T+Ac/oplOKGfE2dQ6X4GZYk/P9dXMXa
fwbP6Pg=
         "]]},
       Annotation[#, "Charting`Private`Tag$26515#1"]& ], 
      TagBox[
       {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl1XWYFQUUQPG37NIpoHQsII00KoKgUooBGAhILd1hoIIKiNINKtLdIQoG
YIAdYICNRXc3xu9+/nG+uefMzPJmd94lNa1fi75JiUTir3SJxD5DlZREYn5y
IlEQM7UGGKld5ANwmudDW207b4xP+QDsd39VfYFWCLO0hhilXeIDcYbnRztt
B2+Cz/hALNXyY7KWGwf8vGp8obkwZrumEUZrl/mjOMsLoL32Nb8Tn/NHcdD9
1fVFWhHM0RpjjHaFP4ZzvCA6aN/wu/AFfwyH3F9DX6wVxVytCcZqV/njOM8L
oaP2LW+KL/njWKYVwBQtDw77eTX5EnMxzHPNnRin/c2fwAVeGGnad/xufMWf
wBH319KXasUxX7sL47V/+CBc5EXQSdvJ78F2PghH3X+jvkxLxQKtKSZo//In
cYkXRWdtF78XO/iTOOb+m/TlWgks1O7GRC2Bp7TLvBi68O/5ffiaP4Xj7r9Z
X6GVxCLtHkzSkvC0doUXR1f+A2+Gb/jTOOH+2vpKrRQWa/dispYOg7WrPBXd
+I+8Ob7lg3HS/bfoq7TrsUS7D1O0ZAzR/uYl0J3/xFvgOz4Ep9xfR1+tlcZS
rRmmail4RvuHl0QP/jO/Hzv5Mzjt/rr6Gq0MlmnNMU1Lj2e1f3kp9OS/8Aew
iz+LM+6/VV+rlcVyrQWmaxnwnJaIZ9N68V/ND+J7/hzOur+evk4rhxXa/SiN
3vpu7SH8wIfinOvr669p5bFSewBl0Ef/TWuJH/kwnHf9bfp6rQJWaQ+iLC44
d7tzr+sVsVp7COVw0blLuIw7XPOG85WwxrmWKI+++u/aw/iJD8cV1zfQN2g3
YK32MCqgn/6H1go/8+dx1fUN9Y1aZazTWuElLSOGaknx+bT+/E9za/zCX+Ml
MJOP4MvNBTGV58Ub5usxJ94h/04j85vmKnjTXDZ+j+5b61gcM/RNjhXRWn/Z
MRPexzDn3nYsjw/j3eavO5bCVszmWxxvwEeoFPvX8S/9Pcc2jm85lsO2eA+c
X+9YEh9glvOb4z684NwKx0KYpr/jWAHXmjc4lsbceK89U2PzW+aqWO++dTwV
r/I2/BVzZgznyfE3ib3O95gfwW7+IlZqhTFduy7eeT+7CX/bXC2e1TWPoHLs
cX2v1ha/8ZFIxN7U39Gqx++et0UVJCEdkmM3umaT8zXiWXg7VI3dru/T2uF3
PgopsQv1zVpNbOTtUS12ub5fa48/+Gikj92nb9Fqxd+Yd0D12NX6Aa0D/uRj
kCF2nf6udmP8fXhH1IjdrB/UOib////wWGSM3aa/p90U7wNPQ83YxfohLQ17
+Dhkil0W7492c/wdeSfM0LLgeS0lPmvsYn7Y3Al7+Xhkjl0W74dWO95N3hmv
alkxQksfnz12MT9i7ox9fAKyxC6L91O7Jd4v3gUztWzxnmkZ4lliF/Oj5i7Y
zycia+yyeF+1OvF+866YpWXHi1rGeLbYxfyYuSsO8EnIFrssvi9aXbzLu2G2
lgMjtUzxbLGL+XFzNxzkk5E9dlt8n7Rb43vEu2OOlhOjtMzxbLGL+Qlzdxzi
U5Ajdp3+sVYP7/MemKvlwmgtSzxb7GJ+0twDh/lU5Ix9qH+i1ccHvCfmaddg
jJY1ni12Mz9l7okjfBpyxa7UP9Vuw1beC/O13BirZYtni13NT5t74SifjlVa
Ebyk5cM1sUv5Z+bbsY33xgItD8Zp2eNZYxfzM+beOBb7FLljt+qfa3fgQ94H
C7W8GK/liGeN3czPmvvgeOxC5EFr/QutAT7ifbEodhMmaDnjWbUR/Jy5L07E
HsJqrShe1vLHjtba8C/NDfEx74fF2nWYqOWKZ9Ve4OfN/XAyvkO4NnaS/pXW
CJ/w/lii5cOk+J3Fs8aO4xfM/XEqvkNYoxXDK1qB2C/mMpgX76pj5Xh34rO4
9j+7EXBZ
         "]]},
       Annotation[#, "Charting`Private`Tag$26515#2"]& ]}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{535., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotRange->{{-6, 6}, {0., 0.39563201053328567`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8103858088274117`*^9, 3.812733466973896*^9},
 CellLabel->"Out[43]=",
 CellID->1384675947,ExpressionUUID->"02cfffaa-ed96-4740-bd97-4100b54c86d2"]
}, Open  ]],

Cell[TextData[{
 "For smaller sample sizes (a lower value for degrees of freedom), there are \
more values in what is termed the ",
 StyleBox["tails",
  FontSlant->"Italic"],
 " of the distribution."
}], "Text",
 CellChangeTimes->{{3.7646970456453676`*^9, 3.764697052125368*^9}, 
   3.764933672159405*^9, {3.7769417708631935`*^9, 3.7769417953686666`*^9}},
 CellID->340901948,ExpressionUUID->"9964538f-75ea-4164-b853-30c23773ae54"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"54aebf4a-d602-4800-8810-c0dcaca13a07"],
 " Distribution"
}], "Subsection",
 ScriptBaselineShifts->{0.3},
 CellID->142563282,ExpressionUUID->"be81add8-99ea-4c83-8293-cc8cb2648d48"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"2e5edcd2-2944-40de-8451-0abda8420db1"],
 " distribution is also dependent on degrees of freedom, ",
 Cell[BoxData[
  FormBox["\[Nu]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "66f3c0f2-aa25-495f-9966-de5a94730d38"],
 ". It is the distribution of sums of squares of ",
 Cell[BoxData[
  FormBox["\[Nu]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "dbf815c2-e405-48cc-88a9-d73ec08f5ac5"],
 " values independently sampled from a normal distribution. It is a special \
case of the gamma distribution and is another one of the commonly used \
probability distributions used for the analysis of categorical variables."
}], "Text",
 CellChangeTimes->{
  3.764697353484368*^9, {3.764697466359368*^9, 3.7646974703173676`*^9}, {
   3.776941867742453*^9, 3.776941914363818*^9}, 3.815841957793838*^9},
 ScriptBaselineShifts->{0.4},
 CellID->946935873,ExpressionUUID->"b496104c-932e-4b8a-a032-7a12f8549b3d"],

Cell[TextData[{
 "We can use the ",
 ButtonBox["ChiSquareDistribution",
  BaseStyle->"Link"],
 " function to plot the PDFs for a ",
 Cell[BoxData[
  FormBox["\[Nu]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "df61c93b-8da3-400b-b1f6-2819b6a071f8"],
 " of 2, 6, and 20."
}], "Text",
 CellChangeTimes->{{3.764697546283368*^9, 3.7646975490083675`*^9}, {
   3.7769419230665426`*^9, 3.7769419308417425`*^9}, 3.7769419900764465`*^9, {
   3.81584499268353*^9, 3.815844992947607*^9}, 3.815845067507801*^9},
 CellID->636615775,ExpressionUUID->"86ab2f6a-fd48-4a6f-9225-ddb916205586"],

Cell[TextData[{
 "Plot three ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"41fdaee4-7111-4971-b5be-316306b2a84d"],
 " distributions:"
}], "CodeCaption",
 CellChangeTimes->{{3.7646975654873676`*^9, 3.764697572518368*^9}},
 ScriptBaselineShifts->{0.5},
 CellID->2122207582,ExpressionUUID->"27603d5b-b20c-48f4-a2e8-56f6fb66788b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"PDF", "[", 
       RowBox[{
        RowBox[{"ChiSquareDistribution", "[", "\[Delta]", "]"}], ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Delta]", ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "6", ",", "20"}], "}"}]}], "}"}]}], "]"}], "//", 
    "Evaluate"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "50"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellLabel->"In[44]:=",
 CellID->282377119,ExpressionUUID->"72a126df-edd3-45fc-8cdb-44aa227abd73"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJw822k0ld/fx3EJCSljyBSRMfPs2vtrVoqSeU4pc2ZRpEhSxojILFMqhESE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    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1lOUnQcbhuGJbauN09i2nca2bTtNY6MxGjW2bdu2beu/Jv/Btfb33LPf
k1kzeyZRw3YV2wYNCAgIQoJg/3+tEDogoCKZPMfT/vaGuF5f+OJAz3E81/D8
nL/s2PZ+701hb6W89oBGWnX7GQPsWN43UfvAcO13bT0Z7X0k17bwp3afhlo1
+yn97ZjuJ2jvGab9pq0jg72XZNpmymn3aKBVtZ/Qz47hfrz2jqFaAm0t6e09
JNU2UVa7S32tiv2YvnZ09+O0twzR4mtrSGfvJom2kTLaHepple1H9LGjuR+r
vWGwFk9bTVp7F4m1DZTWblNXq2Q/pLcd1f0Y7TWDtLjaKtLYO0mkraeUdos6
WkX7Ab3sKO5Ha6/4W4ujrSS1vYOE2jpKajepHfizYN+npx3Z/SjtJQO12NoK
Utnb+V1bSwntBrW08vY9etiR3I/UXvCXFktbTkp7G79payiuXaem9qd9l+52
RPcjtOcM0GJqy/jD3hr486utpph2jRpaOfsO3ewI7odrz+ivxdCWksLeQnxt
FUW1q1TXytq36WqHdz9Me0o/Lbq2hOT25sDfFW0lRbQrVNPK2LfoYodzP1R7
Ql8tmraYZPYm4morKKxdpqpW2r5JZzus+yHaY/poUbVFJLU3EkdbTiHtElW0
UvYNOtlh3A/WHtFbi6ItJIm9gdjaMgpqF6mslbSv09EO7X6Q9pBeWmTtPxLb
64mlLaWAdoFKWgn7Gh3sUIGfJdoDemqRtAUkstcRU1tCfu08FbXi9lXa2yHd
D9Tu00OLqM0nob2WGNpi8mnnqKAVs6/Qzg7h/i/tHt21CNo8frfXEF1bRF7t
LOW1ovZlAj8kg7sfoN2lmxZem8tv9mqiaQvJo53hT62IfYk2djD3/bU7dNXC
aXNIYK8iqvYfubXTlNMK2xdpbQd130+7TRctrPYv8e2VRNEWkEs7RVmtkH2B
VnYQ9321W3TWwmiziWevILI2n5zaScpoBe3ztAz8I+G+j5ebdNJCa7MC/zbY
y4mkzSOHdoLSWgH7HC3sn/TWbtBRC2XPJI69jIjaXLJrxyml5bfP0tz+QS/t
Oh20kPYMYttLiaDNIZt2jJJaPvsMzezv9NSu0V4LYU8nlr2E8Nq/ZNWOUkLL
a5+mqf2NHtpV2mnB7WnEtBcTTptNFu0IxbU89ima2F/prl2hrRbMnkoMexFh
tVlk1g5TTMttn6Sx/YVu2mXaaEHtKUS3FxJGm0km7RBFtVz2CRrZn+mqXaK1
FsSeTDT7P0JrM8ioHaSIltM+TkP7E120i7TSAuxJRPW4gFDadDJoByis5bCP
0cD+SGftAi21n/yjRbHnE9KeRnptP4W07PZR6tsf6KSdp4X2g4laZHseIeyp
pNP2UVDLZh+hnv2ejto5mmvfmaBFsucS3J5CWm0vBbSs9mHq2u/ooJ2lmfaN
8VpEe07gr4c9mTTaHvJrWexD1LHf0l47Q1PtK+O0CPa/gd9OexKptd3k0zLb
B6ltv6Gddpom2hfGauHt2QQJ/H6SSttFXi2TfYBa9mvaaqdorH1mjBbOnhUQ
8Oufv4mk1HaSR8po76em/Yo22kkaaZ8YrYW1Z/KTCdof2g5y2xnsfdSwX9Ja
O0FD7SOjtDD2DH4wXkuhbSeXnd7eS3X7Ba204zTQPjBS869qwHS+M05Lrm0j
p53O3kM1+zkttWPU194zQgtlT+MbY7Vk2lZy2Gnt3VS1n9FCO0o97R3DtZD2
VL4yRkuqbSG7ncbeRRX7Kc21I9TV3jJMC2FP4QujtSTaZrLZqe2dVLaf0Ew7
TB3tDUO14PZkPjNKS6xtIqudyt5BJfsxTbVD1NZeMyTor4/1gEl8YqSWSNtI
FjulvZ2K9iOaaAeppb1icNBfHwMB//CREVpCYQOZ7T/sbVSwH9JYO0BN7SWD
tP8B0YuF5g==
         "]]]}, {}, 
      {RGBColor[0.880722, 0.611041, 0.142051], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwV1mWYVVUAhtFLKSFYSEgjgiDdKdLNDCDd3SEg0ird3SkloYRgIN1t0EqX
tCDd6No/1nP2997LM8zM4VzSNetcvVPMSCQSg7kOKWNFIlFxI5FoqjivjROJ
5GQ5a2JHIhldF/Cx8xJSOE/jT+/Na8/idXsUfbWi9kKS2pP4VnvV7swFGmuV
tePksWeSSBtJH20Zr2idOE8jvZJ2jNz2DBJqI+itFbEXkMSeyFItjt2RczTU
KmpHyWVP5zVtOL20JcTWOnCWBnoF7Qg57Wkk0IbRU1tMLK09Z6ivl9cOk8Oe
SnxtKJ9rhe35vGNP4Bstpt2O09TTymmHyG5PIZ42hB7aImJobTlFXb2sdpBs
9mTiaoP5TFtIRGvDSeroZbQ/yGpP4lVtEN21QvY8Etvjw+9a+4/W2glqa6Xt
3/nQnsgr2kC6afN5SSv9L2rppezfyGJPII42gK7aPF7QUv+TmnpJ+1cy2+OJ
rX3Fp9rXPKeFfpxP9BL2AT6wxxFL+5Iu2lye0Vw/Ro1w79r7yWSPJab2BZ21
OTylmX6U6npxex8Z7THE0PrTSZvNE5rqR6imf2Tv5X17NBGtHx21WTymiX6Y
aL2YvYcM9ij+o6/eQZvJIxprh4jSi9q7ec8eyUv66O21GTykkXaQqnoRexfp
7RG8oLfeTpvOAxpqf1BFL2zvJJ09nOf00ttq07hPA+13KuuF7B2ktYfxjJ56
G20q96iv/UYlvaC9nTT2UJ7yud5am8Jd6mm/UlEvYG8jtT2EJ/TQW2mTuUNd
7QAV9Pz2VlLZg3nMZ3pLbRL/UkfbT3k9n72FlPYgHtFdb6FN5Da1tX2U0/Pa
m0lhD+Qh3fTm2gRuUUvbS1k9j72Jd+0BPKCr3kwbzz/U1PZQRs9tbyS5/RX3
+VRvqo3jJp9ouymt57I3kMz+knt00ZtoY7lBDW0XpcLz3F5PUvsL7tJZb6yN
4TrVtZ2U1HPY60hi9+cOnfRG2miuUU3bQQk9u/0L79j9+JeOekNtFFeJ1rbz
sZ7NXkvicN9zmw56A20kV4jStlFcz2r/zNvhvucW7fX62gguU1Xbykf6h/ZP
vBXue/6hnV5PG87fVNG2UEzPYv/Im+G+5yZt9braMC5RWdtMUT2z/QNvhPue
G7TR62hDuUglbRNF9A/sNbwe7nuu01qvrQ3hAhW1jRTWM9mrSRTue67RSq+l
DeY8FbQNFNIz2t+TMNz3XKWlXlMbxDnKa+spqL8f7icGcpZy+joKeC1DeM6E
Z0e4hxjAGcp6/Rfye086u7jzYt61p7JKW2Gnc57Da+HfFFdoYVcPf0fnDM7z
wjPBOYvrYr52ftt1XHjue18212Xh/w76atfUzOR0+D2FnyeLwuea11e6rnXN
55o23Cfh/uU7VutrwvfL/PCctn8K9wdLwmexvco1OVNY6c9nD1+X5V5L6zqb
BM6Zw/vDZ57zZZo7V/P+Vc7vhe8hPLec5/KW89jwmeT1ZXYq5xmcskvbP5PX
TmMXc15EMnsyK7Tv7DTOs4gfnh38TTM72uv5nefwpj0mfJZpJykVvj/yhJ+Z
vZx44VnCJZrqUVp/TlBS+5HceqrwdYkbniVcpIleVVvpnN55bnh2Os/mDefR
4XPO61ldlwb6964pmc5f4d9JuJ9ZSAmvr3D9wTWX6/+gvE1g
         "]]]}, {}, 
      {RGBColor[0.560181, 0.691569, 0.194885], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwV1mW4VUUYhuFNpyggrZIC0iolrYDSSNkCYoKEAoKEQVjYtKKIgChIK90d
Kh3S3Uh3en8/nuuNmbX2illzTt5WHRq3T5pIJJLgG6Z1qkSiQepE4niKRKI+
HSEXp5lpb9zJj06ZSFzFG/JFNOS/xkE0kffGPL40OmMVyuuW4ZjzNpC/wgE0
1u1BBv5hdMJKlNMtxdG4DvlL7Ecj3W7cwT+EjliBsrolOGJ+PfkL7MOTul1I
zz+It7EcZXSLcdj8uvLn2IuGup1Ix5fCW1gW96JbhEPm15H7YQ8a6HYgLV8S
HbA07kW3EAfNry1/ht2or9uONHwJtMeSuBfdAhwwv5b8KXahnm4bUvPF0Q6L
415087Hf/CfkT7ATdXX/IhVfDG2xKO5FNw/7zH9c/hg7UEe3FSn5ongTC+Ne
dHPjXZpfU/4I21FbtwUp+CJogwVxL7o58S7NryH3xTbU0m1Gcv4BtMb8uBfd
7HiX5ieTC8d6wry4bv2seG/GksqF8DrmxjXqZ8Y7MpZELojXMCeuRz8j3oex
hHw/XsXs+G399Hj2xm6jgO4VzIrf1k+L56y/hfy6lzEzflv/ZzxT/U3k07XC
jPht/R/x/PRbsBmbsBEbsB7rsBZrcAN5HfcSpsf1OXYq/tFXl/vgXzyh24Tr
+jxyS0xDAd0U/K0fJV+J5yJfwGN8b2zF4/JGXDPve/k0mssnkJtP0A64gRax
dujdvus/+fz8ZPzl2J9oMX0m2iu+UX6kOQP4PPzl+O7oa/J5PBrrQ/6OL0hT
0Yq0C01Gexl/jH4uZ6dbYh3TmvIGXI1vUf6Bf4Cmp1Voj1j/cV7zv+bv4U/x
L/LHcR9/O76leGZoHuubZjbvDz4fPwmrnT8j/TD2D2M/G7sUa0Q+h2p8SvoO
khr/UN6MGvJ6XHH8UPk/vBB7Ge6N68BU5JUnYpV5VeUPsAnVdetwWT9EPonn
Y2+Le4lzYQryyBOw0rwq8vvYGM9MtxaX9LniWExGbt14rNBfRE7dc5iE+/S/
Y7l+GZZiCS4gh/FnMRH3mjMu9kJ9Zfk9bMCjujXxXvXZ5WcwAffoxsZeqK8k
98R6VIt1HM9Rn01+GuORS/db7IX6inIPrEPVWMc4qx8sn4hrj/0bWfmn8Dty
yr/G3mjeCPlifLdxHCrw3bEWVWLN4ox5g+TjcY/yYWThm2EccshjYu+M9S1f
iG89jsMjfAraGUm8/27yGlSOtYPTjhkoH4vnIR+K74a/hXbxvaEpPxbZ+V9i
z3XMXfQDpHfO4cbOxx4S50N5PjnthITxd+V/UCnWEU45Ph3tjlTGBxg7Gs9X
PhhrnL+JtvH9oAn/Ec1k7m98Nn405jrPnfR9pDP2o7H+sR/w52JPit9COT4Z
7Yjb6Cr3o9nM+5uvGOsT/zlfWtoNKY31N/YVn4s/Eu+PPxDXwQ+m+fU3+Dfj
O0Jjvi/NqP+Vz8qPwhznHU6L6jPQ95A29gRzvo1vnT/Ll6Et4zpQVh5K79cl
jXVB36a30MXYZ7GmdH/xpWiF+GZw0m8No4V1aWjleP40Bf02vnv6pZyTHpYf
ps3k/XHdsU/Lg/h89LpcnraJ7xyN4puQ+/B30TFyCZpFHonZ8X9KvAe+CL2D
VqU9aRo6zPya9JvYY+gZuTRtEdeNMnIteQhfgCaJ9UvfojfxTnzD8qex/ulq
uSR9JPYEnIj/Y+Tv+UI0Na1Eu9Lk8buxb9Ev5Bz0kPwQbSrvi3uKvzPyQD4v
vSaXo/8DG+FXwA==
         
         "]]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl12OwnlcYhtEvJ7ZtmzVTK2Xq2LZtW22SIrZt27Zt2+na0x+rOfc12TP5
8bxnplkr1S9ZL1okEkkfPRIJf3aNikRu+qEUG+wqXNR+YJmWh1e0BXYWetsP
7T8wI93855ZWmo12VS5pJVmu5eVVbaGdlT72I/tP/BMi3bXbWhk22dW4rP3I
Ci0fr2mL7Gz0tR/bQ4lBD+2OVpbNdnWuaD+xUsvP69piOzv97Cf2MGLSU7ur
lWOLXYOr2s+s0grwhrbEzkF/+6k9nFj00u5p5dlq1+Sa9gurtYK8qS21czLA
fmb/RWx6a/e1Cmyza3Fd+5U1WiHe0pbZuRhoP7f/Jg59tAdaRbbbtbmh/cZa
rTBva8vt3AyyX9j/EJe+2kOtEjvsOtzUfmedVoR3tBV2HgbbL+1/iUc/7ZFW
mZ12XW5ppVivFeVdbaWdlyHh6Bjhj/j01x7bVdhl1+O2VpoNWjHe01bZ+fjD
jsZILQEDtCd2VXbb9bmjlWFjuF3e11bb+fnTjmKUlpCB2lO7GnvsBtzVyrIp
3C7FtTV2AYba0RmtJWKQ9syuzl67Ife0cmwOt8sH2lq7IMPsGIzREjNYe27X
YJ/diPtaebaE2+VDbZ1diOF2TMZqSRiivbBrst9uzAOtAlvD7fKRtt4uzF92
LMZpScN3rL20a3HAbsJDrSLbwu3ysbbBLsLfdmzGa8nCdxz1/y+C2tpBPzbl
kV2J7eF2+UTbaBflHzsOE7Tk4TvWolFHO2Q347FdmR3hdvlU22QX4187LhO1
FOE71qKoqx22m/PErsLOcLt8pm22X2GEHY9JWsrwHWvRCb8Uj9gteGpXZVe4
XT7XttivMtKOz2QtVfiOtRjU147aLXlmV2N3uF2+0LbarzHKTsAULXX4jrWY
NNCO2a14bldnT7hdvtS22a8z2k7IVC1N+I61WDTUjtuteWHXYG+4Xb7Stttv
MMZOxDQtbfiOtdg00k7YbXhp12RfuF1KaDvsNxlrJ2a6lo4RWhwaayfttoRf
7LW0/eF2+Vraab/FODsJM7T0jNTi0kQ7ZbcLvx68r60dCLfLN9ou+23G20mZ
qWVglBaPptppu304R+/raAfD7fKtttt+hwl2MmZpGRmtxaeZdsbuEP753tfV
DoXb5Tttj/0uE+3kzNYyMUZLQHPtrN2RGN7X0w6H2+V7ba/9HpPsFMzRMjNW
S0gL7ZzdiZje19eOhNvlB22f/T6T7ZTM1bIwTktES+283ZlY3jfQjobbpaS2
3y7OFDsV87SsjNcS00q7YHchtvcNtWPhdvlRO2B/wFQ7NfO1bEzQktBau2h3
JY73jbTj4Xb5STtof8g0Ow0LtOxM1JLSRrtkdyOu9421E+F2+Vk7ZH/EdDst
C7UcTNKS0Va7bHcnnvdNtJPhdvlFO2x/zAw7HYu0nEzWktNOu2L3IL73TbVT
4Xb5VTtif8JMOz2LtVxM0VLQXrtq9ySB98200+F2+U07an/KLDsDS7TcTNVS
0kG7ZvcioffNtTPhdvldO2Z/xmw7I0u1PEzTUtFRu273JpH3LbSz4XYppR23
P2eOnYllWl6ma6nppN2w+5DY+5bauXC7lNZO2F8w187Mci0fM7Q0dNZu2n1J
4n0r7Xy4XcpoJ+0vmWdnYYWWn5laWrpot+x+JPW+tXYh3C5ltVP2V8y3s7JS
K8AsLR1dtdt2f5J530a7GG6XctppuwQL7Gys0goyW0tPN+2OPYDk3rfVLoXb
pbx2xv6ahXZ2VmuFmKNloLt21x5ICu/baZfD7VJBO2t/wyI7B2u0wszVMtJD
u2cPIqX37bUr4XapqJ2zv2WxnZO1WhHmaZnoqd23B5PK+w7a1XC7VNLO29+x
xM7FOq0o87XM9NIe2ENI7X1H7Vq4XSprF+zvWWrnZr2Wxt/rpF0PNxq+S7uz
fSN8Y37uEvX//2cU83f/A7TYhS8=
         "]]},
       Annotation[#, "Charting`Private`Tag$26570#1"]& ], 
      TagBox[
       {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwV1Xe4FlIcB/C3hRAlo629d2lKpCEk2jsaSjRUSnvvqJC09y7R0i6jNLVU
KGmgpUKhic/vj89zzvd73nuf7u38zs3WomOtDkkSicTUpIlEpmSJRLEUicTK
5InEx9anrHOseaLje+cTrZn4lIXOF1oL0sfZO9bUTNU/xnT77Cyzf8H5y/an
7TtxF0t0mSmuXyVX4ge5LzV5Rf+z7k1SslSXhRL61fLTHJX78a4uDdN0pXhR
10L+xb4zdzNFfpQl8fM5H2+fjrlyBR7VlZQ/s6/MMXmSnJlFcn95jP0DTJdL
M8M+B5/Yv+S8pf2v9l2YZ5+Pe+ynWrOy1H6xtXD8Xnz+Q2v6+HrmOVtgLRA/
H0/Is6y5WMHy+J1Zi8S/Mb6fr3/Muka/zFrFOteaN36f/Oh8sjVLfC2LnS+y
FmKAs7HWtMzQz7fmp4z9TGvO+D+2r+VzrezP2HflXqbJ2fjY/hPnE+wzMF+u
SDZdKXmtfVWOywOpTXZykJPSPrPOeTV+kgdRh1yUcbZe/wwn5MHUpbX+rO4t
UvGpLjdl9Rvk6pyUh1CPV/XndN24j+W6PJTTb5Sf5ZQ8lPq00Z/Xded+Vujy
Ul6/SX6O0/IwGtBWf0H3NqlZqcvH4/rN8vP8LA+nIa/pf9P1IA2rdPmpoN8i
1+AXeQSNaKe/qOvJA6zWFeAJ/ecxV/wqj6Qxr+sv6XqRls90Bamo/0KuyRl5
FE14Q39Z15sHWaMrxJP6L2OOOCuPpint9b/r+vAQa3WFeUr/VcwA5+ItoBkd
9H/o+vIw63RFqKTfGveL8zG/NKej/k9dPx5hva4oT+u3ybW5EHMY7wmd9Fdi
NknHhnjDqKz/Wq7Db3HX4z3hTf1V3QDSszHeH6rot8t1uSiPi/eDzvq/dAPJ
wKZ4f6iq3yHX45L8Xsw+XfR/6waRkc3xplBNv1Ouz2X5/Zgruur/0Q0mE1ti
pnlGv0tuwO/yB3H3eUt/TTeEzHwes0Z1/W65IX/E2xZ3n27667qhZOGLmDue
1e+RG/FnvENx9+muv6EbFu8hX8Ys8pz+G7kxV2Lm4+7ztv6mbjhZ+Spmkef1
e+UmXJU/irtPD/0t3Yh4J9gas0gN/T65KX/JE+Pu01N/WzeS7GyLWeQF/X65
GX/Lk+Lu00v/r24UOfg6ZpGa+gNyc/6RJ8fdp7f+P91ocrI9ZpEX9Qfll7km
T4m7Tx99gnf0udgRs8hLum/lV7guT427T199Et7V52ZnzCK1dIfkFtyQp8Xd
p58+KWP0edgVs0ht3WG5JTfl6XH36a9Pxlh9XnbHLFJHd0RuxS15Rtx9BuiT
M06fjz0xi9TVfSe35rY8M+4+A/UpeE+fn29iFqmn+15+lX/lWXH3GaS/g/f1
Bdgbs0h93Q9yG/6TZ8eM6R5kpq4sXXWD5Tv5QC7IvphNGuiOym1JMCdmgSH6
uxivK8T+mE0a6o7Jr5GEuTELDNWn5ENdYQ7EbNIo/l7K7UjKvJhp3UPMksvR
XTdMvpsJchEOxqzSWHdcfp1kzI/ZYHj8/ecjXVG+jVmlie4n+Q2SsyBmgxH6
e5moK8ahmFWa6k7I7UnBwnhDdA8zWy5PT91IORWT5OIcjtmlme6k3IE7WBSz
wij9fUzWleBIzC7NdafkjtzJ4niDdI8wR36c3rrR8v1MkUvyXcy6nJEF8pPM
ts/NCvul1qKsoYbP/g8f9kyt
         "]]},
       Annotation[#, "Charting`Private`Tag$26570#2"]& ], 
      TagBox[
       {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwV1He8jmUcx/GHcKxCpLTsXbY0SLasJLMlCtmKyIrsrZRRoVDJ3srISmWn
sktlr5Kdrffvj8/rO67rvu9znmvkbN6xXodkiURibPJEYlnKRGJKUiKRBV+k
SiTq4hLfGmVSJxJX5Zz0Q7kqzSgf4OujhHxEzkZHyJXoe3IK2k0uS1PT/PRj
WoOe8r0f+MdQVN5k/l10iFyBviXf4DvFHDkZzUPH0+q0tPG/+aYoJZ+RH4jv
ylXoJ3Ia2ksuT2+nhegkWosu9/2p/F0oIn9pfkbaX36KPiv/x7fBo/I1ORcd
K1ejmeSDfAOUlI/K99KRcmX6vpySvi2Xo2logfi76N++/SN9HMV0m83NSofK
Xfmb9I0Y1yWneekE+oixf+grKK07Kz8Y35In8mn53vwdKMxPpit8axrNiunm
ZNIP4Ovxl2lbXOdz68fxd/KHaEMc4+/Tj+LH8Kn47nxa/OO9G+gT2GLsbmPD
+G78Lfombou9I5+mzXCOz27eGH4Sn45/h8+Ald73Ob0bXxm709hA/jn+Cm2H
G3xmHOYb4Tj/AZLM7SGnw2nv2Rh7DluNvY2E8c5yilhL+V/aHOf5yUhvvI+c
Ed96/gt6D2YYq4+rfHvc5LPgCN8YJ/gP432e2RTrjG1ydyTzzi5yyti/8hn6
Ki7wn2KVZ76Us2Gm3CD2P47KTXCSHxvPmbdZfhI/yT3wOM7Kr+Ei/xlWmzdd
vhez5Iaxp3BMfh6n+HHxnHlb4kxgu9wTT2CN/ivdfZgtN4o1xTn91jgT+Fnu
hbJYq5+hux9z5Ma4B+f12+IM4xe5N8phnX6m7gHMlZvEfYEL+u+wHt/HnYBZ
5jyIecafj3OFi3FmMFufHfN1L8T+jHtK/5OuIn6V38GT2KCfo8uBBfKLuB/H
5RfiHPLj45ybtz3uLeyQ+6A8Nurn6nJiofxS3DE4Ib8YZ4CfEOfIvJ/j3GOn
3BfJ4w6TU8VvF78jbYFL/BTcbryvnAmbPD+P5sKi2OPGBvEv89doB9yKs46T
/Euxz+N/MW80/xGfmu8Z+4SmpwXpRFqTXvH+X/gqKC7virWiw+M3o+/Kt9Gu
cZ5pEs1HP6JP0wqxrnzLuIPk/+Qc9AN5Kn9HvCPuDjzEf0o3++Z8mhuL49zo
B/NN+eu0IxKxlvKp+F/xL/9xnDfP/ipXxW65HyrGXpFb4TI/DVvMWyDnwRL5
lfi74jfT79BVwx65Pyphq36hLi+Wys2QM/6e2LOxh2IfxFrG7xV/Q7wHO7EL
u7Eofht87bnmyIUb+j1YrM+Pb3Svxp2Km/q9WKIvgGW615An7kn9PiyN9cJy
XQvkjTsLvxn7Wl8IK+SWyBd3C3439o2+MFbKrZA/9h32G1sWaxH3mfw6CsQa
4w9jy/UPY5XcGgWRAjt11bGXH4DK+NP8FboiWC23QSGkxK7YH9jHD0QV/GX+
Sl1RrJHbojBSYbeuBn7jB6EqDpj/ra4Y1srt8BCSsCf2L37nB6MaDpq/KvYx
1snt8XDsf+zV1cJ+fgiq45D5q3Ul8J3cAUWQBvt0tfEHPxRP47D5a3QlsV7u
iKJIG+uhq4M/+WGogSPmr9WVwvdyJxRDulgj3TP4ix+Omjhq/jpdafwgv4Hi
SB/rpquLA/wI1MKxuB/j3OFH+U2UiPsj1lL3LA7yI1Ebx+Mu1ZXBBrkzSsYZ
jbXU1cMhfhTq4ETcu7pHsVHuglLIEGupew6H+dF4Bhfl13GF/zzmOdf95Myx
p/jP4jelJ733f2ajWuw=
         "]]},
       Annotation[#, "Charting`Private`Tag$26570#3"]& ]}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{514., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.810385808906991*^9, 3.812733467020492*^9},
 CellLabel->"Out[44]=",
 CellID->2115842337,ExpressionUUID->"44a77607-bdda-438d-84b1-9e8c6a3014e9"]
}, Open  ]],

Cell[TextData[{
 "Below, we use the ",
 ButtonBox["PDF",
  BaseStyle->"Link"],
 " function to express the formula for the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"ff0a01f0-e612-4ade-bad0-48bdb2ec04db"],
 " distribution."
}], "Text",
 CellChangeTimes->{{3.776942005432513*^9, 3.776942047044915*^9}},
 ScriptBaselineShifts->{0.4},
 CellID->197014087,ExpressionUUID->"b9e42879-1f61-4051-bd40-84cafa735617"],

Cell[TextData[{
 "The PDF for the ",
 Cell[BoxData[
  SuperscriptBox["\[Chi]", "2"]], "InlineMath",
  CellChangeTimes->{{3.70935449305739*^9, 3.7093544989662333`*^9}, {
   3.716537289923249*^9, 3.71653730654972*^9}},ExpressionUUID->
  "1d836c1e-23c1-467e-88ef-586a658840bb"],
 " distribution in all its glory:"
}], "CodeCaption",
 CellChangeTimes->{
  3.8158419917637997`*^9, {3.815845032300312*^9, 3.815845032515545*^9}},
 ScriptBaselineShifts->{0.5},
 CellID->1166843097,ExpressionUUID->"44a2b195-56b3-4f5e-8894-4bf18257204c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PDF", "[", 
  RowBox[{
   RowBox[{"ChiSquareDistribution", "[", "\[Delta]", "]"}], ",", "x"}], 
  "]"}]], "Input",
 CellLabel->"In[45]:=",
 CellID->473713778,ExpressionUUID->"65e90432-35d8-4306-9d45-f3b4451d9526"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {
        FractionBox[
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{
            RowBox[{"-", "\[Delta]"}], "/", "2"}]], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "x"}], "/", "2"}]], " ", 
          SuperscriptBox["x", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            FractionBox["\[Delta]", "2"]}]]}], 
         RowBox[{"Gamma", "[", 
          FractionBox["\[Delta]", "2"], "]"}]], 
        RowBox[{"x", ">", "0"}]},
       {"0", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}},
      Selectable->True]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{1.}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False,
  StripWrapperBoxes->True]], "Output",
 CellChangeTimes->{3.810385808914421*^9, 3.812733467028009*^9},
 CellLabel->"Out[45]=",
 CellID->780447286,ExpressionUUID->"22b3a8bc-f83c-4434-9a08-9e3597561f53"]
}, Open  ]],

Cell["\<\
These distributions and what they represent might seem esoteric at first. As \
you continue in this text, they will start making more sense. Refer back to \
this chapter often as your journey continues. The Wolfram Language contains \
many, many named distributions. Have a look at the documentation to learn \
more.\
\>", "Text",
 CellID->94517747,ExpressionUUID->"7b0a3558-c92a-469d-bee7-b95b413bcf3e"],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseSection",
 CellLabel->"In[46]:=",
 CellID->1643293135,ExpressionUUID->"bc1998d5-74d7-4839-bbca-8faa372d4b2a"],

Cell[BoxData["Exercises"], "Output",
 CellChangeTimes->{3.812733467050992*^9},
 CellLabel->"Out[46]=",
 CellID->147419926,ExpressionUUID->"f5854d35-7e44-40c2-abc6-d385d1745b2c"],

Cell[TextData[{
 "Roll a hypothetical 10-sided die ",
 Cell[BoxData[
  FormBox["10000", TraditionalForm]],ExpressionUUID->
  "487b72c9-624f-4249-ba86-ae4ff596461e"],
 " times and save the result in the computer variable ",
 Cell[BoxData[
 "tenSidedDie"], "InlineCode",ExpressionUUID->
  "ee990626-f8c5-4eb3-8c00-ad3e23798844"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.764697824257368*^9, 3.764697824335368*^9}, {
  3.7646979137393675`*^9, 3.764697917299368*^9}},
 CellID->103155203,ExpressionUUID->"49d0baaa-fcf3-4932-8544-a9e3b4935c89"],

Cell[TextData[{
 "Create a probability histogram of the results indicating the 10 values on \
the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "1ef57e7d-4382-47f3-9388-6039b3a8e162"],
 " axis."
}], "Exercise",
 CellChangeTimes->{{3.764697836287368*^9, 3.7646978437093678`*^9}, {
  3.7649339424068623`*^9, 3.7649339501003027`*^9}},
 CellID->1145460740,ExpressionUUID->"3367f513-f9e2-4165-86e7-f4069d8d1a3b"],

Cell[TextData[{
 "Simulate the roll of two 10-sided dice for a total of ",
 Cell[BoxData[
  FormBox["20000", TraditionalForm]],ExpressionUUID->
  "f9f332c1-861b-4586-b893-b91212bf3fbe"],
 " times. Store the ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object in the computer variable ",
 Cell[BoxData[
 "tenSidedDice"], "InlineCode",ExpressionUUID->
  "2c69975c-5a5a-44bf-b0ae-777a6408fac3"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.7646982260553675`*^9, 3.764698234649368*^9}},
 CellID->1715245472,ExpressionUUID->"d6bf5a73-72da-43e1-ad79-fcc3cf6f52b3"],

Cell[TextData[{
 "Create a computer variable named ",
 Cell[BoxData[
 "totals"], "InlineCode",ExpressionUUID->
  "0261a779-d439-424b-ae61-bacbd3ab9f58"],
 " to hold the sum totals of each of the ",
 Cell[BoxData[
  FormBox["20000", TraditionalForm]],ExpressionUUID->
  "c2f9be98-6bfe-4d20-8afd-f2e4fd54c418"],
 " rolls."
}], "Exercise",
 CellID->1104089727,ExpressionUUID->"47af0ea1-2f00-490e-aa40-e39d886ed131"],

Cell[TextData[{
 "Create a probability density histogram of the ",
 Cell[BoxData[
 "totals"], "InlineCode",ExpressionUUID->
  "7e595ed4-1d25-491f-8aa0-665ac86373d6"],
 " ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object."
}], "Exercise",
 CellChangeTimes->{3.76493408485001*^9},
 CellID->29847962,ExpressionUUID->"f78bec8b-4740-4464-aed0-e3a816e86846"],

Cell["\<\
What is the most likely total and what is the percentage probability of \
rolling it according to your plot?\
\>", "Exercise",
 CellID->1291007583,ExpressionUUID->"a7398205-606a-4609-a0eb-10a046aac26f"],

Cell["\<\
Create a probability density plot of the standard normal distribution.\
\>", "Exercise",
 CellID->1937161840,ExpressionUUID->"b39dd5ee-c3aa-40bf-9b34-484a137c52cd"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tech Notes", "TechNoteSection",
 CellID->874797650,ExpressionUUID->"c67cc183-fce3-4e8b-938e-2754c928f39f"],

Cell["\<\
You can use a semicolon to suppress output to the screen, useful for large \
number outputs and longer strings of code. Try running the code below without \
the semicolon.\
\>", "TechNote",
 CellChangeTimes->{{3.651515120816633*^9, 3.651515125814807*^9}, 
   3.6515155174947033`*^9, 3.768271955427816*^9, 3.7682720455775433`*^9, 
   3.768272083398427*^9, {3.768272706085225*^9, 3.768272752343297*^9}, 
   3.7741962734077787`*^9, {3.774201299104518*^9, 3.774201363482955*^9}, 
   3.8104008399020433`*^9, {3.8104016233558617`*^9, 3.810401624163425*^9}, {
   3.815842026881564*^9, 3.815842029160824*^9}},
 CellID->564397392,ExpressionUUID->"b86d8458-46d8-4603-aa34-b74335ecdb2c"],

Cell[BoxData[{
 RowBox[{"SeedRandom", "[", "123", "]"}], "\n", 
 RowBox[{
  RowBox[{"die", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", "10000"}], "]"}]}], 
  ";"}]}], "ExerciseInput",
 CellChangeTimes->{{3.810385994340486*^9, 3.810386010420065*^9}, 
   3.8103863505315*^9},
 CellLabel->"In[47]:=",
 CellID->61835188,ExpressionUUID->"f683acd7-4aa8-4ae5-ad75-905695210a9f"],

Cell[TextData[{
 "Now try putting the semicolon back in and typing ",
 Cell[BoxData[
  RowBox[{"Short", "[", 
   RowBox[{"%", ",", "3"}], "]"}]], "InlineCode",ExpressionUUID->
  "2bc1d4c0-febe-4e56-a514-ae699694e735"],
 " and then run the code again."
}], "TechNote",
 CellChangeTimes->{{3.651515120816633*^9, 3.651515125814807*^9}, 
   3.6515155174947033`*^9, 3.7742045472253075`*^9, 3.810385859716844*^9, 
   3.812733255054617*^9, 3.815842035849125*^9, {3.8158420788036413`*^9, 
   3.8158420802984743`*^9}, {3.815842226179121*^9, 3.8158422391527987`*^9}},
 CellID->66657729,ExpressionUUID->"6d41c40f-26aa-4cc1-9b7a-58e94d544e6d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{"%", ",", "3"}], "]"}]], "ExerciseInput",
 CellChangeTimes->{{3.7742021317027693`*^9, 3.7742021335509543`*^9}, 
   3.774205008173911*^9, {3.810386017948092*^9, 3.810386032995901*^9}},
 CellLabel->"In[49]:=",
 CellID->27547157,ExpressionUUID->"375de630-f898-4a83-82bf-8c5c425ee3f7"],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
   "4", ",", "6", ",", "2", ",", "3", ",", "6", ",", "1", ",", "1", ",", "3", 
    ",", "4", ",", "2", ",", "2", ",", "5", ",", "1", ",", "2", ",", "5", ",",
     "4", ",", "3", ",", "3", ",", "5", ",", "6", ",", "5", ",", "3", ",", 
    "5", ",", "2", ",", "2", ",", "5", ",", "3", ",", "1", ",", "2", ",", "2",
     ",", 
    RowBox[{"\[LeftSkeleton]", "9940", "\[RightSkeleton]"}], ",", "2", ",", 
    "3", ",", "2", ",", "2", ",", "1", ",", "6", ",", "1", ",", "5", ",", "2",
     ",", "1", ",", "2", ",", "1", ",", "5", ",", "2", ",", "3", ",", "2", 
    ",", "1", ",", "2", ",", "3", ",", "4", ",", "4", ",", "4", ",", "4", ",",
     "3", ",", "3", ",", "3", ",", "1", ",", "5", ",", "6", ",", "2"}], "}"}],
  
  Short[#, 3]& ]], "ExerciseOutput",
 CellChangeTimes->{3.774202134725072*^9, 3.774202178284427*^9, 
  3.8127334671005983`*^9},
 CellLabel->"Out[49]//Short=",
 CellID->2135176944,ExpressionUUID->"33410f2f-497c-4584-95d0-7741e795885c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 CellID->835199206,ExpressionUUID->"4a0b4650-e085-4109-9326-399b9512f8b4"],

Cell[TextData[{
 StyleBox[ButtonBox["For fun, check out G. H. McClelland\[CloseCurlyQuote]s \
manipulatable Wolfram Demonstration on normal distributions ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://demonstrations.wolfram.com/TheNormalDistribution/"], None},
  ButtonNote->"https://demonstrations.wolfram.com/TheNormalDistribution/"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/NormalDistribution",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolfr.am/NormalDistribution"], None},
  ButtonNote->"wolfr.am/NormalDistribution"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellID->26626102,ExpressionUUID->"2bc63fde-a82e-4a5b-a70f-b3e9e6fd6d07"],

Cell[TextData[{
 StyleBox[ButtonBox["Check out the Wolfram guide on normal and related \
distributions for more examples ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/guide/\
NormalRelatedDistributions.html"], None},
  ButtonNote->
   "https://reference.wolfram.com/language/guide/NormalRelatedDistributions.\
html"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/Distributions",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolfr.am/Distributions"], None},
  ButtonNote->"http://wolfr.am/Distributions"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellID->1554366849,ExpressionUUID->"fe66a869-21dd-470d-bd64-2eb92fe738a7"]
}, Open  ]]
}, Open  ]]
},
Editable->False,
Saveable->False,
WindowSize->{808, 911},
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{"\[ThinSpace]", "\[ThinSpace]", 
          StyleBox[
          "Introduction to Statistics\t\t\t\t\t\nwith the Wolfram Language", 
           LineSpacing -> {1, 1}, FontFamily -> "Source Sans Pro", FontSize -> 
           24, FontColor -> GrayLevel[1]], "\[ThinSpace]"}, 
         "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {65, 75}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"07-Klopper-VisualizingData.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"07-Klopper-VisualizingData.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> GrayLevel[0.2], Evaluator -> Automatic, 
                  Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Chapter 7\"", TooltipDelay -> 0.15, 
              LabelStyle -> "TextStyling"], 
             Annotation[#, "Chapter 7", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"09-Klopper-HypothesisTesting.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"09-Klopper-HypothesisTesting.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  GrayLevel[0.2], Evaluator -> Automatic, Method -> 
                  "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Chapter 9\"", TooltipDelay -> 0.15, 
              LabelStyle -> "TextStyling"], 
             Annotation[#, "Chapter 9", "Tooltip"]& ]}, "RowWithSeparators"], 
          Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> GrayLevel[0.2], 
             ImageSize -> {35, 30}, Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> 
                RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> RGBColor[0.12, 0.18, 0.26], 
             ImageSize -> {35, 30}, Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "1 | Introduction" :> 
          NotebookLocate[{"01-Klopper-IntroDataAnalysis.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "2 | Evaluating Basic Math" :> 
          NotebookLocate[{"02-Klopper-BasicMath.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "3 | Collections" :> 
          NotebookLocate[{"03-Klopper-Collections.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "4 | Working with Datasets" :> 
          NotebookLocate[{"04-Klopper-WorkingWithData.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "5 | Data Types" :> 
          NotebookLocate[{"05-Klopper-DataTypes.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "6 | Simple Descriptive Statistics" :> 
          NotebookLocate[{"06-Klopper-DescriptiveStatistics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "7 | Visualizing Data" :> 
          NotebookLocate[{"07-Klopper-VisualizingData.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "8 | Distributions" :> 
          NotebookLocate[{"08-Klopper-Distributions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "9 | Hypothesis Testing" :> 
          NotebookLocate[{"09-Klopper-HypothesisTesting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10 | Parametric Tests, Comparing Means" :> 
          NotebookLocate[{"10-Klopper-ParametricTests.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "11 | Correlation" :> 
          NotebookLocate[{"11-Klopper-Correlation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "12 | Linear Regression" :> 
          NotebookLocate[{"12-Klopper-LinearRegression.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "13 | Comparing Categorical Variables" :> 
          NotebookLocate[{"13-Klopper-ComparingCategoricalVariables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "14 | Nonparametric Tests" :> 
          NotebookLocate[{"14-Klopper-NonparametricTests.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "15 | A Research Project Demonstration" :> 
          NotebookLocate[{"15-Klopper-ResearchProject.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> RGBColor[0.12, 0.18, 0.26], 
   CellMargins -> {{0, 0}, {0, -1}}, CellFrameMargins -> {{27, 0}, {1, 7}}, 
   Background -> RGBColor[0.12, 0.18, 0.26], CellTags -> 
   "DockedCellLogoCell"], 
  Cell["JUAN H. KLOPPER", "Text", FontFamily -> "Source Sans Pro", FontWeight -> 
   "Light", FontSize -> 15, CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> 
   False, CellMargins -> {{0, 0}, {-1, -1}}, 
   CellFrameMargins -> {{27, 0}, {2, 4}}, CellFrameColor -> 
   RGBColor[1., 0.7, 0.1], FontTracking -> "Extended", FontColor -> 
   GrayLevel[1], Background -> RGBColor[0.9, 0.4, 0.], CellTags -> 
   "DockedCellLogoCell"]},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    Introduction to Statistics with the Wolfram Language", "Header"]}],
     "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], 
   None, None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["  |  Distributions", "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 34}, {Inherited, Inherited}}]}},
PrintingOptions->{"FirstPageFooter"->False,
"FirstPageHeader"->False,
"PaperOrientation"->"Portrait",
"PaperSize"->{504, 720}},
ShowAutoSpellCheck->False,
FrontEndVersion->"12.2 for Mac OS X x86 (64-bit) (December 12, 2020)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> 
       "Source San Pro", FontSize -> 8, FontWeight -> "Plain", FontSlant -> 
       "Plain", FontColor -> GrayLevel[0.45]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Source San Pro", FontSize -> 
       8, FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth :> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, 
       AutoStyleOptions -> {
        "FormattingErrorTooltips" -> False, "HighlightComments" -> False, 
         "HighlightEmphasizedSyntaxErrors" -> False, 
         "HighlightExcessArguments" -> False, "HighlightFormattingErrors" -> 
         False, "HighlightGlobalToLocalScopeConflicts" -> False, 
         "HighlightGraphicsCompatibilityProblems" -> False, 
         "HighlightLocalScopeConflicts" -> False, "HighlightMissingArguments" -> 
         False, "HighlightNoKernelPresent" -> False, 
         "HighlightOrderOfEvaluationConflicts" -> False, "HighlightStrings" -> 
         True, "HighlightSymbolContexts" -> False, "HighlightSymbolShadowing" -> 
         False, "HighlightSyntaxErrors" -> False, "HighlightUndefinedSymbols" -> 
         False, "HighlightUnknownOptions" -> False, 
         "HighlightUnwantedAssignments" -> False}, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey :> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Open]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey :> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey :> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 64}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["GrayPointSix"], FontColor -> GrayLevel[0.6]], 
         Cell[
          StyleData["GrayPointSix", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, DefaultNewCellStyle -> 
          "ExerciseInput", CounterIncrements -> "Exercise", MenuSortingValue -> 
          10020, MenuCommandKey :> "2", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth :> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, DefaultReturnCreatedCellStyle -> 
          "Answer", CounterIncrements -> "Question", MenuSortingValue -> 
          10030, MenuCommandKey :> "3", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth :> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, ReturnCreatesNewCell -> True, 
          DefaultReturnCreatedCellStyle -> "Question", 
          LineSpacing -> {1.125, 1., 2.}, MenuSortingValue -> 10032, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          ReturnCreatesNewCell -> True, CellFrameLabelMargins -> 3, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 12}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Baskerville", FontSize -> 
          18, FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Italic", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", StripStyleOnPaste -> True, PageBreakWithin -> False, 
          GroupPageBreakWithin -> False, GeneratedCell -> True, 
          CellAutoOverwrite -> True, ShowCellLabel -> False, 
          DefaultFormatType -> DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221]], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, 
          GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, 
          ShowCellLabel -> False, SpanMaxSize -> 1, FontSize -> 14], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Comment"], FontFamily -> "Verdana", FontSize -> 13, 
          FontColor -> RGBColor[0.3, 0.3, 0.2], Background -> 
          RGBColor[1, 0.9, 0.8]], 
         Cell[
          StyleData["Comment", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Suggestion"], 
          CellFrameLabels -> {{Inherited, Inherited}, {Inherited, 
             Cell[
              BoxData[
               TagBox[
                GridBox[{{
                   ButtonBox[
                   "\"  Insert  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`ReplaceWithSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    ContentPadding -> False, Appearance -> Automatic, Method -> 
                    "Queued"], 
                   ButtonBox[
                   "\"  Stet  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; DocuTools`StetSuggestion[]), 
                    Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "    ", 
                   ButtonBox[
                   "\"  Next  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindNextSuggestion[]), Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], 
                   ButtonBox[
                   "\"  Previous  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindPreviousSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "\"\""}}, 
                 AutoDelete -> False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
                "Grid"]], ShowStringCharacters -> False, Background -> 
              None]}}, Background -> RGBColor[1, 0.8, 0.8]], 
         Cell[
          StyleData["Suggestion", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Tentative"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[
             0.30000000000000016`, 0.6000000000000003, 0.7000000000000003], 
            "Thickness" -> 5}, Evaluatable -> False, CellFrameMargins -> 4, 
          StyleMenuListing -> None, Background -> 
          RGBColor[0.8500000000000003, 0.9500000000000003, 1]], 
         Cell[
          StyleData["Tentative", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["WebOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.91, 0.92, 0.9], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.91, 0.92, 0.86]], 
         Cell[
          StyleData["WebOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Lockdown"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.8, 0.5, 0.4], "Thickness" -> 3}, Evaluatable -> 
       False, StyleMenuListing -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["IndexField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["IndexField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExplanationField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["ExplanationField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EnglishHighlight"], FontFamily -> "WolframCodeSans"], 
         Cell[
          StyleData["EnglishHighlight", "Printout"]]}, Open]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth :> Infinity, TextAlignment -> Left, 
       LineSpacing -> {0.6, 1}, AutoQuoteCharacters -> {}, 
       PasteAutoQuoteCharacters -> {}, StyleMenuListing -> None, FontFamily -> 
       "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth :> Infinity, 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Link", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (Function[
             t, NotebookFind[t, "Notes", All, CellStyle]; 
              NotebookFind[
               t, "NotesSection", All, CellStyle, AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Crosslink"], 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               
               NotebookLocate[#2, "OpenInNewWindow" -> 
                CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None,
             Method -> "Queued"}], 
         Cell[
          StyleData["Crosslink", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeLink"], 
          ButtonBoxOptions -> {
           Appearance -> None, ButtonFunction :> (Documentation`HelpLookup[
              Part[#, 1]]& ), ButtonSource -> ButtonContents, Evaluator -> 
            Automatic}], 
         Cell[
          StyleData["CodeLink", "Printout"]]}, Open]], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 0, FontColor -> GrayLevel[0]], 
      
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 0, FontFamily -> 
       "Source Sans Pro", FontSize -> Inherited 0.95], 
      Cell[
       StyleData["NoLabel"], 
       GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, ShowCellLabel -> 
       False], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariable"], FontFamily -> "Times", FontSize -> 
          Inherited 1.05, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariable", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariableLrg"], FontFamily -> "Times", FontSize -> 
          Inherited 1.1, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariableLrg", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "WolframCodeSans", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "WolframCodeSans", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {0.5, 3}}, 
               ImageMargins -> {{2, 2}, {1, 1}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Open]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Specialized for Klopper", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9, {3.7114709033696413`*^9, 
         3.711470909048764*^9}, {3.73531219927332*^9, 3.735312227736931*^9}, {
         3.745680245296091*^9, 3.7456802496393538`*^9}, {3.745930022124992*^9,
          3.7459300236362534`*^9}, {3.746546663993486*^9, 
         3.7465466650968523`*^9}}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {2, 32}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> "Italic", 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 14}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], LineSpacing -> {1.3, 1., 2.}, 
          MenuSortingValue -> 10010, MenuCommandKey :> "1", FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"], 
          CellMargins -> {{99, Inherited}, {2, 12}}, StripStyleOnPaste -> 
          True, DefaultFormatType -> DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           LanguageCategory -> "Formula", ScriptLevel -> 0, 
          SingleLetterItalics -> True, MenuSortingValue -> 1700, FontFamily -> 
          "Baskerville", FontSize -> 16, FontWeight -> "Regular", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[0.2], 
          UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}], 
              "DisplayFormulaEquationNumber"]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered", MenuSortingValue -> 
          1710, FontFamily -> "Baskerville", FontSize -> 16, FontWeight -> 
          "Regular", FontSlant -> "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       StyleData["InitializationCell"], Background -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Print"], CellMargins -> {{99, 10}, {4, 4}}, FontSize -> 
          15], 
         Cell[
          StyleData["Print", "Presentation"], 
          CellMargins -> {{100, Inherited}, {1.5 Inherited, 1.5 Inherited}}], 
         
         Cell[
          StyleData["Print", "SlideShow"], 
          CellMargins -> {{
            0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.01 
             FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {8, 15}}, 
          FontSize -> 18], 
         Cell[
          StyleData["Print", "Condensed"], 
          CellMargins -> {{18, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "Printout"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "PrintoutGray"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            RGBColor[0.8, 0.043, 0.008]], CellMargins -> {{81, 10}, {4, 8}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            GrayLevel[0.2]], 
          CellMargins -> {{80, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemParagraph"], CellMargins -> {{81, 10}, {4, 1}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["ItemParagraph", "Printout"], 
          CellMargins -> {{80, Inherited}, {Inherited, 0.5 Inherited}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemNumbered"], CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontWeight -> "Bold"], 
          CellMargins -> {{85, 10}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "ItemNumbered", 
          CounterAssignments -> {{"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> 1630, FontFamily -> 
          "Source Sans Pro", FontSize -> 15], 
         Cell[
          StyleData["ItemNumbered", "Printout"], 
          CellMargins -> {{90, Inherited}, {Inherited, Inherited}}]}, Open]], 
      
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteItem"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontSize -> 12, FontWeight -> 
            Bold, FontColor -> GrayLevel[0.25]], 
          CellMargins -> {{93, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, CellFrameLabelMargins -> 4, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          CounterIncrements -> "ItemNumbered", MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNoteItem", "Printout"], 
          CellMargins -> {{93, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Epigraph"], CellMargins -> {{100, 78}, {6, 24}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, TextAlignment -> Left, Hyphenation -> 
          True, HyphenationOptions -> {"HyphenationMinLengths" -> {3, 5}}, 
          LineSpacing -> {1, 2}, TabSpacings -> {1.2, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontWeight -> "Plain", FontSlant -> 
          "Plain"], 
         Cell[
          StyleData["Epigraph", "Printout", StyleDefinitions -> None]]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EpigraphAuthor"], CellMargins -> {{125, 100}, {12, 12}}, 
          TextAlignment -> Left, LineSpacing -> {1, 2}, 
          ParagraphIndent -> -17, TabSpacings -> {1.5, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontTracking -> -0.05], 
         Cell[
          StyleData["EpigraphAuthor", "Printout", StyleDefinitions -> None]]},
         Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ReferenceSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ReferenceSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Reference"], CellDingbat -> Cell[
            TextData[{
              CounterBox["Reference"]}], "SR", FontSize -> 13, 
            CellSize -> {30, Inherited}, TextAlignment -> Right], 
          CellMargins -> {{80, 10}, {3, 4}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, 
          CellChangeTimes -> {{3.7385995432110577`*^9, 3.738599549834622*^9}},
           LineSpacing -> {1, 2}, ParagraphIndent -> -8, 
          TabSpacings -> {0.7, 2.5}, CounterIncrements -> "Reference", 
          MenuSortingValue -> 1870, FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["Reference", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{66, 10}, {3, 4}}, TabSpacings -> {1.2, 2.5}]}, 
        Open]]}, Closed]]}, Visible -> False, FrontEndVersion -> 
  "12.2 for Mac OS X x86 (64-bit) (December 12, 2020)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"ca718aca-56ab-47d2-a45d-5a697c465c9b"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "C:8"->{
  Cell[580, 22, 383, 9, 113, "Section",ExpressionUUID->"0886596a-110a-4bf9-a26d-e53e7705e582",
   CounterAssignments->{{"Section", 7}, {"Subsection", 7}, {"Subsubsection", 7}, {"Exercise", 7}},
   CellTags->"C:8",
   CellID->868451339]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"C:8", 373669, 8096}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 383, 9, 113, "Section",ExpressionUUID->"0886596a-110a-4bf9-a26d-e53e7705e582",
 CounterAssignments->{{"Section", 7}, {"Subsection", 7}, {"Subsubsection", 7}, {"Exercise", 7}},
 CellTags->"C:8",
 CellID->868451339],
Cell[966, 33, 803, 18, 163, "Text",ExpressionUUID->"bd9e37e8-db2e-4461-9e75-90c26174fd70",
 CellID->121416020],
Cell[1772, 53, 760, 15, 163, "Text",ExpressionUUID->"2cd93a65-051a-495f-8bfd-efa9d863f8d4",
 CellID->92426958],
Cell[2535, 70, 368, 7, 63, "Text",ExpressionUUID->"e6d4bc07-fbc5-4ace-b89b-706d9e38e83c",
 CellID->246767786],
Cell[2906, 79, 215, 4, 63, "Text",ExpressionUUID->"c450ee7b-e094-4ca0-89bb-f6691c30a668",
 CellID->110691724]
}, Open  ]],
Cell[CellGroupData[{
Cell[3158, 88, 196, 2, 57, "Subsection",ExpressionUUID->"3362b275-7303-4e50-ab97-902d22e13473",
 CellID->423276631],
Cell[3357, 92, 368, 8, 88, "Text",ExpressionUUID->"e2b720c9-dcdb-4a12-8077-6430d096ce88",
 CellID->59887565],
Cell[3728, 102, 551, 9, 113, "Text",ExpressionUUID->"286d9c1b-994e-408b-b6c6-82978d0fd116",
 CellID->351417190],
Cell[4282, 113, 690, 16, 89, "Text",ExpressionUUID->"24bde6b6-4bdd-4f03-95a5-3d49e613bcf2",
 CellID->21548066],
Cell[4975, 131, 272, 7, 37, "CodeCaption",ExpressionUUID->"d6fc1308-9599-4e1b-89a5-c8b7b514023e",
 CellID->1433940191],
Cell[5250, 140, 361, 10, 54, "Input",ExpressionUUID->"0c54cfff-be73-44fe-91e5-8fbcb191ac3e",
 CellID->560069374],
Cell[5614, 152, 798, 14, 138, "Text",ExpressionUUID->"60559197-742d-4fdf-a85b-4bd98790a36e",
 CellID->42765712],
Cell[6415, 168, 486, 10, 37, "CodeCaption",ExpressionUUID->"18e6fdf9-ef68-4eb9-8007-04af753aeb0e",
 CellID->632037609],
Cell[6904, 180, 158, 3, 29, "Input",ExpressionUUID->"5f6cbcec-29ed-42e5-af1e-ab7d419faea3",
 CellID->161192109],
Cell[7065, 185, 1082, 25, 188, "Text",ExpressionUUID->"1617dbc8-b1f8-4998-a972-c532b21b4dab",
 CellID->118392862],
Cell[8150, 212, 376, 9, 37, "CodeCaption",ExpressionUUID->"27a413c4-e99c-44e1-a778-9af770514824",
 CellID->20933067],
Cell[8529, 223, 420, 11, 54, "Input",ExpressionUUID->"456d11f9-3015-4e68-8c8c-33a4a12be9bb",
 CellID->272051126],
Cell[8952, 236, 1448, 39, 213, "Text",ExpressionUUID->"76b84c60-76ef-462b-a330-21822b0d1a1c",
 CellID->512262468],
Cell[10403, 277, 207, 4, 66, "CodeCaption",ExpressionUUID->"a5989c47-ae26-4a37-81c6-5b6b772d6be9",
 CellID->463522401],
Cell[CellGroupData[{
Cell[10635, 285, 252, 6, 29, "Input",ExpressionUUID->"f0af3271-46b6-4994-9886-e8bc463cc343",
 CellID->290980916],
Cell[10890, 293, 584, 17, 40, "Output",ExpressionUUID->"04b76eb6-4fa6-4be7-a81a-7ae05b23c60d",
 CellID->694336830]
}, Open  ]],
Cell[11489, 313, 319, 9, 66, "CodeCaption",ExpressionUUID->"192de5f8-49f8-40ef-ae3b-28816e05439a",
 CellID->68494916],
Cell[CellGroupData[{
Cell[11833, 326, 159, 3, 29, "Input",ExpressionUUID->"0ea37773-e5fb-4418-92cf-0fb84284f31c",
 CellID->432683771],
Cell[11995, 331, 510, 11, 40, "Output",ExpressionUUID->"976c2e07-924b-4504-b2a4-fcb71d4dfc03",
 CellID->292964012]
}, Open  ]],
Cell[12520, 345, 375, 10, 63, "Text",ExpressionUUID->"9eedb627-fb58-4a00-a2df-e7f15a811936",
 CellID->85046672],
Cell[12898, 357, 331, 8, 37, "CodeCaption",ExpressionUUID->"e9827bd8-5098-41c9-bcc4-4c786f696ab6",
 CellID->28627986],
Cell[CellGroupData[{
Cell[13254, 369, 251, 5, 29, "Input",ExpressionUUID->"29f1bd2f-573a-4bac-9b12-6dfd3f638533",
 CellID->3381550],
Cell[13508, 376, 300, 7, 40, "Output",ExpressionUUID->"95c97f7c-3f9b-4e1c-b7d7-e98e452e8d18",
 CellID->1813630760]
}, Open  ]],
Cell[13823, 386, 203, 2, 38, "Text",ExpressionUUID->"67ec5424-8db6-4c7e-8d2c-c9eb79716141",
 CellID->145482982],
Cell[14029, 390, 338, 8, 37, "CodeCaption",ExpressionUUID->"a673fcfb-6de4-4151-b6e3-e5ed4978d75f",
 CellID->233614204],
Cell[CellGroupData[{
Cell[14392, 402, 256, 5, 29, "Input",ExpressionUUID->"322a93de-4d04-42aa-91e1-1c48a1cece20",
 CellID->116867700],
Cell[14651, 409, 280, 6, 40, "Output",ExpressionUUID->"b73fd4b7-204a-4853-9eb9-fa2b6a2783d8",
 CellID->309297802]
}, Open  ]],
Cell[14946, 418, 346, 6, 88, "Text",ExpressionUUID->"54b484cd-e0b9-487f-9611-f103eb4bdd2a",
 CellID->501766448],
Cell[15295, 426, 215, 2, 37, "CodeCaption",ExpressionUUID->"2023b3f7-e269-4d75-81cb-0af6d9017644",
 CellID->271148052],
Cell[CellGroupData[{
Cell[15535, 432, 236, 5, 29, "Input",ExpressionUUID->"2e2c52e8-af6a-4e7f-a3f3-47b67158cae6",
 CellID->291559845],
Cell[15774, 439, 9435, 242, 330, "Output",ExpressionUUID->"3deb0380-8549-4bb1-8c2f-68a9497ddf33",
 CellID->1457732474]
}, Open  ]],
Cell[25224, 684, 567, 11, 88, "Text",ExpressionUUID->"18f55d5f-1d54-4218-bb87-ecc35a28f0a2",
 CellID->812740575],
Cell[25794, 697, 623, 12, 90, "Text",ExpressionUUID->"1f3af079-f43a-4a5f-971a-640c43f2e44c",
 CellID->25356097],
Cell[26420, 711, 791, 17, 115, "Text",ExpressionUUID->"a46323dd-7248-46db-aea4-6bc957f1746d",
 CellID->104697398],
Cell[27214, 730, 955, 20, 116, "Text",ExpressionUUID->"4c8ab552-0d59-42a2-82a5-e006ff64976d",
 CellID->267213650],
Cell[28172, 752, 447, 12, 38, "CodeCaption",ExpressionUUID->"41380cdf-e21e-45a9-a201-0518968b0f52",
 CellID->93797649],
Cell[CellGroupData[{
Cell[28644, 768, 225, 5, 29, "Input",ExpressionUUID->"655d7f98-0b21-487b-a5f1-49e4f001d726",
 CellID->598609423],
Cell[28872, 775, 5362, 152, 330, "Output",ExpressionUUID->"a791dcef-ce64-4696-a62f-f3c2ada85cd6",
 CellID->1616245542]
}, Open  ]],
Cell[34249, 930, 676, 12, 63, "Text",ExpressionUUID->"9e1b4946-2d4b-4bec-b955-a8c1921b0185",
 CellID->84680248],
Cell[34928, 944, 936, 18, 164, "Text",ExpressionUUID->"cafa9afa-f5a9-40cf-8e6e-f17286deaa07",
 CellID->635034296],
Cell[35867, 964, 1113, 18, 138, "Text",ExpressionUUID->"bb6414b3-2c90-4019-bf1e-81526fc562bf",
 CellID->65808809],
Cell[36983, 984, 1199, 22, 142, "Text",ExpressionUUID->"b7807492-4da4-49a0-a4b3-d6e1d25f0b93",
 CellID->166011649],
Cell[38185, 1008, 1230, 30, 140, "Text",ExpressionUUID->"306441d9-ea1a-4212-996e-5b1aec24039e",
 CellID->442486879],
Cell[39418, 1040, 406, 6, 37, "CodeCaption",ExpressionUUID->"3b295b0b-3462-412b-a3ce-7b4263f6e0c6",
 CellID->457704754],
Cell[CellGroupData[{
Cell[39849, 1050, 284, 7, 29, "Input",ExpressionUUID->"0d5ebf6f-5023-4225-8edc-16544ea419c2",
 CellID->363357430],
Cell[40136, 1059, 1455, 42, 67, "Output",ExpressionUUID->"e7be430d-4f43-436b-a3ef-b51b566ffeb7",
 CellID->718173491]
}, Open  ]],
Cell[41606, 1104, 1023, 24, 65, "Text",ExpressionUUID->"497abdc4-d489-462e-8ac7-cb08e72018d3",
 CellID->441068988],
Cell[42632, 1130, 238, 5, 52, "DisplayFormula",ExpressionUUID->"a275f34c-2607-430f-b756-678f46afb854",
 CellID->788329313],
Cell[42873, 1137, 410, 9, 37, "CodeCaption",ExpressionUUID->"cfdc7245-8391-47b0-a145-63ca1047d03a",
 CellID->11885163],
Cell[CellGroupData[{
Cell[43308, 1150, 200, 5, 51, "Input",ExpressionUUID->"00976e7e-8386-473a-8622-dd96d0f60180",
 CellID->114856603],
Cell[43511, 1157, 233, 5, 58, "Output",ExpressionUUID->"1fb613e6-1646-4900-a82c-1e343cca1311",
 CellID->1483767097]
}, Open  ]],
Cell[43759, 1165, 539, 11, 37, "CodeCaption",ExpressionUUID->"4ebcb57e-2c54-442d-9066-6111713ddc9d",
 CellID->56358650],
Cell[CellGroupData[{
Cell[44323, 1180, 403, 9, 29, "Input",ExpressionUUID->"b11b5f36-3d57-4e1d-baf0-3ddbd112ca4d",
 CellID->301633926],
Cell[44729, 1191, 281, 6, 58, "Output",ExpressionUUID->"affd3e6a-3a43-4eeb-b93e-ae55fdb3f75e",
 CellID->1093490315]
}, Open  ]],
Cell[45025, 1200, 405, 8, 63, "Text",ExpressionUUID->"688c3467-bc23-44e5-8832-5beb03c94a2d",
 CellID->325844190],
Cell[45433, 1210, 293, 6, 37, "CodeCaption",ExpressionUUID->"2cdce688-417b-4e7f-a2bf-494095dabceb",
 CellID->235290855],
Cell[CellGroupData[{
Cell[45751, 1220, 689, 17, 29, "Input",ExpressionUUID->"d2acc071-7ee5-471b-b3ba-64a602202eba",
 CellID->121014798],
Cell[46443, 1239, 4161, 100, 181, "Output",ExpressionUUID->"c1b75137-b2b9-44f4-bd8d-8f0835a4754d",
 CellID->126673179]
}, Open  ]],
Cell[50619, 1342, 516, 11, 63, "Text",ExpressionUUID->"02e3178d-4438-4d21-a0b0-027a32b823f2",
 CellID->202718110],
Cell[51138, 1355, 490, 8, 37, "CodeCaption",ExpressionUUID->"8f88888d-00f4-41da-b6b3-cfcde9a6faf5",
 CellID->447508593],
Cell[CellGroupData[{
Cell[51653, 1367, 352, 8, 29, "Input",ExpressionUUID->"6c15c425-3cd1-4c50-bdae-12f479a73edc",
 CellID->487766923],
Cell[52008, 1377, 244, 4, 40, "Output",ExpressionUUID->"2ff12806-55e8-4023-8da5-be0851cc5e5e",
 CellID->839825276]
}, Open  ]],
Cell[52267, 1384, 599, 12, 63, "Text",ExpressionUUID->"a079c9b9-118c-49d7-88ef-57bd3e6748dd",
 CellID->72720277],
Cell[52869, 1398, 620, 18, 54, "DisplayFormula",ExpressionUUID->"2c5dfd42-ce23-4359-bd73-45b5e6bc8a6f",
 CellID->707922722],
Cell[53492, 1418, 1016, 24, 68, "Text",ExpressionUUID->"7efb3094-5c21-4f8e-9ae5-2561aef4edc3",
 CellID->42081074],
Cell[54511, 1444, 1015, 26, 39, "CodeCaption",ExpressionUUID->"88e888b9-86cd-4fc0-ac0c-f3bca7d5f3a2",
 CellID->50329074],
Cell[CellGroupData[{
Cell[55551, 1474, 482, 11, 29, "Input",ExpressionUUID->"dc1bf21a-bc4b-4e76-a9a3-43c6b28d87f1",
 CellID->358956926],
Cell[56036, 1487, 258, 6, 58, "Output",ExpressionUUID->"a341cfb6-5526-4ddb-9c96-5363d7a89b68",
 CellID->1680885648]
}, Open  ]],
Cell[56309, 1496, 941, 21, 140, "Text",ExpressionUUID->"5e35ba84-0f07-4535-8261-71dcf903f616",
 CellID->670304900],
Cell[57253, 1519, 265, 5, 63, "Text",ExpressionUUID->"b1dccd45-3330-49b4-81c8-28583a689031",
 CellID->106598390]
}, Open  ]],
Cell[CellGroupData[{
Cell[57555, 1529, 116, 1, 57, "Subsection",ExpressionUUID->"884b6122-2959-434e-aa0c-00f62de4c588",
 CellID->176638570],
Cell[57674, 1532, 652, 11, 88, "Text",ExpressionUUID->"983ff0e2-ba0e-4741-8478-8313393bafad",
 CellID->9186485],
Cell[58329, 1545, 364, 6, 63, "Text",ExpressionUUID->"18b1a59d-2392-4d52-8f99-d98572c83e45",
 CellID->101398934],
Cell[58696, 1553, 828, 13, 163, "Text",ExpressionUUID->"ff7bbe12-b0f1-431d-abd9-027ff76218e5",
 CellID->809766297],
Cell[59527, 1568, 552, 12, 64, "Text",ExpressionUUID->"821c4209-5ebd-4b4d-af7b-fa8bca15466c",
 CellID->424553395],
Cell[60082, 1582, 335, 8, 37, "CodeCaption",ExpressionUUID->"ff654f3b-6968-48bd-9dbb-ec1059c4ea4f",
 CellID->221200766],
Cell[60420, 1592, 472, 12, 54, "Input",ExpressionUUID->"20f452e1-5645-46d5-bfb7-05450c36cbb0",
 CellID->204048059],
Cell[60895, 1606, 117, 1, 37, "CodeCaption",ExpressionUUID->"fc8dc9f6-a008-4601-9e6e-f550b29996f3",
 CellID->341591163],
Cell[CellGroupData[{
Cell[61037, 1611, 213, 4, 29, "Input",ExpressionUUID->"db0fc70c-b8d3-453a-a112-76f8f62cfecb",
 CellID->9767186],
Cell[61253, 1617, 806, 25, 40, "Output",ExpressionUUID->"02a33678-742d-439d-b046-6a670c6154ad",
 CellID->557299292]
}, Open  ]],
Cell[62074, 1645, 937, 25, 113, "Text",ExpressionUUID->"95e1924a-6c8f-4d84-881d-96e4abb807ea",
 CellID->323136105],
Cell[63014, 1672, 403, 11, 37, "CodeCaption",ExpressionUUID->"5d267ca5-75a8-46d7-bb59-4b09c5875896",
 CellID->360363996],
Cell[63420, 1685, 203, 5, 29, "Input",ExpressionUUID->"6df83146-552a-4bc1-ae95-e8af8bf36749",
 CellID->685161560],
Cell[63626, 1692, 202, 4, 63, "Text",ExpressionUUID->"12dc2748-64fb-4670-b46a-00e3bd09b162",
 CellID->503533385],
Cell[63831, 1698, 118, 1, 37, "CodeCaption",ExpressionUUID->"643bceba-8673-40d6-8d5b-4dc5508e62e1",
 CellID->114027062],
Cell[CellGroupData[{
Cell[63974, 1703, 216, 4, 29, "Input",ExpressionUUID->"fc08a091-575c-4744-9056-3cdd7220db86",
 CellID->17588274],
Cell[64193, 1709, 353, 8, 40, "Output",ExpressionUUID->"6f3e449f-d0e3-4045-9851-f3ae95ecd961",
 CellID->1353016077]
}, Open  ]],
Cell[64561, 1720, 446, 11, 63, "Text",ExpressionUUID->"1374f829-0819-439f-adc4-e908b3892260",
 CellID->116133576],
Cell[65010, 1733, 189, 2, 37, "CodeCaption",ExpressionUUID->"a6a89e3c-cde9-408b-aace-dab7901f3ec7",
 CellID->20798786],
Cell[CellGroupData[{
Cell[65224, 1739, 222, 5, 29, "Input",ExpressionUUID->"4d70202b-3a8c-4bde-baec-c536074a536a",
 CellID->65285777],
Cell[65449, 1746, 920, 28, 65, "Output",ExpressionUUID->"320eb533-37ba-4eeb-afab-1941a009550b",
 CellID->436868056]
}, Open  ]],
Cell[66384, 1777, 416, 11, 64, "Text",ExpressionUUID->"5584a7d9-3f26-400d-bc12-6ddd4d1c380b",
 CellID->6035978],
Cell[66803, 1790, 347, 8, 38, "Text",ExpressionUUID->"3df2d35e-9084-4b9f-9ca1-4e7dfbcbaad7",
 CellID->235025413],
Cell[67153, 1800, 580, 12, 37, "CodeCaption",ExpressionUUID->"8ddca30a-4f6c-4204-8043-cff6ef8afa48",
 CellID->229700914],
Cell[67736, 1814, 162, 3, 29, "Input",ExpressionUUID->"b6ae380b-47b1-42b3-bade-874d96254f0d",
 CellID->605933267],
Cell[67901, 1819, 489, 10, 37, "CodeCaption",ExpressionUUID->"781ab363-0380-4c9e-a445-2f0c3d3e29a9",
 CellID->12130739],
Cell[CellGroupData[{
Cell[68415, 1833, 353, 9, 29, "Input",ExpressionUUID->"b311d61a-6391-4bd4-a084-7d2fd8692973",
 CellID->546476866],
Cell[68771, 1844, 386, 9, 40, "Output",ExpressionUUID->"1e786f4f-2427-4c26-92cb-f6beaa6f63fb",
 CellID->194828099]
}, Open  ]],
Cell[69172, 1856, 318, 5, 38, "Text",ExpressionUUID->"91758e09-7c3b-4606-a346-00c20ed1b08c",
 CellID->73923205],
Cell[69493, 1863, 211, 2, 37, "CodeCaption",ExpressionUUID->"5f37f94d-48d8-46a1-88d2-fd79b03ea4a6",
 CellID->443292433],
Cell[CellGroupData[{
Cell[69729, 1869, 385, 9, 29, "Input",ExpressionUUID->"5827e516-8ec2-425e-83b7-11a9291a1bd3",
 CellID->587048772],
Cell[70117, 1880, 15560, 395, 322, "Output",ExpressionUUID->"c57fa3fd-d332-4f82-a598-e81f92cedb44",
 CellID->1710781865]
}, Open  ]],
Cell[85692, 2278, 938, 18, 114, "Text",ExpressionUUID->"86818888-39c4-44bb-be57-fa51c49d3f99",
 CellID->35287596],
Cell[86633, 2298, 275, 7, 37, "CodeCaption",ExpressionUUID->"c2746e20-cf11-4c46-959d-216a4644b5f4",
 CellID->428124550],
Cell[CellGroupData[{
Cell[86933, 2309, 228, 5, 29, "Input",ExpressionUUID->"6fe02e4b-920a-4f9b-9f90-54e428cdfca9",
 CellID->413488752],
Cell[87164, 2316, 8890, 257, 333, "Output",ExpressionUUID->"5abc6229-4ffb-4e64-8254-b7f4181814a1",
 CellID->452255372]
}, Open  ]],
Cell[96069, 2576, 566, 9, 88, "Text",ExpressionUUID->"a427a724-75b4-4dfc-9c65-77a0ebc0a704",
 CellID->255990457],
Cell[96638, 2587, 424, 7, 88, "Text",ExpressionUUID->"96721d91-e496-436a-979d-bec3cd6496b8",
 CellID->481178091],
Cell[97065, 2596, 537, 13, 113, "Text",ExpressionUUID->"c74e671a-2f55-468c-8c1d-0079336e1139",
 CellID->626562882],
Cell[97605, 2611, 776, 12, 163, "Text",ExpressionUUID->"4d77b44a-ebff-438c-b1f3-2847a18c322c",
 CellID->110580635],
Cell[98384, 2625, 180, 3, 37, "CodeCaption",ExpressionUUID->"b8833092-062b-4f41-9777-43437a3284f8",
 CellID->2067965092],
Cell[CellGroupData[{
Cell[98589, 2632, 429, 11, 29, "Input",ExpressionUUID->"d53b0196-4e1c-4789-a0de-7f623be58046",
 CellID->173557031],
Cell[99021, 2645, 16472, 291, 284, "Output",ExpressionUUID->"a6bc52c1-2dce-4e97-bb85-2ea0b21d03fb",
 CellID->1111410471]
}, Open  ]],
Cell[115508, 2939, 1625, 30, 240, "Text",ExpressionUUID->"b820b9ae-945e-441e-b990-6e70076d664e",
 CellID->65942760],
Cell[117136, 2971, 921, 15, 114, "Text",ExpressionUUID->"af0cc840-3ce2-4df3-90c0-dd9b9f06d637",
 CellID->77913434],
Cell[118060, 2988, 1597, 39, 190, "Text",ExpressionUUID->"38c02f3a-b7c6-44db-b04f-a52d05480a1e",
 CellID->78729036],
Cell[119660, 3029, 393, 9, 37, "CodeCaption",ExpressionUUID->"864c6688-48ae-4178-9b46-5329b9338309",
 CellID->5861944],
Cell[CellGroupData[{
Cell[120078, 3042, 236, 5, 29, "Input",ExpressionUUID->"66b8a011-0bbe-4654-aedb-3e48c33b7678",
 CellID->870478265],
Cell[120317, 3049, 195, 3, 40, "Output",ExpressionUUID->"52c20f32-af5c-468d-8e13-cc85a539cb43",
 CellID->663024491]
}, Open  ]],
Cell[120527, 3055, 380, 9, 37, "CodeCaption",ExpressionUUID->"dd031c78-8285-47b1-9c54-735cea3966ac",
 CellID->352163608],
Cell[CellGroupData[{
Cell[120932, 3068, 249, 5, 29, "Input",ExpressionUUID->"a19f3dbb-7fb8-45cc-bdcc-68d9756b5b6e",
 CellID->187026937],
Cell[121184, 3075, 198, 3, 40, "Output",ExpressionUUID->"c2a89b84-4dd8-4940-81dd-92c69b9a168e",
 CellID->159975954]
}, Open  ]],
Cell[121397, 3081, 157, 2, 37, "CodeCaption",ExpressionUUID->"75455245-43c8-410b-ad5b-e4cdc7e92d9b",
 CellID->304094515],
Cell[CellGroupData[{
Cell[121579, 3087, 240, 5, 29, "Input",ExpressionUUID->"87208d07-6d1d-409d-b7d6-99c20bb3290c",
 CellID->212033964],
Cell[121822, 3094, 220, 4, 40, "Output",ExpressionUUID->"8a0bb011-55a0-4813-b235-81a96bf655bc",
 CellID->66332834]
}, Open  ]],
Cell[122057, 3101, 473, 11, 88, "Text",ExpressionUUID->"87c7429a-0f7a-4884-ac46-b0c757a41885",
 CellID->7551058],
Cell[122533, 3114, 215, 2, 37, "CodeCaption",ExpressionUUID->"fa8f09cf-ba31-4d85-b6a1-a484fce908fc",
 CellID->620488064],
Cell[CellGroupData[{
Cell[122773, 3120, 195, 4, 29, "Input",ExpressionUUID->"3cd7fc8c-51d2-426b-94ad-518306efdf62",
 CellID->38546484],
Cell[122971, 3126, 191, 3, 40, "Output",ExpressionUUID->"4411e701-adaf-4437-82dc-9b065090886b",
 CellID->311928245]
}, Open  ]],
Cell[123177, 3132, 238, 4, 37, "CodeCaption",ExpressionUUID->"bb58ad06-8618-4922-bc29-f08a59267189",
 CellID->524249967],
Cell[CellGroupData[{
Cell[123440, 3140, 209, 4, 29, "Input",ExpressionUUID->"06fa7ad5-16ae-49f3-b894-f91556af3d89",
 CellID->645924666],
Cell[123652, 3146, 193, 3, 40, "Output",ExpressionUUID->"6b2455c9-f16f-48fd-9a2d-debe5177241f",
 CellID->570431388]
}, Open  ]],
Cell[123860, 3152, 480, 8, 38, "Text",ExpressionUUID->"67cab8c3-d33f-405f-933e-3dab23ce5505",
 CellID->661582274],
Cell[124343, 3162, 471, 16, 63, "DisplayFormula",ExpressionUUID->"e3f1a68f-19ed-42c0-8fdb-8f630378bd34",
 CellID->556501683],
Cell[124817, 3180, 290, 7, 37, "CodeCaption",ExpressionUUID->"ee849cd1-020a-481c-87df-a757950ee6d7",
 CellID->980144212],
Cell[CellGroupData[{
Cell[125132, 3191, 260, 6, 29, "Input",ExpressionUUID->"8315f5d3-7c0a-49e4-bb79-a2a26d1b61c1",
 CellID->174264330],
Cell[125395, 3199, 514, 15, 82, "Output",ExpressionUUID->"e8c355a3-24f7-468d-982c-89d5e51c6bd6",
 CellID->873337908]
}, Open  ]],
Cell[125924, 3217, 455, 12, 37, "CodeCaption",ExpressionUUID->"7e6bdbc6-97d9-405b-8f40-29e557caba63",
 CellID->172762918],
Cell[CellGroupData[{
Cell[126404, 3233, 219, 5, 29, "Input",ExpressionUUID->"6ad97a81-09f7-468d-87ad-4b958d8fa283",
 CellID->737053995],
Cell[126626, 3240, 358, 10, 78, "Output",ExpressionUUID->"95023a44-8efc-4668-800d-ef6d1eecf32e",
 CellID->139492511]
}, Open  ]],
Cell[126999, 3253, 344, 6, 38, "Text",ExpressionUUID->"4554bcf7-6028-43ee-b332-b73e267ff453",
 CellID->27864696],
Cell[127346, 3261, 477, 12, 37, "CodeCaption",ExpressionUUID->"b73dbb20-2cbf-41ac-9e5b-be4531731121",
 CellID->320680758],
Cell[CellGroupData[{
Cell[127848, 3277, 630, 20, 65, "Input",ExpressionUUID->"400a5ce8-265b-4fab-b248-2712bcdc9ff2",
 CellID->6843162],
Cell[128481, 3299, 26373, 453, 342, "Output",ExpressionUUID->"c838c854-e61b-469c-83dd-3a605747c04e",
 CellID->1545973500]
}, Open  ]],
Cell[154869, 3755, 220, 6, 37, "CodeCaption",ExpressionUUID->"a0b85c5f-2843-4444-b53b-a62ff1f8def6",
 CellID->24949686],
Cell[CellGroupData[{
Cell[155114, 3765, 412, 11, 29, "Input",ExpressionUUID->"3055636b-b501-4500-a8f8-b1755c844ea7",
 CellID->135139084],
Cell[155529, 3778, 26366, 453, 344, "Output",ExpressionUUID->"eef744ae-b90a-4260-bb76-50234397e418",
 CellID->771969447]
}, Open  ]],
Cell[181910, 4234, 848, 16, 163, "Text",ExpressionUUID->"65f2d309-e85f-4ce3-a0eb-935b05ebdb26",
 CellID->246688181],
Cell[182761, 4252, 276, 5, 66, "CodeCaption",ExpressionUUID->"32daa0d4-cbc9-4d3d-859b-812f01a0365c",
 CellID->292014550],
Cell[183040, 4259, 463, 11, 54, "Input",ExpressionUUID->"08fed267-ae67-43fd-85d4-0c7ce8a9fac9",
 CellID->405256362],
Cell[183506, 4272, 342, 6, 63, "Text",ExpressionUUID->"1ce682eb-c3d7-4f62-91ec-cdaa200d8ffe",
 CellID->278236021],
Cell[183851, 4280, 128, 1, 37, "CodeCaption",ExpressionUUID->"05266939-7452-4cfe-b2f6-284338c52809",
 CellID->886510950],
Cell[CellGroupData[{
Cell[184004, 4285, 235, 4, 29, "Input",ExpressionUUID->"99c7bf86-d245-4871-9bbe-0d32179684fa",
 CellID->213084500],
Cell[184242, 4291, 263, 4, 40, "Output",ExpressionUUID->"423a0db1-e3ab-4290-a3d5-e4fb10ef4bf4",
 CellID->1229398312]
}, Open  ]],
Cell[184520, 4298, 142, 1, 37, "CodeCaption",ExpressionUUID->"852a95ce-1d23-45e8-b6ef-17f896b1aa36",
 CellID->122167763],
Cell[CellGroupData[{
Cell[184687, 4303, 249, 4, 29, "Input",ExpressionUUID->"ce31a765-48d1-4ee0-99be-f1b279ea3acc",
 CellID->14691677],
Cell[184939, 4309, 236, 4, 40, "Output",ExpressionUUID->"506f4202-f5e5-4a36-80fa-68a4ec9ac020",
 CellID->1557261997]
}, Open  ]],
Cell[185190, 4316, 483, 8, 113, "Text",ExpressionUUID->"86b2c6b6-5642-4b63-bb26-16c9e08cde47",
 CellID->59054695],
Cell[185676, 4326, 949, 15, 188, "Text",ExpressionUUID->"d01c9023-587d-4850-94cb-e113c5acae8f",
 CellID->69466243],
Cell[186628, 4343, 755, 14, 139, "Text",ExpressionUUID->"b734d4aa-10a7-4188-bfef-7e4ee1fda31f",
 CellID->517737602],
Cell[187386, 4359, 563, 12, 89, "Text",ExpressionUUID->"4ce3f8c0-d0b6-4d5c-b7e6-15984e8fbf4c",
 CellID->107113048]
}, Open  ]],
Cell[CellGroupData[{
Cell[187986, 4376, 289, 7, 60, "Subsection",ExpressionUUID->"fc1d4b11-eaa7-45c6-880b-c4128eba85e0",
 CellID->7223967],
Cell[188278, 4385, 824, 17, 89, "Text",ExpressionUUID->"154ae898-9dcb-4d7b-b66d-c8ab8b44731c",
 CellID->25724162],
Cell[189105, 4404, 904, 21, 139, "Text",ExpressionUUID->"7868c78b-4019-41af-ad6e-0a8d600fc5cd",
 CellID->344467047],
Cell[190012, 4427, 615, 14, 39, "Text",ExpressionUUID->"2db32e10-4126-46bf-9783-289d0499d959",
 CellID->118445582],
Cell[190630, 4443, 475, 10, 39, "CodeCaption",ExpressionUUID->"853e36e7-dabe-4566-97b7-9d10a085a666",
 CellID->243432671],
Cell[CellGroupData[{
Cell[191130, 4457, 301, 7, 29, "Input",ExpressionUUID->"b12dc92a-8c66-49f4-94a7-d43eaaa7a5f6",
 CellID->401279574],
Cell[191434, 4466, 573, 18, 87, "Output",ExpressionUUID->"c7af818b-0b7d-4418-84eb-9c4fbfbc9d89",
 CellID->1519177590]
}, Open  ]],
Cell[192022, 4487, 317, 6, 37, "CodeCaption",ExpressionUUID->"eeacc90c-4bfd-4e27-9e24-3107a7606623",
 CellID->245061752],
Cell[CellGroupData[{
Cell[192364, 4497, 651, 20, 54, "Input",ExpressionUUID->"896b53c7-7d58-45aa-840e-9b5cf55a1ac5",
 CellID->191060932],
Cell[193018, 4519, 30969, 532, 352, "Output",ExpressionUUID->"02cfffaa-ed96-4740-bd97-4100b54c86d2",
 CellID->1384675947]
}, Open  ]],
Cell[224002, 5054, 430, 9, 63, "Text",ExpressionUUID->"9964538f-75ea-4164-b853-30c23773ae54",
 CellID->340901948]
}, Open  ]],
Cell[CellGroupData[{
Cell[224469, 5068, 307, 8, 58, "Subsection",ExpressionUUID->"be81add8-99ea-4c83-8293-cc8cb2648d48",
 CellID->142563282],
Cell[224779, 5078, 1048, 22, 115, "Text",ExpressionUUID->"b496104c-932e-4b8a-a032-7a12f8549b3d",
 CellID->946935873],
Cell[225830, 5102, 582, 13, 39, "Text",ExpressionUUID->"86ab2f6a-fd48-4a6f-9225-ddb916205586",
 CellID->636615775],
Cell[226415, 5117, 395, 10, 37, "CodeCaption",ExpressionUUID->"27603d5b-b20c-48f4-a2e8-56f6fb66788b",
 CellID->2122207582],
Cell[CellGroupData[{
Cell[226835, 5131, 698, 20, 54, "Input",ExpressionUUID->"72a126df-edd3-45fc-8cdb-44aa227abd73",
 CellID->282377119],
Cell[227536, 5153, 50148, 850, 335, "Output",ExpressionUUID->"44a77607-bdda-438d-84b1-9e8c6a3014e9",
 CellID->2115842337]
}, Open  ]],
Cell[277699, 6006, 477, 13, 39, "Text",ExpressionUUID->"b9e42879-1f61-4051-bd40-84cafa735617",
 CellID->197014087],
Cell[278179, 6021, 528, 12, 37, "CodeCaption",ExpressionUUID->"44a2b195-56b3-4f5e-8894-4bf18257204c",
 CellID->1166843097],
Cell[CellGroupData[{
Cell[278732, 6037, 237, 6, 29, "Input",ExpressionUUID->"65e90432-35d8-4306-9d45-f3b4451d9526",
 CellID->473713778],
Cell[278972, 6045, 1833, 54, 85, "Output",ExpressionUUID->"22b3a8bc-f83c-4434-9a08-9e3597561f53",
 CellID->780447286]
}, Open  ]],
Cell[280820, 6102, 414, 7, 113, "Text",ExpressionUUID->"7b0a3558-c92a-469d-bee7-b95b413bcf3e",
 CellID->94517747],
Cell[CellGroupData[{
Cell[281259, 6113, 136, 2, 70, "ExerciseSection",ExpressionUUID->"bc1998d5-74d7-4839-bbca-8faa372d4b2a",
 CellID->1643293135],
Cell[281398, 6117, 177, 3, 40, "Output",ExpressionUUID->"f5854d35-7e44-40c2-abc6-d385d1745b2c",
 CellID->147419926],
Cell[281578, 6122, 540, 13, 51, "Exercise",ExpressionUUID->"49d0baaa-fcf3-4932-8544-a9e3b4935c89",
 CellID->103155203],
Cell[282121, 6137, 445, 10, 29, "Exercise",ExpressionUUID->"3367f513-f9e2-4165-86e7-f4069d8d1a3b",
 CellID->1145460740],
Cell[282569, 6149, 559, 15, 47, "Exercise",ExpressionUUID->"d6bf5a73-72da-43e1-ad79-fcc3cf6f52b3",
 CellID->1715245472],
Cell[283131, 6166, 412, 11, 27, "Exercise",ExpressionUUID->"47af0ea1-2f00-490e-aa40-e39d886ed131",
 CellID->1104089727],
Cell[283546, 6179, 356, 11, 27, "Exercise",ExpressionUUID->"f78bec8b-4740-4464-aed0-e3a816e86846",
 CellID->29847962],
Cell[283905, 6192, 212, 4, 45, "Exercise",ExpressionUUID->"a7398205-606a-4609-a0eb-10a046aac26f",
 CellID->1291007583],
Cell[284120, 6198, 174, 3, 26, "Exercise",ExpressionUUID->"b39dd5ee-c3aa-40bf-9b34-484a137c52cd",
 CellID->1937161840]
}, Open  ]],
Cell[CellGroupData[{
Cell[284331, 6206, 112, 1, 70, "TechNoteSection",ExpressionUUID->"c67cc183-fce3-4e8b-938e-2754c928f39f",
 CellID->874797650],
Cell[284446, 6209, 686, 11, 54, "TechNote",ExpressionUUID->"b86d8458-46d8-4603-aa34-b74335ecdb2c",
 CellID->564397392],
Cell[285135, 6222, 442, 12, 53, "ExerciseInput",ExpressionUUID->"f683acd7-4aa8-4ae5-ad75-905695210a9f",
 CellID->61835188],
Cell[285580, 6236, 631, 12, 31, "TechNote",ExpressionUUID->"6d41c40f-26aa-4cc1-9b7a-58e94d544e6d",
 CellID->66657729],
Cell[CellGroupData[{
Cell[286236, 6252, 329, 6, 30, "ExerciseInput",ExpressionUUID->"375de630-f898-4a83-82bf-8c5c425ee3f7",
 CellID->27547157],
Cell[286568, 6260, 1002, 19, 56, "ExerciseOutput",ExpressionUUID->"33410f2f-497c-4584-95d0-7741e795885c",
 CellID->2135176944]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[287619, 6285, 120, 1, 100, "MoreExploreSection",ExpressionUUID->"4a0b4650-e085-4109-9326-399b9512f8b4",
 CellID->835199206],
Cell[287742, 6288, 795, 17, 49, "MoreExplore",ExpressionUUID->"2bc63fde-a82e-4a5b-a70f-b3e9e6fd6d07",
 CellID->26626102],
Cell[288540, 6307, 802, 20, 30, "MoreExplore",ExpressionUUID->"fe66a869-21dd-470d-bd64-2eb92fe738a7",
 CellID->1554366849]
}, Open  ]]
}, Open  ]]
}
]
*)

