(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    626038,      12266]
NotebookOptionsPosition[    519543,      10078]
NotebookOutlinePosition[    604390,      11849]
CellTagsIndexPosition[    604284,      11843]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Hypothesis Testing", "SectionInline",ExpressionUUID->
   "a7a8584e-91a8-4e11-8a63-0ef9dae35833"],
  $Line = 0; Null]], "Section",
 CounterAssignments->{{"Section", 8}, {"Subsection", 8}, {
   "Subsubsection", 8}, {"Exercise", 8}},
 CellTags->"C:9",
 CellLabel->"In[19]:=",
 CellID->868451339,ExpressionUUID->"705a8c63-e7c8-4de3-9c49-066cd3e6fc16"],

Cell[TextData[{
 "We saw in the previous chapter that data point values for a variable come \
in various ",
 StyleBox["patterns. ",
  FontSlant->"Italic"],
 "If we knew the value for a variable for every individual in a population, \
that would be great. As  mentioned before, though, that is usually an \
impossible task. We, therefore, select a sample of individuals from a \
population and take measurements for a variable only for those individuals."
}], "Text",
 CellChangeTimes->{{3.7534116895460196`*^9, 3.753411721408224*^9}, {
  3.8111867637591133`*^9, 3.811186821198113*^9}, {3.811516087637699*^9, 
  3.811516087735284*^9}},
 CellID->76903385,ExpressionUUID->"0e12d893-87e9-4899-91c8-3f183bd280d1"],

Cell[TextData[{
 "These individuals are not equal to the whole population. If we calculated \
the average for the set of data point values for a variable from our sample, \
chances are that it is going to be different from that of the population. A \
mean, median. variance, or standard deviation for a population is called a ",
 StyleBox["parameter",
  FontSlant->"Italic"],
 ", whereas the same values for a sample is called a ",
 StyleBox["statistic",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{
  3.753411735194361*^9, 3.7534117983684573`*^9, {3.811186848606113*^9, 
   3.811186885638113*^9}, {3.811516087786828*^9, 3.811516087845931*^9}, 
   3.81592286490897*^9},
 CellID->74788516,ExpressionUUID->"928bb2dd-ad1e-40e5-a058-12a22fef9104"],

Cell["\<\
Not only will a specific statistic differ from its equivalent parameter, the \
very same statistic will also differ from sample to sample taken from the \
same population. We might walk into five different laboratories and take 10 \
sample values for the same variable under the exact same conditions. Chances \
are that all five laboratories will show slightly different statistics.\
\>", "Text",
 CellChangeTimes->{
  3.753411818153553*^9, 3.7534118672482924`*^9, {3.811516087903607*^9, 
   3.811516087964549*^9}},
 CellID->633868118,ExpressionUUID->"65f0e397-4fd0-4b7b-835a-d2ee419e702e"],

Cell["\<\
This brings home the point that whatever statistic we find for an experiment, \
it is but one of many, many possible statistics based on different samples \
taken from a population.\
\>", "Text",
 CellChangeTimes->{3.7534118865766087`*^9},
 CellID->297129620,ExpressionUUID->"c3662730-2c3c-4e96-b577-30d76056d180"],

Cell["\<\
If we could do an experiment over and over and over again, we could actually \
build up a distribution of a specific statistic for a variable. Let\
\[CloseCurlyQuote]s consider the mean as our prototypical statistic. We can \
indeed say that we will have a distribution of sample means over many similar \
experiments. This thought experiment leads us to the most important theory in \
inferential statistics, the central limit theorem.\
\>", "Text",
 CellChangeTimes->{{3.7110229762503214`*^9, 3.7110236144666433`*^9}, {
   3.7110237374257374`*^9, 3.7110237382266245`*^9}, {3.715858588966408*^9, 
   3.715858623893838*^9}, {3.7534119360483365`*^9, 3.7534119639846478`*^9}, {
   3.8111869058321133`*^9, 3.8111869065241127`*^9}, {3.811186936902113*^9, 
   3.8111869676231127`*^9}, 3.811516088029502*^9},
 CellID->851345186,ExpressionUUID->"92e0c72e-438a-4024-acea-26344d74fbf2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Central Limit Theorem", "Subsection",
 CellChangeTimes->{{3.753411974880517*^9, 3.75341198008759*^9}, {
  3.810913070799996*^9, 3.81091307553847*^9}},
 CellID->82616854,ExpressionUUID->"3379a996-ffd4-4ca1-9e59-da2e07f99159"],

Cell["\<\
Let\[CloseCurlyQuote]s have a look at why this theorem is so important. \
Imagine that we could view the data point values for a variable over a whole \
population. Let\[CloseCurlyQuote]s assume that the distribution of the data \
point values for this variable is uniform. It\[CloseCurlyQuote]s like rolling \
a six-sided die, every value from one through six has the same probability of \
landing face up when the die is rolled.\
\>", "Text",
 CellChangeTimes->{
  3.7534119980415864`*^9, {3.810912991858103*^9, 3.8109130376736836`*^9}, {
   3.8111870520751133`*^9, 3.811187054462113*^9}, {3.811516088096232*^9, 
   3.811516088237947*^9}},
 CellID->587813419,ExpressionUUID->"51da30b8-3f78-424a-8372-5dd00d9efdf1"],

Cell[TextData[{
 "Imagine then that we have ",
 Cell[BoxData[
  FormBox["20000", TraditionalForm]],ExpressionUUID->
  "690b0d9c-5237-4706-b1dd-37863704f00b"],
 " individuals and consider them a complete population. Imagine then further \
that a value for some variable is known for all ",
 Cell[BoxData[
  FormBox["20000", TraditionalForm]],ExpressionUUID->
  "bc32ace8-c44f-4c53-9ed0-202fdd249a6f"],
 " individuals. For the sake of explanation, the variable has a minimum value \
of 18 and a maximum value of 80 and is expressed as integer values. When \
selecting 20 000 values at random from this interval, each value has an equal \
likelihood of being selected."
}], "Text",
 CellChangeTimes->{{3.7534120253565526`*^9, 3.753412123392436*^9}, {
   3.8109133083757515`*^9, 3.8109134103099437`*^9}, 3.8112461654677267`*^9, {
   3.8115160883068647`*^9, 3.811516088385448*^9}, {3.8120158013448277`*^9, 
   3.812016038257889*^9}, {3.8120160692307453`*^9, 3.8120161375114307`*^9}, {
   3.815922901312901*^9, 3.8159229208412333`*^9}, 3.8159229756646147`*^9},
 CellID->429051197,ExpressionUUID->"cb0fa133-72e7-42a9-a28f-11291f47ab4e"],

Cell[TextData[{
 "We can use the Wolfram Language to generate these ",
 Cell[BoxData[
  FormBox["20000", TraditionalForm]],ExpressionUUID->
  "4b55876b-e799-4679-82e7-ee0a5ebb8b96"],
 " values, storing them in the computer variable ",
 Cell[BoxData[
 "populationVar"], "InlineCodeText",ExpressionUUID->
  "3bf79588-aa9c-41f6-9083-674d6b59248a"],
 "."
}], "Text",
 CellChangeTimes->{{3.7534120253565526`*^9, 3.753412123392436*^9}, {
   3.8109133083757515`*^9, 3.810913447837696*^9}, {3.8111871440941133`*^9, 
   3.8111871605351133`*^9}, {3.81151549140418*^9, 3.811515496268874*^9}, {
   3.8120160415647907`*^9, 3.812016048846902*^9}, 3.81592298479261*^9},
 CellID->412431993,ExpressionUUID->"9969c368-8ef0-4c0f-90f3-89f6d7d0ec38"],

Cell[TextData[{
 "Create ",
 Cell[BoxData[
  FormBox["20000", TraditionalForm]],ExpressionUUID->
  "09b8bcfc-7fc7-41f0-a6bb-f315f3616747"],
 " data point values from a discrete uniform distribution:"
}], "CodeCaption",
 CellChangeTimes->{{3.815923011248372*^9, 3.8159230208333597`*^9}},
 CellID->3269854,ExpressionUUID->"b1b297d9-52b8-411d-92b1-740356b2e180"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SeedRandom", "[", "123", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"populationVar", "=", 
   RowBox[{"RandomVariate", "[", 
    RowBox[{
     RowBox[{"DiscreteUniformDistribution", "[", 
      RowBox[{"{", 
       RowBox[{"18", ",", "80"}], "}"}], "]"}], ",", "20000"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.753412203794464*^9, 3.753412235296266*^9}},
 CellLabel->"In[1]:=",
 CellID->380695793,ExpressionUUID->"c98cd634-07f9-4287-8367-a7aeeb8c4f6f"],

Cell[TextData[{
 "The equation for the mean value of a discrete uniform distribution for a \
variable ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "74b0e3f6-f698-43e0-9f30-663e9a9debb6"],
 " (",
 Cell[BoxData[
 "populationVar"], "InlineCodeText",ExpressionUUID->
  "4cf904cb-0f71-4a80-9fc3-7fd2caf77d86"],
 " in our case) is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", "2",
     FractionLine->0.2], 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "max"], "+", 
      SubscriptBox["x", "min"]}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "485e0389-8ca3-452a-a5b8-83dc4a5ff191"],
 ". Since we created such a large population, our real mean (using the ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Mean",
    BaseStyle->"Link"], " "}]], "InlineCodeText",ExpressionUUID->
  "54640bc1-d86f-4ac4-adfb-58de0f5a6af8"],
 "function) will be very close to this."
}], "Text",
 CellChangeTimes->{{3.753412253529486*^9, 3.753412297914815*^9}, {
   3.810914866199523*^9, 3.8109148739372964`*^9}, 3.811516088459004*^9, 
   3.815923069225646*^9},
 CellID->534282841,ExpressionUUID->"e765cce5-6203-45aa-96c7-49a04ed3d6ae"],

Cell["Calculate the mean of our population:", "CodeCaption",
 CellChangeTimes->{{3.811261769914238*^9, 3.8112617778060274`*^9}},
 CellID->119247086,ExpressionUUID->"775c2241-4536-4fc7-8c38-f6804f31867c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", "populationVar", "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.753412325427253*^9, 3.7534123355442085`*^9}},
 CellLabel->"In[3]:=",
 CellID->180367757,ExpressionUUID->"283d7e73-89d6-4088-b6f9-4d1af5a80bed"],

Cell[BoxData["49.05475`"], "Output",
 CellChangeTimes->{3.7534123359412003`*^9, 3.8109150452584267`*^9, 
  3.810921873574614*^9, 3.812470360076557*^9, 3.8127124177343383`*^9},
 CellLabel->"Out[3]=",
 CellID->153299470,ExpressionUUID->"14c2bc74-1ae6-4e86-9e86-ab101d118cbb"]
}, Open  ]],

Cell["\<\
Calculate the theoretical mean from our minimum and maximum values.\
\>", "Text",
 CellChangeTimes->{{3.7534123516880445`*^9, 3.753412381471408*^9}, 
   3.8109137692598667`*^9, 3.8109139079818664`*^9, 3.810914619494855*^9},
 CellID->889210164,ExpressionUUID->"77a52435-cba3-4200-ad2a-fb948d49fcc9"],

Cell["\<\
A space between the fraction and the opening parenthesis is shorthand for \
multiplication:\
\>", "CodeCaption",
 CellChangeTimes->{{3.8109147900309067`*^9, 3.81091479306421*^9}, 
   3.810915073580259*^9},
 CellID->362850034,ExpressionUUID->"bcf9fb51-a06f-4472-947a-b42187fb04c1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2",
   FractionLine->0.2], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Max", "[", "populationVar", "]"}], "+", 
    RowBox[{"Min", "[", "populationVar", "]"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.7534124023455973`*^9, 3.753412430922224*^9}},
 CellLabel->"In[4]:=",
 CellID->548372997,ExpressionUUID->"0e10cc09-b5bc-4bec-999c-e1aeb341437e"],

Cell[BoxData["49"], "Output",
 CellChangeTimes->{3.753412432170858*^9, 3.810915047502651*^9, 
  3.8109218739096475`*^9, 3.812470361643099*^9, 3.812712417996312*^9},
 CellLabel->"Out[4]=",
 CellID->208603060,ExpressionUUID->"e76eb5b1-a83e-482f-b5ec-286d373b7fb9"]
}, Open  ]],

Cell["\<\
We can make this supposition because we know it\[CloseCurlyQuote]s a normal \
distribution and because the sample size is so large, but a histogram will \
show that we have a near discrete uniform distribution.\
\>", "Text",
 CellChangeTimes->{
  3.7534125175206895`*^9, {3.8109148475036535`*^9, 3.810914855939497*^9}, {
   3.81091491487539*^9, 3.810914923930295*^9}, {3.8109149744203434`*^9, 
   3.8109149895428557`*^9}, 3.815923086168202*^9, {3.81592313063243*^9, 
   3.815923131063932*^9}},
 CellID->263090859,ExpressionUUID->"5dadf20e-32d9-4508-ad69-5838d92fa793"],

Cell[TextData[{
 "Specify a bin width of 1 and use  ",
 ButtonBox["Rule",
  BaseStyle->"Link"],
 " (",
 ButtonBox["\[RightArrow]",
  BaseStyle->"Link",
  ButtonData->"Rule"],
 ") to set labels and axes:"
}], "CodeCaption",
 CellChangeTimes->{{3.815923161112591*^9, 3.815923175471916*^9}, 
   3.8159232408652887`*^9, 3.816456050245612*^9},
 CellID->208659539,ExpressionUUID->"9212ca41-4139-4c0e-bafa-621251560d0e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"populationVar", ",", 
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Histogram of Our Variable\>\""}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Variable\>\"", ",", "\"\<Count\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.753412523499675*^9, 3.7534126344324565`*^9}, {
   3.753412711250065*^9, 3.7534127135848255`*^9}, {3.810915010424944*^9, 
   3.81091501078498*^9}, 3.815923253048052*^9},
 CellLabel->"In[5]:=",
 CellID->204492637,ExpressionUUID->"057e5639-f7db-459e-8e7c-297bc9e5a412"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.24499999999999997`], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.24499999999999997`], Thickness[Small]}], 
     RectangleBox[{17.5, 0}, {18.5, 293.},
      RoundingRadius->0], RectangleBox[{18.5, 0}, {19.5, 314.},
      RoundingRadius->0], RectangleBox[{19.5, 0}, {20.5, 306.},
      RoundingRadius->0], RectangleBox[{20.5, 0}, {21.5, 314.},
      RoundingRadius->0], RectangleBox[{21.5, 0}, {22.5, 291.},
      RoundingRadius->0], RectangleBox[{22.5, 0}, {23.5, 339.},
      RoundingRadius->0], RectangleBox[{23.5, 0}, {24.5, 311.},
      RoundingRadius->0], RectangleBox[{24.5, 0}, {25.5, 334.},
      RoundingRadius->0], RectangleBox[{25.5, 0}, {26.5, 326.},
      RoundingRadius->0], RectangleBox[{26.5, 0}, {27.5, 310.},
      RoundingRadius->0], RectangleBox[{27.5, 0}, {28.5, 326.},
      RoundingRadius->0], RectangleBox[{28.5, 0}, {29.5, 309.},
      RoundingRadius->0], RectangleBox[{29.5, 0}, {30.5, 306.},
      RoundingRadius->0], RectangleBox[{30.5, 0}, {31.5, 290.},
      RoundingRadius->0], RectangleBox[{31.5, 0}, {32.5, 341.},
      RoundingRadius->0], RectangleBox[{32.5, 0}, {33.5, 301.},
      RoundingRadius->0], RectangleBox[{33.5, 0}, {34.5, 335.},
      RoundingRadius->0], RectangleBox[{34.5, 0}, {35.5, 310.},
      RoundingRadius->0], RectangleBox[{35.5, 0}, {36.5, 328.},
      RoundingRadius->0], RectangleBox[{36.5, 0}, {37.5, 328.},
      RoundingRadius->0], RectangleBox[{37.5, 0}, {38.5, 343.},
      RoundingRadius->0], RectangleBox[{38.5, 0}, {39.5, 321.},
      RoundingRadius->0], RectangleBox[{39.5, 0}, {40.5, 337.},
      RoundingRadius->0], RectangleBox[{40.5, 0}, {41.5, 292.},
      RoundingRadius->0], RectangleBox[{41.5, 0}, {42.5, 317.},
      RoundingRadius->0], RectangleBox[{42.5, 0}, {43.5, 313.},
      RoundingRadius->0], RectangleBox[{43.5, 0}, {44.5, 316.},
      RoundingRadius->0], RectangleBox[{44.5, 0}, {45.5, 319.},
      RoundingRadius->0], RectangleBox[{45.5, 0}, {46.5, 291.},
      RoundingRadius->0], RectangleBox[{46.5, 0}, {47.5, 334.},
      RoundingRadius->0], RectangleBox[{47.5, 0}, {48.5, 310.},
      RoundingRadius->0], RectangleBox[{48.5, 0}, {49.5, 321.},
      RoundingRadius->0], RectangleBox[{49.5, 0}, {50.5, 328.},
      RoundingRadius->0], RectangleBox[{50.5, 0}, {51.5, 295.},
      RoundingRadius->0], RectangleBox[{51.5, 0}, {52.5, 318.},
      RoundingRadius->0], RectangleBox[{52.5, 0}, {53.5, 312.},
      RoundingRadius->0], RectangleBox[{53.5, 0}, {54.5, 342.},
      RoundingRadius->0], RectangleBox[{54.5, 0}, {55.5, 323.},
      RoundingRadius->0], RectangleBox[{55.5, 0}, {56.5, 330.},
      RoundingRadius->0], RectangleBox[{56.5, 0}, {57.5, 310.},
      RoundingRadius->0], RectangleBox[{57.5, 0}, {58.5, 318.},
      RoundingRadius->0], RectangleBox[{58.5, 0}, {59.5, 313.},
      RoundingRadius->0], RectangleBox[{59.5, 0}, {60.5, 329.},
      RoundingRadius->0], RectangleBox[{60.5, 0}, {61.5, 308.},
      RoundingRadius->0], RectangleBox[{61.5, 0}, {62.5, 365.},
      RoundingRadius->0], RectangleBox[{62.5, 0}, {63.5, 305.},
      RoundingRadius->0], RectangleBox[{63.5, 0}, {64.5, 306.},
      RoundingRadius->0], RectangleBox[{64.5, 0}, {65.5, 327.},
      RoundingRadius->0], RectangleBox[{65.5, 0}, {66.5, 317.},
      RoundingRadius->0], RectangleBox[{66.5, 0}, {67.5, 319.},
      RoundingRadius->0], RectangleBox[{67.5, 0}, {68.5, 344.},
      RoundingRadius->0], RectangleBox[{68.5, 0}, {69.5, 321.},
      RoundingRadius->0], RectangleBox[{69.5, 0}, {70.5, 313.},
      RoundingRadius->0], RectangleBox[{70.5, 0}, {71.5, 295.},
      RoundingRadius->0], RectangleBox[{71.5, 0}, {72.5, 321.},
      RoundingRadius->0], RectangleBox[{72.5, 0}, {73.5, 334.},
      RoundingRadius->0], RectangleBox[{73.5, 0}, {74.5, 311.},
      RoundingRadius->0], RectangleBox[{74.5, 0}, {75.5, 302.},
      RoundingRadius->0], RectangleBox[{75.5, 0}, {76.5, 304.},
      RoundingRadius->0], RectangleBox[{76.5, 0}, {77.5, 293.},
      RoundingRadius->0], RectangleBox[{77.5, 0}, {78.5, 310.},
      RoundingRadius->0], RectangleBox[{78.5, 0}, {79.5, 333.},
      RoundingRadius->0], RectangleBox[{79.5, 0}, {80.5, 328.},
      RoundingRadius->
       0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Variable\"", TraditionalForm], 
    FormBox["\"Count\"", TraditionalForm]},
  AxesOrigin->{16.24, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{483., Automatic},
  PlotLabel->FormBox["\"Histogram of Our Variable\"", TraditionalForm],
  PlotRange->{{17.5, 80.5}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7534125315311985`*^9, {3.7534125775994062`*^9, 3.7534126350079136`*^9}, 
   3.75341271392295*^9, 3.810915015354437*^9, 3.810915050827984*^9, 
   3.8109218745387106`*^9, 3.8124703638266563`*^9, 3.8127124188482275`*^9},
 CellLabel->"Out[5]=",
 CellID->94236984,ExpressionUUID->"a5b56d00-ad25-49f1-91d8-b3799dc3264d"]
}, Open  ]],

Cell[TextData[{
 "What will happen if we pick two random values from this population and \
calculate the average of those two values? What will a histogram of  ",
 Cell[BoxData[
  FormBox["25", TraditionalForm]],ExpressionUUID->
  "2d3d704d-41e2-452b-a949-676bfc2aa168"],
 " of these means look like? In other words, what is the distribution of \
sample means? Note that our new data point values are for sample means!"
}], "Text",
 CellChangeTimes->{
  3.753412758278251*^9, {3.753412792744104*^9, 3.753412794576206*^9}, {
   3.8112618844876943`*^9, 3.811261895117757*^9}, 3.8159233475757313`*^9, {
   3.8159233820951347`*^9, 3.815923388807118*^9}},
 CellID->8021436,ExpressionUUID->"31b92a5c-09a6-4a55-bf4e-f7466c9856be"],

Cell["\<\
You might be amazed to see that the distribution of sample means is not \
uniform. In fact, it is starting to resemble a normal distribution. \
\>", "Text",
 CellChangeTimes->{{3.753412810776889*^9, 3.7534128439761496`*^9}, {
  3.8112619112133665`*^9, 3.8112619238756323`*^9}, {3.811516088541717*^9, 
  3.8115160886332483`*^9}},
 CellID->20488384,ExpressionUUID->"1f114c01-a417-4e46-8daa-3fb91b4e0c7d"],

Cell[TextData[{
 "Create an empty ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object and give it the computer variable name ",
 Cell[BoxData[
 "listMeans25"], "InlineCode",ExpressionUUID->
  "ea5ebb7c-212f-4499-93b1-b45d7e3ff627"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.8109154350033975`*^9, {3.8109162878880587`*^9, 3.810916358236058*^9}, 
   3.8112463130664854`*^9, {3.8115155693892612`*^9, 3.811515570703828*^9}, {
   3.815923450375348*^9, 3.81592346415114*^9}},
 CellID->224763506,ExpressionUUID->"2b8bed74-9485-4d7d-9eff-2cb9373cc190"],

Cell[BoxData[
 RowBox[{
  RowBox[{"listMeans25", "=", 
   RowBox[{"List", "[", "]"}]}], ";"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->770596765,ExpressionUUID->"127a8ecc-10ef-4e0a-b31b-563ebb3747c1"],

Cell[TextData[{
 "Using a simple ",
 ButtonBox["Do",
  BaseStyle->"Link"],
 " loop, we\[CloseCurlyQuote]ll create a block of code that will be repeated \
25 times. Each iteration, two random values from ",
 Cell[BoxData[
 "populationVar"], "InlineCodeText",ExpressionUUID->
  "95f7d1c7-f9b9-48b2-b2e8-33d1353a3160"],
 " will be selected randomly and their mean taken. "
}], "Text",
 CellChangeTimes->{{3.810916127934058*^9, 3.8109161875270586`*^9}, {
  3.8109162327540584`*^9, 3.8109162820320587`*^9}, {3.8112619569969444`*^9, 
  3.811261957993044*^9}, {3.815923490215336*^9, 3.81592350231925*^9}},
 CellID->2227479,ExpressionUUID->"3a15160d-8add-4215-ae17-e31203ca2b54"],

Cell[TextData[{
 "Then, we\[CloseCurlyQuote]ll apply ",
 ButtonBox["AppendTo",
  BaseStyle->"Link"],
 " to ",
 Cell[BoxData[
 "listMeans25"], "InlineCode",ExpressionUUID->
  "f5776aff-f44d-486f-92f8-080a2be859bc"],
 ", all in one line of code:"
}], "CodeCaption",
 CellChangeTimes->{{3.8109212196142244`*^9, 3.8109212590611687`*^9}, {
   3.8109213178180437`*^9, 3.810921332254487*^9}, 3.811515623110568*^9, {
   3.815923549687028*^9, 3.8159235503123913`*^9}, {3.8164560847134533`*^9, 
   3.816456084847307*^9}},
 CellID->893669267,ExpressionUUID->"89af4d06-3b4e-4da2-951e-6ad05b23dd36"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SeedRandom", "[", "1234", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"listMeans25", ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"RandomChoice", "[", 
       RowBox[{"populationVar", ",", "2"}], "]"}], "]"}]}], "]"}], ",", 
   "25"}], "]"}]}], "Input",
 CellChangeTimes->{{3.753413332689181*^9, 3.7534133575457277`*^9}},
 CellLabel->"In[7]:=",
 CellID->45448408,ExpressionUUID->"bcd16f31-e701-4789-b65b-4ec4f07127e6"],

Cell["Finally, create a histogram of the sampling means:", "CodeCaption",
 CellChangeTimes->{{3.7534130062163725`*^9, 3.753413018423707*^9}, {
  3.810921382342496*^9, 3.8109213830105624`*^9}, {3.811261979097154*^9, 
  3.811261979727217*^9}},
 CellID->721492811,ExpressionUUID->"f173802e-7810-46d0-8458-378a420e734b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"listMeans25", ",", 
   RowBox[{"{", "10", "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Histogram of 25 Mean Values\>\""}], 
   ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Mean\>\"", ",", "\"\<Count\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.753413021003808*^9, 3.753413070976372*^9}, 
   3.753413135610562*^9, {3.8109218437556324`*^9, 3.810921847432*^9}},
 CellLabel->"In[9]:=",
 CellID->157956967,ExpressionUUID->"4d469962-c532-4289-add4-b0eff69c0ea7"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.651], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.651], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{20., 0}, {30., 2.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{16.948959167333875`, 54.438550840672555`}, {
           38.8283224498609, 63.93546034594442}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 2]& ,
        TagBoxNote->"2"],
       StyleBox["2", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[2, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{30., 0}, {40., 4.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{53.938550840672555`, 91.42814251401123}, {
           14.221184553777384`, 63.93546034594442}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 4]& ,
        TagBoxNote->"4"],
       StyleBox["4", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[4, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{40., 0}, {50., 9.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{90.92814251401123, 
           128.4177341873499}, {-47.29666018643141, 63.93546034594442}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 9]& ,
        TagBoxNote->"9"],
       StyleBox["9", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[9, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{50., 0}, {60., 6.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{127.91773418734991`, 
           165.4073258606886}, {-10.385953342306138`, 63.93546034594442}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 6]& ,
        TagBoxNote->"6"],
       StyleBox["6", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[6, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{60., 0}, {70., 4.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{164.9073258606886, 202.39691753402724`}, {
           14.221184553777384`, 63.93546034594442}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 4]& ,
        TagBoxNote->"4"],
       StyleBox["4", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[4, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Mean\"", TraditionalForm], 
    FormBox["\"Count\"", TraditionalForm]},
  AxesOrigin->{19., 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotLabel->FormBox["\"Histogram of 25 Mean Values\"", TraditionalForm],
  PlotRange->{{20., 70.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7534130727975044`*^9, {3.753413111572831*^9, 3.7534131375533953`*^9}, {
   3.7534133461352367`*^9, 3.753413361294704*^9}, {3.8109218494802046`*^9, 
   3.8109218753587923`*^9}, 3.812470369607328*^9, 3.812712419446167*^9},
 CellLabel->"Out[9]=",
 CellID->354957032,ExpressionUUID->"6cc05983-b826-4519-9e22-90616c785317"]
}, Open  ]],

Cell["\<\
This process reflects what we do in real life when conducting research. We \
take individuals from a larger population and generate statistics such as a \
mean and a standard deviation. If we started our research one day later, we \
would have had a different sample set. So many things could influence each \
data point value.\
\>", "Text",
 CellChangeTimes->{{3.711025282351228*^9, 3.711025449431779*^9}, {
   3.753413167624039*^9, 3.7534131716722155`*^9}, 3.8112621249187346`*^9, {
   3.811516088712452*^9, 3.811516088889023*^9}},
 CellID->37477650,ExpressionUUID->"eab167d4-9121-46ef-8d49-d0f6a5238091"],

Cell["\<\
The point we are repeating here is that whatever test statistic we calculate \
from a sample, it is but one of many that could have possibly occurred.\
\>", "Text",
 CellChangeTimes->{{3.753413186768851*^9, 3.7534131928167076`*^9}, 
   3.810921923978654*^9},
 CellID->330709172,ExpressionUUID->"6110bf8e-ef19-4e53-a2d1-36a846e9f0a2"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s carry on with our example to illustrate this \
further. Instead of taking two, we will take ",
 Cell[BoxData[
  FormBox["30", TraditionalForm]],ExpressionUUID->
  "c31ba55e-2487-4662-91a0-63bee9b3062c"],
 " individuals at random from our population and calculate the mean of those. "
}], "Text",
 CellChangeTimes->{{3.753413209673607*^9, 3.7534132541317396`*^9}, {
   3.810922946202866*^9, 3.8109229539856443`*^9}, 3.811516088977476*^9},
 CellID->196911225,ExpressionUUID->"09883574-bd90-4424-a69e-40b9c7d41f92"],

Cell[TextData[{
 "Repeat this ",
 Cell[BoxData[
  FormBox["500", TraditionalForm]],ExpressionUUID->
  "9173b672-c842-4fab-9048-5ba3a783fd2f"],
 " times and plot the histogram of all ",
 Cell[BoxData[
  FormBox["500", TraditionalForm]],ExpressionUUID->
  "ca8b08d2-3161-4f0d-b5ad-0bf0875f1e2c"],
 " sample means:"
}], "CodeCaption",
 CellChangeTimes->{{3.8109229473939853`*^9, 3.810922957922038*^9}, 
   3.8111860775171127`*^9, 3.8112621461748605`*^9},
 CellID->787513336,ExpressionUUID->"9c34b4cf-3b48-4af8-8d28-1c14d6605d01"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SeedRandom", "[", "1234", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"listMeans500", "=", 
   RowBox[{"List", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"AppendTo", "[", 
    RowBox[{"listMeans500", ",", 
     RowBox[{"Mean", "[", 
      RowBox[{"RandomChoice", "[", 
       RowBox[{"populationVar", ",", "30"}], "]"}], "]"}]}], "]"}], ",", 
   "500"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Histogram", "[", 
  RowBox[{"listMeans500", ",", 
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Histogram of 500 mean values\>\""}], 
   ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Mean\>\"", ",", "\"\<Count\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7534132758167653`*^9, 3.7534133190097513`*^9}, {
  3.753413366352188*^9, 3.7534133740406313`*^9}, {3.812470406505837*^9, 
  3.812470409596404*^9}, {3.8124704760560913`*^9, 3.812470478830923*^9}},
 CellLabel->"In[10]:=",
 CellID->349814719,ExpressionUUID->"8171b89a-dddc-41d0-bcc3-3386275828ee"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.5389999999999999], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.5389999999999999], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{38., 0}, {39., 1.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{22.91573258606877, 45.23890541004232}, {
           145.91087595498774`, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{39., 0}, {40., 2.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{44.73890541004232, 67.06207823401576}, {
           141.93427354625874`, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 2]& ,
        TagBoxNote->"2"],
       StyleBox["2", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[2, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{40., 0}, {41., 3.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{66.56207823401576, 88.8852510579892}, {
           137.9576711375297, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 3]& ,
        TagBoxNote->"3"],
       StyleBox["3", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[3, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{42., 0}, {43., 8.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{110.20842388196263`, 132.53159670593607`}, {
           118.07465909388459`, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 8]& ,
        TagBoxNote->"8"],
       StyleBox["8", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[8, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{43., 0}, {44., 19.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{132.03159670593607`, 154.35476952990962`}, {
           74.33203259786534, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 19]& ,
        TagBoxNote->"19"],
       StyleBox["19", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[19, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{44., 0}, {45., 32.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{153.85476952990962`, 176.17794235388305`}, {
           22.636201284388022`, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 32]& ,
        TagBoxNote->"32"],
       StyleBox["32", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[32, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{45., 0}, {46., 33.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{175.67794235388305`, 198.0011151778565}, {
           18.659598875658986`, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 33]& ,
        TagBoxNote->"33"],
       StyleBox["33", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[33, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{46., 0}, {47., 42.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{197.5011151778565, 
           219.82428800182993`}, {-17.129822802902225`, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 42]& ,
        TagBoxNote->"42"],
       StyleBox["42", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[42, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{47., 0}, {48., 49.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{219.32428800182993`, 
           241.64746082580336`}, {-44.96603966400539, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 49]& ,
        TagBoxNote->"49"],
       StyleBox["49", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[49, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{48., 0}, {49., 69.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{241.14746082580336`, 
           263.4706336497768}, {-124.49808783858586`, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 69]& ,
        TagBoxNote->"69"],
       StyleBox["69", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[69, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{49., 0}, {50., 62.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{262.9706336497768, 
           285.29380647375024`}, {-96.66187097748269, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 62]& ,
        TagBoxNote->"62"],
       StyleBox["62", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[62, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{50., 0}, {51., 50.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{284.79380647375024`, 
           307.1169792977239}, {-48.9426420727344, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 50]& ,
        TagBoxNote->"50"],
       StyleBox["50", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[50, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{51., 0}, {52., 50.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{306.6169792977239, 
           328.94015212169734`}, {-48.9426420727344, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 50]& ,
        TagBoxNote->"50"],
       StyleBox["50", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[50, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{52., 0}, {53., 31.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{328.44015212169734`, 350.7633249456708}, {
           26.612803693117044`, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 31]& ,
        TagBoxNote->"31"],
       StyleBox["31", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[31, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{53., 0}, {54., 19.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{350.2633249456708, 372.5864977696442}, {
           74.33203259786534, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 19]& ,
        TagBoxNote->"19"],
       StyleBox["19", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[19, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{54., 0}, {55., 19.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{372.0864977696442, 394.40967059361765`}, {
           74.33203259786534, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 19]& ,
        TagBoxNote->"19"],
       StyleBox["19", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[19, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{55., 0}, {56., 7.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{393.90967059361765`, 416.2328434175911}, {
           122.05126150261361`, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 7]& ,
        TagBoxNote->"7"],
       StyleBox["7", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[7, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{56., 0}, {57., 3.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{415.7328434175911, 438.0560162415645}, {
           137.9576711375297, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 3]& ,
        TagBoxNote->"3"],
       StyleBox["3", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[3, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{58., 0}, {59., 1.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{459.37918906553796`, 481.7023618895114}, {
           145.91087595498774`, 150.38747836371678`}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], 
       "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Mean\"", TraditionalForm], 
    FormBox["\"Count\"", TraditionalForm]},
  AxesOrigin->{37.58, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{525., Automatic},
  PlotLabel->FormBox["\"Histogram of 500 mean values\"", TraditionalForm],
  PlotRange->{{38., 59.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7534133090793605`*^9, 3.7534133751905503`*^9, 3.8109218758478413`*^9, {
   3.8124703472723217`*^9, 3.812470375534687*^9}, 3.8124704107712517`*^9, 
   3.8124705332386637`*^9, 3.8127124199721146`*^9},
 CellLabel->"Out[13]=",
 CellID->227566065,ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
144.],ExpressionUUID->"1c2a57a3-1b16-4981-b5d1-ef9d15bf8442"]
}, Open  ]],

Cell["\<\
Low and behold, the sampling distribution of possible sample means is just \
about normally distributed, even when taking it from an original distribution \
that was not nearly normally distributed at all!\
\>", "Text",
 CellChangeTimes->{{3.753413394272561*^9, 3.7534134227124968`*^9}, {
  3.815923632446085*^9, 3.815923632878459*^9}},
 CellID->429891302,ExpressionUUID->"e1fe7475-7424-4126-ad2e-6285dfe3444b"],

Cell["\<\
What you will also notice is that the mean of the sample means also starts to \
cluster around the actual population mean. When taking a sample of subjects \
from a population, it is much more common to get a mean from your sample that \
is close to the population mean than it is to get one that is very different. \
The probability of getting a mean far removed from the population mean \
actually becomes smaller.\
\>", "Text",
 CellChangeTimes->{
  3.753413434855027*^9, {3.753413466359793*^9, 3.753413469640025*^9}, {
   3.810923001438389*^9, 3.8109230032515707`*^9}, {3.8112622681900606`*^9, 
   3.8112622946147027`*^9}, {3.8115160890667667`*^9, 3.811516089165743*^9}, {
   3.812016170691296*^9, 3.81201617156172*^9}, 3.815923639398761*^9, {
   3.815923684014473*^9, 3.8159236867182426`*^9}},
 CellID->144575498,ExpressionUUID->"a519763c-e045-4e1b-b947-16427cfc9a8f"],

Cell["\<\
Let\[CloseCurlyQuote]s find the standard deviation of the small and large \
sample sizes. \
\>", "Text",
 CellChangeTimes->{
  3.7534134891847963`*^9, {3.8109230254767923`*^9, 3.8109230493931837`*^9}},
 CellID->406642659,ExpressionUUID->"6a7ae834-b2c9-4791-abf9-ff9552812cc5"],

Cell[TextData[{
 "Use the ",
 ButtonBox["@",
  BaseStyle->"Link",
  ButtonData->"Prefix"],
 " shorthand to apply the function to more than one ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object using the ",
 Cell[BoxData[
  ButtonBox[
   RowBox[{"//", "\[NegativeThinSpace]", 
    ButtonBox["N",
     BaseStyle->"CodeLink"]}],
   BaseStyle->"Link",
   ButtonData->"Postfix"]],ExpressionUUID->
  "946d09f1-21bd-481b-93db-215cd9b0540d"],
 " postfix to return numerical values:"
}], "CodeCaption",
 CellChangeTimes->{{3.8109230654847927`*^9, 3.8109231729905424`*^9}, {
   3.815923700541587*^9, 3.8159237138370647`*^9}, {3.8159237438403807`*^9, 
   3.8159237560203533`*^9}, 3.815923833817211*^9, 3.816456278704145*^9},
 CellID->563536974,ExpressionUUID->"1e2d2853-67c8-4ccd-a005-4e6d5bc12bd7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StandardDeviation", "/@", 
   RowBox[{"{", 
    RowBox[{"listMeans25", ",", "listMeans500"}], "}"}]}], "//", 
  "N"}]], "Input",
 CellLabel->"In[14]:=",
 CellID->129481955,ExpressionUUID->"9b557bf4-0020-4d7a-8652-3d5819bf8b1c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"12.029200583025734`", ",", "3.213203596141407`"}], "}"}]], "Output",
 CellChangeTimes->{3.7534135701243577`*^9, 3.810921876287885*^9, 
  3.8124704290296793`*^9, 3.8127124202440877`*^9},
 CellLabel->"Out[14]=",
 CellID->780822920,ExpressionUUID->"888532d8-2761-4627-b208-8f0f034117b0"]
}, Open  ]],

Cell[TextData[{
 "Notice how it is much smaller than the sampling standard deviation is for \
the larger number of sample means. When dealing with the standard deviation \
of the distribution of a statistic, we actually use the ",
 StyleBox["standard error",
  FontSlant->"Italic"],
 " and not the standard deviation. Standard error and standard deviation are \
usually quite similar; the difference is that standard deviation is \
calculated with the parameters of the population data and standard error uses \
statistics from the sample data. It is calculated as shown in the equation \
below."
}], "Text",
 CellChangeTimes->{{3.753413583145544*^9, 3.7534136213284826`*^9}, {
   3.810923648625101*^9, 3.810923710109249*^9}, {3.8109237663508725`*^9, 
   3.8109237766329007`*^9}, {3.8112623552287636`*^9, 3.811262358441085*^9}, {
   3.811516089256998*^9, 3.811516089355537*^9}, 3.815923372567287*^9, {
   3.815923891391938*^9, 3.815923912407835*^9}, 3.815924078600114*^9},
 CellID->760237709,ExpressionUUID->"81d19886-3d18-4c2b-b37f-50d33b1004fb"],

Cell[BoxData[
 FormBox[GridBox[{
    {
     RowBox[{
      SubscriptBox["\[Sigma]", 
       OverscriptBox["x", "_"]], "=", 
      FractionBox["\[Sigma]", 
       SqrtBox["n"]]}]}
   },
   GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}], TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.8159239600037117`*^9, 3.815924004559532*^9}},
 CellID->158547233,ExpressionUUID->"9fa039c0-b3a7-482c-b270-7d88f475979a"],

Cell[TextData[{
 "It is simply the standard deviation divided by the square root of the \
sample size. Just for fun, let\[CloseCurlyQuote]s calculate the mean and \
standard error of the sample means so that we can create a probability \
density curve. We will use the computer variables ",
 Cell[BoxData[
 "\[Mu]"], "InlineCodeText",ExpressionUUID->
  "3053a22f-413d-4913-91d1-bc5ec3a5da83"],
 " for the mean and ",
 Cell[BoxData[
 "se"], "InlineCodeText",ExpressionUUID->
  "3f690ebf-76dc-45c2-8f98-d43b1732585d"],
 " for the standard error."
}], "Text",
 CellChangeTimes->{
  3.7534136473817935`*^9, {3.8109237987761145`*^9, 3.8109238042146587`*^9}, {
   3.811516089458062*^9, 3.8115160895590076`*^9}, {3.815924136184134*^9, 
   3.8159241442800837`*^9}, 3.8164563152629833`*^9},
 CellID->626117696,ExpressionUUID->"dee37d0a-ff52-4ac6-888a-9689d3afdb1e"],

Cell["Calculate the mean and standard error:", "CodeCaption",
 CellChangeTimes->{{3.8109238461898556`*^9, 3.810923848545091*^9}, {
  3.811262393485589*^9, 3.8112623946387043`*^9}},
 CellID->50415205,ExpressionUUID->"a2e50c82-713a-40b9-bc53-7443e8436bc4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Mu]", "=", 
   RowBox[{"Mean", "[", "listMeans500", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"se", "=", 
   FractionBox[
    RowBox[{"StandardDeviation", "[", "listMeans500", "]"}], 
    RowBox[{"Sqrt", "[", "500", "]"}]]}], ";"}]}], "Input",
 CellLabel->"In[15]:=",
 CellID->196727227,ExpressionUUID->"dc18d20d-a339-4353-8c4a-9dfbfa188513"],

Cell["Plot the distribution of the sample mean:", "CodeCaption",
 CellChangeTimes->{{3.8109239347867146`*^9, 3.8109239708560405`*^9}},
 CellID->798899445,ExpressionUUID->"99012c1d-28e1-48aa-befb-22bd1b480635"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"PDF", "[", 
     RowBox[{
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"\[Mu]", ",", "se"}], "]"}], ",", "x"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "48", ",", "50"}], "}"}], ",", 
    RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.812470436767828*^9, 3.812470437327725*^9}},
 CellLabel->"In[17]:=",
 CellID->282996700,ExpressionUUID->"256c81e4-5d5e-405d-bc33-4e36507b6cd1"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJw1nHc8Vv3/x2WvbJLslZGZzTmfg9LJykgJFSVlC0myRWZmSBnZyigZkZBV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    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl12XAVeUahOFP6U6LFJOQ7m5Qurs7RQUMurvboBsE7CCVLovuTuPYLXqu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         "]]]}, {}, {}}, {{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl2AW0FQUbheEr3d0pJo00AtIqobR0NxYqGISCQYctjUmZKN0gKN3dIALS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         "]]},
       Annotation[#, "Charting`Private`Tag$29851#1"]& ]}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{478., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.753413726006573*^9, 3.8109218788211384`*^9, 
  3.812470438478449*^9, 3.8127124212929826`*^9},
 CellLabel->"Out[17]=",
 CellID->406591281,ExpressionUUID->"c6db65e6-699a-440e-8747-0e23b6eb0836"]
}, Open  ]],

Cell["\<\
We are getting closer and closer to understanding inferential statistics. Let\
\[CloseCurlyQuote]s put this knowledge of the central limit theorem to work \
by looking at confidence levels.\
\>", "Text",
 CellChangeTimes->{
  3.7534137543128967`*^9, {3.81126402046027*^9, 3.811264023015526*^9}, 
   3.8115160896613493`*^9},
 CellID->133172123,ExpressionUUID->"7df5561c-b38c-4fd0-afa3-ec137e94f408"],

Cell[TextData[{
 "On the plot below, we overlay a density histogram of sample means with the \
probability density of ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["NormalDistribution",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{"\[Mu]", ",", "\[Sigma]"}], "]"}]], "InlineCodeText",
  ExpressionUUID->"339cac6c-85b2-4e20-b226-968817216949"],
 ", where \[Mu] is equal to ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Mean",
    BaseStyle->"CodeLink"], "[", "listMeans500", "]"}]], "InlineCodeText",
  ExpressionUUID->"07d17f64-6b5c-4be3-b586-a88cafd465cc"],
 " and \[Sigma] is equal to ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["StandardDeviation",
    BaseStyle->"CodeLink"], "[", "listMeans500", "]"}]], "InlineCodeText",
  ExpressionUUID->"43f3ebf1-c4f0-44b1-bcce-c22e4c67e0e9"],
 "."
}], "Text",
 CellChangeTimes->{
  3.7534137543128967`*^9, {3.81126402046027*^9, 3.811264023015526*^9}, 
   3.8115160896613493`*^9, {3.812711065007272*^9, 3.812711106223629*^9}, {
   3.815924162486609*^9, 3.8159241855755367`*^9}, {3.815924240719487*^9, 
   3.815924241031101*^9}, {3.815924301305934*^9, 3.815924330771616*^9}, {
   3.815924405295711*^9, 3.8159244052958183`*^9}, {3.815924699785446*^9, 
   3.81592472205549*^9}, {3.81592488446189*^9, 3.8159248884056063`*^9}, {
   3.8164563605573063`*^9, 3.816456363894886*^9}},
 CellID->208166193,ExpressionUUID->"a4272fa3-9cbd-4413-a3d9-3dbdb8825e31"],

Cell[TextData[{
 "Note that ",
 ButtonBox["AxesLabel",
  BaseStyle->"Link"],
 " assumes an ",
 StyleBox["x",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y",
  FontSlant->"Italic"],
 " order for labeling:"
}], "CodeCaption",
 CellChangeTimes->{{3.812712515818529*^9, 3.8127125440777025`*^9}, 
   3.8127171559692345`*^9, 3.8159249674375668`*^9},
 CellID->807656970,ExpressionUUID->"92f737b8-2ab0-428c-a960-333652841261"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Histogram", "[", 
    RowBox[{"listMeans500", ",", "Automatic", ",", "PDF", ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Histogram of 500 Mean Values\>\""}],
      ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Mean\>\"", ",", "\"\<Count\>\""}], "}"}]}]}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"PDF", "[", 
      RowBox[{
       RowBox[{"NormalDistribution", "[", 
        RowBox[{"\[Mu]", ",", 
         RowBox[{"StandardDeviation", "[", "listMeans500", "]"}]}], "]"}], 
       ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "38", ",", "70"}], "}"}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.812470458015882*^9, 3.812470524389173*^9}, {
  3.8124705845176487`*^9, 3.8124706056668673`*^9}, {3.8127112627975845`*^9, 
  3.812711267451851*^9}},
 CellLabel->"In[18]:=",
 CellID->1318686354,ExpressionUUID->"f9d3087d-6b16-447e-b494-386d48de5b7d"],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.5389999999999999], Thickness[Small]}], {}, 
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.5389999999999999], Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{38., 0}, {39., 0.002}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{27.548588871096854`, 41.854752849899}, {
            94.15354835335911, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.002]& ,
         TagBoxNote->"0.002"],
        StyleBox["0.002`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.002, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{39., 0}, {40., 0.004}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{41.354752849899, 55.66091682870115}, {
            91.63779936597534, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.004]& ,
         TagBoxNote->"0.004"],
        StyleBox["0.004`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.004, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{40., 0}, {41., 0.006}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{55.16091682870115, 69.46708080750318}, {
            89.12205037859157, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.006]& ,
         TagBoxNote->"0.006"],
        StyleBox["0.006`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.006, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{42., 0}, {43., 0.016}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{82.77324478630533, 97.07940876510747}, {
            76.54330544167269, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.016]& ,
         TagBoxNote->"0.016"],
        StyleBox["0.016`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.016, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{43., 0}, {44., 0.038}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{96.57940876510747, 110.88557274390962`}, {
            48.87006658045116, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.038]& ,
         TagBoxNote->"0.038"],
        StyleBox["0.038`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.038, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{44., 0}, {45., 0.064}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{110.38557274390962`, 124.69173672271165`}, {
            16.16532974446207, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.064]& ,
         TagBoxNote->"0.064"],
        StyleBox["0.064`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.064, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{45., 0}, {46., 0.066}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{124.19173672271165`, 138.4979007015138}, {
            13.649580757078297`, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.066]& ,
         TagBoxNote->"0.066"],
        StyleBox["0.066`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.066, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{46., 0}, {47., 0.084}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{137.9979007015138, 
            152.30406468031595`}, {-8.99216012937569, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.084]& ,
         TagBoxNote->"0.084"],
        StyleBox["0.084`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.084, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{47., 0}, {48., 0.098}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{151.80406468031595`, 
            166.11022865911798`}, {-26.602403041062104`, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.098]& ,
         TagBoxNote->"0.098"],
        StyleBox["0.098`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.098, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{48., 0}, {49., 0.138}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{165.61022865911798`, 
            179.91639263792013`}, {-76.91738278873761, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.138]& ,
         TagBoxNote->"0.138"],
        StyleBox["0.138`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.138, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{49., 0}, {50., 0.124}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{179.41639263792013`, 
            193.72255661672227`}, {-59.30713987705117, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.124]& ,
         TagBoxNote->"0.124"],
        StyleBox["0.124`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.124, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{50., 0}, {51., 0.1}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{193.22255661672227`, 
            207.52872059552442`}, {-29.11815202844589, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.1]& ,
         TagBoxNote->"0.1"],
        StyleBox["0.1`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.1, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{51., 0}, {52., 0.1}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{207.02872059552442`, 
            221.33488457432645`}, {-29.11815202844589, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.1]& ,
         TagBoxNote->"0.1"],
        StyleBox["0.1`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.1, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{52., 0}, {53., 0.062}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{220.83488457432645`, 235.1410485531286}, {
            18.681078731845858`, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.062]& ,
         TagBoxNote->"0.062"],
        StyleBox["0.062`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.062, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{53., 0}, {54., 0.038}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{234.6410485531286, 248.94721253193075`}, {
            48.87006658045116, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.038]& ,
         TagBoxNote->"0.038"],
        StyleBox["0.038`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.038, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{54., 0}, {55., 0.038}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{248.44721253193075`, 262.7533765107329}, {
            48.87006658045116, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.038]& ,
         TagBoxNote->"0.038"],
        StyleBox["0.038`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.038, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{55., 0}, {56., 0.014}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{262.2533765107329, 276.5595404895349}, {
            79.05905442905646, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.014]& ,
         TagBoxNote->"0.014"],
        StyleBox["0.014`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.014, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{56., 0}, {57., 0.006}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{276.0595404895349, 290.36570446833707`}, {
            89.12205037859157, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.006]& ,
         TagBoxNote->"0.006"],
        StyleBox["0.006`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.006, {}], "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        TagBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{58., 0}, {59., 0.002}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{303.6718684471392, 317.97803242594125`}, {
            94.15354835335911, 97.16929734074289}}],
          "DelayedMouseEffectStyle"],
         StatusArea[#, 0.002]& ,
         TagBoxNote->"0.002"],
        StyleBox["0.002`", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[0.002, {}], 
        "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}}}, {GraphicsComplexBox[CompressedData["
1:eJw1mnk4VP///pFUROUthFS2kCWSbHNeT2YwzHYGRRSyZC9ki5JsochWFIpQ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     "], {{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
        GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1mW0VVUUQGF4dDdIp9ItqYRISwkGjYBFKCiNKEo3dhG2UtJg0Z0GqHR3
Slikfkt/zLHXnOc+eIO9z74U7NKr5bMJiRIlSozbCf+vtxL+nyuYb1ofxe/4
1sNm1nO4y/wh7jb/hDk+u5Q3Np/CTd6fpzZ/gfY8G5+MwnwVRmmzeS3zfvzK
W/DjeIWX53eaP0BF/iNma0t4I/NJ3OD9eCrz52jHs/JJKMRXYqQ2i9c078Mv
vDk/hpd5OV7EPB0V+A+YpS3mDc0ncJ335SnNn6Etz8InoiBfgRHaTF7DvBc/
82b8KIbysryweRrK8+8xU1vEG5iP4xrvw1OYP0UbnplPQAG+HMO1Gfxe8x7s
5E35EbzEy/BC5qkox7djhraQ1zcfw9/8eZ7c/Ala80x8PPLzZRimfcHvMe/G
Dt6EH8aLvDQvaJ6Csnxb7LW2gNczH8Vf/DmezPxxnCWekY9DPv4dXtE+59XN
u+I88Qf4IQzhpXgB8/sow7fGXmvzeV3zEfzJe/Ok5o/wCM/AxyJvnF28rH3G
q8VZi/PEG/ODeIGX5PnN76E03xJ7rc3j95sP4w/eiycxf4iHeXo+Bnn4Nxiq
fcqrxlmL88Qb8QMYzEvwfOZ3UYpvjr3W5vI65kPxvvFneYL5AzzE0/HRyM2/
xkvaJ7xKnLU4T7wh349BvDjPa34HJfmm2GvtKp7REvPpaMXT8lHIxb/Ci9p2
NND2YaBWjOcxv40SfGPsqXYFPePi4NPQ0piGj0ROvhRDtG2or+3FAK0oz21+
C8X5htg77TJ6aP/EGdYe5KnNI3AHX4IXtK2op+1B/7iTeC7zmyjG18ceaZfQ
XbsdZ1VrwVOZhyMHX4zB2hbU1Xajn3Ynz2l+A0X5utgL7Td0027FmdSa85Tm
YcjOF2GQthn3a7vQVyvCp+MintZuxlnTm/EUcechG1+Igdom1NF+RR+tMJ+G
C3hKuxFnSG/Kk8ddhqx8AQZoG3Gf9gue1wrxqTiPJ7XrcTb0JjxZ3FHIwuej
v7YBtbWf8ZxWkE/BOTyhXYuzoD/Ak8bdg8x8Hvpp61FL24neWgH+Ps7ice3v
2Hu9MU8Sdwoy8bnoq61DTW0Hemn5+Xs4g67aX7HXeqO4M7EWNbSfEF9q+fi7
OI0u2p+xl3rDuPuwBvdqP+IZPS9/B6fQWfsDr+sN4g7Datyj/YCeeh7+Nk7i
Me13vKbXj7sIq1Bd+x499Nz8LZxAJ+0qXtXrxZ2ClaimbUd3PRd/E8fRUbuC
yXrduBuwAlW1beim5+R3IAeyI1ucv3jXsRxVfG4rnvbZrPwNHEMH7TIm6XXi
XcYyVNa24Ck9S/zZ8e+Bu/havK4dRXvtEiZq98U1YB6CjPxL9NA+5pXNO+PO
5y2sF1BJ34wnzZn1R6xX4x7VmlrPIoe5lfUSXot9jHcTa8L9zPW4H3E5/r44
F/F74GB8N3h+Le4QXES72Ffrb9YJ1tqe34h7HFfi7otzGWcap5GYt4zPx51j
zmCdg+5+7iNeybwD3/Lm1vO4W9+EJ8yZ9K/NTcxnkD32HEXMq/Gq53N4bfMB
HOZt+UWM57V4/KdsMNLz2egmfYOK2kY8rmXkk3EIbbQLGKfXjLsmfgdU0Dag
q56BT8JBtNbOY6xeI+4WfIXy2np00dPzdEiLNPHexB2CpSjnM+vQ2edSxzsS
9wOWoKy+Fo95lireh3j3sRhl9DXo5FlKPhEH8Kh2DmP0avGuYxFKa6vRUU/B
J2B/nBntLEbrVeNdx0KU0lahg56cj8c+PKydwSi9SrzrWICS2kq015PxcdiL
h7TTGKlXjncd81FCW4F2elI+FnvQSjuFEXG++T8YxNPxWejE56G4thxttSR8
DHajpXYSw+Ms8dsYyNPymejI56KYtgxtEv776k00GrvwoHYCw8SK/BYG8DR8
BjrwL1FU+w6ttX8BWO+DRA==
          "]]]}, {}, {}}, {{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], LineBox[CompressedData["
1:eJwl1lW4VVUUQOEr3SEhDZeQ7k7pEoNOFVDBxgSLDiVULECwpbtLuru7GxVF
ETBB/efnw2DNMc55OHutvTc3sXuvVs/dkZCQcCtJQkKsHazfGopiFn8IU7W0
6KPd5hUxiF/kLXGYvwUpoaN/VmjFMJs/jGlaOryq/cMrYTC/xFvhCH8bSdFJ
X6kVxxz+CKZr6fGa9i+vjCH8Mm+No3w4kqGzvkorgbm8K6pgqP6d1gbH+Agk
Rxd9tVYS83g3VMUw/XutLY7zkUgR+6Gv0UphPu+OanH9+g9aO5zgo5Ayrl9f
q5XGAv4oqsf16le09jjJ30GquF59nVYGC/ljqIHUcS0+W6+XxSL+OGoiTfxu
n23Qy2Ex74FaSIt0SI8M8Xt9b6PvlMcS3hO1Y//0H7UOOMXfRcb4vfomrQKW
8idQJ/ZP/0nriNP8PWSK36tv1ipiGX8SM7QMeD1uMNwT+8mvmjvhDD/J62Im
H83XmgtjNM+O780tsNScOa7dvMVcCT+aH8ByfZ+1Mr7Sn+IzzRnxBv/Z2iru
c/N31nvxB5bwX61t8Xf8jjg/68/6TWtn61VrS/yJsz4/Za2H3zHL59esbfAX
3vf5OmsR/Bbu81+srXGX+QfrfVhmvm5thzvjzKxbtcr4yfxgPIv6fmsVfK0/
zWeZM+FNngT14v7hv5i74Bz/AOu1u/GBlgNZ4rz5NnMVrODPoH6ct35Newjn
+YfIGuetb9eqYiV/Fg2QDdlxF3IgZ5y17+7wvWpYxZ9Dw7g39F+1h3GBf4Rc
eErfqVXHat4LjTBav649gov8Y+TG0/ourQbW8OfRGO/rN7SuuMTHIE9cm75b
q4m1/AU0ib3Rb2rdcJmPRd64Nn2PVgvr+ItoGnsR56h1j/uGj0O+uD59r1Yb
6/lLaBbXF/eF9mjct/wT5I/r0/dpdbCBv4zZWmb01ZKieVxv3Jfmx+Je4eNR
IK5X3x/PDzbyVzAn7h3005Lh3rj+uE/Nj+MKn4DEuH79gFYXm3hvzNWyoL+W
HC1iP+I+NveIZ4t/ioKxH/rBuN+wmffBPC0rBmgpcF/sTzxH5p5xH/PPUCj2
Rz+k1ccW/irma9kwUEuJ+2O/+C3zE/Hc8c9ROPZLP6w1wFb+GhZo2TFIS4UH
Yr/4bfOT8czzL7BBK4oPtZwoEvvHj5gbYht/HQvjGcVgLTUejP3j/8T7JJ5j
/iU2asXwkZYLd8d+8qPmRtjO38AiLQeGaGnQMvaT/xvPcrw3+FfYpBXHx1pu
FI395cfMjbGDv4nFWk4M1dKiVewvj/98n4n3mPFrbOYlMEbLg2Kx3/y4uQl2
8r5YouXCMC0dWsd+xzsSz8b7iX+DLbwkxmp5UTz2n58wN8UufoBXxTe8H19q
zo23eHq0ibPgSRB/dNzgp831MZtP5FvNpTCO50OJOBd+0twMu/lBXg0TeX++
zJwHb/MMaBtnxJOiF7/Jz5gbYA6fxLeZS+MTnh8l47z4qXgGsYcf4tUxiQ/g
y815MZxnRLs4O54Mz/Pf+FlzQ8zlk/l2cxmM5wVQKs6Rn45nFXv5YV4Dk/lA
/q05H0bwTGgfZ8qT4wX+Oz9nboR5fArfYS6LCTwRpeN8+Zl4prGPH+E1MYUP
4ivM+TGSZ0aHOGueAi/yP/h5c2PM51P5TnM5fMoLoozWj5+NZx/7+VFeC1P5
YL7SXACj+J3oqE3kKfES/5NfMDfBAj6N7zKXx2e8EMpq/fm5eEfgAD/Ga2Ma
H8JXmRPxDs+CTtokngov87/4RXNTLOTT+W5zBXzOC6OcNoCfj3cJDvLjvA6m
86F8tbkg3uVZ0VmbzFPjFf43v2RuhkV8Bt9jrogv4t2D8tpAfiHeMTjET/B7
MIMP42vMhfAez4Yu2hSeBr35LX7Z3ByL+Uy+11wJX8Y7CVfM92N5PG/W9kn+
/1u/gu/+B4BIgUE=
          "]]},
        Annotation[#, "Charting`Private`Tag$32212#1"]& ]}}], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Mean\"", TraditionalForm], 
    FormBox["\"Count\"", TraditionalForm]},
  AxesOrigin->{37.58, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{357.76822916666725`, Automatic},
  PlotLabel->FormBox["\"Histogram of 500 Mean Values\"", TraditionalForm],
  PlotRange->{{38., 59.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.812470462069915*^9, 3.812470524899734*^9}, {
  3.81247059494805*^9, 3.81247060706892*^9}, {3.812712412267885*^9, 
  3.812712423299782*^9}},
 CellLabel->"Out[18]=",
 CellID->55952152,ExpressionUUID->"f1e03f6d-ebeb-468d-9cb9-3fcfcd61f744"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Confidence Levels", "Subsection",
 CellChangeTimes->{{3.753413782784768*^9, 3.7534137856002436`*^9}, 
   3.8109238827995167`*^9},
 CellID->34424452,ExpressionUUID->"50459ced-4e88-4ee0-b86b-ee487214746b"],

Cell[TextData[{
 "If you have read a research paper before, chances are that you have come \
across a confidence interval. Perhaps something like \
\[OpenCurlyDoubleQuote]The mean concentration of substance A was ",
 Cell[BoxData[
  FormBox["30", TraditionalForm]],ExpressionUUID->
  "f608e2d7-22b7-4dc8-a002-6a9ed2a95983"],
 " mmol/L (",
 Cell[BoxData[
  FormBox["95", TraditionalForm]],ExpressionUUID->
  "51998d4e-0f61-46eb-bd14-10e92a9055b9"],
 "% CI ",
 Cell[BoxData[
  FormBox[
   RowBox[{"28.2", "\[Dash]", "31.8"}], TraditionalForm]],ExpressionUUID->
  "8014c8b7-345b-421e-bf9d-a72bb3ee06a7"],
 " mmol/L).\[CloseCurlyDoubleQuote] The confidence level chosen in this \
example was ",
 Cell[BoxData[
  FormBox["95", TraditionalForm]],ExpressionUUID->
  "f76b7208-acf2-4cb9-b5da-8bb3856245b4"],
 "%, resulting in the confidence interval of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"28.2", "\[Dash]", "31.8"}], TraditionalForm]],ExpressionUUID->
  "6e734c42-31c4-4c37-9a0d-43ffe53c240f"],
 " mmol/L."
}], "Text",
 CellChangeTimes->{
  3.75341379448249*^9, {3.811515664172057*^9, 3.811515669019717*^9}, {
   3.811516089769322*^9, 3.811516089879733*^9}, {3.8159250134617033`*^9, 
   3.8159250224852*^9}},
 CellID->9480275,ExpressionUUID->"deee10b9-aeee-46c8-ad2f-144399b61a4a"],

Cell["\<\
Confidence intervals are important in inferential statistics. In our example \
case, we are inferring that the mean from our sample can be used to represent \
the wider population. Therefore, anyone reading our results can use this \
information in their work. Why? Because a confidence of 95% is considered \
statistically sound if
the researchers can demonstrate it.\
\>", "Text",
 CellChangeTimes->{{3.7534138217126894`*^9, 3.7534138535525594`*^9}, {
   3.8109245176992316`*^9, 3.8109246540232315`*^9}, 3.8112627696141977`*^9, {
   3.811516089986375*^9, 3.8115160900984163`*^9}, {3.8159251270773897`*^9, 
   3.8159251274987087`*^9}, 3.815925246740971*^9},
 CellID->36352243,ExpressionUUID->"54142fba-a805-40df-b44c-c85f217ff3aa"],

Cell[TextData[{
 "We have to be careful of a subtle fact here. The ",
 Cell[BoxData[
  FormBox["95", TraditionalForm]],ExpressionUUID->
  "05ccaf2d-f617-4097-94a8-7fc7891791f4"],
 "% confidence interval of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"28.2", "\[Dash]", "31.8"}], TraditionalForm]],ExpressionUUID->
  "fa010290-f9ab-4fad-9b6e-5a637d1b2833"],
 " mmol/L does not mean that we are ",
 Cell[BoxData[
  FormBox["95", TraditionalForm]],ExpressionUUID->
  "092a831c-7272-4463-9875-a36733a21fb1"],
 "% confident that the population mean falls between these two limits. What \
it actually means can be illustrated as follows. Imagine that we ran our \
experiment 100 times and every time we have a different sample, a different \
mean, and different limits for our confidence intervals. If each of these \
were calculated for a confidence level of ",
 Cell[BoxData[
  FormBox["95", TraditionalForm]],ExpressionUUID->
  "0487ff44-7b55-48a2-95d6-5ded5f34feda"],
 "%, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"95", " "}], TraditionalForm]],ExpressionUUID->
  "12547133-ed25-4ad2-a426-c83c32c43129"],
 "of the cases will actually have the population mean within the limits. When \
considering our single experiment, we cannot be sure that ours is one of the ",
 Cell[BoxData[
  FormBox["95", TraditionalForm]],ExpressionUUID->
  "bc219fe9-3608-48d5-a1ef-be8141aa2416"],
 "."
}], "Text",
 CellChangeTimes->{
  3.7534138619909935`*^9, {3.810926162368232*^9, 3.8109261627562313`*^9}, {
   3.8112641804752703`*^9, 3.811264188284051*^9}, {3.811515699859846*^9, 
   3.811515699859888*^9}, {3.811516090207761*^9, 3.8115160906871777`*^9}, {
   3.8159252719247017`*^9, 3.815925272500972*^9}, 3.815925324242737*^9},
 CellID->3168370,ExpressionUUID->"ca958259-729e-4656-855f-d6be3466600e"],

Cell["\<\
So, how do we calculate the confidence interval limits for a particular \
confidence level? As with all things in the Wolfram Language, it is not that \
difficult. It also gives us the opportunity to discuss the difference between \
a sampling distribution and the distribution of our sample.\
\>", "Text",
 CellChangeTimes->{
  3.753413909272581*^9, {3.8112642937135925`*^9, 3.81126429418864*^9}, 
   3.811516090807056*^9, 3.815925376971868*^9},
 CellID->383165176,ExpressionUUID->"0ac88c03-5ae5-421e-b264-98303f271be9"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s create a new population. We will once again imagine \
that there are only ",
 Cell[BoxData[
  FormBox["20000", TraditionalForm]],ExpressionUUID->
  "1af9e0be-d415-4174-830d-836a8405b286"],
 " subjects in this population. We will imagine that a variable that we are \
interested in has a normal distribution in the population. In the code that \
follows, we create the population, storing it in the computer variable ",
 Cell[BoxData[
 "populationVar2"], "InlineCodeText",ExpressionUUID->
  "290d637b-e5bf-430e-a981-8264e4d7d7c6"],
 ", and use the",
 Cell[BoxData[
  RowBox[{" ", 
   ButtonBox["RandomChoice",
    BaseStyle->"Link"]}]], "InlineCodeText",ExpressionUUID->
  "6a3d3b7c-4632-40b8-855c-83606efe7ce3"],
 " function to take a random sample of ",
 Cell[BoxData[
  FormBox["30", TraditionalForm]],ExpressionUUID->
  "3e7edb7a-bf1e-4a8b-89d9-fa0b55feeca7"],
 " subjects from the population."
}], "Text",
 CellChangeTimes->{{3.7534139363671627`*^9, 3.7534139606930933`*^9}, {
  3.8109262358862314`*^9, 3.810926237203232*^9}, {3.8112642457317953`*^9, 
  3.8112642580260243`*^9}, {3.811515720875546*^9, 3.811515721936488*^9}, {
  3.8115160909328938`*^9, 3.8115160911909943`*^9}, {3.815925397964761*^9, 
  3.815925434220314*^9}},
 CellID->51074226,ExpressionUUID->"a8f5cfc9-cf7d-4572-b99a-8203284d2395"],

Cell["\<\
Create a list of values for a variable in a population with a mean of 300 and \
a standard deviation of 15:\
\>", "CodeCaption",
 CellChangeTimes->{{3.810926333170232*^9, 3.8109263432562313`*^9}, {
  3.8109263822022314`*^9, 3.810926387939232*^9}, {3.810929430302637*^9, 
  3.8109294310507116`*^9}},ExpressionUUID->"0bf24a45-ed47-4b37-a219-\
d488899ccc2e"],

Cell[BoxData[{
 RowBox[{"SeedRandom", "[", "123", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"populationVar2", "=", 
   RowBox[{"RandomVariate", "[", 
    RowBox[{
     RowBox[{"NormalDistribution", "[", 
      RowBox[{"300", ",", "15"}], "]"}], ",", "20000"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7534140014511194`*^9, 3.753414015088657*^9}},
 CellLabel->"In[19]:=",
 CellID->261097792,ExpressionUUID->"1d8abaed-c30e-4e50-a7b5-931e18870d76"],

Cell["\<\
Take 30 samples from our population but do not suppress the output:\
\>", "CodeCaption",
 CellChangeTimes->{{3.8109294149661036`*^9, 3.810929425370144*^9}, {
  3.810929458610467*^9, 3.8109294625828643`*^9}, {3.8159262832476473`*^9, 
  3.815926290832356*^9}, {3.816456408668108*^9, 3.816456410718822*^9}},
 CellID->551294921,ExpressionUUID->"0bb4eaff-56ab-4014-801e-4a5a6fe9c0c2"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SeedRandom", "[", "123", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ourSample", "=", 
  RowBox[{"RandomChoice", "[", 
   RowBox[{"populationVar2", ",", "30"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7534140337946415`*^9, 3.7534140479607706`*^9}},
 CellLabel->"In[21]:=",
 CellID->306621083,ExpressionUUID->"0ec01a6d-8c35-4c35-a159-f20ca74d5cfa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "269.30958350888665`", ",", "331.6033527278347`", ",", "313.0092747698598`",
    ",", "304.0340120937012`", ",", "302.5427796478849`", ",", 
   "312.9844805436289`", ",", "309.7722977476006`", ",", 
   "291.61489928376284`", ",", "273.65963729059956`", ",", 
   "284.4805099815898`", ",", "327.4355850968835`", ",", "280.7011301914167`",
    ",", "284.0103172906011`", ",", "327.41360784055206`", ",", 
   "313.38306541750705`", ",", "310.45310283074974`", ",", 
   "301.1450825443554`", ",", "310.8217858841463`", ",", "319.8409456451008`",
    ",", "333.7117138527976`", ",", "291.7630602113766`", ",", 
   "280.4447627600447`", ",", "307.1315128369964`", ",", 
   "314.65707088150697`", ",", "301.4028777700769`", ",", 
   "312.15024814910396`", ",", "290.9418111030977`", ",", 
   "300.1089098513706`", ",", "282.8293277044575`", ",", 
   "298.05717230321864`"}], "}"}]], "Output",
 CellChangeTimes->{3.7534140493999166`*^9, 3.8109218792441807`*^9, 
  3.8124709316293297`*^9, 3.8127124236037517`*^9},
 CellLabel->"Out[22]=",
 CellID->472562108,ExpressionUUID->"a1896b35-993b-42c4-807f-9ea4147ce8b1"]
}, Open  ]],

Cell[TextData[{
 "Start with the ",
 ButtonBox["Mean",
  BaseStyle->"Link"],
 " for our sample:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7534140635286055`*^9, {3.8109295385504603`*^9, 3.8109295933439393`*^9}},
 CellID->113048072,ExpressionUUID->"b74d624a-06d9-46fe-b828-2feca2198e55"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mean", "[", "ourSample", "]"}]], "Input",
 CellChangeTimes->{{3.7534140667071037`*^9, 3.753414072344035*^9}},
 CellLabel->"In[23]:=",
 CellID->152780421,ExpressionUUID->"cfb1cb72-d42b-4d65-aac4-4a54294fb9bd"],

Cell[BoxData["302.7137972586904`"], "Output",
 CellChangeTimes->{3.7534140730880995`*^9, 3.810921879484205*^9, 
  3.812470933866234*^9, 3.8127124238357286`*^9},
 CellLabel->"Out[23]=",
 CellID->11360799,ExpressionUUID->"be15b60f-f94d-41d4-953b-18b71a15f4c8"]
}, Open  ]],

Cell[TextData[{
 "We note the difference between our sample mean and the population mean. We \
wish to infer if this result will hold for the real population, which we know \
to be ",
 Cell[BoxData[
  FormBox["300", TraditionalForm]],ExpressionUUID->
  "7c4d0870-b950-49fd-a988-adc87359bf65"],
 " since we were the creators of the population. "
}], "Text",
 CellChangeTimes->{
  3.7534140898462367`*^9, {3.753414123808444*^9, 3.753414141032383*^9}, {
   3.8109296321148157`*^9, 3.8109296496805725`*^9}, 3.81092971736734*^9, {
   3.811501333409717*^9, 3.8115013355888414`*^9}, {3.811516091320361*^9, 
   3.811516091463307*^9}, 3.815926344144311*^9},
 CellID->13380602,ExpressionUUID->"f7869b7c-3e2c-4374-8040-5d26982dcb5f"],

Cell["To do so, let\[CloseCurlyQuote]s look at the standard deviation:", \
"CodeCaption",
 CellChangeTimes->{{3.810929724454049*^9, 3.8109297313697405`*^9}},
 CellID->91562945,ExpressionUUID->"98d8f1c1-91de-4cdd-ab8d-b93e5f44b9c9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardDeviation", "[", "ourSample", "]"}]], "Input",
 CellChangeTimes->{{3.7534141514106345`*^9, 3.7534141588567276`*^9}},
 CellLabel->"In[24]:=",
 CellID->101081222,ExpressionUUID->"030622bd-0006-47cc-9949-b15fe6e15b50"],

Cell[BoxData["17.116504968104294`"], "Output",
 CellChangeTimes->{3.7534141590821185`*^9, 3.810921879767233*^9, 
  3.812470935499362*^9, 3.8127124240637054`*^9},
 CellLabel->"Out[24]=",
 CellID->106894639,ExpressionUUID->"2c35a8cc-bbea-42d4-9618-ba4f88f3967d"]
}, Open  ]],

Cell[TextData[{
 "Visualize it using ",
 ButtonBox["Histogram",
  BaseStyle->"Link"],
 " with a bin size of 10:"
}], "CodeCaption",
 CellChangeTimes->{
  3.8109440426402225`*^9, {3.8112649957014456`*^9, 3.8112650187001457`*^9}, {
   3.815926367520584*^9, 3.8159263685120077`*^9}},
 CellID->481008101,ExpressionUUID->"d1af8243-05fe-4355-ae6b-7ffcd0193e23"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{"ourSample", ",", 
   RowBox[{"{", "10", "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Histogram of Our Sample\>\""}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Value\>\"", ",", "\"\<Count\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7534141933385267`*^9, 3.753414230528143*^9}, 
   3.8109440731242228`*^9, 3.815926906246244*^9},
 CellLabel->"In[25]:=",
 CellID->513043682,ExpressionUUID->"ddee13bc-e773-49c9-bac6-30ac325b9f88"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.63], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.63], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{260., 0}, {270., 1.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{16.929743795036188`, 40.42814251401137}, {
           50.05969101820576, 64.32930211038106}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{270., 0}, {280., 1.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{39.92814251401137, 63.42654123298655}, {
           50.05969101820576, 64.32930211038106}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{280., 0}, {290., 5.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{62.92654123298655, 
           86.42493995196173}, {-5.0187533504954445`, 64.32930211038106}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 5]& ,
        TagBoxNote->"5"],
       StyleBox["5", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[5, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{290., 0}, {300., 4.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{85.92493995196173, 109.42333867093691`}, {
           8.750857741679852, 64.32930211038106}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 4]& ,
        TagBoxNote->"4"],
       StyleBox["4", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[4, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{300., 0}, {310., 7.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{108.92333867093691`, 
           132.4217373899121}, {-32.557975534846065`, 64.32930211038106}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 7]& ,
        TagBoxNote->"7"],
       StyleBox["7", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[7, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{310., 0}, {320., 8.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{131.9217373899121, 
           155.42013610888728`}, {-46.32758662702136, 64.32930211038106}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 8]& ,
        TagBoxNote->"8"],
       StyleBox["8", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[8, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{320., 0}, {330., 2.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{154.92013610888728`, 178.41853482786235`}, {
           36.29007992603046, 64.32930211038106}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 2]& ,
        TagBoxNote->"2"],
       StyleBox["2", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[2, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{330., 0}, {340., 2.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{177.91853482786235`, 201.41693354683753`}, {
           36.29007992603046, 64.32930211038106}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 2]& ,
        TagBoxNote->"2"],
       StyleBox["2", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[2, {}], 
       "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Value\"", TraditionalForm], 
    FormBox["\"Count\"", TraditionalForm]},
  AxesOrigin->{258.4, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotLabel->FormBox["\"Histogram of Our Sample\"", TraditionalForm],
  PlotRange->{{260., 340.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.753414231524475*^9, 3.8109218801712737`*^9, 
  3.8109440842702227`*^9, 3.8124709368388557`*^9, 3.8127124245846534`*^9},
 CellLabel->"Out[25]=",
 CellID->177906808,ExpressionUUID->"d287b630-ab65-4913-bd44-824a5924ff49"]
}, Open  ]],

Cell[TextData[{
 "For the sake of illustrating the difference between the distribution of \
data point values in our sample and a sampling distribution, let\
\[CloseCurlyQuote]s start by creating a ",
 ButtonBox["SmoothHistogram",
  BaseStyle->"Link"],
 " of the sample."
}], "Text",
 CellChangeTimes->{
  3.810986902276731*^9, {3.81098695767027*^9, 3.8109869828017826`*^9}, 
   3.811265052038811*^9, {3.8115013034900055`*^9, 3.811501322755108*^9}},
 CellID->805924332,ExpressionUUID->"796365a6-73a3-4930-8018-6ae9d368d559"],

Cell[TextData[{
 ButtonBox["SmoothHistogram",
  BaseStyle->"Link"],
 " requires a List (or saved data) to plot the PDF: "
}], "CodeCaption",
 CellChangeTimes->{{3.810986672533678*^9, 3.810986705884678*^9}, {
  3.8109867950260067`*^9, 3.8109868072952337`*^9}},
 CellID->269783227,ExpressionUUID->"a1885656-2c86-476e-89ad-c7a7d5a74a28"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SmoothHistogram", "[", 
  RowBox[{"ourSample", ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Smooth Histogram of Our Sample\>\""}],
    ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Value\>\"", ",", "\"\<Count\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7534143133058424`*^9, 3.753414321065074*^9}, {
   3.8109441348062224`*^9, 3.8109441378282223`*^9}, 3.815926920574737*^9},
 CellLabel->"In[26]:=",
 CellID->915259749,ExpressionUUID->"91be5c72-7b3e-47cd-b478-147c17eda0e1"],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJztm+k31V/4981TKimKDBkyRJSEVK5LIZnKWKYyZdaZPocMmed5JlI0KRVK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    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1kOwGIgSBdAX27Zt27Zt2zYHsW3bnIlt27bt5J/8WZzqu+pV161O1LhD
5faBAwICAhEpSEDA7xw5yH85IhEITzjCEobQhCIkIQhOMIIS5PcOAhHALwt/
8oPvfOMrX/jMJz7ygfe84y1veM0rXvKC5zzjKU94zCMe8oD73OMud7jNLW5y
g+tc4ypXuMwlLnKB85zjLGc4zSlOcoLjHOMoRzjMIQ5ygP3sYy972M0udrKD
7WzjX/5hK1vYzCY2soH1rGMta1jNKlayguUsYylLWMwiFrKA+cxjLnOYzSxm
MoPpTGMqU5jMJCYygfGMYyxjGM0oRjKC4Qzjb/7iT/5gKEMYzCAGMoD+9KMv
fehNL3rSg+50oytd6EwnOtKB3wfajra0oTWtaEkLmtOMpjShMY1oSAPqU4+6
1KE2tahJDapTjapUoTKVqEgFylOOspShNKUoSQmKU4yiFKEwhShIAfKTj7zk
ITe5yEkOspONrGQhM5nISAbSk460pCE1qUhJCpKTjKQkITGJSEgC4hOPuMQh
NrGISQyiE42oRCEykYhIBMITjrCEITShCEkIghOMoAQhMIH4XSa/FMtPfvCd
b3zlC5/5xEc+8J53vOUNr3nFS17wnGc85QmPecRDHnCfe9zlDre5xU1ucJ1r
XOUKl7nERS5wnnOc5QynOcVJTnCcYxzlCIc5xEEOsJ997GUPu9nFTnawnW38
yz9sZQub2cRGNrCedaxlDatZxUpWsJxlLGUJi1nEQhYwn3nMZQ6zmcVMZjCd
aUxlCpOZxEQmMJ5xjGUMoxnFSEYwnGH8zV/8yR8MZQiDGcRABtCffvSlD73p
RU960J1udKULnelERzrQnna0pQ2taUVLWtCcZjSlCY1pREMaUJ961KUOtalF
TWpQnWpUpQqVqURFKlCecpSlDKUpRUlKUJxiFKUIhSlEQQqQn3zkJQ+5yUVO
cpCdbGQlC5nJREYykJ50pCUNqUlFSlKQnGQkJQmJSURCEhCfeMQlDrGJRUxi
EJ1oRCUKkYlERCIQnnCEJQyhCUVIQhCcYAQlCIEJFOi/p+KX8ZMffOcbX/nC
Zz7xkQ+85x1vecNrXvGSFzznGU95wmMe8ZAH3Oced7nDbW5xkxtc5xpXucJl
LnGRC5znHGc5w2lOcZITHOcYRznCYQ5xkAPsZx972cNudrGTHWxnG//yD1vZ
wmY2sZENrGcda1nDalaxkhUsZxlLWcJiFrGQBcxnHnOZw2xmMZMZTGcaU5nC
ZCYxkQmMZxxjGcNoRjGSEQxnGH/zF3/yB0MZwmAGMZAB9KcffelDb3rRkx50
pxtd6UJnOtGRDrSnHW1pQ2ta0ZIWNKcZTWlCYxrRkAbUpx51qUNtalGTGlSn
GlWpQmUqUZEKlKccZSlDaUpRkhIUpxhFKUJhClGQAuQnH3nJQ25ykZMcZCcb
WclCZjKRkQykJx1pSUNqUpGSFCQnGUlJQmISkZAExCcecYlDbGIRkxhEJxpR
iUJkIhGRCIQnHGEJQ2hCEZIQBCcYQQP+//IH/A96QoQ8
         "]]]}, {}, {}}, {{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        NCache[
         Rational[1, 120], 0.008333333333333333]], AbsoluteThickness[1.6], 
       LineBox[CompressedData["
1:eJwl10O0GIYSANAX21Zj23Zj27ZtO2mcNrZt27Zt29a/OX9xz8xqdqOEDdtV
bBsoICAgSpCAgD8xMNKAoAQjOCEISShCE4awhCM8EYhIJCL/qUVUohGdGMQk
FrGJQ1zi8RfxSUBCEpGYJCQlGclJQUpSkZo0pCUd6clARjKRmSxkJRvZyUFO
cpGbPOQlH/kpQEEKUZi/KUJRilGcEpSkFKUpQ1nKUZ4KVKQSlalCVapRnRrU
pBa1qUNd6lGfBjSkEY1pQlOa0ZwWtKQVrWlDW9rRng50pBOd6UJXutGdHvSk
F73pQ1/60Z8BDGQQgxnCUIYxnBH8w0hGMZoxjGUc45nAv/zHRCYxmSlMZRrT
mcFMZjGbOcxlHvNZwEIWsZglLGUZy1nBSlaxmjWsZR3r2cBGNrGZLWxlG9vZ
wU52sZs97GUf+znAQQ5xmCMc5RjHOcFJTnGaM5zlHOe5wEUucZkrXOUa17nB
TW5xmzvc5R73ecBDHvGYJzzlGc95wUte8Zo3vOUd7/nARz7xmS985Rvf+cFP
fvGbP80fiMAEISjBCE4IQhKK0IQhLOEITwQiEonIRCEq0YhODGISi9jEIS7x
+Iv4JCAhiUhMEpKSjOSkICWpSE0a0pKO9GQgI5nITBayko3s5CAnuchNHvKS
j/wUoCCFKMzfFKEoxShOCUpSitKUoSzlKE8FKlKJylShKtWoTg1qUova1KEu
9ahPAxrSiMY0oSnNaE4LWtKK1rThz/BuR3s60JFOdKYLXelGd3rQk170pg99
6Ud/BjCQQQxmCEMZxnBG8A8jGcVoxjCWcYxnAv/yHxOZxGSmMJVpTGcGM5nF
bOYwl3nMZwELWcRilrCUZSxnBStZxWrWsJZ1rGcDG9nEZrawlW1sZwc72cVu
9rCXfeznAAc5xGGOcJRjHOcEJznFac5wlnOc5wIXucRlrnCVa1znBje5xW3u
cJd73OcBD3nEY57wlGc85wUvecVr3vCWd7znAx/5xGe+8JVvfOcHP/nFb/4s
/kAEJghBCUZwQhCSUIQmDGEJR3giEJFIRCYKUYlGdGIQk1jEJg5xicdfxCcB
CUlEYpKQlGQkJwUpSUVq0pCWdKQnAxnJRGaykJVsZCcHOclFbvKQl3zkpwAF
KURh/qYIRSlGcUpQklKUpgxlKUd5KlCRSlSmClWpRnVqUJNa1KYOdalHfRrQ
kEY0pglNaUZzWtCSVrSmDW1pR3s60JFOdKYLXelGd3rQk170pg996Ud/BjCQ
QQxmCEMZxnBG8A8jGcVoxjCWcYxnAv/yHxOZxGSmMJVpTGcGM5nFbOYwl3nM
ZwELWcRilrCUZSxnBStZxWrWsJZ1rGcDG9nEZrawlW1sZwc72cVu9rCXfezn
AAc5xGGOcJRjHOcEJznFac5wlnOc5wIXucRlrnCVa1znBje5xW3ucJd73OcB
D3nEY57wlGc85wUvecVr3vCWd7znAx/5xGe+8JVvfOcHP/nFb/4c/YEITBCC
EozghCAkoQhNGMISjvBEICKRiBzk/7/E/wAqf4RT
        "]]}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       NCache[
        Rational[1, 120], 0.008333333333333333]], AbsoluteThickness[1.6]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        NCache[
         Rational[1, 120], 0.008333333333333333]], AbsoluteThickness[
       1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        NCache[
         Rational[1, 120], 0.008333333333333333]], AbsoluteThickness[
       1.6]}, {}}}], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Value\"", TraditionalForm], 
    FormBox["\"Count\"", TraditionalForm]},
  AxesOrigin->{246.18083245667887`, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{578., Automatic},
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Smooth Histogram of Our Sample\"", TraditionalForm],
  PlotRange->{{246.18083245667887`, 355.29532013981316`}, {0., 
   0.02192406949136121}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7534143246006174`*^9, 3.810921884178674*^9, 
  3.8109441457472224`*^9, 3.8124709401088543`*^9, 3.81271242631948*^9},
 CellLabel->"Out[26]=",
 CellID->3807023,ExpressionUUID->"ca44392b-31f0-4d72-b53e-e8f224d5d1d7"]
}, Open  ]],

Cell["\<\
It is not a smooth bell-shaped curve, but it is certainly getting there. We \
can create a model distribution from our sample. This model distribution will \
be that of a sampling distribution. Instead of the standard deviation, it \
will use standard error to serve as the standard deviation parameter in the \
model.\
\>", "Text",
 CellChangeTimes->{
  3.7534143432976274`*^9, {3.810943938507222*^9, 3.8109439429862223`*^9}, {
   3.8109443124422226`*^9, 3.810944337146222*^9}, 3.811265109985628*^9, {
   3.8115160916038713`*^9, 3.8115160918961887`*^9}},
 CellID->226754189,ExpressionUUID->"d64a8a00-c0c0-44d1-87e8-2e6b40394341"],

Cell["Plot the model sampling distribution:", "CodeCaption",
 CellChangeTimes->{{3.717430814189918*^9, 3.717430844374918*^9}, {
   3.717435468924362*^9, 3.7174354743186707`*^9}, {3.7174355085976315`*^9, 
   3.7174355119308224`*^9}, 3.752555159259868*^9, {3.7528944791634007`*^9, 
   3.7528945124330435`*^9}, 3.7534121602249575`*^9, {3.7534143750158215`*^9, 
   3.75341438181664*^9}, {3.8109443712282224`*^9, 3.8109443835912223`*^9}, {
   3.8109834321546593`*^9, 3.810983439026469*^9}, 3.815927078965435*^9, {
   3.819018179272966*^9, 3.819018181018306*^9}},
 CellID->143414462,ExpressionUUID->"cf15e393-01bc-4fa1-8758-af93b7717f6d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"PDF", "[", 
    RowBox[{
     RowBox[{"NormalDistribution", "[", 
      RowBox[{
       RowBox[{"Mean", "[", "ourSample", "]"}], ",", 
       RowBox[{
        RowBox[{"StandardDeviation", "[", "ourSample", "]"}], "/", 
        RowBox[{"Sqrt", "[", "30", "]"}]}]}], "]"}], ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "288", ",", "320"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Model Sampling Distribution\>\""}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.753414414256935*^9, 3.7534144396081257`*^9}, {
  3.810983288294377*^9, 3.8109832998410373`*^9}},
 CellLabel->"In[27]:=",
 CellID->15794757,ExpressionUUID->"27b58ca1-290f-4584-bd8d-62525d1f6dc1"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJw12nc4V///P3AySkVFRigje4WGkc7jSVJSsleIjOw4B0V2RgPZoowoJfQu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    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt1WWYVlUUQOFx6BBQQkBJaZDuEJCw6W6GUhoEgzbBLkqlJMWgMejuTuk0
KFtMwHerP9Zz9lr3Y5jvnnvP5Evq16RvYkJCwk24lPjfejHxv7ms+YL1YZzB
Fy7Wsx7BXeaPUMm8HfN9dimvbT4YP8c8EunMU9He9Tv4uyjEl2GMtoBXN+/B
Ud6Kn8eTvAwvYf4QFfk2zNOW8FrmA///4iOQ1jwF7aTb+TsoGL8zRmvzeTXz
7vj9eUt+Dk/w0ry4eS4q8K34RFvMa5r34wYfztOYJ6Mtz8knogD/HC9o83hV
8y58yVvws3icl+LFzB+gPN+Cj7XrGKal5pPQhufgE3An/wzPa4fRXDuDwVpJ
XtQ8B+X4ZnykXcNQLRV/D615dj4e+fmneE47hGbaaQyKPeVFzLNRlm/Ch9rf
GKKl5O+iFb+Nj0M+vhTPagfRVDuFx7QSvLB5FsrwjZir/YWntBT8HbTk2fhY
5OVL8Ix2AE20kxioFeeFzDNRmm/AB9qfeFJLzieiBc/K30YevhhPa/vRWDuB
AVoxXtA8A6X4eszR/sATWjI+Ac15Fv4WcvNFGKXtQyPtOPprRfls/I7HtURt
PJrxzPxN5OILMVLbi4baMfTTivBZ+A2DtZu0cWjKb+Vv4A6+ACO0PWigHUW8
xIX5TFzFoHiRtbFoYryFv47b413FcG03HtaOoI9WiM/Ar3hMuxH3UG/MM5lf
Q854BzFM24WHtC/RWyvIp+MXDNSuxz3TG/GM5leRI94tDNV24kHtMHppBfj7
+BkDtGtxz/SG8fxhBx7QDqGnfiefhp/QX/s77pHeIJ4vbMf92kE8qufnU/Ej
+ml/xT2J8y2eH2zDfdoBPKLn41PwA/pqf8Y90B+K5wNbca+2Hz30vHwyvkcf
7Y/4zvqD8TxgC+pr+9BdzxPfJ/Yam1FP34turuXmueLMjPMsvkfsKTahrs/s
QVefy8kn4Tv01n7HK/p9sYfYiDrabnTRc/AC5ukoydfFGaFdQS/tN7ys3csz
xM9C9jinMFD7hFcx74z3j9/DdyGJZ+efm+vG2Rf7Y77fegLvm++yro0zJPbd
eireJf289W7sw2XXvo7/H8fQM85P61XrS9b6rn8be4DTcZbpX1nvwSHczL+J
74/jeJmfs94WZyMGxD23nozv5Fpl645492NvrEdRW9+JzvHv9M/MdcyH4xky
T0MJ85o4v1xfyGuY9+ISf5T/ihd5PZ4+fndki/MU/bV1qKXtQCctG5+Ii3hE
+wVj9LrxrGItamrb0VHPyifgAnpoP2O0XieeVazB3do2dNCzxBkU50icBbFv
8YxiNWr4zFa097lMvHY8S1iF6voWtHMtIx8f9x/dtZ/wgl4rnh2sRDVtM9rq
Gfg4fINu2o94Xq/Je2IFqmqb0Cb2jo+N/UdX7Qc8F89G3FMsRxVtI1rr6fnb
+ApdtO/xrF4j7iGWobK2Aa30dPwtnEeS9h2e0avzdLFfyMrnoof2BSpp69FS
S8vfxDl01q7gab0aTxv7hSzxNwnd411ARW0dWmhp+Bs4i07aZYzSq/I0sX/I
HH+D0C2eO1TQ1qK5lpq/jjPoqF3CSL0KTx17gVv5bHTVPkV5bQ2aaan4aziN
DtpFjNAr81SxN7iFz0IXbSnKaavRVEvJ85mnojhfjVe1U2ivXcBwrRJPGXuH
THwmkrQlKKutQhMtBc9rnoJifBVe0U6infYthmkVeYrYW2TkM9BZW4wy2ko0
1pLzPObJKMpXxvuvnUDbOBcwVKvAk8feIwOfjk7aIpTWVqCRloznNk9CEb4C
L2nH0Ub7GkO08jxZPAu4Oc46dIxzAaW05WiY+O+f44Rc5vdQmCzHi9oxtI5z
DE9p5XhiPBtIz6ehg7YAJbVlaKD9A0h9cNw=
         "]]]}, {}, {}}, {{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl1mWUVmUUQOEBVLpDpbtbEUVplE4RJUVMECUUlO7GAAWlu0S6u7sbAQNQ
FJu0xecsf2zu2fu7axZz77xnJk+7Tk1eT5SQkHA1cUJCXBu4rjeUxFLeBtO1
VOivJcYDWg/+jbk5zvMR2KAVwiQtR9yrNfTPBnMpLOPPYoaWGgO0JHhQ68mv
mFvgAh+JjVphTNZyxr1aI77RXBrLeVvM1NJgoHYXymm9+Lfmlvicj8ImrQim
aLniXq0x32QugxX8OczS0mKQdjce0nrz78yt8AUfjc1aUUzVcse9WhO+2VwW
K3k7zNbSYbB2D8prffhVc2t8yd/BFq0Ypml54l7tSb4lnjlW8ecxR0uPIVpS
PKz15d+b2+Ar/i6Soqm+NZ4xVvMXMFfLgKFaMjyi9eM/mJ/FRf4ekuEpfVs8
U6zhL2KelhHDtOSooPXnP5rb4hJ/H8nRTN8ezxBr+UuYr2XCcC0FHtUG8J/M
z+EyH4MUeFrfEc8M6/jLWKBlxggtJR7TBvKfze3wNR+LlHhG3xnPCOv5K6iI
Qfov2vP4hn+AVGiu74pngg28PSphsP6r9gKu8A+RGi303fEMsJF3QGUM0a9p
L+JbPg5p0FLfE98zNvFXUQVD9evaS/iOj0datNL3xveIzbwjqiIdWvtsn14R
W/hrqIb0yICMyBRn2H373VMJW/nrqI5h+g3tZVzlHyFznFH9gFYZ23gn1MBw
/ab2Cr7nHyNLnEH9oFYF23lnfKJlwUgtFR6PHcFvmdvjB36MV8QyPoFvNRfH
dJ4XZ8zVscZ8b5xN8yFzVZwzPxE/G/pB14fxaZxN1zrooi90vReXMSr2imut
2Auxf/hp12qxx7A6zo1rvTjn8bVjB7nejp9n1w6x51xrxp6Kn3WfH3ethK+x
PM6xa11M9Nk21xKYEfvHtTbymc+61sBa832xH8yHzdWwkx/ij2AR78o/Nd+H
0TwNasYu47+ZX8VPfBK2ayUxU8uP+2NX8CPm6tjF30Ct2F3671pH/MwnI2vs
Bv2oVgO7+ZuojWzIjhzIGTvAfcfinWIP74Y6yBXn22fH9Sewl3dH3dhv+h/a
a/iFT0HuOM/6ifi+sI+/hXqxv/Q/tfjl9CufijxxfvWTWi3s52+jfuwr/S+t
E67xacgb51c/pdXGAd4DDWI/6X9rnXGdT0e+OL/6aa0ODvKeaBj7SP9H64Ib
fAbyx/nVz2h1cYj3wiLtfryjpUWj2Ef833inuMlnokCcZ/2sVg+HeW8s1rLi
XS0dGsd+4nfMb+AWn4WCceb1z7T6OML7YImWDe9p6dEk9hWPX8hv8tvG2SgU
u0A7pzXAUd4XS7XseF/LgCdjf/FE6MZ/43NQOHaDdl5riGO8H5ZpOTBGy4im
sc94YnTnv/O5KBK7QrsQzwjHeX8s13JirJYJT8Vu4knwFv+Dz8MOXgqztAIo
qnXhn8czwwk+ACu0XPhAy4xmsbv4XXib/8nnYycvjdlaQRTTuvIv4hniJB+I
lVpufKhlwdPaBH43evC/+ALs4mUwRyuE4nEG+ZfxTHGKD8IqLQ/GxZ7DM9pE
fg968r9jn2I3L4u5WmGUiDPKv4pnHPuMD8ZqLS/Gx45B89gRPCl68X9iN2IP
fwDztCIoGWeZX4xnHvuXD8Ga2F34KPYKWsTO4MnQm/8bewp7+YOYH+8CpeL8
80vxzGP38cO8AhbzoXytOT8+5lnRMnYDT44+/A4/Ya6MFXwR32cuhwXxjlA6
9kbs+XgX+Iwf4Y9iCR/G15kLYALPhlaxU3gK9OXxx+9JcxWsNC+W9psfwifx
7lAm9k3s+3hHOMeP8sewlA/n680F43cAz47WsYt4SvTjieK9m6tilXmJzw+Y
y2NhvNP4/5sfxzrzRdf6if//+7yse/8Dm3lu/w==
         "]]},
       Annotation[#, "Charting`Private`Tag$33970#1"]& ]}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{522., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotLabel->FormBox["\"Model Sampling Distribution\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7534144308694844`*^9, 3.7534144401476774`*^9}, 
   3.810921885217778*^9, 3.812470941916711*^9, 3.8127124270444074`*^9},
 CellLabel->"Out[27]=",
 CellID->808559886,ExpressionUUID->"d22a34e2-682a-42c2-8e50-0c93d806cd25"]
}, Open  ]],

Cell[TextData[{
 "It is from this distribution that we can calculate the confidence interval \
values for a specific confidence level. To do so, we must import the \
Hypothesis Testing Package into the Wolfram Language. In the code cell below, \
we import this package using the ",
 Cell[BoxData[
  ButtonBox["Needs",
   BaseStyle->"Link"]], "InlineCodeText",ExpressionUUID->
  "c9e60fb7-0698-4126-b76a-d87b9f314d5d"],
 " function. Downloading packages is nothing to be concerned about with the \
Wolfram Language. In fact, you\[CloseCurlyQuote]ve probably downloaded a few \
already just by using particular functions."
}], "Text",
 CellChangeTimes->{{3.7534144606731396`*^9, 3.7534145047383194`*^9}, {
   3.810983536900303*^9, 3.8109836022264566`*^9}, 3.81098753734752*^9, {
   3.8109878822255197`*^9, 3.8109878847065196`*^9}, {3.81151609204517*^9, 
   3.8115160923502398`*^9}, {3.812016515197266*^9, 3.8120165242086077`*^9}, 
   3.815927209345932*^9, {3.8159272743096523`*^9, 3.815927298333578*^9}},
 CellID->192996318,ExpressionUUID->"f84a7025-7d33-4173-b64f-398a9e431910"],

Cell[TextData[{
 "If you ever want to check on your paclets, palettes, and applications, use ",
 ButtonBox["SystemOpen",
  BaseStyle->"Link"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.810984305549884*^9, 3.810984352210884*^9}, {
   3.8109865442606783`*^9, 3.810986545129678*^9}, 3.8109875319095197`*^9},
 CellID->124732588,ExpressionUUID->"51194f31-e335-4b52-84d3-496cd8784b27"],

Cell[BoxData[
 RowBox[{"SystemOpen", "@", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{"$UserBaseDirectory", ",", "\"\<Applications\>\""}], "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{3.8109843372138844`*^9},
 CellLabel->"In[28]:=",
 CellID->10224243,ExpressionUUID->"edb7df8d-ea25-486a-b11a-3016113d8d17"],

Cell["\<\
Take note of the quotation marks and the back tick at the end:\
\>", "CodeCaption",
 CellChangeTimes->{{3.810987277467246*^9, 3.810987279426442*^9}, 
   3.8159273720870857`*^9},
 CellID->399979887,ExpressionUUID->"da11c21f-e0da-4f22-a520-77a552119fea"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<HypothesisTesting`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.753414520275778*^9, 3.7534145258169656`*^9}},
 CellLabel->"In[29]:=",
 CellID->85819258,ExpressionUUID->"1d23a07e-3538-4d9e-ae52-d160ad63693d"],

Cell[TextData[{
 "We can now use the ",
 ButtonBox["MeanCI",
  BaseStyle->"Link"],
 " function to calculate the confidence intervals around our sample mean."
}], "Text",
 CellChangeTimes->{{3.8109887612316217`*^9, 3.8109887796854672`*^9}, {
  3.8115024020331354`*^9, 3.81150242547948*^9}, {3.811515746958002*^9, 
  3.811515776598881*^9}},
 CellID->517796865,ExpressionUUID->"2a4681b0-1f08-4994-b0d7-c6a9cadb1faa"],

Cell[TextData[{
 "The default for ",
 ButtonBox["MeanCI",
  BaseStyle->"Link"],
 " will calculate a 95% confidence interval:"
}], "CodeCaption",
 CellChangeTimes->{{3.810987277467246*^9, 3.810987279426442*^9}, {
   3.810988648476348*^9, 3.810988664140914*^9}, {3.810988712537753*^9, 
   3.8109887129567947`*^9}, 3.811515798517663*^9},
 CellID->5019096,ExpressionUUID->"867a51e9-37f5-45aa-a6fc-220cd8eee355"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MeanCI", "[", "ourSample", "]"}]], "Input",
 CellLabel->"In[30]:=",
 CellID->621441086,ExpressionUUID->"444a3a25-a347-4dac-9397-0026fe586a7f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"296.32238926374976`", ",", "309.1052052536311`"}], "}"}]], "Output",
 CellChangeTimes->{3.7534145759459305`*^9, 3.810921888264083*^9, 
  3.8124709617706423`*^9, 3.812712428369275*^9},
 CellLabel->"Out[30]=",
 CellID->255275005,ExpressionUUID->"5d75c327-56a9-4cfa-85bf-52a92c5b406c"]
}, Open  ]],

Cell["Specify other confidence levels:", "CodeCaption",
 CellChangeTimes->{{3.810987277467246*^9, 3.810987279426442*^9}, {
  3.810988648476348*^9, 3.810988664140914*^9}, {3.810988712537753*^9, 
  3.8109887129567947`*^9}, {3.8109888701685143`*^9, 3.810988871878686*^9}},
 CellID->49015631,ExpressionUUID->"a9523c76-095b-4aab-9959-d834a97e0680"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MeanCI", "[", 
  RowBox[{"ourSample", ",", 
   RowBox[{"ConfidenceLevel", "\[Rule]", "0.8"}]}], "]"}]], "Input",
 CellLabel->"In[31]:=",
 CellID->50039497,ExpressionUUID->"ba95c230-78bf-4b65-b8f1-881ffa824043"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"298.61552519890506`", ",", "306.8120693184758`"}], "}"}]], "Output",
 CellChangeTimes->{3.7534146219848385`*^9, 3.810921888505107*^9, 
  3.8124709629695883`*^9, 3.8127124286102505`*^9},
 CellLabel->"Out[31]=",
 CellID->472965019,ExpressionUUID->"6a0bce29-6034-4e03-b1b7-e93052413fb7"]
}, Open  ]],

Cell[TextData[{
 "You will notice that the limits are much narrower for a lower confidence \
level. When you read the next section about hypothesis testing and research \
questions, this will become clear. The confidence level of ",
 Cell[BoxData[
  FormBox["95", TraditionalForm]],ExpressionUUID->
  "c852a152-205e-4979-b21b-20ed7b7202e7"],
 "% represents ",
 Cell[BoxData[
  FormBox["0.95", TraditionalForm]],ExpressionUUID->
  "7fa86a7b-f98a-45e2-9db9-724d757818ef"],
 " of the area under the curve of the probability distribution function \
(which is ",
 Cell[BoxData[
  FormBox["1.0", TraditionalForm]],ExpressionUUID->
  "0fe0ea63-9c07-4c33-aed7-e87eacdfe978"],
 " in total). Centered from the middle of the curve, the confidence interval \
is worked out to cover ",
 Cell[BoxData[
  FormBox["0.95", TraditionalForm]],ExpressionUUID->
  "bafd561d-ccc1-4232-8c31-abcddef64482"],
 " of the area under the curve. The limits are read off of the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "a483deaa-da05-4a9b-aa2a-5ab4451b45f4"],
 " axis. This tells you why a lower confidence level, such as ",
 Cell[BoxData[
  FormBox["80", TraditionalForm]],ExpressionUUID->
  "c939ef07-6915-45ae-b0d0-074d4fc2a4ec"],
 "%, has narrower limits. It simply covers less of the area under the curve."
}], "Text",
 CellChangeTimes->{{3.753414640071479*^9, 3.7534146583845434`*^9}, {
   3.811502525215452*^9, 3.811502534362367*^9}, {3.8115086287047653`*^9, 
   3.8115086316550603`*^9}, {3.811516092505096*^9, 3.811516092978545*^9}, {
   3.8120165855873137`*^9, 3.812016591919424*^9}, {3.812470858659346*^9, 
   3.812470858786509*^9}, 3.815927442382413*^9, {3.8159275133881817`*^9, 
   3.815927542228458*^9}},
 CellID->434876685,ExpressionUUID->"2b938dd7-b7f6-4669-916a-5a5e6af4868c"],

Cell["\<\
We can illustrate the confidence intervals by drawing two vertical lines on \
the previous plot. First we create two computer variables to hold the lower \
and upper bound values with the confidence interval.\
\>", "Text",
 CellChangeTimes->{{3.7534149501474986`*^9, 3.7534150381841173`*^9}, 
   3.8115160931425877`*^9, {3.815927624585047*^9, 3.81592764725947*^9}},
 CellID->539473576,ExpressionUUID->"2abdc406-3433-40b1-b6bd-787cd1fff353"],

Cell["\<\
Create two computer variables to hold the CI values; use indexing to get the \
first and second values:\
\>", "CodeCaption",
 CellChangeTimes->{{3.810987277467246*^9, 3.810987279426442*^9}, {
   3.810988648476348*^9, 3.810988664140914*^9}, {3.810988712537753*^9, 
   3.8109887129567947`*^9}, {3.8109888701685143`*^9, 3.810988871878686*^9}, {
   3.810988960550552*^9, 3.8109889808985863`*^9}, {3.810990165389317*^9, 
   3.8109901959193172`*^9}, 3.815927779323276*^9, {3.816456486061616*^9, 
   3.8164564905265417`*^9}},
 CellID->841841160,ExpressionUUID->"71eb79f5-feaf-4d59-8095-b7196b00455c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"lb", ",", " ", "ub"}], "}"}], "=", 
  RowBox[{"MeanCI", "[", "ourSample", "]"}]}]], "Input",
 CellChangeTimes->{{3.753414906763459*^9, 3.7534149434833174`*^9}, {
  3.812016613947047*^9, 3.8120166322658*^9}},
 CellLabel->"In[32]:=",
 CellID->170426323,ExpressionUUID->"001d393a-dfa4-44fc-945d-7f07c7f1aa7f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"296.32238926374976`", ",", "309.1052052536311`"}], "}"}]], "Output",
 CellChangeTimes->{3.753414944489625*^9, 3.8109218887421303`*^9, 
  3.812470918612205*^9, 3.8124709654483767`*^9, 3.8127124288392277`*^9},
 CellLabel->"Out[32]=",
 CellID->15162716,ExpressionUUID->"868a358d-a2eb-429c-8896-361fa399d024"]
}, Open  ]],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    ButtonBox["Epilog",
     BaseStyle->"CodeLink"], "\[Rule]", 
    ButtonBox["Line",
     BaseStyle->"CodeLink"]}], TraditionalForm]], "InlineCode",
  FormatType->"TraditionalForm",ExpressionUUID->
  "4171d81b-a6fc-4c2e-8ade-27d83aef2d70"],
 " argument will add lines between specified points: "
}], "CodeCaption",
 CellChangeTimes->{{3.7534150884237876`*^9, 3.7534151422728176`*^9}, {
   3.8109890050910053`*^9, 3.8109890066181583`*^9}, 3.810989158142309*^9, {
   3.8115015836450295`*^9, 3.811501584262065*^9}, {3.8115158253242807`*^9, 
   3.811515825324306*^9}, {3.811515863766532*^9, 3.8115158637665567`*^9}, 
   3.812811210067183*^9, 3.815927861356284*^9},
 CellID->513969088,ExpressionUUID->"909f7cfc-cf5b-4edf-bdec-ae6a9c25aa82"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sampleDist", "=", " ", 
   RowBox[{"NormalDistribution", "[", 
    RowBox[{
     RowBox[{"Mean", "[", "ourSample", "]"}], ",", 
     RowBox[{
      RowBox[{"StandardDeviation", "[", "ourSample", "]"}], "/", 
      RowBox[{"Sqrt", "[", "30", "]"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"lines", "=", 
   RowBox[{"Line", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"lb", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"lb", ",", "0.13"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"ub", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"ub", ",", "0.13"}], "}"}]}], "}"}]}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"PDF", "[", 
    RowBox[{"sampleDist", ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "288", ",", "320"}], "}"}], ",", 
   RowBox[{"Filling", "->", "Axis"}], ",", 
   RowBox[{"Ticks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"lb", ",", "\"\<lb\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"ub", ",", "\"\<ub\>\""}], "}"}]}], "}"}], ",", 
      "Automatic"}], "}"}]}], ",", 
   RowBox[{"PlotRange", "->", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<Theoretical Sampling Distribution with 95% CI\>\""}], ",", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Dashed", ",", "lines"}], "}"}]}]}], "]"}], "\n"}], "Input",
 CellChangeTimes->{{3.81247099960143*^9, 3.812471043780047*^9}, {
  3.8124710785084352`*^9, 3.8124710807067013`*^9}, {3.812471161422242*^9, 
  3.812471219542739*^9}, {3.8127172817582345`*^9, 3.8127172838062344`*^9}},
 CellLabel->"In[33]:=",
 CellID->1768381628,ExpressionUUID->"c9af9a1d-4f8d-4566-8e73-bbf82424fe8c"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJw12nc4Vv//B3AySkVFRigje4WGkc7rTVJSsleIjOw4B0V2RgPZoowoJTSs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    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt1WWYVlUUQOFx6BBQQkBJaZDuEJCw6W6GUhoEgzbBLkqlJMWgMejuTuk0
KFtMwHerP9Zz9lr3Y5jvnnvP5Evq16RvYkJCwk24lPjfejHxv7ms+YL1YZzB
Fy7Wsx7BXeaPUMm8HfN9dimvbT4YP8c8EunMU9He9Tv4uyjEl2GMtoBXN+/B
Ud6Kn8eTvAwvYf4QFfk2zNOW8FrmA///4iOQ1jwF7aTb+TsoGL8zRmvzeTXz
7vj9eUt+Dk/w0ry4eS4q8K34RFvMa5r34wYfztOYJ6Mtz8knogD/HC9o83hV
8y58yVvws3icl+LFzB+gPN+Cj7XrGKal5pPQhufgE3An/wzPa4fRXDuDwVpJ
XtQ8B+X4ZnykXcNQLRV/D615dj4e+fmneE47hGbaaQyKPeVFzLNRlm/Ch9rf
GKKl5O+iFb+Nj0M+vhTPagfRVDuFx7QSvLB5FsrwjZir/YWntBT8HbTk2fhY
5OVL8Ix2AE20kxioFeeFzDNRmm/AB9qfeFJLzieiBc/K30YevhhPa/vRWDuB
AVoxXtA8A6X4eszR/sATWjI+Ac15Fv4WcvNFGKXtQyPtOPprRfls/I7HtURt
PJrxzPxN5OILMVLbi4baMfTTivBZ+A2DtZu0cWjKb+Vv4A6+ACO0PWigHUW8
xIX5TFzFoHiRtbFoYryFv47b413FcG03HtaOoI9WiM/Ar3hMuxH3UG/MM5lf
Q854BzFM24WHtC/RWyvIp+MXDNSuxz3TG/GM5leRI94tDNV24kHtMHppBfj7
+BkDtGtxz/SG8fxhBx7QDqGnfiefhp/QX/s77pHeIJ4vbMf92kE8qufnU/Ej
+ml/xT2J8y2eH2zDfdoBPKLn41PwA/pqf8Y90B+K5wNbca+2Hz30vHwyvkcf
7Y/4zvqD8TxgC+pr+9BdzxPfJ/Yam1FP34turuXmueLMjPMsvkfsKTahrs/s
QVefy8kn4Tv01n7HK/p9sYfYiDrabnTRc/AC5ukoydfFGaFdQS/tN7ys3csz
xM9C9jinMFD7hFcx74z3j9/DdyGJZ+efm+vG2Rf7Y77fegLvm++yro0zJPbd
eireJf289W7sw2XXvo7/H8fQM85P61XrS9b6rn8be4DTcZbpX1nvwSHczL+J
74/jeJmfs94WZyMGxD23nozv5Fpl645492NvrEdRW9+JzvHv9M/MdcyH4xky
T0MJ85o4v1xfyGuY9+ISf5T/ihd5PZ4+fndki/MU/bV1qKXtQCctG5+Ii3hE
+wVj9LrxrGItamrb0VHPyifgAnpoP2O0XieeVazB3do2dNCzxBkU50icBbFv
8YxiNWr4zFa097lMvHY8S1iF6voWtHMtIx8f9x/dtZ/wgl4rnh2sRDVtM9rq
Gfg4fINu2o94Xq/Je2IFqmqb0Cb2jo+N/UdX7Qc8F89G3FMsRxVtI1rr6fnb
+ApdtO/xrF4j7iGWobK2Aa30dPwtnEeS9h2e0avzdLFfyMrnoof2BSpp69FS
S8vfxDl01q7gab0aTxv7hSzxNwnd411ARW0dWmhp+Bs4i07aZYzSq/I0sX/I
HH+D0C2eO1TQ1qK5lpq/jjPoqF3CSL0KTx17gVv5bHTVPkV5bQ2aaan4aziN
DtpFjNAr81SxN7iFz0IXbSnKaavRVEvJ85mnojhfjVe1U2ivXcBwrRJPGXuH
THwmkrQlKKutQhMtBc9rnoJifBVe0U6infYthmkVeYrYW2TkM9BZW4wy2ko0
1pLzPObJKMpXxvuvnUDbOBcwVKvAk8feIwOfjk7aIpTWVqCRloznNk9CEb4C
L2nH0Ub7GkO08jxZPAu4Oc46dIxzAaW05WiY+O+f44Rc5vdQmCzHi9oxtI5z
DE9p5XhiPBtIz6ehg7YAJbVlaKD9A0h9cNw=
         "]]]}, {}, {}}, {{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl1mWUVmUUQOEBVLpDpbtbEUVplE4RJUVMECUUlO7GAAWlu0S6u7sbAQNQ
FJu0xecsf2zu2fu7axZz77xnJk+7Tk1eT5SQkHA1cUJCXBu4rjeUxFLeBtO1
VOivJcYDWg/+jbk5zvMR2KAVwiQtR9yrNfTPBnMpLOPPYoaWGgO0JHhQ68mv
mFvgAh+JjVphTNZyxr1aI77RXBrLeVvM1NJgoHYXymm9+Lfmlvicj8ImrQim
aLniXq0x32QugxX8OczS0mKQdjce0nrz78yt8AUfjc1aUUzVcse9WhO+2VwW
K3k7zNbSYbB2D8prffhVc2t8yd/BFq0Ypml54l7tSb4lnjlW8ecxR0uPIVpS
PKz15d+b2+Ar/i6Soqm+NZ4xVvMXMFfLgKFaMjyi9eM/mJ/FRf4ekuEpfVs8
U6zhL2KelhHDtOSooPXnP5rb4hJ/H8nRTN8ezxBr+UuYr2XCcC0FHtUG8J/M
z+EyH4MUeFrfEc8M6/jLWKBlxggtJR7TBvKfze3wNR+LlHhG3xnPCOv5K6iI
Qfov2vP4hn+AVGiu74pngg28PSphsP6r9gKu8A+RGi303fEMsJF3QGUM0a9p
L+JbPg5p0FLfE98zNvFXUQVD9evaS/iOj0datNL3xveIzbwjqiIdWvtsn14R
W/hrqIb0yICMyBRn2H373VMJW/nrqI5h+g3tZVzlHyFznFH9gFYZ23gn1MBw
/ab2Cr7nHyNLnEH9oFYF23lnfKJlwUgtFR6PHcFvmdvjB36MV8QyPoFvNRfH
dJ4XZ8zVscZ8b5xN8yFzVZwzPxE/G/pB14fxaZxN1zrooi90vReXMSr2imut
2Auxf/hp12qxx7A6zo1rvTjn8bVjB7nejp9n1w6x51xrxp6Kn3WfH3ethK+x
PM6xa11M9Nk21xKYEfvHtTbymc+61sBa832xH8yHzdWwkx/ij2AR78o/Nd+H
0TwNasYu47+ZX8VPfBK2ayUxU8uP+2NX8CPm6tjF30Ct2F3671pH/MwnI2vs
Bv2oVgO7+ZuojWzIjhzIGTvAfcfinWIP74Y6yBXn22fH9Sewl3dH3dhv+h/a
a/iFT0HuOM/6ifi+sI+/hXqxv/Q/tfjl9CufijxxfvWTWi3s52+jfuwr/S+t
E67xacgb51c/pdXGAd4DDWI/6X9rnXGdT0e+OL/6aa0ODvKeaBj7SP9H64Ib
fAbyx/nVz2h1cYj3wiLtfryjpUWj2Ef833inuMlnokCcZ/2sVg+HeW8s1rLi
XS0dGsd+4nfMb+AWn4WCceb1z7T6OML7YImWDe9p6dEk9hWPX8hv8tvG2SgU
u0A7pzXAUd4XS7XseF/LgCdjf/FE6MZ/43NQOHaDdl5riGO8H5ZpOTBGy4im
sc94YnTnv/O5KBK7QrsQzwjHeX8s13JirJYJT8Vu4knwFv+Dz8MOXgqztAIo
qnXhn8czwwk+ACu0XPhAy4xmsbv4XXib/8nnYycvjdlaQRTTuvIv4hniJB+I
lVpufKhlwdPaBH43evC/+ALs4mUwRyuE4nEG+ZfxTHGKD8IqLQ/GxZ7DM9pE
fg968r9jn2I3L4u5WmGUiDPKv4pnHPuMD8ZqLS/Gx45B89gRPCl68X9iN2IP
fwDztCIoGWeZX4xnHvuXD8Ga2F34KPYKWsTO4MnQm/8bewp7+YOYH+8CpeL8
80vxzGP38cO8AhbzoXytOT8+5lnRMnYDT44+/A4/Ya6MFXwR32cuhwXxjlA6
9kbs+XgX+Iwf4Y9iCR/G15kLYALPhlaxU3gK9OXxx+9JcxWsNC+W9psfwifx
7lAm9k3s+3hHOMeP8sewlA/n680F43cAz47WsYt4SvTjieK9m6tilXmJzw+Y
y2NhvNP4/5sfxzrzRdf6if//+7yse/8Dm3lu/w==
         "]]},
       Annotation[#, "Charting`Private`Tag$50415#1"]& ]}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{288.00000065306125`, 0},
  DisplayFunction->Identity,
  Epilog->{
    Dashing[{Small, Small}], 
    LineBox[{{{296.32238926374976`, 0}, {296.32238926374976`, 0.13}}, {{
       309.1052052536311, 0}, {309.1052052536311, 0.13}}}]},
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotLabel->FormBox[
   "\"Theoretical Sampling Distribution with 95% CI\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{{{296.32238926374976`, 
      FormBox["\"lb\"", TraditionalForm]}, {309.1052052536311, 
      FormBox["\"ub\"", TraditionalForm]}}, Automatic}]], "Output",
 CellChangeTimes->{3.8159279581147346`*^9},
 CellLabel->"Out[35]=",
 CellID->584106183,ExpressionUUID->"f8943c83-e8ce-4f0f-9d65-76f9c114b7db"]
}, Open  ]],

Cell["\<\
The next plot is a demonstration of the confidence intervals and the area \
under the curve:\
\>", "CodeCaption",
 CellChangeTimes->{{3.8127173474162345`*^9, 3.8127173621622343`*^9}},
 CellID->11011103,ExpressionUUID->"5c5be05c-daf5-48d3-9f50-8e6fc9b71eab"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"PDF", "[", 
    RowBox[{
     RowBox[{"NormalDistribution", "[", 
      RowBox[{
       RowBox[{"Mean", "[", "ourSample", "]"}], ",", 
       RowBox[{
        RowBox[{"StandardDeviation", "[", "ourSample", "]"}], "/", 
        RowBox[{"Sqrt", "[", "30", "]"}]}]}], "]"}], ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "288", ",", "320"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<Theoretical Sampling Distribution with 95% CI\>\""}], ",", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"Line", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"lb", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"lb", ",", "0.13"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ub", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"ub", ",", "0.13"}], "}"}]}], "}"}]}], "}"}], "]"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.753414414256935*^9, 3.7534144396081257`*^9}, {
  3.7534146980814037`*^9, 3.753414791713073*^9}, {3.753414881961773*^9, 
  3.753414894752574*^9}, {3.75341515425777*^9, 3.753415208009058*^9}, {
  3.810990246025317*^9, 3.810990248292317*^9}},
 CellLabel->"In[36]:=",
 CellID->139862196,ExpressionUUID->"0caa4ec3-7242-4d64-a309-f1462c4a53d6"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJw12nc4V///P3AySkVFRigje4WGkc7jSVJSsleIjOw4B0V2RgPZoowoJfQu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    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt1WWYVlUUQOFx6BBQQkBJaZDuEJCw6W6GUhoEgzbBLkqlJMWgMejuTuk0
KFtMwHerP9Zz9lr3Y5jvnnvP5Evq16RvYkJCwk24lPjfejHxv7ms+YL1YZzB
Fy7Wsx7BXeaPUMm8HfN9dimvbT4YP8c8EunMU9He9Tv4uyjEl2GMtoBXN+/B
Ud6Kn8eTvAwvYf4QFfk2zNOW8FrmA///4iOQ1jwF7aTb+TsoGL8zRmvzeTXz
7vj9eUt+Dk/w0ry4eS4q8K34RFvMa5r34wYfztOYJ6Mtz8knogD/HC9o83hV
8y58yVvws3icl+LFzB+gPN+Cj7XrGKal5pPQhufgE3An/wzPa4fRXDuDwVpJ
XtQ8B+X4ZnykXcNQLRV/D615dj4e+fmneE47hGbaaQyKPeVFzLNRlm/Ch9rf
GKKl5O+iFb+Nj0M+vhTPagfRVDuFx7QSvLB5FsrwjZir/YWntBT8HbTk2fhY
5OVL8Ix2AE20kxioFeeFzDNRmm/AB9qfeFJLzieiBc/K30YevhhPa/vRWDuB
AVoxXtA8A6X4eszR/sATWjI+Ac15Fv4WcvNFGKXtQyPtOPprRfls/I7HtURt
PJrxzPxN5OILMVLbi4baMfTTivBZ+A2DtZu0cWjKb+Vv4A6+ACO0PWigHUW8
xIX5TFzFoHiRtbFoYryFv47b413FcG03HtaOoI9WiM/Ar3hMuxH3UG/MM5lf
Q854BzFM24WHtC/RWyvIp+MXDNSuxz3TG/GM5leRI94tDNV24kHtMHppBfj7
+BkDtGtxz/SG8fxhBx7QDqGnfiefhp/QX/s77pHeIJ4vbMf92kE8qufnU/Ej
+ml/xT2J8y2eH2zDfdoBPKLn41PwA/pqf8Y90B+K5wNbca+2Hz30vHwyvkcf
7Y/4zvqD8TxgC+pr+9BdzxPfJ/Yam1FP34turuXmueLMjPMsvkfsKTahrs/s
QVefy8kn4Tv01n7HK/p9sYfYiDrabnTRc/AC5ukoydfFGaFdQS/tN7ys3csz
xM9C9jinMFD7hFcx74z3j9/DdyGJZ+efm+vG2Rf7Y77fegLvm++yro0zJPbd
eireJf289W7sw2XXvo7/H8fQM85P61XrS9b6rn8be4DTcZbpX1nvwSHczL+J
74/jeJmfs94WZyMGxD23nozv5Fpl645492NvrEdRW9+JzvHv9M/MdcyH4xky
T0MJ85o4v1xfyGuY9+ISf5T/ihd5PZ4+fndki/MU/bV1qKXtQCctG5+Ii3hE
+wVj9LrxrGItamrb0VHPyifgAnpoP2O0XieeVazB3do2dNCzxBkU50icBbFv
8YxiNWr4zFa097lMvHY8S1iF6voWtHMtIx8f9x/dtZ/wgl4rnh2sRDVtM9rq
Gfg4fINu2o94Xq/Je2IFqmqb0Cb2jo+N/UdX7Qc8F89G3FMsRxVtI1rr6fnb
+ApdtO/xrF4j7iGWobK2Aa30dPwtnEeS9h2e0avzdLFfyMrnoof2BSpp69FS
S8vfxDl01q7gab0aTxv7hSzxNwnd411ARW0dWmhp+Bs4i07aZYzSq/I0sX/I
HH+D0C2eO1TQ1qK5lpq/jjPoqF3CSL0KTx17gVv5bHTVPkV5bQ2aaan4aziN
DtpFjNAr81SxN7iFz0IXbSnKaavRVEvJ85mnojhfjVe1U2ivXcBwrRJPGXuH
THwmkrQlKKutQhMtBc9rnoJifBVe0U6infYthmkVeYrYW2TkM9BZW4wy2ko0
1pLzPObJKMpXxvuvnUDbOBcwVKvAk8feIwOfjk7aIpTWVqCRloznNk9CEb4C
L2nH0Ub7GkO08jxZPAu4Oc46dIxzAaW05WiY+O+f44Rc5vdQmCzHi9oxtI5z
DE9p5XhiPBtIz6ehg7YAJbVlaKD9A0h9cNw=
         "]]]}, {}, {}}, {{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl1mWUVmUUQOEBVLpDpbtbEUVplE4RJUVMECUUlO7GAAWlu0S6u7sbAQNQ
FJu0xecsf2zu2fu7axZz77xnJk+7Tk1eT5SQkHA1cUJCXBu4rjeUxFLeBtO1
VOivJcYDWg/+jbk5zvMR2KAVwiQtR9yrNfTPBnMpLOPPYoaWGgO0JHhQ68mv
mFvgAh+JjVphTNZyxr1aI77RXBrLeVvM1NJgoHYXymm9+Lfmlvicj8ImrQim
aLniXq0x32QugxX8OczS0mKQdjce0nrz78yt8AUfjc1aUUzVcse9WhO+2VwW
K3k7zNbSYbB2D8prffhVc2t8yd/BFq0Ypml54l7tSb4lnjlW8ecxR0uPIVpS
PKz15d+b2+Ar/i6Soqm+NZ4xVvMXMFfLgKFaMjyi9eM/mJ/FRf4ekuEpfVs8
U6zhL2KelhHDtOSooPXnP5rb4hJ/H8nRTN8ezxBr+UuYr2XCcC0FHtUG8J/M
z+EyH4MUeFrfEc8M6/jLWKBlxggtJR7TBvKfze3wNR+LlHhG3xnPCOv5K6iI
Qfov2vP4hn+AVGiu74pngg28PSphsP6r9gKu8A+RGi303fEMsJF3QGUM0a9p
L+JbPg5p0FLfE98zNvFXUQVD9evaS/iOj0datNL3xveIzbwjqiIdWvtsn14R
W/hrqIb0yICMyBRn2H373VMJW/nrqI5h+g3tZVzlHyFznFH9gFYZ23gn1MBw
/ab2Cr7nHyNLnEH9oFYF23lnfKJlwUgtFR6PHcFvmdvjB36MV8QyPoFvNRfH
dJ4XZ8zVscZ8b5xN8yFzVZwzPxE/G/pB14fxaZxN1zrooi90vReXMSr2imut
2Auxf/hp12qxx7A6zo1rvTjn8bVjB7nejp9n1w6x51xrxp6Kn3WfH3ethK+x
PM6xa11M9Nk21xKYEfvHtTbymc+61sBa832xH8yHzdWwkx/ij2AR78o/Nd+H
0TwNasYu47+ZX8VPfBK2ayUxU8uP+2NX8CPm6tjF30Ct2F3671pH/MwnI2vs
Bv2oVgO7+ZuojWzIjhzIGTvAfcfinWIP74Y6yBXn22fH9Sewl3dH3dhv+h/a
a/iFT0HuOM/6ifi+sI+/hXqxv/Q/tfjl9CufijxxfvWTWi3s52+jfuwr/S+t
E67xacgb51c/pdXGAd4DDWI/6X9rnXGdT0e+OL/6aa0ODvKeaBj7SP9H64Ib
fAbyx/nVz2h1cYj3wiLtfryjpUWj2Ef833inuMlnokCcZ/2sVg+HeW8s1rLi
XS0dGsd+4nfMb+AWn4WCceb1z7T6OML7YImWDe9p6dEk9hWPX8hv8tvG2SgU
u0A7pzXAUd4XS7XseF/LgCdjf/FE6MZ/43NQOHaDdl5riGO8H5ZpOTBGy4im
sc94YnTnv/O5KBK7QrsQzwjHeX8s13JirJYJT8Vu4knwFv+Dz8MOXgqztAIo
qnXhn8czwwk+ACu0XPhAy4xmsbv4XXib/8nnYycvjdlaQRTTuvIv4hniJB+I
lVpufKhlwdPaBH43evC/+ALs4mUwRyuE4nEG+ZfxTHGKD8IqLQ/GxZ7DM9pE
fg968r9jn2I3L4u5WmGUiDPKv4pnHPuMD8ZqLS/Gx45B89gRPCl68X9iN2IP
fwDztCIoGWeZX4xnHvuXD8Ga2F34KPYKWsTO4MnQm/8bewp7+YOYH+8CpeL8
80vxzGP38cO8AhbzoXytOT8+5lnRMnYDT44+/A4/Ya6MFXwR32cuhwXxjlA6
9kbs+XgX+Iwf4Y9iCR/G15kLYALPhlaxU3gK9OXxx+9JcxWsNC+W9psfwifx
7lAm9k3s+3hHOMeP8sewlA/n680F43cAz47WsYt4SvTjieK9m6tilXmJzw+Y
y2NhvNP4/5sfxzrzRdf6if//+7yse/8Dm3lu/w==
         "]]},
       Annotation[#, "Charting`Private`Tag$37157#1"]& ]}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Epilog->LineBox[{{{296.32238926374976`, 0}, {296.32238926374976`, 0.13}}, {{
      309.1052052536311, 0}, {309.1052052536311, 0.13}}}],
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{567., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotLabel->FormBox[
   "\"Theoretical Sampling Distribution with 95% CI\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.753414883168544*^9, 3.7534148954526997`*^9}, {
   3.753415194788431*^9, 3.753415209374401*^9}, 3.810921889827239*^9, 
   3.812712430159096*^9},
 CellLabel->"Out[36]=",
 CellID->179887690,ExpressionUUID->"30bd2474-44fa-43bb-8212-33746adb7c4b"]
}, Open  ]],

Cell[TextData[{
 "For a confidence level of ",
 Cell[BoxData[
  FormBox["95", TraditionalForm]],ExpressionUUID->
  "ec439295-4d3f-408b-b9f6-2bbf0c192270"],
 "%, we see ",
 Cell[BoxData[
  FormBox["2.5", TraditionalForm]],ExpressionUUID->
  "a37c4853-6a29-4313-819d-98940a21c171"],
 "% of the area of the curve to the left of the left vertical line and \
another ",
 Cell[BoxData[
  FormBox["2.5", TraditionalForm]],ExpressionUUID->
  "2a8b5a38-2bac-41de-a69a-48d66eeb4460"],
 "% of the area to the right of the right vertical line."
}], "Text",
 CellChangeTimes->{{3.7534152270401735`*^9, 3.753415356712494*^9}, 
   3.811516093310266*^9, {3.812016740916348*^9, 3.812016742070488*^9}, {
   3.8127173327942343`*^9, 3.8127173341702347`*^9}, 3.8159282933555527`*^9},
 CellID->668779,ExpressionUUID->"16322982-613b-4246-875e-afceaa4584d4"],

Cell[TextData[{
 "This is exactly how we are going to calculate a ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "1bd87c61-edda-4197-8bb1-8a1635300f62"],
 "-value for a parametric test, i.e. for testing the difference in means \
between two samples. According to the central limit theorem, there can be any \
number of possible differences. We will calculate a statistic from our sample \
means and that will create the points on the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "64f64333-6e61-4284-b6b9-3162c19d6070"],
 " axis, creating the vertical lines. We can then calculate the area under \
the density curve from the lines toward either side, giving us a one-sided \
test ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "2f1d5182-ab89-4ccd-8473-1eeee0af47af"],
 "-value (or toward both ends for a two-sided test)."
}], "Text",
 CellChangeTimes->{{3.753415365585741*^9, 3.7534155340084333`*^9}, 
   3.810989188638358*^9, {3.810990273145317*^9, 3.8109902765123167`*^9}, {
   3.810998398899555*^9, 3.810998403559555*^9}, {3.811508711789073*^9, 
   3.8115087433682303`*^9}, 3.81271270059406*^9, 3.815928760860132*^9, {
   3.815928847187993*^9, 3.8159288985385733`*^9}},
 CellID->454562945,ExpressionUUID->"15cd734f-56d4-4aec-9164-bfcb4c19c262"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Hypothesis Testing and Research Questions", "Subsection",
 CellChangeTimes->{{3.753415546264665*^9, 3.7534155594683843`*^9}, {
  3.810990232402317*^9, 3.810990232641317*^9}, {3.810997445906106*^9, 
  3.810997451057621*^9}},
 CellID->24235370,ExpressionUUID->"12a886e5-1537-4f9b-8eef-824b9197fc4f"],

Cell["\<\
It\[CloseCurlyQuote]s time to get a bit more rigorous. Our main interest in \
learning about statistics is to infer results from statistical tests \
performed on sample data to a larger population. We go through this exercise \
of taking samples from a population in such a way as to minimize any bias in \
the sample. Such bias might mean that our results are not transferable or \
generalizable, i.e. we cannot use the results as inference (extrapolate from \
the results of our sample and use it on the larger population).\
\>", "Text",
 CellChangeTimes->{
  3.753415568898143*^9, {3.811508755585452*^9, 3.8115087650383973`*^9}, 
   3.8159289927948103`*^9},
 CellID->303767301,ExpressionUUID->"cd323c02-2a66-43a1-9be9-43adc8d07d57"],

Cell["\<\
Statistical tests are mathematical constructs (i.e. our sample means, \
distributions, and probability density curves) that provide a numerical \
solution to a research question. Think of these tests as using computation to \
calculate probabilities and then comparing those probabilities to meaningful \
threshold values. The research question is the fundamental building block of \
statistical analysis. It comes before any intervention takes place, before \
any data is collected, and most definitely before any data analysis is \
performed. \
\>", "Text",
 CellChangeTimes->{{3.7534155991452746`*^9, 3.753415649976368*^9}, {
   3.8109912350779963`*^9, 3.810991313952883*^9}, {3.810991768773115*^9, 
   3.8109917798361154`*^9}, {3.810997239015419*^9, 3.8109972656660843`*^9}, {
   3.810997309712488*^9, 3.8109973343519516`*^9}, {3.8109973660051165`*^9, 
   3.8109974191264286`*^9}, {3.810997464812997*^9, 3.810997464812997*^9}, {
   3.811508786498305*^9, 3.8115087870723047`*^9}, {3.811516093481057*^9, 
   3.811516093828195*^9}, 3.812811285793518*^9, {3.815929016777606*^9, 
   3.815929038994575*^9}, {3.8159290713864613`*^9, 3.815929072618167*^9}},
 CellID->111954806,ExpressionUUID->"8d857024-3b21-4f48-bf26-691b6fe7952d"],

Cell[TextData[{
 "It is not correct to mine data for research questions and small ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "9ccb260c-3c48-4b60-b20d-96d4d6bf1b12"],
 "-values (high-confidence levels), but choosing too narrow a research \
question can result in a good deal of wasted resources if the results are \
completely out of the window of acceptability. A broader question with \
built-in follow ups will hopefully yield a more targeted approach where \
statistical certainty can be satisfied and the public trust maintained."
}], "Text",
 CellChangeTimes->{{3.7534155991452746`*^9, 3.753415649976368*^9}, {
   3.8109912350779963`*^9, 3.810991313952883*^9}, {3.810991768773115*^9, 
   3.8109917798361154`*^9}, {3.810997239015419*^9, 3.8109972656660843`*^9}, {
   3.810997309712488*^9, 3.8109973343519516`*^9}, {3.8109973660051165`*^9, 
   3.8109974191264286`*^9}, {3.8109974800835238`*^9, 3.810997529308446*^9}, 
   3.810998428472555*^9, 3.815929085427141*^9, {3.81592913749856*^9, 
   3.815929137938409*^9}, {3.815929176834322*^9, 3.815929192074247*^9}},
 CellID->657567918,ExpressionUUID->"47f5637b-9fde-4044-a429-abde5a849003"],

Cell[TextData[{
 "A research question has to be stated in a standard form that allows for the \
use of statistical tests. In inferential statistics, we call this standard \
form ",
 StyleBox["hypothesis testing ",
  FontSlant->"Italic"],
 "or",
 StyleBox[" testing the null hypothesis. ",
  FontSlant->"Italic"],
 "We can illustrate this through an example. Consider the question of whether \
there is a difference between the effect on blood pressure between two drugs. \
Let\[CloseCurlyQuote]s run through an experiment to answer this question in \
our minds."
}], "Text",
 CellChangeTimes->{{3.7108196073207607`*^9, 3.7108202712957735`*^9}, {
   3.7158594598403273`*^9, 3.715859477758462*^9}, 3.7158595511203957`*^9, {
   3.7158596320003853`*^9, 3.715859662267935*^9}, {3.7165387914809775`*^9, 
   3.7165387924711003`*^9}, {3.7534156703289766`*^9, 
   3.7534156863610864`*^9}, {3.810997650437557*^9, 3.8109976550430174`*^9}, {
   3.8115160940030203`*^9, 3.8115160945430737`*^9}},
 CellID->74284736,ExpressionUUID->"7cce45a1-c5a2-414e-a472-ed72c5220fa0"],

Cell["\<\
Such a question might stem from wondering about the correct drug to give to a \
certain population with hypertension (high blood pressure). The population is \
a set of people with hypertension. In a way that minimizes bias, a number of \
individuals are taken from that population. Testing the whole population is \
almost never feasible. Now individuals in the sample are randomly assigned to \
receive one of the two drugs. It is common for one of them to be a placebo, \
but that is not of interest here. Blood pressure readings are taken after \
treatment for all the individuals in the sample. We now need to evaluate if \
there was a difference in the mean blood pressures between the two groups.\
\>", "Text",
 CellChangeTimes->{
  3.7534157029058475`*^9, {3.8115088744773045`*^9, 3.811508909648305*^9}, 
   3.811516094725151*^9},
 CellID->426131847,ExpressionUUID->"ff1b6ad5-e8e0-4551-9ab0-5bf6ef65b7ca"],

Cell[TextData[{
 "Now that we have thought about the problem, we start by setting up our \
research question as a hypothesis. A hypothesis has two parts, called the ",
 StyleBox["null",
  FontSlant->"Italic"],
 " and the ",
 StyleBox["alternative hypothesis",
  FontSlant->"Italic"],
 ". The null hypothesis reflects our base belief, i.e. that there is no \
difference between the mean blood pressures of the two samples (groups). It \
is usually denoted as ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "0"], TraditionalForm]],ExpressionUUID->
  "0f4767e2-10cc-43a1-8826-03dd281ce805"],
 ". The alternative hypothesis states that there is a difference in the mean \
blood pressures between the two groups. We denote this as ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "\[Alpha]"], TraditionalForm]],ExpressionUUID->
  "9a17cf44-7f52-472e-a311-22d84297653a"],
 "."
}], "Text",
 CellChangeTimes->{{3.753415758672743*^9, 3.7534157957616043`*^9}, {
   3.811508917650305*^9, 3.811508932356305*^9}, 3.811516094910733*^9},
 CellID->618537001,ExpressionUUID->"afc5c37d-3ab3-41c7-9f3d-16d8056147ea"],

Cell["\<\
Choosing the appropriate statistical test to compare the mean blood pressures \
between the two groups will result in a numerical value called the test \
statistic. You could well imagine that there are many possible values for \
this test statistic based on the blood pressure readings that were captured \
for the samples. If we started our experiment a week later, we might have \
ended up with a different set of individuals from the population. This \
difference in means that we calculate from our sample will be one of many \
possible differences. This should remind you of the central limit theorem.\
\>", "Text",
 CellChangeTimes->{{3.753415810178034*^9, 3.7534158280083647`*^9}, {
   3.8115089375463047`*^9, 3.8115089410463047`*^9}, 3.8115160950977173`*^9, 
   3.815929245002194*^9},
 CellID->38558333,ExpressionUUID->"6f022fb5-4e04-4a4a-a133-d87338bf0f61"],

Cell[CellGroupData[{

Cell[TextData[{
 "What Is a ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "231369fc-09f3-43e9-864b-76127553fc1e"],
 "-Value?"
}], "Subsubsection",
 CellChangeTimes->{{3.810991699747115*^9, 3.8109917217381153`*^9}, {
  3.810998474669555*^9, 3.8109984750065556`*^9}, {3.8159302727043056`*^9, 
  3.815930312193163*^9}},
 CellID->345702858,ExpressionUUID->"916d9d0c-585c-4761-a78d-8a934c364b54"],

Cell[TextData[{
 ButtonBox["Wolfram MathWorld ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://mathworld.wolfram.com/P-Value.html"], None},
  ButtonNote->"https://mathworld.wolfram.com/P-Value.html"],
 "states that the ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "287e1a83-fe6d-4b0c-a0e6-79feed47dc7e"],
 "-value is simply \[OpenCurlyDoubleQuote]the probability that a variate \
would assume a value greater than or equal to the observed value strictly by \
chance: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", " ", 
    RowBox[{"(", 
     RowBox[{"z", "\[GreaterEqual]", 
      SubscriptBox["z", "observed"]}], ")"}]}], TraditionalForm]], 
  "InlineMath",ExpressionUUID->"3bb4fab0-2fc6-44d5-adbe-3f0ad17e82f9"],
 ".\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.8109977702475553`*^9, 3.8109978754245553`*^9}, {
   3.810998012328555*^9, 3.8109980622895555`*^9}, {3.8109981225625553`*^9, 
   3.810998127657555*^9}, {3.810998172853555*^9, 3.810998194208555*^9}, {
   3.810998436403555*^9, 3.810998447370555*^9}, {3.8109990212566442`*^9, 
   3.810999021261645*^9}, {3.811515936350121*^9, 3.8115159723953*^9}, 
   3.8159292543650084`*^9, {3.8159300016742973`*^9, 3.815930024168442*^9}, 
   3.8164565480613537`*^9},
 CellID->174075022,ExpressionUUID->"96d91dea-1614-4783-9636-ff6f0d1d3960"],

Cell[TextData[{
 "As stated previously, the central limit theorem ensures that there will be \
a bell-shaped distribution of these possible differences in means, and ours \
will be one of them. According to the sampling distribution, some values \
(differences in means) will occur more commonly than others. We can set an \
arbitrary significance value, beyond which the value would occur very rarely. \
We convert this value to a probability (",
 StyleBox["p-",
  FontSlant->"Italic"],
 "value) by calculating the area under the distribution curve beyond the \
cut-off (vertical) lines. The cut-off (or significance level) is called the ",
 Cell[BoxData[
  FormBox[
  Cell["\[Alpha]",ExpressionUUID->"9adb440d-2c1f-41ab-b609-6b27b80c346b"], 
   TraditionalForm]],ExpressionUUID->"b8983fea-9230-4559-a6a8-8f1042411cd9"],
 "-value and is usually set at ",
 Cell[BoxData[
  FormBox["0.05", TraditionalForm]],ExpressionUUID->
  "fc72d715-724a-451c-aa3c-9cd5d0ba0328"],
 " (or ",
 Cell[BoxData[
  FormBox["5", TraditionalForm]],ExpressionUUID->
  "2b3e86a4-7dba-46ad-bdea-f50b6a62843c"],
 "%). If the probability is smaller than this, we call the difference between \
the groups statistically significant."
}], "Text",
 CellChangeTimes->{{3.753415867767057*^9, 3.753415936660855*^9}, {
   3.8109982989475555`*^9, 3.810998302032555*^9}, {3.8109991980833254`*^9, 
   3.810999204876004*^9}, {3.810999241476664*^9, 3.810999243277844*^9}, {
   3.8110725576090784`*^9, 3.8110725579390783`*^9}, {3.8115089672203045`*^9, 
   3.8115089859613047`*^9}, {3.811516095293521*^9, 3.81151609549336*^9}, {
   3.812016924484898*^9, 3.81201692723085*^9}, 3.815930055613806*^9, {
   3.815930142360423*^9, 3.815930142695953*^9}},
 CellID->141989411,ExpressionUUID->"c157202c-90b0-444f-9dd9-1b4c4e468c04"],

Cell[TextData[{
 "Consider this carefully, though. The distribution of possible test \
statistics is drawn up from the null hypothesis, i.e. that there is no \
difference between the two groups. Given that we accept that, in reality, \
there is no difference, if we then find a rare value, we say, given that \
there is no real difference, that we found a rare value and therefore reject \
our null hypothesis and accept the alternative hypothesis. We never actually \
prove that there is a difference. We simply say that given that there is no \
difference, we found a rare result. There is no way to set up a distribution \
that states as its base that there is a difference. The curve that is drawn \
from all the possible test statistics assumes that there is no difference! \
This is actually a bit hard to swallow when you first learn about it. A ",
 StyleBox["p",
  FontSlant->"Italic"],
 "-value is based on a mathematical curve that states that there is no \
difference. There is no magical power behind it and the significance level of \
0.05 isn\[CloseCurlyQuote]t magical either.",
 StyleBox[" ",
  FontSlant->"Italic"],
 "It doesn\[CloseCurlyQuote]t actually prove anything!  In fact, many \
scholars and even journals are moving away from the use of ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "8ab0a15e-ba75-4aee-87ac-e4f2936c8616"],
 "-values."
}], "Text",
 CellChangeTimes->{
  3.7534159577883654`*^9, {3.75341600799513*^9, 3.753416043586993*^9}, {
   3.8109983412565556`*^9, 3.8109983463885555`*^9}, {3.8110922824801383`*^9, 
   3.8110922846487045`*^9}, {3.8110923625730534`*^9, 3.8110923628890533`*^9}, 
   3.8110924048740535`*^9, {3.8110925058760533`*^9, 3.8110925193330536`*^9}, {
   3.811509035183305*^9, 3.8115091501023045`*^9}, {3.811516095685815*^9, 
   3.811516097130287*^9}, {3.815930154560904*^9, 3.815930176775756*^9}, {
   3.8159302300140867`*^9, 3.8159302624357357`*^9}},
 CellID->304883007,ExpressionUUID->"4c56299f-e35e-45d8-87d2-7b8b67ba3408"]
}, Open  ]],

Cell[CellGroupData[{

Cell["What Is the z-Distribution?", "Subsubsection",
 CellChangeTimes->{{3.811096854124649*^9, 3.811096863784649*^9}, 
   3.8159303209607763`*^9},
 CellID->429092826,ExpressionUUID->"8afe460e-9919-4f51-bfe0-37a8aced2ff4"],

Cell[TextData[{
 "Next is a plot of a standard normal sampling distribution drawn for ",
 Cell[BoxData[
  FormBox["100", TraditionalForm]],ExpressionUUID->
  "66705cfe-c7b7-4c6b-a2c8-571572657d49"],
 " samples, with a mean of ",
 Cell[BoxData[
  FormBox["0", TraditionalForm]],ExpressionUUID->
  "e348f124-82f3-4531-bd55-ba7940bd041f"],
 " and a standard error of ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "3f96ddba-b4d0-4c10-99a2-d6217065e723"],
 ". This is sometimes referred to as the ",
 StyleBox["z",
  FontSlant->"Italic"],
 " distribution, although the sample size is not relevant to that definition. \
It is also sometimes referred to as the \[OpenCurlyDoubleQuote]standard \
normal distribution.\[CloseCurlyDoubleQuote] As described here, it is a model \
of all the possible test statistics, with ",
 Cell[BoxData[
  FormBox["0", TraditionalForm]],ExpressionUUID->
  "e64716a4-cf32-417d-b31e-d8e444f09332"],
 " (no difference in means between the two groups) occurring most often. The \
test statistic for our difference will fall somewhere on the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "1de768de-d5b9-48e3-a31e-4b72fbc6ac86"],
 " axis. Remember that since we are dealing with computing a continuous \
variable probability, it makes more sense to calculate the area under the \
curve (",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "0c7d4fd7-5abb-48ae-81ab-04c48fc27b9b"],
 "-value) between two points, as the probability of using a continuous random \
variable to obtain a specific value is zero. "
}], "Text",
 CellChangeTimes->{{3.7534160542863617`*^9, 3.753416181097309*^9}, {
   3.753416245809288*^9, 3.7534162670415177`*^9}, 3.8110725730270786`*^9, 
   3.8110956380065503`*^9, {3.811096649726559*^9, 3.811096692795252*^9}, {
   3.81109672781175*^9, 3.811096728150716*^9}, {3.8110968867056494`*^9, 
   3.811096934833649*^9}, {3.8110970180146494`*^9, 3.8110970282656493`*^9}, 
   3.811098455421649*^9, {3.811509161929305*^9, 3.811509199499305*^9}, {
   3.811516097338036*^9, 3.811516098055046*^9}, {3.8127162672343044`*^9, 
   3.8127162780213833`*^9}, {3.812716321255706*^9, 3.812716349223502*^9}, 
   3.815930407929202*^9, 3.8159304660652857`*^9, {3.815930500081662*^9, 
   3.815930510256815*^9}, 3.815930588880766*^9},
 CellID->703035283,ExpressionUUID->"491b6fe8-50f2-4e31-a122-9365fbcf250e"],

Cell["\<\
Plot the curve from the test statistic toward its left and right tails:\
\>", "CodeCaption",
 CellChangeTimes->{{3.8110984423946495`*^9, 3.811098445352649*^9}, {
  3.811098487834649*^9, 3.811098521433649*^9}},
 CellID->107372641,ExpressionUUID->"da625b29-a04e-41c5-9189-c86e8e7d5862"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"PDF", "[", 
    RowBox[{
     RowBox[{"NormalDistribution", "[", 
      RowBox[{"0", ",", 
       FractionBox["1", 
        RowBox[{"Sqrt", "[", "100", "]"}]]}], "]"}], ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<\!\(\*StyleBox[\"z\",FontSlant->\"Italic\"]\) Distribution for 100 \
Samples\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7108218287414737`*^9, 3.710821831607623*^9}, {
  3.7534162778566055`*^9, 3.7534163559371843`*^9}, {3.811096598154717*^9, 
  3.811096600970435*^9}},
 CellLabel->"In[37]:=",
 CellID->542644812,ExpressionUUID->"6b07a317-73cb-4921-8e28-62864db05314"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJw1mnk0Ve/7/imZwomolCIhUxlCSdybhChjKGSKBrwRMmRISKbMEQkhY5kS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    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1ne4j3Ucx+HjmNl7k5mZVWSPyt5771UhIRklKVIhm2QTSdl779mgrdCi
lNKiSen+5I/7er7v1znW+T3PcynYa3CrhxMTEhKS8F7ireu7ibfOFZxPu1bl
OG/4YgXX/dzhvIQ7nDfH13zvKruM825u2I/ZN3jB7mJnc55KNns5z2qv2CWd
t/OR3cL+iD52ebuo82KK2pt4XbvOcO06z2ud7azOL5LVXsYE7UOaax/SWytn
F3FeRBF7I6u1v3lU+5vntE52FucpZLGXMl77gGbaB/TSytqFnRdS2N7Aa9pf
DNP+YqLW0c7sPJnM9hKe0d6nqfY+PbUydiHnBRSy17NK+5Oh2p88q3WwMzlP
IpO9mKfj86OJ9h49tDvtgs7zKWiv41XtD4ZofzBBa29njM+JjPYixsV9QGPt
Xbprpe0Czi9TwF7LSu13HtF+Z7zWzs4Qnw0Z7IU8FfcSjbTTdNNK2Sv4jcHa
bzyjt7XTx2dBensBY7VTNNRO0VUrGfcP13hYu8bTehs7XfzsSWfP50ntHRpo
79BFK2Ev5yqDtKuM01vbaeNnTVr7ZcZob1Nfe5vOWnF7Gb8yUPuVp/RWdpr4
2ZLGnscT2lvU096ik1bMXsovDNB+Yaze0n6cN6mrvUnHeObsJfzMQ9rPPKm3
sEdzkvu1k3TQi9qL+YkHtZ8Yoze3R3GC+7QTtNeL2Iv4kQe0H3lCb2aP5Dj3
asdppxe2F3KF/toVHteb2iM4Rh3tGG31QvYCfqCf9gOj9SbxruAotbWjtNEL
xv3G7eQnX9yP8exzhFq+7witfW9eez7f01f7nlF6o3i2OUxN7TCt9Dzx+zrP
43Z7TXzO2mX6aJcZqTW0U8d9TWr7JYbFfWOXcN7GIbuGfYiWdm77defyzvvI
71zJ9XD8euf88b6M+8L3VXY9Gs9lfM7xzLKL7+J+c72bg/SOzym66wjXBvE8
uFbhWLx34r6KdxJ7uC3uc9eK8feL903cF9GZy1C//h7XI/G+9LXirlvjz9Lv
cj1Adf0gLZxz6audyznvJZ/zXPLFOzn+Xb6+0i7tvJNv7V72tzxm17dTxfNJ
KnsOQ7QDVNMO0FzLac/lEj21SwzX68U7hv1U1fbTTM9hz+Ebemjf8KheN94p
7KOKto+menY7G1nJEs9LvDvYG5+F79lLE9+XOZ6NeC+wJ35W+h4a+1qmeA7i
mWc3lfTdNPK1jPZsvqa79jXD9DrxjLOLitouGuoZ7FlcpJt2kaF67XjG2cnd
2k4a6OntmVygq3aBIXqteMbZEZ+ftoP6ejp7Bl/RRfuKR/Sa8YyznQradurp
ae3pfEln7UsG6zXslPF+JKU9m/7aNspr26irpbGn8QWdtC+I/2BUt1PE+5EU
9iz6aVspp23lfi21PZXP6ah9ziC9mp083o8kt2fSV9tCWW0L98X9bb/IZ3TQ
PmOgXtVOFu9Lktkz6KNtpoy2mXu1VHZe5znktVczRTtPe+08A+K5s5PG+5Sk
9vR4RrVN3Kltoo6W0s7jPJs88ZwyWTtHO+0cD2mV7cR435JoT6OXtpHS2kZq
ayns3M6zyG2vYpJ2lrbaWR7U7rGTxPuYJPZUemobKKVtoJaW3M7lPJNc8R7i
Be1T2mif8oBWKSHh//8cjk4Sf1E/Y3o4rqektp6aWjI7p/MMctoreV77hNba
J/SP95J9k1H2TaZo3e11lLDXUUNLaudwnk4OewXPaSvsUs47OGO3ss/QL96Z
9r+MtP9lstbNXupczHkLa+3i9lqqJ/7/T0rI7jyN7MYrTNQ+pqX2MX21u+x/
GGH/wyStq72GYvYaqmn/AUt8Wso=
         "]]]}, {}, {}}, {{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl1ne8znUYxvFjlLL3KOLYe0sqZJOKjr05Rkal0Day9yhEw96y9wpllJld
mqSpPajM3verPz6+1/V5Hjy/+3s/53USk/smPZkiISHhWMqEhDjvc64UimGl
3gHjuev6c7iuV0J37iP9UXykj8ZCLiemcDkhJtzvj1VycazSN+rFME/vqE+Q
b8jP44ZeGT24j/UkfKxv1UthkT5GXyTnwit6LqTiquur5RJYrXfCRO6m/gJu
6lXwGHdWb4az+lgs5nLjVS43UnM19DVySazRO2NSPBBejEHhbkdP/RO5OT7R
x2EJlwdTuTy4haupr5VLYa3eBZNj5niJS4GqXC/9U7kFPo3ZYyl3B6Zxd+BW
7gF9nVwa6/RkTOFSYmDMHvdwvfXP5Jb4LOaNZdydmM7diTRcLX29XAbr9a54
hUuFQTFjVOP66J/LrfB5zBjLubx4jcuL27ja+ga5LDbo3fAqlxqDY8a4l3tc
/0JujS9ixrgddfiNXDlsjH3DVO4WDImZ4j7uCf1LuQ2+jJkiLerym7jy2BQ7
hWncrXg5Zoj7uSf1c3JbnIsZIh3q8Zu5Ctgce4PpXBoMjZmhOtdXPy+3w/mY
GdKjPr+Fq4gtsSexU3iK/4prj69iJsiABvxWrhK2xh7EzuBp/gLXARdiBsiI
hvw2rjK2xT3HTqAf/3V8t/B1PDMyoRG/nauC7XGPcefoz3/DdcI38YzIjAf5
HbHj2BH3FHeKLGjstXdiX/FO3EHcF7LiIa/tjN3Dzphv3AWyITtyICce9r5d
sVPYFXOMmWMA/y3XGd/qryEXHuF3x85gd8wxZoxn+O+4LvhOn4HcaMK/GzuC
d2OO8W9xt2FY7CgacM/q38vJ+F7fppfGYn2m/racDzP0fPFMcnksj++215vK
78Uuxf8jV4rOb3IWx3x+n7Mq+sXnc96OgxjutT3OKjgaPubpLIfDWKa/76yG
D9HQ33/O+QN/wNnV+Z6zMo6E9/p2ZxkcwhKv73feg9e9tsJ5F2bye513R4/5
Oyvg7fj54n2Pyntiv+Pz6Zv1Elig99dnymkxQk+LRtzz+kW5Gy7qb2Allz/+
by5//KzhkvS9co34DHHfsWt4gf+R644f9TeRF834fVzNmGPcd+wf8uEu5EcB
JKK59+73vgfiueNuYx/xIv8T1wM/6W+hIFrw73O1Ys4x29hLvMT/zD2Gn/VZ
KISW/AdcbXwQzxx7iYH8L1xP/KLPRmG04g9wdeK+4hljLzGI/5XrhV/1OSiC
1rEXXF0cjM8d+4XB/G9cb/ymz0VRtIl75urhUHzuuDsM4X/n+uB3fR6KoW3s
FVcfh+Nz43UuHUZy6ZDEvaz/IT+OP/T5KI52sWfxvcGReI64Zy49RnHp0Ywb
qv8pP4E/9QUogfax51xDHI3ninvmMmA0lwHNuWH6X3L8YvKXvhAl0SG+B7Fv
+DCeM+6Sy4gxXEa04Ibrl+S+uKQvQil05I9xD+JYPGfcLZcJY7lMaMmN0C/L
T+GyvhiruAJ4gyuA0lwn/bjcGMfjuePuucwYx2VGK26k/rf8NP7Wl2A1l4g3
uUSU4TrrJ+SHcCLmELvBZcF4Lgtac6P0f+R++EdfijVcQbzFFURZrot+Un4Y
J2MusTtcVkzgsqINN1r/N77b+FdfhrVcIcziCqEcl6yfkh/BqZhT7BaXDRO5
bGjLjdGvyANwRV+OdVxhzOYKozzXVT8tN8HpmFPsGpcdk7jsaMeN1a/Kz+Bq
/EzGeq4I5nBFUIHrpp+Rm+KMvkUviYX6qNhDOQcm6znQnhunX5OfxTV9h14W
S/UV+ga5KObqRbFbrogV8TPAeW/K/393rui9/wEFgFkf
         "]]},
       Annotation[#, "Charting`Private`Tag$38702#1"]& ]}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{592., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotLabel->FormBox[
   "\"\\!\\(\\*StyleBox[\\\"z\\\",FontSlant->\\\"Italic\\\"]\\) Distribution \
for 100 Samples\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7534162882737775`*^9, 3.7534163566871758`*^9}, 
   3.8109218908493414`*^9, 3.8127124307930326`*^9},
 CellLabel->"Out[37]=",
 CellID->426693001,ExpressionUUID->"42c5c0ee-4dd5-4373-ae06-06d01f22c9bb"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Process of Hypothesis Testing", "Subsubsection",
 CellChangeTimes->{{3.811098641958649*^9, 3.8110986484966493`*^9}},
 CellID->238580891,ExpressionUUID->"79080bc4-5736-47fa-951e-f405ad26eb23"],

Cell[TextData[{
 "Below is an idealized image of the process. It represents a distribution of \
possible test statistics. The orange area under the curve is equal to 5% of \
the total area under the curve. The black line translates to a specific test \
statistic value on the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "8d2f4ef0-c697-4f0b-b780-55c835cf5fb8"],
 " axis (difference between means). We will learn later how to transform our \
actual difference in means to this ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "49a3c3b6-5fa7-4be5-90a0-e664de5cd514"],
 " axis value. For the ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "fcd6474b-f401-4e71-a75a-ee304f074d05"],
 "-value, we calculate the black area under the curve. It is clearly smaller \
than 5%, so we reject our null hypothesis and accept our alternative \
hypothesis, i.e. a statistically significant result."
}], "Text",
 CellChangeTimes->{
  3.753416367527193*^9, 3.753416400168923*^9, {3.811516098277173*^9, 
   3.81151609923524*^9}, {3.815930632320672*^9, 3.815930645712303*^9}, {
   3.815930700048764*^9, 3.815930701048284*^9}, 3.816456586060974*^9},
 CellID->156611181,ExpressionUUID->"3645aa67-1fe2-4b37-a844-449223ec577f"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzs2rFtF0YchuG/AoqgY4VskTIpU7gxokWxFWOlMZKNhGg8A0swCAPgJVgD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    "], {{0, 1600}, {2400, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSizeRaw->{2400, 1600},
  PlotRange->{{0, 2400}, {0, 1600}}]], "Output",
 CellChangeTimes->{3.8109218913803945`*^9},
 CellLabel->"Out[54]=",
 CellID->2668181,ExpressionUUID->"580266a2-8cdb-4213-a938-a096b779dc0a"],

Cell["\<\
This is actually called a one-tailed test. We put all of our eggs in one \
basket, so to speak. The alternative hypothesis in this case would actually \
not state that there is a difference in the effect of the drug on blood \
pressure but that one is higher than the other, with the null hypothesis that \
it is equal to or lower than the placebo group. This form of hypothesis \
testing should rarely be used. It is only valid if we can convince ourselves \
and our peers that it was correct to hold such an assumption.\
\>", "Text",
 CellChangeTimes->{{3.7534164544737225`*^9, 3.7534165053846307`*^9}, {
  3.811513172063079*^9, 3.811513188103683*^9}, {3.811516099464973*^9, 
  3.811516099704653*^9}, {3.815930715751705*^9, 3.815930735856406*^9}},
 CellID->52238752,ExpressionUUID->"8680aae0-8a53-454c-ae5a-bd830bbb72d8"],

Cell["\<\
It is much more common to use the two-tailed approach, where we simply state \
the alternative hypothesis as there being a difference. This means we split \
our 5% area into two, i.e. 2.5% on either side. We also duplicate the black \
areas.\
\>", "Text",
 CellChangeTimes->{
  3.7534165147495966`*^9, {3.7534165465126433`*^9, 3.7534165535448413`*^9}, {
   3.8115132248393564`*^9, 3.811513244846357*^9}, {3.811516099941227*^9, 
   3.81151610018332*^9}},
 CellID->59218591,ExpressionUUID->"4a50c0a0-6036-4568-ab17-45e29eab26b6"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzs2jHqYIUVxeE/MQTt3EJ2YZmUFsOAYhuiZCI2I4xiyFamNhuYzj24gOzA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    "], {{0, 1600}, {2400, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSizeRaw->{2400, 1600},
  PlotRange->{{0, 2400}, {0, 1600}}]], "Input",
 CellLabel->"In[38]:=",
 CellID->132359010,ExpressionUUID->"a34125cd-8915-44ce-91de-07c420ff87c1"],

Cell[TextData[{
 "The reason why we duplicate the black line is easy to understand. It simply \
follows from the order in which we do the subtraction to calculate the \
difference in means. If the mean blood pressure in the first group was 110 mm \
Hg and in the second group it was 111 mm Hg, the difference could be either ",
 Cell[BoxData[
  FormBox[
   RowBox[{"+", "1"}], TraditionalForm]],ExpressionUUID->
  "7678ebed-e70b-4478-8891-b93d42685106"],
 " or ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1"}], TraditionalForm]],ExpressionUUID->
  "f327205a-aab1-4298-9a8e-ff028d6df24f"],
 " depending on which group we place first."
}], "Text",
 CellChangeTimes->{3.7534165982572875`*^9, 3.811513292874159*^9, 
  3.811516100423191*^9},
 CellID->789409204,ExpressionUUID->"ce13eab1-a31c-4553-814a-e7492ccf705b"],

Cell[TextData[{
 "Irrespective of which, we convert this difference into a value that we \
place on the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "66ad176f-a40a-4480-a378-7859490c9773"],
 " axis of this sampling distribution of all possible differences that is \
guaranteed by the central limit theorem. We duplicate it on the other side of \
the graph for a two-tailed test."
}], "Text",
 CellChangeTimes->{{3.753416622909378*^9, 3.753416662368902*^9}, {
  3.8115132682186937`*^9, 3.8115132907659483`*^9}, {3.815930759399626*^9, 
  3.8159307603680563`*^9}},
 CellID->521413849,ExpressionUUID->"1f09d46a-9c33-45d7-80c6-be1f0be2d3c2"],

Cell[TextData[{
 "Since we are dealing with continuous variables, we stated that we can only \
calculate the area under the curve between values. The idea here is that we \
calculate the area on the curve from negative infinity to the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "167887f8-c260-49c5-9b2c-923a6b789584"],
 " axis value on the left side and from the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "58c62be6-b826-41ac-973a-97347376f73c"],
 " axis value on the right to positive infinity. This is not too complicated \
and is accomplished using the cumulative distribution function."
}], "Text",
 CellChangeTimes->{
  3.7534166534138184`*^9, {3.7534168413692837`*^9, 3.7534168483047657`*^9}, 
   3.811513289003772*^9, 3.811516100675623*^9, {3.815930770968388*^9, 
   3.815930797967924*^9}},
 CellID->571596540,ExpressionUUID->"66050313-cfaf-4780-9833-ae41390d393e"],

Cell["\<\
A few things are important to reiterate. Any difference we find between \
statistics for two or more groups is but one of many possible differences \
that we could have found if we could run an experiment many times over.\
\>", "Text",
 CellChangeTimes->{{3.7534166920415397`*^9, 3.753416704296776*^9}, {
  3.8115132827331448`*^9, 3.8115132942072926`*^9}},
 CellID->347515460,ExpressionUUID->"29b8b41f-3cda-48e2-9f65-afc273e27507"],

Cell[TextData[{
 "Given the results at hand, we construct a distribution of sampling values \
(all the many possible outcomes) and place our specific value somewhere on \
this curve. Through calculating the area under the curve, this allows us to \
find out what the probability was of finding such a result, i.e. we calculate \
a ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "e2fcd6d6-b40f-459b-9720-facb9a299746"],
 "-value."
}], "Text",
 CellChangeTimes->{{3.753416718161702*^9, 3.7534167380166435`*^9}, 
   3.810998377932555*^9, 3.811513298891761*^9, {3.815930822835287*^9, 
   3.8159308239984007`*^9}},
 CellID->88470855,ExpressionUUID->"a720bcd8-6458-42a5-a2a2-881df48b9ca4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cumulative Distribution Function", "Subsection",
 CellChangeTimes->{{3.753416775008709*^9, 3.7534167804481688`*^9}, {
  3.811098322261649*^9, 3.811098325086649*^9}},
 CellID->6340904,ExpressionUUID->"cb7a8bb0-c6a2-48b6-8f38-50b49ed29c5e"],

Cell[TextData[{
 "We have mentioned before that the total area under the curve of a PDF is ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "8461c277-3f9c-4b23-97dc-9a7d3c6b67de"],
 " (representing ",
 Cell[BoxData[
  FormBox["100", TraditionalForm]],ExpressionUUID->
  "b498218a-553c-4c27-95f4-5137d8ac117b"],
 "%). "
}], "Text",
 CellChangeTimes->{
  3.7534168022059927`*^9, 3.811185905368113*^9, 3.8115133887397447`*^9, 
   3.811516100928443*^9, {3.815930863351268*^9, 3.815930863608039*^9}},
 CellID->21272686,ExpressionUUID->"f414acb2-a79d-4953-9a97-0f2da13a4cbe"],

Cell["\<\
Let\[CloseCurlyQuote]s take another look at the PDF of the standard normal \
distribution:\
\>", "CodeCaption",
 CellChangeTimes->{3.815930917624251*^9},
 CellID->615112329,ExpressionUUID->"2df57f37-4fd0-4601-aa50-422798acf36d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"PDF", "[", 
    RowBox[{
     RowBox[{"NormalDistribution", "[", "]"}], ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellLabel->"In[38]:=",
 CellID->150587764,ExpressionUUID->"e7bf6da2-24f7-4232-9aa9-959f1b94e44c"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJw1m3k0F873/+378tq8Xqgo3hVSKVqEmSlCiWTPXilkSYWE7NmJyJYUspUs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    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1WWYVlUUQOFxUEpAEBRBuru7u7u7G6S7uxskVRQMsLuREAxApEulBATF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         "]]]}, {}, {}}, {{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl12WYVVUfQPGhU0G6uxSlu0G6lO7u7u4wCSVUGqRBEElBQumUVrpTCemO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         "]]},
       Annotation[#, "Charting`Private`Tag$13576#1"]& ]}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotRange->{{-6, 6}, {0., 0.39894211025341036`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.815927958703435*^9, 3.815928066153823*^9},
 CellLabel->"Out[38]=",
 CellID->434199305,ExpressionUUID->"59b31282-6380-416f-ba65-e81fc37bf5a6"]
}, Open  ]],

Cell[TextData[{
 "The area under the curve is actual calculated by the cumulative \
distribution function (CDF). It steps along the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "60b3c48f-ac69-4ab1-98a0-aa2314c9c787"],
 " axis from the left and starts adding the area under curve as it goes. Put \
differently, the value of a CDF at a point ",
 StyleBox["a",
  FontSlant->"Italic"],
 " is the area under the PDF from -\[Infinity] to ",
 StyleBox["a",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{
  3.753416866917973*^9, {3.8115135218020496`*^9, 3.811513540379907*^9}, {
   3.811513984859053*^9, 3.8115139991436243`*^9}, {3.811514029715567*^9, 
   3.811514039725566*^9}, {3.811516101182967*^9, 3.811516101457694*^9}, {
   3.815930942431992*^9, 3.815930950655815*^9}},
 CellID->121538785,ExpressionUUID->"793b8703-44fc-4336-9428-e362813d03bf"],

Cell["\<\
Let\[CloseCurlyQuote]s look at a plot of the CDF for the standard normal \
distribution:\
\>", "CodeCaption",
 CellChangeTimes->{3.816456607327791*^9},
 CellID->1811596032,ExpressionUUID->"342c5659-e53c-494b-9560-af28ff4fb422"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"CDF", "[", 
    RowBox[{
     RowBox[{"NormalDistribution", "[", "]"}], ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "6"}], ",", "6"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.717493068080056*^9, 3.7174931226464925`*^9}, 
   3.717493177410085*^9, {3.7174932153457985`*^9, 3.717493250491655*^9}, {
   3.7174936917787666`*^9, 3.717493700056589*^9}},
 CellLabel->"In[39]:=",
 CellID->172466177,ExpressionUUID->"ed4b1524-9c0d-4a11-8e7a-6c3290441bef"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJw1m2k4Vd///s3TMZzJUZKoD6FJKTLttUKpSKJkJipDMpRZJVLGJJU5oTJE
EqJMZ4VkShNCknnmmMn43+d7/X+euF6XJ3uvde/7/Vr2OZI2LgaX2FhYWCTZ
WViYv23fRDE2NkTQCdnRJOIsEUtI3BH9RVAE0Ugjh/Ni92PP/oa4nOGloS/2
bseFLAwx2jfD07LCwsgusv3BXewaVqtvqNUgRUVlrz9cXKc/wI7LSrnv2E5B
U6Sq7rbxHEwl1zz96z4y8n2kcN3rdw22HHaZckCWhL4k7++Gxb3Y/OKLJ5Y7
icjxjkBE5aFVrHp79MGKq4Jo6qZdqdNbMlDl9C/YdZEf7fFglPaYyILHUEnp
yE0+1Nb0sOavGwZsk4wHRp/xIF3n7IitpDPga4Y4L2sCF4LCmyRyTW2BOH/e
fnoRB5oPq7/4X8F1wCcx+HXkFRvKe9N/3G5TEHA6ezcuM5MFzcXdvnRW9BGw
rvrbIB69Rg8P6vOQDEkB29XXz3wK+Ee3aBn6mmKbA7LsC3pKi+bpnQlKtwUt
i4Dj7Fvz8IRpehc4KtZp9hHsvcVpwrVjjB79rLiZ1aoOUHyaCTGJfXTFLPdR
oePfwa+LTnJv+lrpCbYn/igJ/QJevnKRdU8q6Osn9hNm5jrBqweH4Qv5chDd
0x7der0HRDoEtFoH/gI+ruKXeWL6gcCcrmrOmT4gId+61VNzCHS71xz0DBoD
C+27xbGqETD54VSlV+00yJzPcxotGwPpwanWF0PnQWOrX2OJ1ASQWsimeCf+
A27Zn7L8wSToyt9Wrmq/BiZldl23np4E52K7Q8aiWOCAXmdIvQ0DJL+MKNeN
YYNBHEW3nV8zAIfZ1QlOHw5YWELMYm9hgCbrrAyDIC6Y7W+3Y2OMAd4JiFos
OvHANorL6IcFBpBOkBzm1uWDmsckcjpWGGDZM2gt25Af9uw1aLBYZ4Cx5S2C
mYcFYa8nL6vpBgOk2AU3b9lBhM/jZaNrcI460hixWYoESZWF0+M4C7pka1QJ
k2HDm8b7/3Cu0HpfXiRKgTXdChLrOK9dtVI0EqTCqMYB1w2cWbl/xO9ao8KB
nvutTFY8fq3yJAsNLp7+Mc/k5c6cYeEZGgz2sFtj8v9/HqCfnfcGk29JdaDL
wSIoST47MdFGEktSb70tFEFDpSzW56ITNLCO885W6g+E0UV7o+XlcRvMJern
Cd+nVHRptHH/S8kAjEddzXzxOQXx7mtSvRGWjH0cg/f/ZZIR/8u8Tzx9H7CE
pJ7O2zkkZHn3VldbWzPm/fHu2eOZRAQeUit5raaw87yTb9QthVC9PCHUcSs3
YHnMMzdnL4Bs8stFFzm3geHtZh5FrgQk9/eraniNArgxqS0YE8mLxkKUtz6d
OgY2p6kuzidxo9JIO8X+fhOwYGK31TqTExnqbltIqb8CqLSG28157ChN+pGD
iMkNoFpy6GBdFiuq0prOyBsKB2KKHuvFbhv008eTpZqPx4MjLAzBmdAVuoB8
oWHPt5dg8EdbPExapHPtuWBZO/4W8OUeePY8c5Ye2TVk+ViwDATkHwwV3M2g
u+tzdiaIfwIpK04H9KyG6F9cBF9s+fQFeBbyHiZdGQJ9lqnx+tHDwHIurzM/
jAGIHE3P3n0dBfUpXqTJzFmQeuCI9Ylb42CwQlrFOXoRhHp5OVbSJ0Bg86Xh
9oAV0Pz1rrVP6iSodnW14z26AaqBcJ+/PAP4JivuSHrECjd/uCQE7zPAGZab
57KC2eGpBxti/NUMMGIRfjLnFicMt2osc+9lAI3iC2wvvblhBZm25+QMA0z+
fJrmb84LX+yN9678h+eR5+dM+2kCDB5xL7JeY4CZw9845Y4JwLrJjOoFPM+0
S09+uwAheErMLO4pnp+45qw80RdE+GoCverC+XRbqZ3zUxK0SO34NYfzYPt+
FvU4MkzOOei/irNlO8H33mMKPMK+e4mZZ/+STcPoLhXusPfNZ+Yxaef2vaW3
hKHxou4Yk+OiH5yT96HBOqmfy0zeWyM+zucjAtm1vq8z2dXxkHFBlQji5bSZ
O3JmE5Y4fiPU+QsN9XcpDr5JU8bKEv3stBuFEbn9smGSuBmmkfeo8Uw7Fe0S
nO4QI/hgwzXa+j39FJRx4K5Si1AMFsRXcDtygIxkL+QmfrxQgDlKPTsiM0lC
Ox8bezyZbMKUpRcUyoeJ6LrJktvRL8NYymri1ZutQkhtOC1ZgMYGbMxOPTYZ
E0BL3pd1yiQ2ATL1KtVtlICUWEyd3hfvAyGx9LQxTj5U09h71bNYA2DbTjq7
ivMgxS8lxblC50Avi+YjeUkuZHEiel+lih3Y/FC9vU6BAx0iFU4s5HiB7RMC
gSZybCjJ6mDz9PtgUL74V6dSngX9i1L58IktBny7YHeVJ3KV/q2bS1SN6zng
CBmbZ3uwRE8I29GsMPsGmBKuozdv5uhmY0KvxDZ9AOek0/VPxE3Rk4y7/tze
UwWG1D4clTsyQt9/5nzOelAD0Dib/cHScgCkw+wAr8kh8KywNORx8ATI+hyr
aXlqFJi/7h3Jfz8DioKuPRuVGAfHdlw8NXJ/ARy+6Plgv+cEODvAs54ZuQwO
zh2pHbg2Cb6TjkenGa0Dcb4O19dkBhhOILRqklnhRUtC+zUfBlj6EcS7IsgO
TfSTRUM+MICn+eqW9hUO2CIRO6fTyQA8EZwtfutcsKxJ+K4DgwF+TP32L+3n
gWsOow4XlhjA7IzvxNQXPkjRpJzLX2WAhfOvWMca+eH6W+nL+Xh+WfLa5ghl
gvDsrd3T/nh+xJLjNBJtiVDRWFyuGecpfq1lzQsk6Gqy5dI0zr4vnCVZzpOh
xumt6ivMfhbqTUw+T4Hn1hISmfnFqGoPCCepsPi/2zHMPOqJLNvOqgtDU4WM
XiZHdN+SFdURQVsdqn+o18hgyZH7vPNO0pDJjgMalIGT2BLlwnkFA2FUTlXI
nDNwxJJcKZ/TLlAR3/XBMybmwZhMgby9gC0FNRrED74XfImtNzbFX3QiI/G7
O9mKVD5i9ZT/vNsdScigJ/Oq+dpvrMhc2OOnHRGNUlWOM4LnMUEanFkbEET9
olTjGTcBkNxYZRg1yI9sr8TtP9a1A1TsP9G6ssCHsCTGi6FHh4Hr0W8+UIQX
Wc/Urw1w6YK5//bc9tvCjeIkr/36WWwF+ArCMx7s40SRu6cVz0W7AqFEY5m/
e9hR74EQmTvDt8HZYIvBw7KsaPpPnXitaRSouCF3aSxgnd55OVGcMJ8E8pM9
837fXaabui0bcU9mgtqtNeq3shboSkJc36IFCkGJ/szN2NQZekbtRX5dTToQ
FDWMG66ZArV7DukcPjkGDj/mV5aNnwMvHlsmy7WMg3umI9KzMUugSdxNk842
CfKqKn/weawCyWu6miENk6DTTlf8/WYWuOthXsFWHQbgT7vgOkdlg5fCLr+9
kcwAr/Z4pJ5n4YBWNX+Cd35hAHMrUR9/Vi6Y48Az9mKIAW70lu9rmuGGQtdr
4wrnGICv2OqTZjMv7BItbhxaZoBP9F1Lld8JsMFeTHoC78vJzQu8DnQBGKK3
8GMPvv+7RA0qf1YKQQW2y68LcaYSSsUT+okw61EdfRDn3OcKLXHtJJh/zC5g
EWcDofkun3Yy3Hqg0nntf38/ZOz8nQLJDebqzDwh63no+ZEKozHlz0weUTq5
FEgXhkrD7tNMHuXve97eI4L8JBTcb5ymYqJa3wTEJ2noh4l3vRY4hOWqB15p
HBVGtAopsflxI2w3mr2vvkhFFL5QpGfjgbWFnzppxElFyv0pY6oforHBzU7L
bewUJNn+pLmfnof9GFmbXREkI4mYj5GWCfVYgnHu80UeEjJROyi5I3IA2+6n
nK7HS0QneA2iuOc3MArdpT98tyDiF6nPsgTCIJ1/wVZvJz+aGPe6qGK5Gwg6
rTjFHMH7UFTnbksvBN8svmftseJBcqWeW78sGgDjZvmmOAsuNG98oUFb8RJI
avK8q+XBgVp4HEU0Ez1ADNdyZqojG3rNl/pj+NddQE0/cO2dEwu6HZj8yfLO
Y3x+PE+iENfonx4k+K2Wp4JHvXM7LvL8oyu07ZLskMgFbCqU74cU5ukGJ0U0
sgqKQTd/jpHj5mn62M7xp5WwEoRZWJ3edGCU7mXwcyjPuR7I/HfDl9O4H2h4
NSS2xA8BRP1oyXlvHNx+8rb/KO8oeKmwyegJnAH1suyxiDEGPFvYfqUTFoCq
+/tPv/QmQNnVjhCi8DKYEPrV9d1kEhj3Fux0+bsGWiO93vmyMYD4Zs83sd9Z
oPCHR6O3nBlApyyk7/kPNujtQ17IK2CA8t+FQS4leB92eJs2tTHAFc/zmN1H
Lvhmw6qzZoIBtDZ8ndszeWBZ+2GF2EU8L/NfHFcj+KAl5+ouXbwPve1i/XWi
+GFYquvZMLwPPc/5spr6CsKlJy6Sznh+utiiws00iTBT2/rLF5zhzpCqvZok
uHHE+zQD52pegfwLimTIrUXyWGbOd9kvOXLKeB/u17Nh9qH4xy+98rupcFya
epeZRxmhwVsPtgrD5Htb/jCZ885uD+gggoRZZVx3VP2HbR0MXLW6QkObooS5
dl44ho28szN77yqM4k3QyM2zl7F7t6+HRPpTkf1yqb0jexC2yVvRJvAOBUXv
3dvXPJWKWXcGU96EkdFh3eJoiZ5y7EBboNzrcBLy8nK5wJBrw0QefOkXCCGi
GoGYX3G1M1i+kMj3rduFUJrJxV/XNvOB0/KDzyt3CiD76bW3Z6IkgaHcD6l2
BQIqXeaa2S+oCBY282uNGfCi6tPyK/hQBvdsC0sPm3OjwB+/j69km4Pb93x6
F69wIq/EhLAkc2cQ3faw2cSFHRlPDjf3/bsFalNOCAQ4sKLKqIoPqcqR4Gr7
17ff/63TewpVc5NJicD3a/7fQe4V+tDE4arqsxngvPfXK3+3L9Id1Wy7zi/m
Axv/6MitUrP02TXiDcHUciBef45d8tgUyF9+mj4tMAYCRDVeEiTnAO2N56bg
V+OgiD8kL4+6BFKf3F8R6J0Am3UfW1xbWQHdP0SC+YsnAZbC8UOtbAN4GurT
9mMMoCnReOJ4Myt8XZL9b1cMA6zTfPxYqtkhm0WMSnUtA6R1/egRRpzwxJYd
L2QHGOBvo1D8h3fcsN29je/+LN6Pn9YLLsTxwof5XmtmeB/KXfT3aIoiQI8W
76pXeB+6yvYF1wUKwItOOxspzPMPfbZJMkAITi4p/8nCudUl3860mggbJa//
68V5vdwr+U4pCQ4fr9NYYPqg+yOX3+/J0Kujf4Ppj/cqJByW8ylwB11nKzNP
KQLBjxOfU+GEbGo5kyv3KVK2PROG1pIvJpm8+DmY//5LEcRGOxmwSWQrJvZE
lpOeQ0PlXnMGxwcxrOGfu23la2GktfbNp4HLGjNOUSBcLqWi4fWGeg69m9gS
q4aRUzUFDS7GPDNaise2r/zj0vpMRtJ3Dnu/ti/C2C7AB2e/kNBrpeBUzsXv
WNusenVgLRHVs+2OfxU4jq2yfYq0SBBCUjpf1dzdOcDbRTmtna8EUGbWGV0D
qy3g5pb+6kevCWia0dt2vXg/YKu60wbreZFTuOz+nBItkNNdeaDgDzfyu7kt
/D+L88Bpzznj2n5OhPKT+3ZccQAxhhx7Ts/gefvtduXgmA/I/SlpRhplRX9t
gqh3ykPBW7HUVYYBK0yZkqLk3WGAFyO39xnosMPI8nPD/yoYQP6PZoGGOieE
S4Io4C8DvEwtuBKlyg05xHPqRqYYwLpX7eFTCV74X3Qrnyh+PljIkXYdECRA
0vGS/YL4/rofL78TxisA7UUJV1rxPgnnUxouXxOEVbVH8x7g62+qnPqv4w4R
vrhR+LGduV8zG/Im/iQ48qFRZRZnefAtKtmLDE91L48w/UpxbiGM7EmBuhKq
X5h9Ymn3SnXQjgpJ1OCXzP302CZ44rylMHS2Oj/EZAr2/c/sbhGUHH7IxDl0
Dyau1DnLIkdDyjENHWxS+hj3NVPDXAVh1PXu1OJ1Vhcs37qAs1iTirAij7xf
WDh2eFLOOU6Dgmob+fxF3mZiSeXCEqJ6ZOQf/dXcvqMKszn96RPnSRJStO1a
3bW/GzOSs+CM1yai2KN1SrszlzAHMQdKV5YgKrfR4XkeRwTj9qnsli/50QW/
LwQJd2kgq4zuiZfwoUsMFYkXFqpg1PXxmye/eVBetGfnoWk9YDP4Uquigwu9
iKmIEgu+AIS7LxBHNLjgHU2b6tERBti0dKWmdx8PrP/5abhyHj8PZaJWKSIf
TG8dZLdbwfdnS5tvMZkf1uoeSJDB19+JjzeCZ1UABgia7ziKr4+ZSluHBhsR
GvrGHKhg+kV6VUs7BwlG89QLjDLXN5RByF0kQXWB7rglnHleGeltWibDs127
mpj+0RpyUruXQYH6GrwmzPXuLrCd0P9LhTnB3l+ZTISWfwb/CkPU9HOWydJd
H+rGp0SQdKhF3rlIMtbB+PfVY52GLgRKE3mNFLD0yLsTgsvCSHUPijEln8Mk
a587K3AJo+j3/42soeuYvrP+5yhhKnodLFO9FXuIxaYeV1on4/4xdYqWK/kG
49Ld8+XSNjK6I/HVICirFqt3C/tN3UxC72MaOH1p/ViEMuOp0SYi2u1UxK3G
vY6NT93mlzoliLr5YrXDJylgKqSEUH6UHzX+Thgb/S4Hzhht/nHFig8pT9dy
1vBAILr2WDvCnwcVC8dRotfPAGpFxlijHxeq1mqOuK95EVhcffSbNYYDydme
7Nqb5g70Ka5ln8LYEOW0rANtLgjANTPON2Es6KOlioV44yOw+urIwc1n1ui9
JyUUmyRSQceDfyXUo//ooeNSRWngNTA6Y9u+5D5PV+2328fJXQykWN60L5tM
0zX/aM+e/fIRdF49cPbBq1H615ZbpzgG64BoRH9HW3Mffo53Ke50HgLfqqvq
1DnHQUkYPd9/cATULxyIuMcxA9oFe5TDW8dA5N4fiXfr58Hg1XzNQJUJMLVf
U0+r7R/40gN3ftedBIn1Dtdanq+BbmoflbA8CVSMdyUdecsC/9R8vVxuzwBz
eWH63oVssErYN/hpHjNvpA8l8RxwMWXr6kwr3s9XWGY707gg702jpqFxfB7c
q780HMYDq2SGeHfh/jH72Us20IkPLgu7DVNx/1Bm3K9YceOHA/q/XrrjeZWX
aeAOMBGEwroxVhfx/IB3hDxVBSLcw37sVD3O9gflZP47SIJKQ9Jykzg7qJn7
kqXJkEhL4mT6h0GxxrspWQo0PuGsweyLyNiYCM2tVFifaOa38T/fNo+wEBCG
YnGL7UzWOMueaOgtgnaFHtJSYtmBdT7MqSj2o6E1wW/bFey1sF6uK3+W/YWR
dsqols6Di5hvyA6HoEgqiqm9ZJQXFIhFmSr/LXtEQR2sr37W3U/BiBcv6jfH
k5GLkofjnW+l2GWVfHaRJBJ6arQlbfBaK3Y8M0tsVxwR7XdsWi0PncaCIgLR
HiiEZsm82X5RPEDGZrHB7LgAcvMfM2cJlADJ6TFftA0IqP0axXGx9yBQ5pDL
Qq68aIuHdffatuPgG5u3SewNbqSt6+QoD82AquvUxq4wTsQ7MvObJnAVGHrl
yolEsSP3DdOno2k3QeBrusTLUFaUPeD08D7hPqgO3t5WfWiD3pH0X9uCbALo
GtL3Gj++Qhc9rExWiEoHyVLNbFFWi/R75XY9ya75oCimN6b78iy9OWd28XdL
GZDe/utwOecU+JRNNiIzRkH6H/Pfq/2zYLr2U0fi43HQdOm8x4Ofi0BgL+su
se8TQI+4tj29YgUUjBrevJwzCQJCSsSe394AVVESsW5KeP9YBSjOFLBCmZes
i3UPGSCT4Dfc/JIdPvn9d9P1GgY4Jr6PduEZJ3z+58ir1j68byrfn9oXyw17
lt1kGDMM8E5XL9vVlxf2PHDkIOH+YaEoe/CsKwHKgeyKe/h82v+2vcbnogCs
nbJ7zcnsw2itluPWQvDZiNz4c5yVtu+NUCkkwkPTh/u7mf3VsJndJ4cEs8cO
PprH+UhGr1JEJhnGmU19ZPrHjE6MG3pOgf9pOhD+13/9p7Hcx1RYdELzPZMP
xlseSCkUQdxPHp4KjxfFOqHhZ1o5DYV7zfZNSalh1Se9BzjKhdFay5vN4Tcs
sFOZfWNm9VTEKmhO/yPih7n2a/1Mb6YgDSCZ5DYVi/0MbNV0aCWjYnFaQMmv
QkyxysW+4g8JoXruo0XZ3zAeAdHVZ21EpGlOSMPiRrEmf/lbV98LoScmag3O
auwgTFbNCdULIGOPDtMPBZtBbWymE1sjARlncXUFVcmDo69T1WnDvEhXtFB2
PV8TzPvf+0Za50YBr6wrr+4zAjtFGj1W2bjQz582c5qn7IHxjMQdfgoHsnV0
yzSs8Qb23bHOh/jYkMVYSHJmUQhoNDMaiT/ACn0fBhZk3GIAva7AJOk97FBw
ROj0qTIG+CmWMnRfjBPKc/sFMv7g8yXGXIJrKzc8/7uqfg/uG/EOESE5bLhv
GJi00pfw84P/t71XJvngks7emz14fxz6VlCpMsYPW44M9lXj/XHsT/Bkf6cg
tGQXEgrB1790TEy89DoROsoIC/zCuXYj9YmeKwkyrLzPz+Dc4rbN5LQdGdKc
i2KYvpEW4PSo7TIF5nPqv2P2R5P69YElYyq07z+ZzNxPmy1BRlJ6wrAnfNMA
k/WFMtm51UTQKdW7i3UCu7CuXs4iYxUaUmlS9Jn1PoWxVFm0TGkII7WRqg6/
aCcsw952MMeAiiIEYrWlVUOxvG97xn4YUNA2jmctW5rSsVNHZ8yBBRndrCnQ
kPWvxGLeziW7mJLQ0RCYc0qsC7unqaxedJ6ImoOR5AHCIqYW38w2+VkQlW6x
e0TSEgKfEvJ3LX7iR5//pP8t2SYF3N8F7b3fxodcm9ZTuhnKYI9ZPvXKPx5k
t3wei75+CmTfdegVW+FCXh5G21/lWIP32yq0Dm7ngl0eZVpNwwxwcoLqZ0zC
+1ukqhbDfeP7PmLTwRleKIkdH5XBfSN6IkBZfYYAfSZ68gn4+u+J3qh//0cA
6pg8+aLM/H+sNmtZTp8QzNmYjPmAc4ExWP4wR4RvfAbdh5n+HvPQ9fkwCXbf
LiUxfeN150ta3QgZNmdrpDB9Q4OGTmd2U6BS6zud/6132O5Y229UeHXodgOT
X6vy36r5IYJ+sCVNDSrTMNO4dJ2aPzSkbvzc0Oq8EvZu/NZI6G9htL6Dz2uK
YYwpvdd8rT1MRds/7i1u+c8Ls846+WXLPAWR+HrE0w0fY4eiH5QXzJHRrdk/
GZyc+VhycJNo9DoJXd/2lRqY14g5gh9XOpaIyLr9EGvrtiFM5b5l2QxBELGE
JO7hfUkDpYGyKwcSBaHfc5XTXvj13dSn2vkZEuErw2Hh7zhvEh20VDYgwYFL
n2ymcN72q3wk7xgZXo4s6WTOL9+k8y8uHqdAzHjFn5m/3FEOZXFVKizXF4tk
3q8qxdXt4x5hWEPc+Mvk2rfnTu8xFUHpLL/S03KlMUsVExUeMxra8mR00DT0
ODZ18WK7xwVhlLobfrAC9thD76qMOFcqAqVJ1wae3cVSnigMaF+nIF6SQLGD
63Pszdns1lA/MiqJ5/ZKISBs3cPwjKYfCb3TSVHgZO/ABj2mc6a8iGhKdxl1
i81hg+NptcupQrDDf5/bG6aPlytq+jYT4VaN5PF+pi/mtShH1pOgHbfuEPP8
tnhEK0OujgzjWS8rM/dXdH+29cFKCrw0NbqHeT/yShWjIflU2H4rsZLJ5iMb
GnZJNFS3rHgvcw5iluH5+7M24/PZIaioJ/cMVn3spbnnkggyveuiJ1dGwko+
Cb5N5RJBzwxCs8rcDmDblYL35rHSkOOwfIuywllMrHHFMldAGI1bK//lW72G
Rfz9zpm7lYpu7ZbIehgehbkOFLVEiVKQq0J+xzG2XExirfpDwk4yckz9ZHGy
4jNmc8vba4ckCX0dLZQYtu3D0Kb6+I5tRHSw+tuywJY1rC00NMXNQhCp6ngv
xZyiANrnJKu5s/xI6ruTxFWKHLimkxlk5MyH0izFqw8BACoaPWNKH/CgNOeI
LXb3zoCZA7bLg2FcqPQc5+7hL7agoiz1nnU6B7on+prFWdYdvN68q+ZXAhua
fSJ9HLsbBFozp5qy41kQ4ZJmfMS1R2BvMZElyW2NfpWVKD7yMwXcGvTjumr7
j76G/VJf/ZYDWCzCLTqezNMDOCZKqflFoNZHfoum7zT9noM2m+njj4BzIbG1
fnCU7pr+MPNUWh2gok3hGo/6QNi1Q5xKJkOgTezoRnv1GGBpsdGdbB4B5sZw
p//gNDA1UdSurRsDor+V1+ey5oFNS1fbbvkJwPd4Ub7rwz8gY2v8+MCxSVBW
UR3Lc28N1LkpKpbPT4LaxbvRtFQWWHF6r1L9JQY4kU0ItnnJBqOHHt7hfcMA
B1SBoXUoB+SQtuhca8H7fvDsl9hHXPDz9N58d9wvN5281sPw44Fb1yTFZhcY
gP9tI89Rcz7IH5qxawnvJ1EF3q6fNvzwN++qpQPeT5EPZ8OoJwShxj4PLStm
P0WeqNy1iwi1Wc541eK8quLXkbybBK2ML0ZN4FzWcqdrdCsZTozX1jPfv/Lc
uvnBcDsFKqwk72c+nzVsfj2NwlSYoaDs+b/zUNnknj/+IkjiQ9fE1O7tWJnd
x2d9d2hoP+n0uMINTczyjZN4UrAwkgptfzz9wRZzj/Az2XhCRQzvpqfNXwOw
xoaSrR2JFKRwmj0qvfEZNpzxY/JyKhnpmBdZ3GspwW6PnZjSeUFCxLgnyjCt
BesujH2vnEJEDkdmP8xMT2GTJw+/P3RaCPFbjLOcaOYG1JUNq0xjAdSnsBSQ
yiIBqvq9Jf0vEFAQV6PnjMFBYPrvvVm2Py8q4GGrDrunDdx/mGTWRHAjQr2d
xt0oU7BpIFvwWDwnusPLQTri6AQKa8paPFLY0eZzPCK2qzdAV4GvXHE87pNf
b6Wbe0eAqS6dKxWGG/R76sOE2PfxgDi3TdPFYYUuFpeW37cvHWjcMNIbvrlI
z6r62XZ+bz6wTuPbUhk8S097VXOg1K0MnEval0FrwJ/7fckZ1/+OgsPA0XO+
ZhY4/Zf3wD90HJiS6b/W8xfBHJe+5Y3aCWB/7S0nTFkBf7f96l9KnwRpN4Q1
Wm02wKnqJuqGAgOMr//e/fk5K0TlCaSwB/j+cq6K02PY4ffMOmuNT3h+MIs8
rgeccK/XWMJO3Cez1ARkRoO5oU6cQfRT3CcNiAvS3ld44fPrmgqj/xjAc9st
iog1Afr+iF+9jvskef7s4JlzAvBx+pjBOp6v9ytOxp2nheCTjKWmFOZ5ZeVK
slwOEfZ1yjT+xbnku+O72RckWH2AX4npk48hX9LFFDL82C2fyvTJTPJ3jx1J
FLjjziIrM0/HTx98pHSfCgvfOb1j8g/Wk59ky0QQf+G5VE6XzVgZzT5T4xMN
cVg3xbL9UcHgrI90erUwkm7td3fRNseO56h2tn6nIpXC3tDb/L5YzrkaUnUn
Bcn07dN2WInBcmq0elf+kBFBbuKY3+ZCTN+d+9zsAAl19735UCb4DUvZzBOX
201Ee5WUJmZyRzAlfAJ4fBZCe19fnd+UwQY8K7VYBH4LoNclb3+rDW0CEy1h
SPk3Ab0d+rohrycPLqfJT7Es8qK8A9zV5QqaIOG0/bYjgjxo7mbri7an5wBH
RHAQjcyFzBrSc59W2oH3R/btvbKDAxmMJayqHPYGnwYNvLVF2dDe88UjOYoh
wHQl76/zdla4UzZumHyDAZ63sf8kirPDq/fpPydKGOCFWlOAAj8nzHZIZGzD
fdKF9HYZCXDDpS3f3jUyGEBxz0GOwlkeKCU+LPsQ90kNeynBvV188M7aTeV6
3Cdp1H295E5+GNfytLoU38/nx/LcvBsFYb/oTmIQvv7j1aby2VeI8My+6NQW
5nzimtWusydBhxfK3cz3gzIE7fKdVmRo9aTUkemTxsczYlWtKPB0eV4msy+4
ss6rBJ6hwtBlrwTmfk56PYqJ0hRBzpLRBp/6ZLGK96KxQbj03NxOOpK3Uxe7
ccWKFn1SGLk5ysWzX72CpTmVtu40pSLr7CMbutoh2PiRN7JTphTkUV30QmL0
JSYdar3y/SIZHbXlj9rT8RHLs4kIf2FDQlzYbK0ozx9MXH9ne7UVEd0xSbx1
7dgC9vJ82PJ8qyCqCm9beXdeEOQrlNI1W/nRmYG+C/k3/gPxs5cDq4f4kJZq
XV4xUAZ6+kc+n+PBzwcnq5VlSnWB/jmd/boEbkS/KTG6WdMahIHxrnYSF2wd
J6mq4v7YZ+dwjsLGA8uaMjyX5xjAebb4hFofLzS3J1fw4P2c09q6iaWXADNz
76Wt4s+TYKvvaFSTAFSZsB9QYPp3niyAP4VgXcf+3cU49++/yf9qnAjD/qw8
HWL6w9Pe7eI9JPgiHtUz35exeH7xTe0hw97Af8FMv1jqXDYktFNg7b5sLeZ6
h8wTx8drcX+8ZlfHZN0Xi0T9DhHksy5xRB8IYyrOpbtnBmjorIvU6oGjitiB
J7fldvUJo+pKcUWFkfPYgbLEp5UMKtq9+HpUE3hiSaKNBOU1CqrXreC9EPgI
E2xdMzu2SkaPv5tOJ1i9xd4fvsz9mYuMZHson5+mNGBsuoh7hIWEjnOPfEox
HMSkpe30gZgg8j4sfOoeQxhsGj9zqyZMED5mPVN/jel/sgY+V3SI8KbvBe+v
OOdIKJEKT5JgwD6938z3L9dcB06FYmRY/7s1i+mP8rbRmZ8hBV4psXdj5m3w
3Mj9DAUqvBT4OpR5v5dFj/QWXRBBW3Kv/IgvkMIwovOWg7Y0lOT/4TvNRRtz
ErgsKuIgjIZqA9n5jtphETe2xFG8qchtr77qly9BWCfXux2X/ChoLb55cSwn
DQuJ2+whdoeM/FfNvxsvVmCbdo6pe98hoUkJHcVWcjt2K/Dv8Q1/Iho30uRe
dpnFNI0adCIfCkHNoNv5Ofj1pMe4n3NsJMLuIZnFPpwdi6XHeapIMHr9QgzT
F0/+vkJg/0iGcj/3bmXu57fFgYuxJRTIYVIpxbwf+7Q0QM6mwruGcojJanTq
f49e0JCAmiJbxD6IYRc+k1skaUi3QtMnfkAfo66ISquuiiAXTNE1wIiEvZKP
Ty3mE0Gq214VebAfwKwJPF9vc9LQ6jPgSvhsiG1u2vnrCkkYHfrU3GuZdA2T
iyO/LJPE1yPitc/EwSjMnHvyP1NxCtptG0kx8nyNvW4hyr/bRUaeDy9ntel8
xnKDXD7JSZHQ5Sccezr4+zDTkOLYpB1EJPddbjUyYxXTa70/GntJEH3eYlo+
uk4GMoP3eaPM+dH7py/4CEWygL2G8afBgw+drmryHf+FgajCIfWfsTyIFq0p
badzBlhPIFb3aC606y7VZf2RLXDul+l8kMuB7mNnV5YnroPOJJ6G7jQ2NJl0
VPyRXhBIXS9RkEtlQZGfq+8fPfYIaKsvXfoTsEZ/Nb5S3/M6BXwjqe+Ov/aP
XkmR1JFKyAHNNs+26aTP0z3arjjMBReBeMVpVbuwabouvdiV4P0RiJZ8ix3m
GKPrfJa2TrhdB4gdB2y9rvUBkfOxcyZ6Q6CzllM088UYkKmTFhBtHAFSvJ/d
/X5NA4Orz4vNq8aA9durb3Li54HB6haHRbkJsOnTme3Zr/6BYx8v5fzWmARf
Dl+T2+61BvJ3+RdEzU6CSO0CAdZ4FuhgfWFG5yIDuMvopv16ygb1jz/uU8tl
gC06RhIKARww8n705QDcFwN3+KvMh+O+yNWmrIL74uCuY8+uu/PAHr69Oa24
L8ZLeXlLn+WDm9/fDRrB+4ivpWYCmPFD4vuuZFu8/9VqgnW7oCDcNNqRYc70
Pz/7hh07iTCy79W9zzgfq3iu0ClDgkuhOUeYvngpLZb4azMZFkg+zGH6om1P
gupdcQp8obYmw3webQ5PhJPIVPiy9Ml1Zl73uV1cTL0jgjZZqYvn1khiOT90
ov4F0xA4x5EgzqeJJd2ZqHAKF0YD3a1EFwNb7FpkxveyeCraY/FGccwrAHMM
WikbfkZBzjXvklnknmHNdbyY/Esyumt8jKZmVoIJVD+5fDmThD70JIRmqrVg
u0sjuY68IKItc59N+zOmsO1ylMIPRkLo6uLIvf3e3CBMm+NVk7UA2i90lJAf
uA20sjs2iDoQkEZOp48u/0Ewdp3lnUQwLwqwFXP5T1UbHCupP931mBsVCWY1
HlQxBcHPeGk/UzjR+iPWfQRRJ3BxUnPXy0x2FL7N86nRqxuAX8l4H0plRXXE
zpiifRHgXlj3wVKbDXpu08yRwNvxQMaXOyvPZ4VOffubrMySDh5niLhT7y/S
J1lWVHwE8sGhTPE/B+Jm6RwoKRafKsD0+NTH/lcMIOL7IzLu1yhgnZqqmi6e
BbI/mt4N3RkHKcMzIUVpi6DkxkL29uoJ4PGcsMj/cAWkbE+wUX0xCQoWKpsZ
hhsgj8ZBPXKAAQr0eDPfJrLCUv3zRpcjGUD6jprKwQfs8PdI3nRGNT5f9Nxv
tt/jhKPjrelNvQyw4KP0RPs2N/y6ulPUHfdFiZm6/hVbXviXfPV6K+6L7I9l
7iydJ0AxW8zREZ9vbLHkhfJTAlA55nz0Mp4vO3lW0XRtIcih1af4jDm/hsMy
tmcSoXfQCzWmL3KceyS4P5UE/ThauZm+qC4g3qSfRIYdJLMopi+ye04uno2j
wPt7tq4x8yVZRI+cpIsgISNW2cddm7CcgJk44zoa+mxRwk3EVLBbn5drPGuF
kdJY7M2gt2bY0Vy7s49bqKhIimj4JMwHOynI/fZHN95nyv8ueQbFYHHDfvs/
9ZCRte/XQ9/LCrA/uoYNAqMk1M56Jjo76Cs2vm1j4F0/nqewcMXd6iOY09aP
bv+ahFDhjpg2giUbGBc8cVKhTwCRlI4XgzubAMu8n2NLLwEteP3ryKDKg0Ux
7xOe67zINJixrDqvAZyU2muMaTzo1ViQy3mjc+D6sYHw55u5kNxrVuvzt+yA
vUPRnYRdHKgzPU8KzHiBOQf5m/rb2ZC05vum4MVgIKnTZWoiygrLRmp1qn1x
fzinNXmXxg4jCsyRKu6H93UH9Lg4OOHfZpvbRZ34+U7vt504Fzfco//gQiLu
hxxCPJVK4zxQRPGdkw/uh02dX28KtfLB4IBkswrcD7mKxqdvNfNDXdqFrcX4
/hn4aSloVAtC+nwJRyC+/kFvfZSf2xFhqYL5EPPzY+mhW1K5LpHgiIHMc6Yf
fv9lyqCYkWF1veRZph8WZFdvvmpGgd0TB9OY+6e+m9f6nDbu9zRneV9DWSx3
x8vghGM0JCn9eCMmSAcrAd1FNnrC6JbA69EnXY7YM+chvQELKnpyuOxu6bdg
LGyZUbtuSUECT9dMrfxeYuTs2JOJ9mR0z69wa3XoR0xdtY2VfpmENLtm2KID
OjFHI/GdjbZENK+QZ+w0OI91KF5a8OkSRLfLOWbY+wWAzG06r2MXPzqSm5w/
uvs/kEM23m3N4EP30nu3Hxs5DP7Wh0g0CPGib1PKt+5Y64Lt6mVtthRuRJnc
lq4oZA2un2bPyeHlgvLyHTemhnA/efmo0nWZG175nfvhF+6Dai3h3Og3L+wU
PmW5tMwAh3UCQnraCVDg0sb0HP68rHsdXl6tEYD29NAeeXx9bgyUs/A1CMHC
i+cZ75gsniScNkyEcWZf9zF98KIE4YbZHxI0mLBOZ/pglkZPzv0/ZNglc8OP
6Q+GcFOrWgsFlibyH2H2b6Lx1Q5qlwjSaO7RFa6hYnLtR7fyjNKQgYwbvQwd
wlwdWBtWBoVRl1hER73DeWxfxWfh27NU9HaN5WvJVw9M5Sd/tjYrFdHWKHZf
xR5hy4sHs4VYKCg/1s+cX+gtdpSUf7OHj4zmQ3S/6ok1YHoGxeemOEjI58Y3
G8GpASzp2pWES/8JonnbVPe6GGHwWWIQRAUKwsxSF19X5nyhuQXaahPhwtuY
F004Lzy3cpw+hp83dk0/YfrfFvV//h4qZKhi/PYB0//Ca97I/VOjQP6KcQdm
ngLDzQ6P76NCP+xyMPN+i5qKsv0uiSD/a56mFBUpbK/fEuGkHQ393lzYlTR4
DHvVM1gy5CSMbIq4qqIaLmOht7SJ3/2oqO/ehwdZdkGYL32+8ro/BRV+6Zxd
PJWGuZfoVw/cI6Os7l90wpUK7OWGYmF0MAn9i0yW63rahtWHtMZwBRFRLfGp
c+KWWWwmzErAOFQI/jdZcjIbvx7sziNLm1oi1Dto6sP0v0KV00eP0UmwqGnc
iel/sxn+6owyMrz2JUeQuX+7zNiHaoso0HMpSpJ5P7vlnlGzMmnIdA2TfJAC
sL2NZ9jHpGhocKfSX/Ugfez/vu/B8v9//u/z7v/H/w8GnbB3
    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1mOYnVcUQOGJbdtWG9tJ29hsG1u1Yte225SxndqI7ca21b67+bGeb691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         "]]]}, {}, {}}, {{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl1mO0XVcbQOEb2zZrxrXCRm1Tp0ga243T2Kztfm1j22bT2LZt9nnH92Pm
vHPevcbIWWvflRSq07JGi0QJCQkFkiQkxGfPxAkJewxPYAJPrNfR5vFa/F/z
IxjAE6GENoqnQB2+g2eypjVfywfyk+bK+JMXgDGhlz/2mp/ERJ7EmrrafF6b
rzM/ioHxPPL7eXe+y1zSz0ebU6Iu38kz+3kb/i8fxE+Zq+AvXjDR/79fD77b
bEzobd5nfgqTeFKxnraAf8TXmx/DoHgepbQxPBXq8V08izVt+To+mJ82V8Xf
vBCSan34fvPTmMyTWVNfW8jr8A3mxzE4nkdpbSxPjfp8N89qTTu+ng/hZ8zV
MJIXRjKtLz9gfgZTeHJrGmiLeF2+0VwMQ+J5lNHG8TRowPfwbNZ8zDfwofys
uTpG8SJIrvXjB83PYipPYU1DbTGvxzeZi2NoPB/vkTaep0VDvpdnt6Y938iH
8XPmVzCaF0UKrT8/ZH4O03hKaxppS3h9vtlcAsPi+XiPtAk8HRrxfTyHNR34
Jj6cnze/ijH8HqTUBvDD5ucxnaeyprG2lDfgW8wlMTyej/dFm8jTozHfz3Na
05Fv5iP4BfNrGMvvRSptID9ifgEzeENs1UphRDwT74g2iWdAE36Af4qLvAbG
afchtTaIHzW/iJk8tb9DE20Zb8S3mUvj03g+3gttMs+Ipvwg/wyX+OsYr92P
NNpgfsz8EmbxxtiulcFn8UycvzaFZ0Izfoh/jsv8DUzQHkBabQg/bi6L2bwJ
dmhP4PN4Js5Zm8ozozk/zL/AFf4mJmoPIp02lJ8wl8Mc3hQ7tSfxRTwT56lN
41kQF9wR/iWu8rcwSXsI6bVh/KS5PObyZtilPYUv45k4N206z4qW/Cj/Chkw
XDulVcA83hy7tafxlZYhzkmbwbOhFT/Gv0ZGjNBOaxUxn7fAHu0ZfK1ljLPQ
ZvLsaM2P82/iro13RDujVcIC3hJlMUvPgTb6Cf5t3JNx7tpZ7WUs5K1QDrP1
nGirn+TfxR0X56qd0ypjEW+N8pij50I7/RT/Pu6qODftvFYFi3kbVMBcPTc+
1k/zH+LOiXPRLmhVsYS3RcW4J2KP/eyiXg1LeTtUit/t+L1DLuRGHuSNPfX8
Jc9WxzL+MV5GvtgvP7usv4LlvD0qY56eB+31M/xH5I/90q5or2IF74AqmK/n
RQf9LP8JBWK/tKvaa1jJO6IqFuj50FE/x39Gwdgv7ZpWA6t4J1TDQj0/Ounn
+S8oFPulXddex2reGdWxSC+AzvoF/isKx/fQbmhvYA3vgr3as/hGyxR7oS3m
BdGFX+S/oUh8L+2m9ib+4V2xT3sO32qZY2+0JbwQuvJL/HcUje+p3dLewlre
Dfu15/GdliX2SlvKC6Mbv8z/wDX+NiZrD8d9HfvAb5vfxr/8ExzQXsD3WtbY
S20ZL4JP+BX+P1zn72CK9kjcy7FP/I75Hazj3XFQexE/aNlir7XlvCi686v8
T9zg72Kq9mjcy7Fv/K75XaznPXBIewk/atnjLLQV/B704Nf4X7jJa2Ka9ljc
xbGPPP6zVJNvMPbEYV4WP2k54my0lfxe9OTX+d+4xd/DdO3xuItjX3mi6Hwj
T+PfjKZ8Oe/Fj5jL4WeeM85NW8XvQy9+I37frOnEt/CR/Lb5fczgxeKOjv3m
iaPzTTytNc34Ct6bHzWXxy88V5yntprfj978ZvxOW9OZb+Wj+B3zB5jJi8fd
HefAk0Tnm3k6a5rzlbwPP2augF957jhnbQ1/AH34rbg3rOnCt/HR/K75Q8zi
JeLdi/PhSaPzLTy9NS34Kt6XHzdXxG88T5y/9g9/EH357bibrOnKt/MxPP4T
WovP5iXjnYxz48lQi2/lGTzTkq/m/fgJcyX8zvOipraWP4R+/E7cc9Z04zv4
WJ6I1+ZzeKl4V7WRPDlq8208o2da8TW8f9yX5j/M+fAef5j3N9+N3znzTvM4
80fmuebS8c6G+9we393ngHgPfObH+/F9fY73USbeR58foBg+RHH8B/q/hbU=

         "]]},
       Annotation[#, "Charting`Private`Tag$15463#1"]& ]}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8159279588211107`*^9, 3.815928066291872*^9},
 CellLabel->"Out[39]=",
 CellID->1698019128,ExpressionUUID->"0dcee08a-db04-4801-9c7e-e651c10cd9d8"]
}, Open  ]],

Cell[TextData[{
 "This is how the area under the curve for the black and orange lines in the \
previous plot are calculated. We can use it to simply read the area (",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "bc46ef4f-5cfc-4eb7-b5da-b6cb30f150f6"],
 "-value from the ",
 StyleBox["y",
  FontSlant->"Italic"],
 " axis for any given value on the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis). "
}], "Text",
 CellChangeTimes->{
  3.7534169077056155`*^9, 3.810998394892555*^9, {3.811514085142024*^9, 
   3.8115140864488935`*^9}, 3.811516101711659*^9, {3.815930996785833*^9, 
   3.815931029279416*^9}, 3.8164569070064383`*^9},
 CellID->245242507,ExpressionUUID->"d9ba9954-81bf-4dd0-b7a1-7067d66a8e00"],

Cell[TextData[{
 "The area under the curve for an ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "51266126-4aec-447a-b6db-e5284810ec0c"],
 " value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1.96"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "185fbad4-d674-4401-a502-abe2b2f6de84"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7661374062733555`*^9, 3.766137421852356*^9}, {
  3.815931191110836*^9, 3.815931216050309*^9}},
 CellID->689982380,ExpressionUUID->"c8f43d6d-c554-4802-b4e3-900447753150"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CDF", "[", 
  RowBox[{
   RowBox[{"NormalDistribution", "[", "]"}], ",", 
   RowBox[{"-", "1.96"}]}], "]"}]], "Input",
 CellLabel->"In[40]:=",
 CellID->186824713,ExpressionUUID->"9fa583ce-d188-4205-b26f-aba2ffd50517"],

Cell[BoxData["0.02499789514822043`"], "Output",
 CellChangeTimes->{3.8159279588454857`*^9, 3.815928066316625*^9},
 CellLabel->"Out[40]=",
 CellID->1893634468,ExpressionUUID->"f032bb6d-7f97-47ce-8fcd-3d34ce4b54f3"]
}, Open  ]],

Cell[TextData[{
 "So, if you look back up at the plot of the PDF and draw a line upwards at \
the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1.96"}], TraditionalForm]],ExpressionUUID->
  "67a60912-0877-4f24-8407-66e995a248c3"],
 ", you will get about ",
 Cell[BoxData[
  FormBox["0.025", TraditionalForm]],ExpressionUUID->
  "cb8f21ca-31bd-4dea-895f-876602383474"],
 " (",
 Cell[BoxData[
  FormBox["2.5", TraditionalForm]],ExpressionUUID->
  "98ffa6f0-e85c-47a1-bfc8-e352e92d1ac0"],
 "%) of the area under the curve. What about ",
 Cell[BoxData[
  FormBox[
   RowBox[{"+", "1.96"}], TraditionalForm]],ExpressionUUID->
  "89064faa-53b6-4423-83be-055219fea335"],
 ", though?"
}], "Text",
 CellChangeTimes->{{3.7534169560463657`*^9, 3.75341696931888*^9}, 
   3.811516101974263*^9, 3.8159313339352417`*^9},
 CellID->195958994,ExpressionUUID->"fff01d51-d111-4a3f-95a0-48be164a8416"],

Cell[TextData[{
 "The area under the curve for an ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "42db325d-7c4b-4932-93a6-49264dad8722"],
 " value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"+", "1.96"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "deca69df-d6ac-44b1-af5e-81adbbd721a1"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7661374359743557`*^9, 3.7661374501393557`*^9}, {
  3.7661374860133553`*^9, 3.7661374871643553`*^9}, {3.815931366632083*^9, 
  3.8159313696074123`*^9}},
 CellID->1382345062,ExpressionUUID->"7bb0d2d3-62bb-421b-946b-7f9e0b769f13"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CDF", "[", 
  RowBox[{
   RowBox[{"NormalDistribution", "[", "]"}], ",", "1.96"}], "]"}]], "Input",
 CellLabel->"In[41]:=",
 CellID->147794102,ExpressionUUID->"ba25120a-94cb-40e3-84d5-bfae2d5b814f"],

Cell[BoxData["0.9750021048517795`"], "Output",
 CellChangeTimes->{3.815927958883541*^9, 3.815928066363763*^9},
 CellLabel->"Out[41]=",
 CellID->619748689,ExpressionUUID->"7d96e2f1-c931-47d3-a4a1-e051d8af175a"]
}, Open  ]],

Cell[TextData[{
 "As the CDF adds from the left, a line drawn upwards from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"+", "1.96"}], TraditionalForm]],ExpressionUUID->
  "564f18e4-1fb6-4d3a-bc9d-73806d208179"],
 " will accumulate ",
 Cell[BoxData[
  FormBox["0.975", TraditionalForm]],ExpressionUUID->
  "2741c0cb-01fc-4780-8824-44c4412bd83b"],
 " (",
 Cell[BoxData[
  FormBox["97.5", TraditionalForm]],ExpressionUUID->
  "95c7183e-6d1f-4fec-9da1-1f6a77edd6a4"],
 "%) of the area under the curve. This is not what we want. We need the area \
under the curve from this point onwards to the right. As we know that the \
total area is ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "7fbe3eb0-d698-48b5-be25-cb8a93222795"],
 ", we can simply subtract from ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "00913936-4946-4652-8a77-a25c85d18b77"],
 "."
}], "Text",
 CellChangeTimes->{{3.753417015390725*^9, 3.753417034069754*^9}, {
   3.8115137701078777`*^9, 3.811513804668333*^9}, {3.811516102239376*^9, 
   3.811516102775387*^9}, 3.815931383063385*^9, 3.8159314180393*^9},
 CellID->259727332,ExpressionUUID->"e5bbb14b-cb46-4bee-a6c3-4d349bb018d0"],

Cell[TextData[{
 "Calculate the area under the curve for an ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "dd6a70c3-6877-490b-866c-e48339fbe6b1"],
 " value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"+", "1.96`"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "593fdd9e-2240-448f-9aad-c6dad9d149f7"],
 " toward the right:"
}], "CodeCaption",
 CellChangeTimes->{{3.76501346163533*^9, 3.765013467642931*^9}, {
   3.7661375963503556`*^9, 3.766137681635701*^9}, 3.815931491448197*^9},
 CellID->177022354,ExpressionUUID->"d458f3cc-9d40-4754-8190-3f704572363d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{"CDF", "[", 
   RowBox[{
    RowBox[{"NormalDistribution", "[", "]"}], ",", "1.96"}], "]"}]}]], "Input",
 CellLabel->"In[42]:=",
 CellID->672278343,ExpressionUUID->"51bb926c-56c0-409b-a710-bcb9f00d0bee"],

Cell[BoxData["0.024997895148220484`"], "Output",
 CellChangeTimes->{3.81592795890693*^9, 3.815928066387329*^9},
 CellLabel->"Out[42]=",
 CellID->1943533653,ExpressionUUID->"bf30f9ef-9f02-4547-b96b-62ad2b93fcdb"]
}, Open  ]],

Cell[TextData[{
 "So, there you have it. The CDF calculates the actual area under the curve \
for a value on the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis that we desire or, more precisely, from -\[Infinity] to a given value \
on the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis. All that is left to do is to convert a difference in means (or other \
statistic) to a value that we can place on the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis of the PDF plot. We will do this in the next chapter."
}], "Text",
 CellChangeTimes->{
  3.7534170826812572`*^9, {3.753417335913196*^9, 3.7534173476249084`*^9}, {
   3.811514159211616*^9, 3.8115141947927046`*^9}, {3.811516103089551*^9, 
   3.811516103651018*^9}, {3.815931563503394*^9, 3.8159316046626987`*^9}, {
   3.8164569686545067`*^9, 3.816456970286023*^9}},
 CellID->142533006,ExpressionUUID->"4726fa54-1ba1-4e44-889d-d0c23d794126"],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseSection",
 CellChangeTimes->{3.64915840416916*^9, 3.649159030746593*^9, 
  3.649519312595612*^9, 3.649550255371595*^9},
 CellLabel->"In[44]:=",
 CellID->1643293135,ExpressionUUID->"d74e4a74-77b8-4ec5-98ab-aad9e1310002"],

Cell["Import the Hypothesis Testing Package.", "Exercise",
 CellChangeTimes->{
  3.7471558498394938`*^9, 3.753072290811141*^9, {3.7530723365582333`*^9, 
   3.7530723387025013`*^9}, 3.753417171347194*^9, {3.815931628646803*^9, 
   3.815931630934338*^9}},
 CellID->103155203,ExpressionUUID->"25883fae-0db7-470d-a76e-c0089fa048c7"],

Cell[TextData[{
 "Create a computer variable named ",
 StyleBox["vals",
  FontWeight->"Bold"],
 " to hold a List object containing ",
 Cell[BoxData[
  FormBox["500", TraditionalForm]],ExpressionUUID->
  "0510c10f-469c-4180-90e8-dea3ee77d5f2"],
 " random values from a normal distribution with a mean of ",
 Cell[BoxData[
  FormBox["100", TraditionalForm]],ExpressionUUID->
  "7811014c-2c46-4758-8620-07eee2caffe4"],
 " and a standard deviation of ",
 Cell[BoxData[
  FormBox["20", TraditionalForm]],ExpressionUUID->
  "130c04c1-5165-4433-897a-4b570803a43f"],
 "."
}], "Exercise",
 CellChangeTimes->{3.747155860023603*^9, 3.753072298925431*^9, 
  3.753417182322873*^9},
 CellID->1145460740,ExpressionUUID->"129409bc-4362-4f10-ab94-4dd68c008ca9"],

Cell[TextData[{
 "Create a histogram of ",
 StyleBox["vals",
  FontWeight->"Bold"],
 " with a default bin size."
}], "Exercise",
 CellChangeTimes->{{3.747155860023603*^9, 3.747155894623425*^9}, 
   3.753072309814814*^9, 3.7534171912330284`*^9},
 CellID->1715245472,ExpressionUUID->"77a5e565-63dd-42f0-9890-40289b2725d2"],

Cell[TextData[{
 "Create a smooth histogram of ",
 StyleBox["vals",
  FontWeight->"Bold"],
 " representing an idealized distribution and add a fill to the axis."
}], "Exercise",
 CellChangeTimes->{{3.747155860023603*^9, 3.747155869887032*^9}, 
   3.747155900543589*^9, 3.753072320215952*^9, 3.7534172043449717`*^9, {
   3.8127164260822344`*^9, 3.8127164396872344`*^9}},
 CellID->1104089727,ExpressionUUID->"d35745bb-0a1b-4d76-97aa-d54dd04e7ce7"],

Cell[TextData[{
 "Calculate the 95% confidence interval for the mean of ",
 StyleBox["vals",
  FontWeight->"Bold"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.747155860023603*^9, 3.747155869887032*^9}, 
   3.747155911399448*^9, 3.7530723600144987`*^9, 3.7534172346658974`*^9, {
   3.8127164708042345`*^9, 3.8127164725072346`*^9}},
 CellID->1291007583,ExpressionUUID->"ba6f6439-24f0-4cd3-a50a-341b942f9f7c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 CellID->835199206,ExpressionUUID->"f25e3732-5eac-421b-8af1-cb7771523c9f"],

Cell[TextData[{
 StyleBox[ButtonBox["Check out this interactive Demonstration by C. Boucher \
all about hypothesis testing ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
HypothesisTestsAboutAPopulationMean/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/HypothesisTestsAboutAPopulationMean/"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/PopulationMean",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolfr.am/PopulationMean"], None},
  ButtonNote->"wolfr.am/PopulationMean"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{{3.7661380186363983`*^9, 3.7661380358131156`*^9}},
 CellTags->"LastCellOfAPage",
 CellID->26626102,ExpressionUUID->"42f0a43e-d6df-4ac1-987d-e7d6d9156cc0"],

Cell[TextData[{
 StyleBox[ButtonBox["For more information on Wolfram\[CloseCurlyQuote]s \
Hypothesis Testing Package, see this tutorial ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/HypothesisTesting/tutorial/\
HypothesisTesting.html"], None},
  ButtonNote->
   "https://reference.wolfram.com/language/HypothesisTesting/tutorial/\
HypothesisTesting.html"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/HypothesisTesting",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolfr.am/HypothesisTesting"], None},
  ButtonNote->"http://wolfr.am/HypothesisTesting"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{{3.766138054189953*^9, 3.766138068750409*^9}},
 CellTags->"LastCellOfAPage",
 CellID->1554366849,ExpressionUUID->"ffed17e3-296f-42c6-be90-14a51d65a0d1"],

Cell[TextData[{
 StyleBox[ButtonBox["Wolfram Media author Seth Chandler provides a precise \
definition of the ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://community.wolfram.com/groups/-/m/t/1824481"], None},
  ButtonNote->"https://community.wolfram.com/groups/-/m/t/1824481"],
  BaseStyle -> "Hyperlink"],
 StyleBox[ButtonBox["p",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://community.wolfram.com/groups/-/m/t/1824481"], None},
  ButtonNote->"https://community.wolfram.com/groups/-/m/t/1824481"],
  FontSlant->"Italic",
  BaseStyle -> "Hyperlink"],
 StyleBox[ButtonBox["-value\[LineSeparator]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://community.wolfram.com/groups/-/m/t/1824481"], None},
  ButtonNote->"https://community.wolfram.com/groups/-/m/t/1824481"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/definition-P-value",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolfr.am/definition-P-value"], None},
  ButtonNote->"http://wolfr.am/definition-P-value"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{{3.766138054189953*^9, 3.766138068750409*^9}, {
   3.815238860997666*^9, 3.81523886144563*^9}, 3.819018244243333*^9},
 CellTags->"LastCellOfAPage",
 CellID->10843091,ExpressionUUID->"c89d2024-1eb9-4a9c-8a31-da5d8d8a92d7"]
}, Open  ]]
}, Open  ]]
},
Editable->False,
Saveable->False,
WindowSize->{808, 911},
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{"\[ThinSpace]", "\[ThinSpace]", 
          StyleBox[
          "Introduction to Statistics\t\t\t\t\t\nwith the Wolfram Language", 
           LineSpacing -> {1, 1}, FontFamily -> "Source Sans Pro", FontSize -> 
           24, FontColor -> GrayLevel[1]], "\[ThinSpace]"}, 
         "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {65, 75}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"08-Klopper-Distributions.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"08-Klopper-Distributions.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> GrayLevel[0.2], Evaluator -> Automatic, 
                  Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Chapter 8\"", TooltipDelay -> 0.15, 
              LabelStyle -> "TextStyling"], 
             Annotation[#, "Chapter 8", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"10-Klopper-ParametricTests.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"10-Klopper-ParametricTests.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  GrayLevel[0.2], Evaluator -> Automatic, Method -> 
                  "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Chapter 10\"", TooltipDelay -> 0.15, 
              LabelStyle -> "TextStyling"], 
             Annotation[#, "Chapter 10", "Tooltip"]& ]}, "RowWithSeparators"],
           Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> GrayLevel[0.2], 
             ImageSize -> {35, 30}, Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> RGBColor[0.12, 0.18, 0.26], 
             ImageSize -> {35, 30}, Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "1 | Introduction" :> 
          NotebookLocate[{"01-Klopper-IntroDataAnalysis.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "2 | Evaluating Basic Math" :> 
          NotebookLocate[{"02-Klopper-BasicMath.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "3 | Collections" :> 
          NotebookLocate[{"03-Klopper-Collections.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "4 | Working with Datasets" :> 
          NotebookLocate[{"04-Klopper-WorkingWithData.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "5 | Data Types" :> 
          NotebookLocate[{"05-Klopper-DataTypes.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "6 | Simple Descriptive Statistics" :> 
          NotebookLocate[{"06-Klopper-DescriptiveStatistics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "7 | Visualizing Data" :> 
          NotebookLocate[{"07-Klopper-VisualizingData.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "8 | Distributions" :> 
          NotebookLocate[{"08-Klopper-Distributions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "9 | Hypothesis Testing" :> 
          NotebookLocate[{"09-Klopper-HypothesisTesting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10 | Parametric Tests, Comparing Means" :> 
          NotebookLocate[{"10-Klopper-ParametricTests.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "11 | Correlation" :> 
          NotebookLocate[{"11-Klopper-Correlation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "12 | Linear Regression" :> 
          NotebookLocate[{"12-Klopper-LinearRegression.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "13 | Comparing Categorical Variables" :> 
          NotebookLocate[{"13-Klopper-ComparingCategoricalVariables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "14 | Nonparametric Tests" :> 
          NotebookLocate[{"14-Klopper-NonparametricTests.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "15 | A Research Project Demonstration" :> 
          NotebookLocate[{"15-Klopper-ResearchProject.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> RGBColor[0.12, 0.18, 0.26], 
   CellMargins -> {{0, 0}, {0, -1}}, CellFrameMargins -> {{27, 0}, {1, 7}}, 
   Background -> RGBColor[0.12, 0.18, 0.26], CellTags -> 
   "DockedCellLogoCell"], 
  Cell["JUAN H. KLOPPER", "Text", FontFamily -> "Source Sans Pro", FontWeight -> 
   "Light", FontSize -> 15, CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> 
   False, CellMargins -> {{0, 0}, {-1, -1}}, 
   CellFrameMargins -> {{27, 0}, {2, 4}}, CellFrameColor -> 
   RGBColor[1., 0.7, 0.1], FontTracking -> "Extended", FontColor -> 
   GrayLevel[1], Background -> RGBColor[0.9, 0.4, 0.], CellTags -> 
   "DockedCellLogoCell"]},
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    Introduction to Statistics with the Wolfram Language", "Header"]}],
     "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], 
   None, None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["  |  Hypothesis Testing", "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 34}, {Inherited, Inherited}}]}},
ShowAutoSpellCheck->False,
FrontEndVersion->"12.2 for Mac OS X x86 (64-bit) (December 12, 2020)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> 
       "Source San Pro", FontSize -> 8, FontWeight -> "Plain", FontSlant -> 
       "Plain", FontColor -> GrayLevel[0.45]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Source San Pro", FontSize -> 
       8, FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth :> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, 
       AutoStyleOptions -> {
        "FormattingErrorTooltips" -> False, "HighlightComments" -> False, 
         "HighlightEmphasizedSyntaxErrors" -> False, 
         "HighlightExcessArguments" -> False, "HighlightFormattingErrors" -> 
         False, "HighlightGlobalToLocalScopeConflicts" -> False, 
         "HighlightGraphicsCompatibilityProblems" -> False, 
         "HighlightLocalScopeConflicts" -> False, "HighlightMissingArguments" -> 
         False, "HighlightNoKernelPresent" -> False, 
         "HighlightOrderOfEvaluationConflicts" -> False, "HighlightStrings" -> 
         True, "HighlightSymbolContexts" -> False, "HighlightSymbolShadowing" -> 
         False, "HighlightSyntaxErrors" -> False, "HighlightUndefinedSymbols" -> 
         False, "HighlightUnknownOptions" -> False, 
         "HighlightUnwantedAssignments" -> False}, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey :> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Open]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey :> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey :> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 64}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["GrayPointSix"], FontColor -> GrayLevel[0.6]], 
         Cell[
          StyleData["GrayPointSix", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, DefaultNewCellStyle -> 
          "ExerciseInput", CounterIncrements -> "Exercise", MenuSortingValue -> 
          10020, MenuCommandKey :> "2", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth :> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, DefaultReturnCreatedCellStyle -> 
          "Answer", CounterIncrements -> "Question", MenuSortingValue -> 
          10030, MenuCommandKey :> "3", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth :> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, ReturnCreatesNewCell -> True, 
          DefaultReturnCreatedCellStyle -> "Question", 
          LineSpacing -> {1.125, 1., 2.}, MenuSortingValue -> 10032, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          ReturnCreatesNewCell -> True, CellFrameLabelMargins -> 3, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 12}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Baskerville", FontSize -> 
          18, FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Italic", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", StripStyleOnPaste -> True, PageBreakWithin -> False, 
          GroupPageBreakWithin -> False, GeneratedCell -> True, 
          CellAutoOverwrite -> True, ShowCellLabel -> False, 
          DefaultFormatType -> DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221]], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, 
          GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, 
          ShowCellLabel -> False, SpanMaxSize -> 1, FontSize -> 14], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Comment"], FontFamily -> "Verdana", FontSize -> 13, 
          FontColor -> RGBColor[0.3, 0.3, 0.2], Background -> 
          RGBColor[1, 0.9, 0.8]], 
         Cell[
          StyleData["Comment", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Suggestion"], 
          CellFrameLabels -> {{Inherited, Inherited}, {Inherited, 
             Cell[
              BoxData[
               TagBox[
                GridBox[{{
                   ButtonBox[
                   "\"  Insert  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`ReplaceWithSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    ContentPadding -> False, Appearance -> Automatic, Method -> 
                    "Queued"], 
                   ButtonBox[
                   "\"  Stet  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; DocuTools`StetSuggestion[]), 
                    Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "    ", 
                   ButtonBox[
                   "\"  Next  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindNextSuggestion[]), Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], 
                   ButtonBox[
                   "\"  Previous  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindPreviousSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "\"\""}}, 
                 AutoDelete -> False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
                "Grid"]], ShowStringCharacters -> False, Background -> 
              None]}}, Background -> RGBColor[1, 0.8, 0.8]], 
         Cell[
          StyleData["Suggestion", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Tentative"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[
             0.30000000000000016`, 0.6000000000000003, 0.7000000000000003], 
            "Thickness" -> 5}, Evaluatable -> False, CellFrameMargins -> 4, 
          StyleMenuListing -> None, Background -> 
          RGBColor[0.8500000000000003, 0.9500000000000003, 1]], 
         Cell[
          StyleData["Tentative", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["WebOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.91, 0.92, 0.9], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.91, 0.92, 0.86]], 
         Cell[
          StyleData["WebOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Lockdown"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.8, 0.5, 0.4], "Thickness" -> 3}, Evaluatable -> 
       False, StyleMenuListing -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["IndexField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["IndexField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExplanationField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["ExplanationField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EnglishHighlight"], FontFamily -> "WolframCodeSans"], 
         Cell[
          StyleData["EnglishHighlight", "Printout"]]}, Open]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth :> Infinity, TextAlignment -> Left, 
       LineSpacing -> {0.6, 1}, AutoQuoteCharacters -> {}, 
       PasteAutoQuoteCharacters -> {}, StyleMenuListing -> None, FontFamily -> 
       "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth :> Infinity, 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Link", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (Function[
             t, NotebookFind[t, "Notes", All, CellStyle]; 
              NotebookFind[
               t, "NotesSection", All, CellStyle, AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Crosslink"], 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               
               NotebookLocate[#2, "OpenInNewWindow" -> 
                CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None,
             Method -> "Queued"}], 
         Cell[
          StyleData["Crosslink", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeLink"], 
          ButtonBoxOptions -> {
           Appearance -> None, ButtonFunction :> (Documentation`HelpLookup[
              Part[#, 1]]& ), ButtonSource -> ButtonContents, Evaluator -> 
            Automatic}], 
         Cell[
          StyleData["CodeLink", "Printout"]]}, Open]], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 0, FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 0, FontFamily -> 
       "Source Sans Pro", FontSize -> Inherited 0.95], 
      Cell[
       StyleData["NoLabel"], 
       GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, ShowCellLabel -> 
       False], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariable"], FontFamily -> "Times", FontSize -> 
          Inherited 1.05, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariable", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariableLrg"], FontFamily -> "Times", FontSize -> 
          Inherited 1.1, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariableLrg", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "WolframCodeSans", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "WolframCodeSans", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {0.5, 3}}, 
               ImageMargins -> {{2, 2}, {1, 1}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Open]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Specialized for Klopper", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9, {3.7114709033696413`*^9, 
         3.711470909048764*^9}, {3.73531219927332*^9, 3.735312227736931*^9}, {
         3.745680245296091*^9, 3.7456802496393538`*^9}, {3.745930022124992*^9,
          3.7459300236362534`*^9}, {3.746546663993486*^9, 
         3.7465466650968523`*^9}}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {2, 32}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> "Italic", 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 14}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], LineSpacing -> {1.3, 1., 2.}, 
          MenuSortingValue -> 10010, MenuCommandKey :> "1", FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"], 
          CellMargins -> {{99, Inherited}, {2, 12}}, StripStyleOnPaste -> 
          True, DefaultFormatType -> DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           LanguageCategory -> "Formula", ScriptLevel -> 0, 
          SingleLetterItalics -> True, MenuSortingValue -> 1700, FontFamily -> 
          "Baskerville", FontSize -> 16, FontWeight -> "Regular", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[0.2], 
          UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}], 
              "DisplayFormulaEquationNumber"]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered", MenuSortingValue -> 
          1710, FontFamily -> "Baskerville", FontSize -> 16, FontWeight -> 
          "Regular", FontSlant -> "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       StyleData["InitializationCell"], Background -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Print"], CellMargins -> {{99, 10}, {4, 4}}, FontSize -> 
          15], 
         Cell[
          StyleData["Print", "Presentation"], 
          CellMargins -> {{100, Inherited}, {1.5 Inherited, 1.5 Inherited}}], 
         Cell[
          StyleData["Print", "SlideShow"], 
          CellMargins -> {{
            0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.01 
             FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {8, 15}}, 
          FontSize -> 18], 
         Cell[
          StyleData["Print", "Condensed"], 
          CellMargins -> {{18, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "Printout"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "PrintoutGray"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            RGBColor[0.8, 0.043, 0.008]], CellMargins -> {{81, 10}, {4, 8}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            GrayLevel[0.2]], 
          CellMargins -> {{80, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemParagraph"], CellMargins -> {{81, 10}, {4, 1}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["ItemParagraph", "Printout"], 
          CellMargins -> {{80, Inherited}, {Inherited, 0.5 Inherited}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemNumbered"], CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontWeight -> "Bold"], 
          CellMargins -> {{85, 10}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "ItemNumbered", 
          CounterAssignments -> {{"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> 1630, FontFamily -> 
          "Source Sans Pro", FontSize -> 15], 
         Cell[
          StyleData["ItemNumbered", "Printout"], 
          CellMargins -> {{90, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteItem"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontSize -> 12, FontWeight -> 
            Bold, FontColor -> GrayLevel[0.25]], 
          CellMargins -> {{93, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, CellFrameLabelMargins -> 4, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          CounterIncrements -> "ItemNumbered", MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNoteItem", "Printout"], 
          CellMargins -> {{93, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Epigraph"], CellMargins -> {{100, 78}, {6, 24}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, TextAlignment -> Left, Hyphenation -> 
          True, HyphenationOptions -> {"HyphenationMinLengths" -> {3, 5}}, 
          LineSpacing -> {1, 2}, TabSpacings -> {1.2, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontWeight -> "Plain", FontSlant -> 
          "Plain"], 
         Cell[
          StyleData["Epigraph", "Printout", StyleDefinitions -> None]]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EpigraphAuthor"], CellMargins -> {{125, 100}, {12, 12}}, 
          TextAlignment -> Left, LineSpacing -> {1, 2}, 
          ParagraphIndent -> -17, TabSpacings -> {1.5, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontTracking -> -0.05], 
         Cell[
          StyleData["EpigraphAuthor", "Printout", StyleDefinitions -> None]]},
         Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ReferenceSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ReferenceSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Reference"], CellDingbat -> Cell[
            TextData[{
              CounterBox["Reference"]}], "SR", FontSize -> 13, 
            CellSize -> {30, Inherited}, TextAlignment -> Right], 
          CellMargins -> {{80, 10}, {3, 4}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, 
          CellChangeTimes -> {{3.7385995432110577`*^9, 3.738599549834622*^9}},
           LineSpacing -> {1, 2}, ParagraphIndent -> -8, 
          TabSpacings -> {0.7, 2.5}, CounterIncrements -> "Reference", 
          MenuSortingValue -> 1870, FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["Reference", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{66, 10}, {3, 4}}, TabSpacings -> {1.2, 2.5}]}, 
        Open]]}, Closed]]}, Visible -> False, FrontEndVersion -> 
  "12.2 for Mac OS X x86 (64-bit) (December 12, 2020)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"82ef0715-d52c-4c49-b801-f91e1b6e4884"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "C:9"->{
  Cell[580, 22, 389, 9, 113, "Section",ExpressionUUID->"705a8c63-e7c8-4de3-9c49-066cd3e6fc16",
   CounterAssignments->{{"Section", 8}, {"Subsection", 8}, {"Subsubsection", 8}, {"Exercise", 8}},
   CellTags->"C:9",
   CellID->868451339]},
 "LastCellOfAPage"->{
  Cell[516250, 9994, 884, 21, 49, "MoreExplore",ExpressionUUID->"42f0a43e-d6df-4ac1-987d-e7d6d9156cc0",
   CellTags->"LastCellOfAPage",
   CellID->26626102],
  Cell[517137, 10017, 949, 22, 49, "MoreExplore",ExpressionUUID->"ffed17e3-296f-42c6-be90-14a51d65a0d1",
   CellTags->"LastCellOfAPage",
   CellID->1554366849],
  Cell[518089, 10041, 1426, 33, 49, "MoreExplore",ExpressionUUID->"c89d2024-1eb9-4a9c-8a31-da5d8d8a92d7",
   CellTags->"LastCellOfAPage",
   CellID->10843091]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"C:9", 603521, 11825},
 {"LastCellOfAPage", 603781, 11830}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 389, 9, 113, "Section",ExpressionUUID->"705a8c63-e7c8-4de3-9c49-066cd3e6fc16",
 CounterAssignments->{{"Section", 8}, {"Subsection", 8}, {"Subsubsection", 8}, {"Exercise", 8}},
 CellTags->"C:9",
 CellID->868451339],
Cell[972, 33, 708, 13, 138, "Text",ExpressionUUID->"0e12d893-87e9-4899-91c8-3f183bd280d1",
 CellID->76903385],
Cell[1683, 48, 759, 16, 138, "Text",ExpressionUUID->"928bb2dd-ad1e-40e5-a058-12a22fef9104",
 CellID->74788516],
Cell[2445, 66, 601, 10, 138, "Text",ExpressionUUID->"65f0e397-4fd0-4b7b-835a-d2ee419e702e",
 CellID->633868118],
Cell[3049, 78, 324, 6, 88, "Text",ExpressionUUID->"c3662730-2c3c-4e96-b577-30d76056d180",
 CellID->297129620],
Cell[3376, 86, 887, 13, 138, "Text",ExpressionUUID->"92e0c72e-438a-4024-acea-26344d74fbf2",
 CellID->851345186]
}, Open  ]],
Cell[CellGroupData[{
Cell[4300, 104, 230, 3, 57, "Subsection",ExpressionUUID->"3379a996-ffd4-4ca1-9e59-da2e07f99159",
 CellID->82616854],
Cell[4533, 109, 726, 12, 138, "Text",ExpressionUUID->"51da30b8-3f78-424a-8372-5dd00d9efdf1",
 CellID->587813419],
Cell[5262, 123, 1129, 20, 166, "Text",ExpressionUUID->"cb0fa133-72e7-42a9-a28f-11291f47ab4e",
 CellID->429051197],
Cell[6394, 145, 729, 15, 64, "Text",ExpressionUUID->"9969c368-8ef0-4c0f-90f3-89f6d7d0ec38",
 CellID->412431993],
Cell[7126, 162, 359, 8, 37, "CodeCaption",ExpressionUUID->"b1b297d9-52b8-411d-92b1-740356b2e180",
 CellID->3269854],
Cell[7488, 172, 516, 13, 54, "Input",ExpressionUUID->"c98cd634-07f9-4287-8367-a7aeeb8c4f6f",
 CellID->380695793],
Cell[8007, 187, 1157, 32, 94, "Text",ExpressionUUID->"e765cce5-6203-45aa-96c7-49a04ed3d6ae",
 CellID->534282841],
Cell[9167, 221, 203, 2, 37, "CodeCaption",ExpressionUUID->"775c2241-4536-4fc7-8c38-f6804f31867c",
 CellID->119247086],
Cell[CellGroupData[{
Cell[9395, 227, 259, 5, 29, "Input",ExpressionUUID->"283d7e73-89d6-4088-b6f9-4d1af5a80bed",
 CellID->180367757],
Cell[9657, 234, 273, 4, 40, "Output",ExpressionUUID->"14c2bc74-1ae6-4e86-9e86-ab101d118cbb",
 CellID->153299470]
}, Open  ]],
Cell[9945, 241, 308, 5, 38, "Text",ExpressionUUID->"77a52435-cba3-4200-ad2a-fb948d49fcc9",
 CellID->889210164],
Cell[10256, 248, 290, 6, 37, "CodeCaption",ExpressionUUID->"bcf9fb51-a06f-4472-947a-b42187fb04c1",
 CellID->362850034],
Cell[CellGroupData[{
Cell[10571, 258, 393, 10, 50, "Input",ExpressionUUID->"0e10cc09-b5bc-4bec-999c-e1aeb341437e",
 CellID->548372997],
Cell[10967, 270, 262, 4, 40, "Output",ExpressionUUID->"e76eb5b1-a83e-482f-b5ec-286d373b7fb9",
 CellID->208603060]
}, Open  ]],
Cell[11244, 277, 578, 10, 88, "Text",ExpressionUUID->"5dadf20e-32d9-4508-ad69-5838d92fa793",
 CellID->263090859],
Cell[11825, 289, 413, 12, 37, "CodeCaption",ExpressionUUID->"9212ca41-4139-4c0e-bafa-621251560d0e",
 CellID->208659539],
Cell[CellGroupData[{
Cell[12263, 305, 619, 13, 54, "Input",ExpressionUUID->"057e5639-f7db-459e-8e7c-297bc9e5a412",
 CellID->204492637],
Cell[12885, 320, 5656, 99, 326, "Output",ExpressionUUID->"a5b56d00-ad25-49f1-91d8-b3799dc3264d",
 CellID->94236984]
}, Open  ]],
Cell[18556, 422, 723, 13, 114, "Text",ExpressionUUID->"31b92a5c-09a6-4a55-bf4e-f7466c9856be",
 CellID->8021436],
Cell[19282, 437, 412, 7, 63, "Text",ExpressionUUID->"1f114c01-a417-4e46-8daa-3fb91b4e0c7d",
 CellID->20488384],
Cell[19697, 446, 553, 14, 37, "CodeCaption",ExpressionUUID->"2b8bed74-9485-4d7d-9eff-2cb9373cc190",
 CellID->224763506],
Cell[20253, 462, 202, 5, 29, "Input",ExpressionUUID->"127a8ecc-10ef-4e0a-b31b-563ebb3747c1",
 CellID->770596765],
Cell[20458, 469, 671, 14, 88, "Text",ExpressionUUID->"3a15160d-8add-4215-ae17-e31203ca2b54",
 CellID->2227479],
Cell[21132, 485, 586, 14, 37, "CodeCaption",ExpressionUUID->"89af4d06-3b4e-4da2-951e-6ad05b23dd36",
 CellID->893669267],
Cell[21721, 501, 523, 13, 54, "Input",ExpressionUUID->"bcd16f31-e701-4789-b65b-4ec4f07127e6",
 CellID->45448408],
Cell[22247, 516, 316, 4, 37, "CodeCaption",ExpressionUUID->"f173802e-7810-46d0-8458-378a420e734b",
 CellID->721492811],
Cell[CellGroupData[{
Cell[22588, 524, 566, 13, 54, "Input",ExpressionUUID->"4d469962-c532-4289-add4-b0eff69c0ea7",
 CellID->157956967],
Cell[23157, 539, 4745, 135, 190, "Output",ExpressionUUID->"6cc05983-b826-4519-9e22-90616c785317",
 CellID->354957032]
}, Open  ]],
Cell[27917, 677, 617, 10, 113, "Text",ExpressionUUID->"eab167d4-9121-46ef-8d49-d0f6a5238091",
 CellID->37477650],
Cell[28537, 689, 343, 6, 63, "Text",ExpressionUUID->"6110bf8e-ef19-4e53-a2d1-36a846e9f0a2",
 CellID->330709172],
Cell[28883, 697, 553, 10, 64, "Text",ExpressionUUID->"09883574-bd90-4424-a69e-40b9c7d41f92",
 CellID->196911225],
Cell[29439, 709, 526, 13, 37, "CodeCaption",ExpressionUUID->"9c34b4cf-3b48-4af8-8d28-1c14d6605d01",
 CellID->787513336],
Cell[CellGroupData[{
Cell[29990, 726, 1099, 26, 126, "Input",ExpressionUUID->"8171b89a-dddc-41d0-bcc3-3386275828ee",
 CellID->349814719],
Cell[31092, 754, 29785, 683, 362, 14245, 426, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"1c2a57a3-1b16-4981-b5d1-ef9d15bf8442",
 CellID->227566065]
}, Open  ]],
Cell[60892, 1440, 421, 7, 88, "Text",ExpressionUUID->"e1fe7475-7424-4126-ad2e-6285dfe3444b",
 CellID->429891302],
Cell[61316, 1449, 883, 14, 138, "Text",ExpressionUUID->"a519763c-e045-4e1b-b947-16427cfc9a8f",
 CellID->144575498],
Cell[62202, 1465, 286, 6, 38, "Text",ExpressionUUID->"6a7ae834-b2c9-4791-abf9-ff9552812cc5",
 CellID->406642659],
Cell[62491, 1473, 792, 22, 68, "CodeCaption",ExpressionUUID->"1e2d2853-67c8-4ccd-a005-4e6d5bc12bd7",
 CellID->563536974],
Cell[CellGroupData[{
Cell[63308, 1499, 262, 7, 29, "Input",ExpressionUUID->"9b557bf4-0020-4d7a-8652-3d5819bf8b1c",
 CellID->129481955],
Cell[63573, 1508, 324, 6, 40, "Output",ExpressionUUID->"888532d8-2761-4627-b208-8f0f034117b0",
 CellID->780822920]
}, Open  ]],
Cell[63912, 1517, 1047, 17, 188, "Text",ExpressionUUID->"81d19886-3d18-4c2b-b37f-50d33b1004fb",
 CellID->760237709],
Cell[64962, 1536, 652, 18, 40, "DisplayFormula",ExpressionUUID->"9fa039c0-b3a7-482c-b270-7d88f475979a",
 CellID->158547233],
Cell[65617, 1556, 856, 18, 113, "Text",ExpressionUUID->"dee37d0a-ff52-4ac6-888a-9689d3afdb1e",
 CellID->626117696],
Cell[66476, 1576, 254, 3, 37, "CodeCaption",ExpressionUUID->"a2e50c82-713a-40b9-bc53-7443e8436bc4",
 CellID->50415205],
Cell[66733, 1581, 398, 10, 81, "Input",ExpressionUUID->"dc18d20d-a339-4353-8c4a-9dfbfa188513",
 CellID->196727227],
Cell[67134, 1593, 209, 2, 37, "CodeCaption",ExpressionUUID->"99012c1d-28e1-48aa-befb-22bd1b480635",
 CellID->798899445],
Cell[CellGroupData[{
Cell[67368, 1599, 578, 14, 29, "Input",ExpressionUUID->"256c81e4-5d5e-405d-bc33-4e36507b6cd1",
 CellID->282996700],
Cell[67949, 1615, 31171, 533, 314, "Output",ExpressionUUID->"c6db65e6-699a-440e-8747-0e23b6eb0836",
 CellID->406591281]
}, Open  ]],
Cell[99135, 2151, 408, 8, 63, "Text",ExpressionUUID->"7df5561c-b38c-4fd0-afa3-ec137e94f408",
 CellID->133172123],
Cell[99546, 2161, 1382, 31, 90, "Text",ExpressionUUID->"a4272fa3-9cbd-4413-a3d9-3dbdb8825e31",
 CellID->208166193],
Cell[100931, 2194, 416, 14, 37, "CodeCaption",ExpressionUUID->"92f737b8-2ab0-428c-a960-333652841261",
 CellID->807656970],
Cell[CellGroupData[{
Cell[101372, 2212, 1105, 26, 102, "Input",ExpressionUUID->"f9d3087d-6b16-447e-b494-386d48de5b7d",
 CellID->1318686354],
Cell[102480, 2240, 35592, 769, 256, "Output",ExpressionUUID->"f1e03f6d-ebeb-468d-9cb9-3fcfcd61f744",
 CellID->55952152]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[138121, 3015, 209, 3, 57, "Subsection",ExpressionUUID->"50459ced-4e88-4ee0-b86b-ee487214746b",
 CellID->34424452],
Cell[138333, 3020, 1278, 32, 115, "Text",ExpressionUUID->"deee10b9-aeee-46c8-ad2f-144399b61a4a",
 CellID->9480275],
Cell[139614, 3054, 742, 12, 138, "Text",ExpressionUUID->"54142fba-a805-40df-b44c-c85f217ff3aa",
 CellID->36352243],
Cell[140359, 3068, 1775, 39, 217, "Text",ExpressionUUID->"ca958259-729e-4656-855f-d6be3466600e",
 CellID->3168370],
Cell[142137, 3109, 531, 9, 113, "Text",ExpressionUUID->"0ac88c03-5ae5-421e-b264-98303f271be9",
 CellID->383165176],
Cell[142671, 3120, 1346, 29, 165, "Text",ExpressionUUID->"a8f5cfc9-cf7d-4572-b99a-8203284d2395",
 CellID->51074226],
Cell[144020, 3151, 365, 7, 66, "CodeCaption",ExpressionUUID->"0bf24a45-ed47-4b37-a219-d488899ccc2e"],
Cell[144388, 3160, 466, 11, 54, "Input",ExpressionUUID->"1d8abaed-c30e-4e50-a7b5-931e18870d76",
 CellID->261097792],
Cell[144857, 3173, 389, 6, 37, "CodeCaption",ExpressionUUID->"0bb4eaff-56ab-4014-801e-4a5a6fe9c0c2",
 CellID->551294921],
Cell[CellGroupData[{
Cell[145271, 3183, 371, 7, 54, "Input",ExpressionUUID->"0ec01a6d-8c35-4c35-a159-f20ca74d5cfa",
 CellID->306621083],
Cell[145645, 3192, 1145, 20, 89, "Output",ExpressionUUID->"a1896b35-993b-42c4-807f-9ea4147ce8b1",
 CellID->472562108]
}, Open  ]],
Cell[146805, 3215, 287, 8, 37, "CodeCaption",ExpressionUUID->"b74d624a-06d9-46fe-b828-2feca2198e55",
 CellID->113048072],
Cell[CellGroupData[{
Cell[147117, 3227, 232, 4, 29, "Input",ExpressionUUID->"cfb1cb72-d42b-4d65-aac4-4a54294fb9bd",
 CellID->152780421],
Cell[147352, 3233, 258, 4, 40, "Output",ExpressionUUID->"be15b60f-f94d-41d4-953b-18b71a15f4c8",
 CellID->11360799]
}, Open  ]],
Cell[147625, 3240, 722, 14, 89, "Text",ExpressionUUID->"f7869b7c-3e2c-4374-8040-5d26982dcb5f",
 CellID->13380602],
Cell[148350, 3256, 231, 3, 37, "CodeCaption",ExpressionUUID->"98d8f1c1-91de-4cdd-ab8d-b93e5f44b9c9",
 CellID->91562945],
Cell[CellGroupData[{
Cell[148606, 3263, 247, 4, 29, "Input",ExpressionUUID->"030622bd-0006-47cc-9949-b15fe6e15b50",
 CellID->101081222],
Cell[148856, 3269, 260, 4, 40, "Output",ExpressionUUID->"2c35a8cc-bbea-42d4-9618-ba4f88f3967d",
 CellID->106894639]
}, Open  ]],
Cell[149131, 3276, 355, 9, 37, "CodeCaption",ExpressionUUID->"d1af8243-05fe-4355-ae6b-7ffcd0193e23",
 CellID->481008101],
Cell[CellGroupData[{
Cell[149511, 3289, 539, 12, 54, "Input",ExpressionUUID->"ddee13bc-e773-49c9-bac6-30ac325b9f88",
 CellID->513043682],
Cell[150053, 3303, 6735, 197, 189, "Output",ExpressionUUID->"d287b630-ab65-4913-bd44-824a5924ff49",
 CellID->177906808]
}, Open  ]],
Cell[156803, 3503, 524, 11, 88, "Text",ExpressionUUID->"796365a6-73a3-4930-8018-6ae9d368d559",
 CellID->805924332],
Cell[157330, 3516, 334, 7, 37, "CodeCaption",ExpressionUUID->"a1885656-2c86-476e-89ad-c7a7d5a74a28",
 CellID->269783227],
Cell[CellGroupData[{
Cell[157689, 3527, 596, 13, 54, "Input",ExpressionUUID->"91be5c72-7b3e-47cd-b478-147c17eda0e1",
 CellID->915259749],
Cell[158288, 3542, 21963, 382, 391, "Output",ExpressionUUID->"ca44392b-31f0-4d72-b53e-e8f224d5d1d7",
 CellID->3807023]
}, Open  ]],
Cell[180266, 3927, 640, 11, 113, "Text",ExpressionUUID->"d64a8a00-c0c0-44d1-87e8-2e6b40394341",
 CellID->226754189],
Cell[180909, 3940, 632, 8, 37, "CodeCaption",ExpressionUUID->"cf15e393-01bc-4fa1-8758-af93b7717f6d",
 CellID->143414462],
Cell[CellGroupData[{
Cell[181566, 3952, 848, 20, 102, "Input",ExpressionUUID->"27b58ca1-290f-4584-bd8d-62525d1f6dc1",
 CellID->15794757],
Cell[182417, 3974, 21507, 373, 360, "Output",ExpressionUUID->"d22a34e2-682a-42c2-8e50-0c93d806cd25",
 CellID->808559886]
}, Open  ]],
Cell[203939, 4350, 1077, 18, 164, "Text",ExpressionUUID->"f84a7025-7d33-4173-b64f-398a9e431910",
 CellID->192996318],
Cell[205019, 4370, 383, 8, 37, "CodeCaption",ExpressionUUID->"51194f31-e335-4b52-84d3-496cd8784b27",
 CellID->124732588],
Cell[205405, 4380, 328, 8, 29, "Input",ExpressionUUID->"edb7df8d-ea25-486a-b11a-3016113d8d17",
 CellID->10224243],
Cell[205736, 4390, 262, 5, 37, "CodeCaption",ExpressionUUID->"da11c21f-e0da-4f22-a520-77a552119fea",
 CellID->399979887],
Cell[206001, 4397, 249, 4, 29, "Input",ExpressionUUID->"1d23a07e-3538-4d9e-ae52-d160ad63693d",
 CellID->85819258],
Cell[206253, 4403, 413, 9, 63, "Text",ExpressionUUID->"2a4681b0-1f08-4994-b0d7-c6a9cadb1faa",
 CellID->517796865],
Cell[206669, 4414, 407, 9, 37, "CodeCaption",ExpressionUUID->"867a51e9-37f5-45aa-a6fc-220cd8eee355",
 CellID->5019096],
Cell[CellGroupData[{
Cell[207101, 4427, 166, 3, 29, "Input",ExpressionUUID->"444a3a25-a347-4dac-9397-0026fe586a7f",
 CellID->621441086],
Cell[207270, 4432, 322, 6, 40, "Output",ExpressionUUID->"5d75c327-56a9-4cfa-85bf-52a92c5b406c",
 CellID->255275005]
}, Open  ]],
Cell[207607, 4441, 343, 4, 37, "CodeCaption",ExpressionUUID->"a9523c76-095b-4aab-9959-d834a97e0680",
 CellID->49015631],
Cell[CellGroupData[{
Cell[207975, 4449, 234, 5, 29, "Input",ExpressionUUID->"ba95c230-78bf-4b65-b8f1-881ffa824043",
 CellID->50039497],
Cell[208212, 4456, 324, 6, 40, "Output",ExpressionUUID->"6a0bce29-6034-4e03-b1b7-e93052413fb7",
 CellID->472965019]
}, Open  ]],
Cell[208551, 4465, 1790, 37, 218, "Text",ExpressionUUID->"2b938dd7-b7f6-4669-916a-5a5e6af4868c",
 CellID->434876685],
Cell[210344, 4504, 450, 7, 88, "Text",ExpressionUUID->"2abdc406-3433-40b1-b6bd-787cd1fff353",
 CellID->539473576],
Cell[210797, 4513, 603, 10, 66, "CodeCaption",ExpressionUUID->"71eb79f5-feaf-4d59-8095-b7196b00455c",
 CellID->841841160],
Cell[CellGroupData[{
Cell[211425, 4527, 358, 8, 29, "Input",ExpressionUUID->"001d393a-dfa4-44fc-945d-7f07c7f1aa7f",
 CellID->170426323],
Cell[211786, 4537, 345, 6, 40, "Output",ExpressionUUID->"868a358d-a2eb-429c-8896-361fa399d024",
 CellID->15162716]
}, Open  ]],
Cell[212146, 4546, 800, 18, 39, "CodeCaption",ExpressionUUID->"909f7cfc-cf5b-4edf-bdec-ae6a9c25aa82",
 CellID->513969088],
Cell[CellGroupData[{
Cell[212971, 4568, 1932, 55, 174, "Input",ExpressionUUID->"c9af9a1d-4f8d-4566-8e73-bbf82424fe8c",
 CellID->1768381628],
Cell[214906, 4625, 21614, 376, 174, "Output",ExpressionUUID->"f8943c83-e8ce-4f0f-9d65-76f9c114b7db",
 CellID->584106183]
}, Open  ]],
Cell[236535, 5004, 267, 5, 37, "CodeCaption",ExpressionUUID->"5c5be05c-daf5-48d3-9f50-8e6fc9b71eab",
 CellID->11011103],
Cell[CellGroupData[{
Cell[236827, 5013, 1518, 40, 126, "Input",ExpressionUUID->"0caa4ec3-7242-4d64-a309-f1462c4a53d6",
 CellID->139862196],
Cell[238348, 5055, 21691, 377, 388, "Output",ExpressionUUID->"30bd2474-44fa-43bb-8212-33746adb7c4b",
 CellID->179887690]
}, Open  ]],
Cell[260054, 5435, 834, 19, 65, "Text",ExpressionUUID->"16322982-613b-4246-875e-afceaa4584d4",
 CellID->668779],
Cell[260891, 5456, 1317, 25, 193, "Text",ExpressionUUID->"15cd734f-56d4-4aec-9164-bfcb4c19c262",
 CellID->454562945]
}, Open  ]],
Cell[CellGroupData[{
Cell[262245, 5486, 303, 4, 57, "Subsection",ExpressionUUID->"12a886e5-1537-4f9b-8eef-824b9197fc4f",
 CellID->24235370],
Cell[262551, 5492, 745, 12, 163, "Text",ExpressionUUID->"cd323c02-2a66-43a1-9be9-43adc8d07d57",
 CellID->303767301],
Cell[263299, 5506, 1238, 18, 188, "Text",ExpressionUUID->"8d857024-3b21-4f48-bf26-691b6fe7952d",
 CellID->111954806],
Cell[264540, 5526, 1165, 18, 165, "Text",ExpressionUUID->"47f5637b-9fde-4044-a429-abde5a849003",
 CellID->657567918],
Cell[265708, 5546, 1056, 20, 163, "Text",ExpressionUUID->"7cce45a1-c5a2-414e-a472-ed72c5220fa0",
 CellID->74284736],
Cell[266767, 5568, 923, 14, 238, "Text",ExpressionUUID->"ff1b6ad5-e8e0-4551-9ab0-5bf6ef65b7ca",
 CellID->426131847],
Cell[267693, 5584, 1101, 25, 166, "Text",ExpressionUUID->"afc5c37d-3ab3-41c7-9f3d-16d8056147ea",
 CellID->618537001],
Cell[268797, 5611, 877, 13, 213, "Text",ExpressionUUID->"6f022fb5-4e04-4a4a-a133-d87338bf0f61",
 CellID->38558333],
Cell[CellGroupData[{
Cell[269699, 5628, 415, 10, 55, "Subsubsection",ExpressionUUID->"916d9d0c-585c-4761-a78d-8a934c364b54",
 CellID->345702858],
Cell[270117, 5640, 1337, 29, 93, "Text",ExpressionUUID->"96d91dea-1614-4783-9636-ff6f0d1d3960",
 CellID->174075022],
Cell[271457, 5671, 1780, 33, 241, "Text",ExpressionUUID->"c157202c-90b0-444f-9dd9-1b4c4e468c04",
 CellID->141989411],
Cell[273240, 5706, 2003, 34, 340, "Text",ExpressionUUID->"4c56299f-e35e-45d8-87d2-7b8b67ba3408",
 CellID->304883007]
}, Open  ]],
Cell[CellGroupData[{
Cell[275280, 5745, 221, 3, 55, "Subsubsection",ExpressionUUID->"8afe460e-9919-4f51-bfe0-37a8aced2ff4",
 CellID->429092826],
Cell[275504, 5750, 2390, 47, 269, "Text",ExpressionUUID->"491b6fe8-50f2-4e31-a122-9365fbcf250e",
 CellID->703035283],
Cell[277897, 5799, 294, 5, 37, "CodeCaption",ExpressionUUID->"da625b29-a04e-41c5-9189-c86e8e7d5862",
 CellID->107372641],
Cell[CellGroupData[{
Cell[278216, 5808, 868, 22, 80, "Input",ExpressionUUID->"6b07a317-73cb-4921-8e28-62864db05314",
 CellID->542644812],
Cell[279087, 5832, 21146, 369, 404, "Output",ExpressionUUID->"42c5c0ee-4dd5-4373-ae06-06d01f22c9bb",
 CellID->426693001]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[300282, 6207, 201, 2, 55, "Subsubsection",ExpressionUUID->"79080bc4-5736-47fa-951e-f405ad26eb23",
 CellID->238580891],
Cell[300486, 6211, 1270, 25, 191, "Text",ExpressionUUID->"3645aa67-1fe2-4b37-a844-449223ec577f",
 CellID->156611181],
Cell[301759, 6238, 68021, 1120, 373, "Output",ExpressionUUID->"580266a2-8cdb-4213-a938-a096b779dc0a",
 CellID->2668181],
Cell[369783, 7360, 833, 12, 163, "Text",ExpressionUUID->"8680aae0-8a53-454c-ae5a-bd830bbb72d8",
 CellID->52238752],
Cell[370619, 7374, 537, 10, 88, "Text",ExpressionUUID->"4a50c0a0-6036-4568-ab17-45e29eab26b6",
 CellID->59218591],
Cell[371159, 7386, 79389, 1306, 362, "Input",ExpressionUUID->"a34125cd-8915-44ce-91de-07c420ff87c1",
 CellID->132359010],
Cell[450551, 8694, 813, 18, 139, "Text",ExpressionUUID->"ce13eab1-a31c-4553-814a-e7492ccf705b",
 CellID->789409204],
Cell[451367, 8714, 661, 13, 114, "Text",ExpressionUUID->"1f09d46a-9c33-45d7-80c6-be1f0be2d3c2",
 CellID->521413849],
Cell[452031, 8729, 926, 18, 139, "Text",ExpressionUUID->"66050313-cfaf-4780-9833-ae41390d393e",
 CellID->571596540],
Cell[452960, 8749, 441, 7, 88, "Text",ExpressionUUID->"29b8b41f-3cda-48e2-9f65-afc273e27507",
 CellID->347515460],
Cell[453404, 8758, 706, 14, 115, "Text",ExpressionUUID->"a720bcd8-6458-42a5-a2a2-881df48b9ca4",
 CellID->88470855]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[454159, 8778, 244, 3, 57, "Subsection",ExpressionUUID->"cb7a8bb0-c6a2-48b6-8f38-50b49ed29c5e",
 CellID->6340904],
Cell[454406, 8783, 590, 14, 65, "Text",ExpressionUUID->"f414acb2-a79d-4953-9a97-0f2da13a4cbe",
 CellID->21272686],
Cell[454999, 8799, 238, 5, 37, "CodeCaption",ExpressionUUID->"2df57f37-4fd0-4601-aa50-422798acf36d",
 CellID->615112329],
Cell[CellGroupData[{
Cell[455262, 8808, 407, 11, 29, "Input",ExpressionUUID->"e7bf6da2-24f7-4232-9aa9-959f1b94e44c",
 CellID->150587764],
Cell[455672, 8821, 26334, 452, 178, "Output",ExpressionUUID->"59b31282-6380-416f-ba65-e81fc37bf5a6",
 CellID->434199305]
}, Open  ]],
Cell[482021, 9276, 881, 20, 114, "Text",ExpressionUUID->"793b8703-44fc-4336-9428-e362813d03bf",
 CellID->121538785],
Cell[482905, 9298, 237, 5, 37, "CodeCaption",ExpressionUUID->"342c5659-e53c-494b-9560-af28ff4fb422",
 CellID->1811596032],
Cell[CellGroupData[{
Cell[483167, 9307, 651, 15, 29, "Input",ExpressionUUID->"ed4b1524-9c0d-4a11-8e7a-6c3290441bef",
 CellID->172466177],
Cell[483821, 9324, 22740, 394, 178, "Output",ExpressionUUID->"0dcee08a-db04-4801-9c7e-e651c10cd9d8",
 CellID->1698019128]
}, Open  ]],
Cell[506576, 9721, 727, 18, 90, "Text",ExpressionUUID->"d9ba9954-81bf-4dd0-b7a1-7067d66a8e00",
 CellID->245242507],
Cell[507306, 9741, 549, 14, 39, "CodeCaption",ExpressionUUID->"c8f43d6d-c554-4802-b4e3-900447753150",
 CellID->689982380],
Cell[CellGroupData[{
Cell[507880, 9759, 241, 6, 29, "Input",ExpressionUUID->"9fa583ce-d188-4205-b26f-aba2ffd50517",
 CellID->186824713],
Cell[508124, 9767, 213, 3, 40, "Output",ExpressionUUID->"f032bb6d-7f97-47ce-8fcd-3d34ce4b54f3",
 CellID->1893634468]
}, Open  ]],
Cell[508352, 9773, 939, 27, 90, "Text",ExpressionUUID->"fff01d51-d111-4a3f-95a0-48be164a8416",
 CellID->195958994],
Cell[509294, 9802, 607, 15, 39, "CodeCaption",ExpressionUUID->"7bb0d2d3-62bb-421b-946b-7f9e0b769f13",
 CellID->1382345062],
Cell[CellGroupData[{
Cell[509926, 9821, 222, 5, 29, "Input",ExpressionUUID->"ba25120a-94cb-40e3-84d5-bfae2d5b814f",
 CellID->147794102],
Cell[510151, 9828, 209, 3, 40, "Output",ExpressionUUID->"7d96e2f1-c931-47d3-a4a1-e051d8af175a",
 CellID->619748689]
}, Open  ]],
Cell[510375, 9834, 1184, 29, 116, "Text",ExpressionUUID->"e5bbb14b-cb46-4bee-a6c3-4d349bb018d0",
 CellID->259727332],
Cell[511562, 9865, 599, 14, 39, "CodeCaption",ExpressionUUID->"d458f3cc-9d40-4754-8190-3f704572363d",
 CellID->177022354],
Cell[CellGroupData[{
Cell[512186, 9883, 247, 6, 29, "Input",ExpressionUUID->"51bb926c-56c0-409b-a710-bcb9f00d0bee",
 CellID->672278343],
Cell[512436, 9891, 211, 3, 40, "Output",ExpressionUUID->"bf30f9ef-9f02-4547-b96b-62ad2b93fcdb",
 CellID->1943533653]
}, Open  ]],
Cell[512662, 9897, 899, 20, 113, "Text",ExpressionUUID->"4726fa54-1ba1-4e44-889d-d0c23d794126",
 CellID->142533006],
Cell[CellGroupData[{
Cell[513586, 9921, 246, 4, 70, "ExerciseSection",ExpressionUUID->"d74e4a74-77b8-4ec5-98ab-aad9e1310002",
 CellID->1643293135],
Cell[513835, 9927, 328, 5, 30, "Exercise",ExpressionUUID->"25883fae-0db7-470d-a76e-c0089fa048c7",
 CellID->103155203],
Cell[514166, 9934, 744, 20, 47, "Exercise",ExpressionUUID->"129409bc-4362-4f10-ab94-4dd68c008ca9",
 CellID->1145460740],
Cell[514913, 9956, 320, 8, 26, "Exercise",ExpressionUUID->"77a5e565-63dd-42f0-9890-40289b2725d2",
 CellID->1715245472],
Cell[515236, 9966, 445, 9, 26, "Exercise",ExpressionUUID->"d35745bb-0a1b-4d76-97aa-d54dd04e7ce7",
 CellID->1104089727],
Cell[515684, 9977, 406, 9, 26, "Exercise",ExpressionUUID->"ba6f6439-24f0-4cd3-a50a-341b942f9f7c",
 CellID->1291007583]
}, Open  ]],
Cell[CellGroupData[{
Cell[516127, 9991, 120, 1, 100, "MoreExploreSection",ExpressionUUID->"f25e3732-5eac-421b-8af1-cb7771523c9f",
 CellID->835199206],
Cell[516250, 9994, 884, 21, 49, "MoreExplore",ExpressionUUID->"42f0a43e-d6df-4ac1-987d-e7d6d9156cc0",
 CellTags->"LastCellOfAPage",
 CellID->26626102],
Cell[517137, 10017, 949, 22, 49, "MoreExplore",ExpressionUUID->"ffed17e3-296f-42c6-be90-14a51d65a0d1",
 CellTags->"LastCellOfAPage",
 CellID->1554366849],
Cell[518089, 10041, 1426, 33, 49, "MoreExplore",ExpressionUUID->"c89d2024-1eb9-4a9c-8a31-da5d8d8a92d7",
 CellTags->"LastCellOfAPage",
 CellID->10843091]
}, Open  ]]
}, Open  ]]
}
]
*)

