(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    327899,       7200]
NotebookOptionsPosition[    217068,       4923]
NotebookOutlinePosition[    301450,       6685]
CellTagsIndexPosition[    301381,       6680]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "Linear Regression", "SectionInline",ExpressionUUID->
   "716862e6-ae72-456a-9ae4-aea6c6594971"],
  $Line = 0; Null]], "Section",
 CellChangeTimes->{
  3.652728456208679*^9, 3.652728527108994*^9, {3.76200839270086*^9, 
   3.7620083927008753`*^9}, {3.777662677488593*^9, 3.7776626774886007`*^9}},
 CounterAssignments->{{"Section", 11}, {"Subsection", 11}, {
   "Subsubsection", 11}, {"Exercise", 11}},
 CellTags->"C:12",
 CellLabel->"In[1]:=",
 CellID->868451339,ExpressionUUID->"9efbf9d7-0dc9-4f5d-bf16-aafac152024b"],

Cell[TextData[{
 "In this chapter, we will build on our understanding of model creation that \
was alluded to at the start of the previous chapter. We are still considering \
how one variable, the ",
 StyleBox["independent variable",
  FontSlant->"Italic"],
 ", affects another variable, the ",
 StyleBox["dependent variable",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.753582609596444*^9, 3.7535826619517827`*^9}, {
   3.7535827031803265`*^9, 3.7535827387542496`*^9}, 3.7662272665032654`*^9, 
   3.7662282214743195`*^9, {3.816087497984083*^9, 3.816087498135191*^9}, {
   3.8164893241360683`*^9, 3.816489324216626*^9}, {3.8190198329217253`*^9, 
   3.819019834299728*^9}},
 CellID->477014819,ExpressionUUID->"42a7cd27-7536-467d-b918-d0f4dd2e1b75"],

Cell["\<\
Because randomness in the data will almost never give us a perfect \
prediction, our modeling methods will always hold some error. This error is \
the difference between the predicted dependent variable data point value and \
the real data point value, given a specific independent data point value.\
\>", "Text",
 CellChangeTimes->{{3.7535827411265335`*^9, 3.7535827529556437`*^9}, 
   3.7662273802062654`*^9, 3.7662282250266747`*^9},
 CellID->210260908,ExpressionUUID->"003f658a-7a5b-4825-8bf2-7dc7f0a5492a"],

Cell["\<\
The model from which we predict the value of the dependent variable is shown \
here.\
\>", "Text",
 CellChangeTimes->{{3.753582763733828*^9, 3.7535827964404907`*^9}, {
   3.7662275326924486`*^9, 3.7662275331724963`*^9}, 3.81350263164858*^9, {
   3.816087500679007*^9, 3.816087501303114*^9}},
 CellID->328828069,ExpressionUUID->"76b1d43a-f246-4b02-bf7d-4108f2e50b7b"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["y", "i"], "=", 
   RowBox[{
    SubscriptBox["b", "0"], "+", 
    RowBox[{
     SubscriptBox["b", "1"], 
     SubscriptBox["X", "i"]}], "+", 
    SubscriptBox["\[CurlyEpsilon]", "i"]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.777662706746464*^9, 3.777662726888475*^9}},
 CellID->774087943,ExpressionUUID->"7592531c-5596-4594-adcb-37e5e4ef693b"],

Cell[TextData[{
 "If we forget the error term ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CurlyEpsilon]", "i"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"b534f970-aaa7-45d3-b3a0-33af37f4f25f"],
 " for a moment, equation (1) should be familiar from high-school algebra, \
where we looked at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", 
    RowBox[{"c", "+", 
     StyleBox["mx",
      FontSlant->"Italic"]}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"48d80408-aef0-4979-9296-a5dacb91cf2e"],
 ". This is an equation for a straight line, with ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]], "InlineMath",ExpressionUUID->
  "6ea6d054-16ce-4b79-8ebf-8d246ac9e983"],
 " being the slope of the line and ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]], "InlineMath",ExpressionUUID->
  "4354dee2-af39-404d-9aad-2b477fcd043e"],
 " being the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "dd070b7f-0db3-4724-b85c-fb7b61bfd495"],
 " axis intercept where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "4c7a0195-eef2-43b3-9c0f-bee6cc921378"],
 "."
}], "Text",
 CellChangeTimes->{{3.7535828278305492`*^9, 3.7535828591366863`*^9}, {
   3.7535830331538525`*^9, 3.7535830892606473`*^9}, {3.766227541989378*^9, 
   3.7662277365018272`*^9}, {3.7662277912102976`*^9, 3.7662277912102976`*^9}, 
   3.7662279010542808`*^9, {3.7662285474392605`*^9, 3.7662285679412603`*^9}, {
   3.7776627949762697`*^9, 3.777662804608824*^9}},
 CellID->254026257,ExpressionUUID->"7da03f94-b6d8-425b-a241-a6365f6732d0"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s plot such a line for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "=", 
    FractionBox["1", "2",
     FractionLine->0.2]}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "42ed8c7f-5a05-46b6-bdc0-89891b9ff7fe"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "=", "2"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "c69fc677-fdac-4d19-88b9-3918813ff534"],
 ". The equation becomes ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", 
    RowBox[{"2", "+", 
     RowBox[{
      FractionBox["1", "2",
       FractionLine->0.2], "x"}]}]}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"b01cf045-1268-47ae-91d6-9bd6b510ff03"],
 ". At ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "6e4af7a8-e3e1-45a6-8f33-21758518071f"],
 ", we have ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", "2"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "317c9c1b-0530-4cf7-93df-3675bee2b736"],
 " and therefore the point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", "2"}], ")"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"cf18f2e6-b879-48bd-9d04-2aabbc37a3e9"],
 ". Because we wish to make two plots on the same coordinate plane, we will \
use the ",
 ButtonBox["Show",
  BaseStyle->"Link"],
 " function. The straight line can be created using the ",
 ButtonBox["Plot",
  BaseStyle->"Link"],
 " function. The ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "4a4688c1-f0db-44dc-bf1c-f6ef7b7eb0cb"],
 " intercept point can be created using the ",
 ButtonBox["ListPlot",
  BaseStyle->"Link"],
 " function."
}], "Text",
 CellChangeTimes->{{3.7535828614604635`*^9, 3.7535828954735565`*^9}, {
   3.7535831282857466`*^9, 3.753583220392702*^9}, {3.766227812297406*^9, 
   3.7662278181929955`*^9}, {3.76622790514869*^9, 3.766227912886464*^9}, 
   3.76622858096626*^9, {3.76622861642126*^9, 3.76622866879326*^9}, {
   3.8007221075103946`*^9, 3.80072210775814*^9}},
 FontTracking->-0.1,
 CellID->350556872,ExpressionUUID->"fbd92688-de46-4163-a410-b628477e049b"],

Cell[TextData[{
 "Note the double curly braces in the ",
 ButtonBox["ListPlot",
  BaseStyle->"Link"],
 " function:"
}], "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, {3.7535829197508698`*^9, 
   3.753582944426888*^9}, {3.7662493086697836`*^9, 3.766249330125929*^9}},
 CellID->121526939,ExpressionUUID->"f70a77d7-c42a-42f6-b396-fed90c5eb110"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", "x"}], "+", "2"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}]}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"0", ",", "2"}], "}"}], "}"}], ",", 
     RowBox[{"PlotMarkers", "\[Rule]", "Red"}]}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->489446090,ExpressionUUID->"7089f44e-9c2c-45a4-a3eb-3a23c25a97cb"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVkGs01GkcgIdhhmHGvP3LaV3muE5Je8ahdB3vb5UJRVcJHesyK2xL2axi
aZRqE5JpTjdbqaMW495Bhb80Ozu1iSyzKDazUmZtQ8hojNn2w3Oej885j2NM
8q5vjCkUStBn/ndui2+rwaAhr+9IZlMoWhw8/u3l8QkNOW7ypl9G1WJkK0np
H9aQG++H3z5L1+LLR99y6x9ryAFHgTdhpcV3vPLOx53RkNZTdvu5HC1+VNYb
1cHSkIWSp3e3bdRirSSees3+PXliwBVfOarFB5IK/L03jJNxwlffeU5qcVaW
c6uf6zsyyiGtsOrjHA6H7fzSPSOkmietUao/YedNQejLS6/JNdXSh6sGdDgw
0K3EFvWTjcqBc68G53H/4TeemVkvyF933g7z6NLjxup4b0dxO2maemW8Q7mA
43UZ3YHVYtLcLCKxpM+AC/4YbLBzuY+D016mFAopsERJF94aeoZrfRyImVEK
3NE7OesYSjzA86yrjjKCxIKfE/eIBvHbvjKBaZ8RRNa0/6v/XYUt9za1HA8z
hkdvbxRnF41i7bzYa0e3MahJr6iV5WqsT6Pl+YVQYVnozPOqqvf4TflQf28v
FbZz2FcnvCfxRXoOtznIBJKGKaH2eArvX9sW8lunCZRv5VrdcpnB6qInJ5cH
mEIA7e7OB56zuOhRwsWqZ6aQcrM1wWfNHLb7JflqZxANmoYZmTZf6HBSk+8N
gZwGMd/X2eQ663FfsfS0yp8ObtKC+p0WBsyo+PtgTzsd+CrKhfYjFOAcFvlH
rzeDS9bxTO5RI9hmcY9GNJuB6HrCmdWJxgCd9x7brDaHa88vywsOUSH4wLbY
LU3mkJEknrBPMQGfxgAtax0DxqKXLw2LMYVpj8V5K2sZcFavNhmKo4EsK9U4
2csCmsa3aFjhdNj/8XYavdICKrYekqX6m4HSda1qvYsldO2SR3K3mkO8WyxP
XGoJOZUNH09sZED73oiMrzhMSKjp2e3mawGr9qnLFpcwYZCWX5XhbQlJJwV/
8m1ZYN3BnqZymXAuzuyTkZgF2RvaF3rdWNBmH21QL7aCdD2TvsfOCloWTlNX
FFhBd/0mdT5iw1i/44zcjA1PHOLkeUVsELK9YgUBbPipMaRkmIFA9rK869Ap
NkQ5vYqMyEfggZKqK+VsMDTwbN3pi0D08lK+hIpARB17JslaBG3ZR0YDMQIb
l3XRrhQCmEXFNYtE6POvvdOMYwT4rHFPP9WMwMFbqOBmEMC29RSKWz539IeL
fTMJUC2sDS5pRcDKz9+cnk3AGbnAqaUNwa0K2cWxswS8CIl5Oi1DoHjnuVpx
lQDhkSs2wg4E1rFWP5xqJuBcLf2h7xCChyvsA0taCYiUsEp3/IUg6sMKTksb
AR7HlpyPfI2gPFsgn5YR0AvOsekqBPybmdbCDgI4XT4WdaMIhIP/NPgOEVD3
PjXCUYPAvHQuN/I1ATndP/rxJhBUHaR/na4iILThJI8/iWBW50SvGyVgPvMC
NWwKQa5NeKijhgA/ZmVF4SwCnuqAO3+SgKWT9ZLrWgQ9ZamGfVMEqHseHJfO
IeCsu3C3cJaA88WK3QodgseUGxnSOQJiRJ185TyCeIV0u0JHwCqhctmIHoFl
4QPnET0BNP9B9GEBQW2oYtZgIKDPfURnMCD4D8ZNLlU=
        "]]},
      Annotation[#, "Charting`Private`Tag$5213#1"]& ]}, {}}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], GeometricTransformationBox[InsetBox[
       StyleBox[
        InterpretationBox[
         ButtonBox[
          TooltipBox[
           GraphicsBox[{
             {GrayLevel[0], RectangleBox[{0, 0}]}, 
             {GrayLevel[0], RectangleBox[{1, -1}]}, 
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}},
            AspectRatio->1,
            DefaultBaseStyle->"ColorSwatchGraphics",
            Frame->True,
            FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
            FrameTicks->None,
            
            ImageSize->
             Dynamic[{
              Automatic, 1.35 CurrentValue["FontCapHeight"]/
               AbsoluteCurrentValue[Magnification]}],
            PlotRangePadding->None],
           StyleBox[
            RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> False]],
          Appearance->None,
          BaseStyle->{},
          BaselinePosition->Baseline,
          ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
            If[
             Not[
              AbsoluteCurrentValue["Deployed"]], 
             SelectionMove[Typeset`box$, All, Expression]; 
             FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
             FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
             FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
             MathLink`CallFrontEnd[
               FrontEnd`AttachCell[Typeset`box$, 
                FrontEndResource["RGBColorValueSelector"], {
                0, {Left, Bottom}}, {Left, Top}, 
                "ClosingActions" -> {
                 "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
          DefaultBaseStyle->{},
          Evaluator->Automatic,
          Method->"Preemptive"],
         RGBColor[1, 0, 0],
         Editable->False,
         Selectable->False],
        StripOnInput->False,
        GraphicsBoxOptions->{DefaultBaseStyle->Directive[
          PointSize[0.012833333333333334`], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]]}], {0., 0.}], {{{0., 2.}}, {{0., 
      2.}}}]}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 1.50000006122449},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{487., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-1, 5}, {1.50000006122449, 4.49999993877551}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7535829603278556`*^9, 3.802441649705532*^9, 
  3.8106622091844397`*^9},
 CellLabel->"Out[1]=",
 CellID->528293010,ExpressionUUID->"b286ea6c-4d11-444e-839f-8c9a13e955f0"]
}, Open  ]],

Cell[TextData[{
 "Note the slope of ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "2",
    FractionLine->0.2], TraditionalForm]],ExpressionUUID->
  "f18c3e8b-6ba4-4180-9133-ad7f5d78585d"],
 ". This is the rise over run, i.e. we rise one unit on the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "bc34c25f-b5f2-4a0f-85c4-3e25bc15920f"],
 " axis for every two units we move on the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "841c1f56-d189-48f5-b266-c7a0738f96ed"],
 " axis. When ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "00e2667f-03cf-4276-af09-2691ee574935"],
 ", we see that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", "2"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "2b74c3f5-b803-4b98-baad-4c3721d2f933"],
 ", the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "ad5e3a8a-e2f7-42c3-be49-5e5539bd2751"],
 " intercept (red square). All we have to do to this conceptual model is add \
the error term ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CurlyEpsilon]", "i"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"544f226f-5fb3-4a03-becb-99cf25b084f6"],
 " for every real ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "d73d555e-4b87-4dab-b9b4-a306df0d300f"],
 " value."
}], "Text",
 CellChangeTimes->{{3.7093804383717885`*^9, 3.709380536587288*^9}, {
   3.7093805875727124`*^9, 3.7093805875727124`*^9}, {3.710739670940694*^9, 
   3.7107396980214396`*^9}, 3.7107398083900366`*^9, {3.716008335622714*^9, 
   3.716008350444014*^9}, {3.7778148795492897`*^9, 3.777814891741753*^9}, 
   3.80061430186767*^9, 3.8007213942666426`*^9, {3.8007221151068726`*^9, 
   3.8007221218969693`*^9}, {3.8007230160720267`*^9, 
   3.8007230161747513`*^9}, {3.8007231009573803`*^9, 3.800723103569228*^9}, {
   3.8007253073395863`*^9, 3.800725320748905*^9}, 3.816087688398679*^9},
 CellID->1969182359,ExpressionUUID->"3a9e471d-458f-452b-9bdb-41abc519d7f2"],

Cell[TextData[{
 "Now if we replace ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]], "InlineMath",ExpressionUUID->
  "803cd85c-8f53-47bf-9de0-837fe6b0b47e"],
 " with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "0"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "ed758424-2acc-45ed-a220-8a67dc6927cd"],
 " and ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]], "InlineMath",ExpressionUUID->
  "3f0745c1-ff13-4791-8122-e5fe0b7ffe92"],
 " with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "1"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "d2d70c7a-323d-425d-8652-15f90a7f023f"],
 ", we have the two ",
 StyleBox["regression coefficients",
  FontSlant->"Italic"],
 " needed for all single independent variable models."
}], "Text",
 CellChangeTimes->{3.7535830103733234`*^9},
 CellID->105609684,ExpressionUUID->"a4818449-f5ac-44df-8fc7-c3390c6534fb"],

Cell["\<\
Note that we needn\[CloseCurlyQuote]t stick to a single independent variable. \
Moving up to 3D space, we can calculate a dependent variable by using two \
independent variables. Going up to 4D in our imagination, we can use three \
independent variables and so on. The equation for two independent variables \
is shown in equation (2).\
\>", "Text",
 CellChangeTimes->{{3.7535832671492205`*^9, 3.7535832954741216`*^9}, {
   3.7662279223974147`*^9, 3.7662279284130163`*^9}, 3.766230711942255*^9, 
   3.8007232993901415`*^9},
 CellID->365430473,ExpressionUUID->"a7bb4433-9088-4e61-88c8-ed719a00c733"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["y", "i"], "=", 
   RowBox[{
    SubscriptBox["b", "0"], "+", 
    RowBox[{
     SubscriptBox["b", "1"], 
     SubscriptBox["X", "i"]}], "+", 
    RowBox[{
     SubscriptBox["b", "2"], 
     SubscriptBox["X", "2"]}], "+", 
    SubscriptBox["\[CurlyEpsilon]", "i"]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.7776629710022182`*^9, 3.777662981534481*^9}},
 CellID->2146816857,ExpressionUUID->"976ef2c1-aa3a-460f-9848-dd5d070f7da1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculating the Regression Coefficients", "Subsection",
 CellChangeTimes->{{3.7535833281002455`*^9, 3.753583336507456*^9}, {
  3.766230717444255*^9, 3.7662307199322553`*^9}},
 CellID->123957802,ExpressionUUID->"bb26fa75-76e0-46ff-b995-21723ab6696d"],

Cell["\<\
It is time to bring back the error term. Our aim (for a single independent \
variable) is to create an equation that best fits the data. Real-world data \
never fits a straight line because there is always some noise or variability \
to contend with.\
\>", "Text",
 CellChangeTimes->{{3.753583359956402*^9, 3.7535834622388926`*^9}, {
  3.766227931726348*^9, 3.7662279347656517`*^9}, {3.766230789288255*^9, 
  3.7662307908962555`*^9}},
 CellID->372258150,ExpressionUUID->"fb935305-2755-457e-bc48-5d3c7a3168ae"],

Cell["\<\
We can sum up our problem in the next plot. It shows value pairs for the \
independent and dependent variables and a few straight lines. The straight \
lines represent our linear model that predicts a dependent variable data \
point value given an independent data point value. But how do we choose \
between these models?\
\>", "Text",
 CellChangeTimes->{
  3.7535834739121103`*^9, {3.7662279374209175`*^9, 3.766227944198595*^9}, {
   3.7662308055282555`*^9, 3.766230809295255*^9}},
 CellID->129569525,ExpressionUUID->"ab8b95f2-1c73-41ec-8246-4a8a84e9c0f2"],

Cell[TextData[{
 "Below we plot our data point values. The ",
 StyleBox["x",
  FontSlant->"Italic"],
 " coordinate of each point comes from the independent variable and the ",
 StyleBox["y",
  FontSlant->"Italic"],
 " coordinate comes from the dependent variable for each corresponding \
subject. To ",
 StyleBox["guess",
  FontSlant->"Italic"],
 " the correct lines, we will use three sets of regression coefficients \
(slope, or ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "1"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "d08d3d00-78dc-4380-9d9f-f76dcef108ec"],
 ", and intercept, or ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "0"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "ffcdb322-0fbe-4eb1-9574-71ec71b855de"],
 "). The three equations are shown in (3). "
}], "Text",
 CellChangeTimes->{{3.753583512556883*^9, 3.7535835799728894`*^9}, {
  3.766227964470622*^9, 3.7662279736225367`*^9}, {3.7662308419972553`*^9, 
  3.766230883506255*^9}},
 CellID->95670558,ExpressionUUID->"d22bdaa7-d645-42cd-bbea-799e9faf3829"],

Cell[BoxData[{
 FormBox[
  RowBox[{"y", "=", 
   RowBox[{
    RowBox[{"-", "0.5"}], "+", "x"}]}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"y", "=", 
   RowBox[{"1", "+", "x"}]}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{"y", "=", 
   RowBox[{
    RowBox[{"-", "0.3"}], "+", 
    RowBox[{"1.2", "x"}]}]}], TraditionalForm]}], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.7776630700749617`*^9, 3.777663077128133*^9}},
 CellID->438405120,ExpressionUUID->"3525970f-66a8-4336-9231-a178f3764345"],

Cell[TextData[{
 "Create a plot with the data point values and three possible models using \
the ",
 ButtonBox["Show",
  BaseStyle->"Link"],
 " function with ",
 ButtonBox["ListPlot",
  BaseStyle->"Link"],
 " for the markers and ",
 ButtonBox["Plot",
  BaseStyle->"Link"],
 " for the models:"
}], "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.7535836170054674`*^9, {
   3.7662308891462555`*^9, 3.766230929069255*^9}, {3.800613055140753*^9, 
   3.800613083357687*^9}, 3.8006131178369656`*^9, {3.800613185932508*^9, 
   3.8006132065006056`*^9}},
 CellID->751527036,ExpressionUUID->"6ad0798b-e523-434e-93e7-cc9054726682"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "5"}], "}"}]}], "}"}], ",", 
     RowBox[{"PlotMarkers", "\[Rule]", "Red"}]}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "-", "0.5"}], ",", 
       RowBox[{"x", "+", "1"}], ",", 
       RowBox[{
        RowBox[{"1.2", " ", "x"}], "-", "0.3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "10"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7857234729139643`*^9, 3.7857235713517704`*^9}},
 CellLabel->"In[2]:=",
 CellID->16031443,ExpressionUUID->"5ce92946-8b60-4864-ba6b-aa13c2860bd6"],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], GeometricTransformationBox[InsetBox[
       StyleBox[
        InterpretationBox[
         ButtonBox[
          TooltipBox[
           GraphicsBox[{
             {GrayLevel[0], RectangleBox[{0, 0}]}, 
             {GrayLevel[0], RectangleBox[{1, -1}]}, 
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}},
            AspectRatio->1,
            DefaultBaseStyle->"ColorSwatchGraphics",
            Frame->True,
            FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
            FrameTicks->None,
            
            ImageSize->
             Dynamic[{
              Automatic, 1.35 CurrentValue["FontCapHeight"]/
               AbsoluteCurrentValue[Magnification]}],
            PlotRangePadding->None],
           StyleBox[
            RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> False]],
          Appearance->None,
          BaseStyle->{},
          BaselinePosition->Baseline,
          ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
            If[
             Not[
              AbsoluteCurrentValue["Deployed"]], 
             SelectionMove[Typeset`box$, All, Expression]; 
             FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
             FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
             FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
             MathLink`CallFrontEnd[
               FrontEnd`AttachCell[Typeset`box$, 
                FrontEndResource["RGBColorValueSelector"], {
                0, {Left, Bottom}}, {Left, Top}, 
                "ClosingActions" -> {
                 "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
          DefaultBaseStyle->{},
          Evaluator->Automatic,
          Method->"Preemptive"],
         RGBColor[1, 0, 0],
         Editable->False,
         Selectable->False],
        StripOnInput->False,
        GraphicsBoxOptions->{DefaultBaseStyle->Directive[
          PointSize[0.012833333333333334`], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]]}], {0., 0.}], {{{1., 1.}}, {{2., 1.5}}, {{
      3., 3.1}}, {{4., 4.5}}, {{5., 5.}}}]}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwty31M1HUcwHEgRAQJ7oFHD+7u++XBJRBaHkiu3wcQ6tAiCZHiYMAQaUBE
gJqCS0SQ55SyCATMmlYTuDEGXrt9gTyBFDcyHA+WPCWCyJ3nxQkol63PH++9
/npLU7KjD1iYmZm986L/PB5/tNRk0jLmp/7VZDKymXFNpmJGy/SPUmT+eiPb
reBFX+3XMu8W6x8VM0bmknBZlHtGyyr9Y6qv9huZMvGO8j7RsrhXH8blnnnx
J2+7Oxi+yPQBrov3iZHJ0+cDGioWmOfr+S63wpeYMP/DsSDnOVYe7JfVUGFg
tfyQ0p/qJllkWXPY8E0dezdkcCJBNswuNafp/OvnWerJ3udfrqlZ5ntdTb+z
aeZ171hneZGaC7SWRic0jbDQ1jaiCR3mCi40qvKPalheqyrnDZ8prvnYcNX4
DiV37m+d7T9lc5zvjUnnecFt7qyjwTAo03GeWx7M1WdNcKmHFmTrnjzh+hdG
smzuz3ILiRq39mwjN6Iu3552b5Grl52OHxpbQfXcvptvZb//xRq6xE0Zcvne
L5nDtblZzz1WK1xzSm9szLQFgKb4yuXrz7nHfacGVCpL+F8zcM/ZUaX41Aq1
gKjPMoIDoqxRS1BoqoK4jTaoFXz8ib/k80VbdD0IBbtky3126Ab4all+/soJ
e9QWqsWzS/I2BxBxtx7VJtnBm6kX+sZqeFDQH1rTIbaHLs9zresz+KgDdAgj
KwfjBCgPmrwP8ZQyIcqHjenJFX4+jqgAwrxKRRECJ1QIBy29Ygu0TqgQXhYU
Fe/+yxl1hIth++OD1C6oE5jr0uQ9X7uizjB1Y7vvdLEb6gLKgYJOkrIJdQUL
Y1Hg6l4R6gYhEeZJj7e6o5sgkqdqOmnngYrgju22P1pWPVARRG0mSuOoGHUH
L1V6T+YBCUTmDRWN/uYB1o1/dvw8LgGHnb9k7O8Uw9TZ6uPLcikqgUJxU09t
jxSVgL364cjOrQSVQsk3w6vtjQSVArMV1x12pCiBxZrvbSKLKUog/G78VFAJ
RQk0bBaofE5TlEBkz4mP1lVSlMAlfWJ/dy1FCSTtcy0JvEhRArfdqs29eilK
4JWD4aOCaxQlUNT+rM3iOkUJBOzJSJoYoCiBysK3Wf0QRQlETFgU8icpSuC8
ryrGfJqiBAxHcnx1MxQl8B1vYnzwAUUJmELVwWU6ihKIrcnjH9FTlEDL+Jb5
NANFCSjyvq3b9ZSiBNq79+a8tkJRAjZ2G+TkGUUJJH/QLeGtUZRA1w+Hn5pM
FCXwL2z0M+A=
        "]]},
      Annotation[#, "Charting`Private`Tag$5452#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwtyXlQ1HUcxvFdFOQU9uBe2OPLV0CwQcplQ8ffBxRksSRMMQMJGEQMi1AC
EnEAEVSuFCNoQarVyREFdhgH2tpZloGQkIopCBYoWNA8GC4xTiGa+fzxzGue
eYvjkg8eN2KxWG+v73/PR54tWFub0rJY2aKT4pLd44Ptp6LG17/Azb9MmcTs
j+Ic/P7BlDZbHz4focxkHI7dFpy5ut7VT3plykJGFd2neiyZ0o54vtHuqVQw
47G+Q91Bk9qW0YFdEmUtI0985lNVOKFt1tzNcFX+wPA/fV8vs3+qbfAqLxco
u5gybkDBncpRrV6fNXPn4RBzIKB75Ji0V3v0g0rrnvhHTPyF1lfXVzXa6/X7
YrbBBEP/zmy6kqthZjXptR79M0xgfYOkPbCX+c3rbojqnZdMar06Zae7gVEf
GW6u5i0y5Y+mLV5efsp0nV64uNS2wlyznZvrlk4zneZnlxKcWRCfNiE1fvGC
8d2ZpshdZMNEdLtTY/I8k1YfVzzQtAEU0kuRPfol5oBz273Ej4zh8MN9ye9+
vspsfaxs8gzZBIa5M9wtG9ioGXwd1xpxaMwINYeZjoudavVG1BJcUt4sjjpt
gm6GsM+S/H3CTOH2jztcKtxtIKq9WMZYmkOdIbhKaMKBjz95TZQ9aQF+Mnsb
mOcAn7dXuthhBVfMJIqVMS58sSivvpdjDT+v3Pylr4UHJcJ//pU32KB82B3/
TYe+lIPaQrNbef2mJC5qB/f5oUXd7/FQe6jZksZRSfmoA1gmxhZuc7dFHWEP
LRAE8+xQJzixkUacm7JDnWAzLzdv/1/2qDMo9xyJlGkcUAGwpxPkui8dURcw
dO3wHstzQl1B1XmuSRLnjArBaD7XbzlcADmZOsUrDxEEBLNjZra7gEjJalio
EEEoR11zwcoVbpkO/6ozEUOfhe8fdcuu8NzY8cM/s8QQ5iFRzQ8IwYN/tX95
QgxUnag7dVyESsD0xvD92kERKgHDtZLzi3IxSiBLWKMr04lRAtaa5/27tktQ
N8iv6F1uvCFB3UBrIaxMtyUohcnSm+aheQSlEDQUaZDlE5RClQdP7X6JoBRC
dTknjYsISuG72egHLWUEpRBz2DHfT0lQCr87lbBpK0EpbD0RNMBrIyiF3MaV
BqOfCErB562kmJFOglIoygrRKnoISiF4xCiLO0pQCtXe6kPsMYJSmMtI8Z4e
JyiFbzkjg91PCEphLVDjf3maoBQiSlO5GbMEpVA36PUsYY6gFKJSv6rcu0BQ
Co0t4SmvLxGUgrmVmVyyQlAKsUdbRJxVglJovpW+sLZGUAr/AQ77KIo=
        "]]},
      Annotation[#, "Charting`Private`Tag$5452#2"]& ], 
     TagBox[
      {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVy3k4lAkAx3EmxSKaGVcSY95mXpUiFWKf3p+zRm3Kbd0SNqUmSm1Ek01K
6S6pJLZLS7OSo9WLh9TTankclbGSI5vFMI5JZLb94/t8/vqahu/x2MFQUlL6
4Vv/eyTg5zSFQkonNxaVKhRyuldStyuwV0r7DNy/u1MqpzcFMj3KX0jpFSr5
V1o75bRB0D2juHNSWmJzNaGgUk6Lg9vEH7lS2iYnxcb38Lc/zKqjwWWYlu7e
Vlo4OUkLogcsr58apEM0xp4EDU3QOvt/bLfV/0RTrtZPnraP0RdYDmkPsj7Q
vUX99pFlw/QWh4auIOtWemZsw1CT50c64ljN14uzlbRKNWfzc6sOmvf+cOlJ
USX1hG1U91BcSzsWPeLWObZS+UWfNJNRTsUXVQjtyW6qR8h3Ngt+S13uG9GY
SP9EpbBNJTKNPuq87vh4g/UIFdwg+N1r6xAVcWDQeu7YGFVAiiQ5xBg1GFxn
WLxHTm15OzjY5iGnsq1PBDS1f6HK4/PspndNU95/btjjeXaWWj3BNYnoUlDd
43Es/hxl3Jf5CurnMHArvMbHq4eBqg7R61knFYzW//KyokIFT/9oHn14aB4W
C9edDtw3D+leBR326WpwPxRjZ+muhpDgftbuOnUE1p22pTTVocZ5sCBZoonY
vSs5KcMaKPNs8l9trA0dtrP1VP183FmfybEoWIBLU4Ibvx3Vhr/FlHzNYybO
mPRPCh4tANNfd+JUMwvrI3Lr2zOZEHeOeze/Z6NsyeUi1RgWnEL657Z91EGJ
jltGgx8b7wwyJEtV9JDDP8AUW+vAb+W4TqyWPjSjw06tIHUhSdSKn2NhACde
mpErWw9bn9tzvdwWIkqF55Mo1UNRjPmaSx6G0GKLUjd16oPp9lcMKVyEPCff
ANtKAwSlrlV9kGgE5ZFIQfWVhcguLxztFy1G96u15j2phugg25UTcowhfplY
yg1fBFXZi/2T90zAkItsprcZ4dqXx2nbIzhwcFUOHV21GPxlUfNqBzhwY1bk
HJtvDPM3t81FsaZo07BqKZw2RvGt0r7or6ZwN+OK5e9MYGFQ2Fgv4oJXEV29
awcH5g+TtrizCajd/LukQMJBXmVb3JpcAt3nzxyZEphCO4n56hxvCZJMcqov
VJtixo9Xol+yBNqV/779fhUXnd2GTbr2PBy/2jpdfJMLu4Gsi8JnPNAaJlkJ
ugQMtGQDE5v5GM7MV3dLJTDwfnmcrIkPl46AbtvjBAZzWxydW/i4bsauIE8Q
GN6exLrcxodb9dGf5mYQkPW/Fq+T8HFXFvyi6gKBaalwJKWXj1Dvhcdt8gho
KpXt1pbz0Wx4RplXQ8CS4xxtbkRiWZTLO3YtAavuQZsjxiRExTOPGM8JrM2/
pNrIIWG5OSa06yWBdWb9d+J4JDKSNtLZTQQcLE/2Vawk4drFSGJ9IOCJxnCB
A4kb5hVeyj0EvBmHrLKdSIwfFJqP9BLwrTVlDLmQuM3skjT8QyBgY1zuWTcS
CsdKu/QRAju26nW98SThkxnPOigjEMWii5b6kCiULB+IHCewsyUq+bAficD4
a1nOnwnE+pUbmwSRKK7aJlz9hcBew/DhvSEk1Od/J+DOENjXof6sJoxEmH8V
hzlLIP5m8WmdCBJlvyZ8VigIHAgNDIqMJPEfqlc0NQ==
        "]]},
      Annotation[#, "Charting`Private`Tag$5452#3"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.916666666666667, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0.916666666666667, 5.}, {0, 5.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.785723574163253*^9, 3.8024416508815317`*^9, 
  3.810662209295507*^9},
 CellLabel->"Out[2]=",
 CellID->1315156991,ExpressionUUID->"20d150d3-c507-4f21-8503-9ddbda6740a6"]
}, Open  ]],

Cell[TextData[{
 "Given the data point values for the two variables, there is a mathematical \
way of calculating the best regression coefficients (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "0"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "4b10fe94-54f1-4e58-a6f3-4eb17f90ac96"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "1"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "7e2d7eb5-cbc8-4f50-ba46-ef32bb661125"],
 ")."
}], "Text",
 CellChangeTimes->{{3.7535836448153887`*^9, 3.7535836660255127`*^9}, {
  3.8006137017563715`*^9, 3.800613703816373*^9}},
 CellID->58404393,ExpressionUUID->"6e2bc18b-eeb6-4eed-88c0-9762f4040791"],

Cell[TextData[{
 "We start by adding the squares of the errors, which, as we remember, are \
the differences between the predicted value and the actual value, also called \
the ",
 StyleBox["residuals",
  FontSlant->"Italic"],
 ". This is called the ",
 StyleBox["sum of squared residuals",
  FontSlant->"Italic"],
 " or ",
 StyleBox["residual sum of squares",
  FontSlant->"Italic"],
 ". Note that we square the errors so that we have positive values because \
some of the real values will be above and some below the predicted line and \
these will cancel if we simply add them."
}], "Text",
 CellChangeTimes->{
  3.753583693208686*^9, 3.753583729735649*^9, {3.7662279764478197`*^9, 
   3.7662279822163963`*^9}, {3.7662309887342553`*^9, 3.7662310301952553`*^9}, 
   3.8006137396872272`*^9},
 CellID->304492099,ExpressionUUID->"2a1ef63b-9e74-4fa6-8955-49a9666e32ba"],

Cell["\<\
So what we aim to do is to look for regression coefficients based on trying \
to minimize this sum of squared residuals. The smaller this value, the better \
the final line models our data.\
\>", "Text",
 CellChangeTimes->{{3.753583733636979*^9, 3.7535837484241343`*^9}, 
   3.7662279854877234`*^9, 3.766231263717255*^9},
 CellID->37962401,ExpressionUUID->"d924658b-5b52-43c7-97ae-2fb6ec03815b"],

Cell["\<\
There are beautiful equations to do this, either using vector calculus or \
gradient descent. These are quite difficult to do. To calculate the \
regression coefficients using the Wolfram Language could not be any easier, \
though.\
\>", "Text",
 CellChangeTimes->{{3.7535837804782467`*^9, 3.7535838018347893`*^9}, {
  3.7662279885920334`*^9, 3.766227991543329*^9}, {3.7662312960112553`*^9, 
  3.766231296890255*^9}},
 CellID->131348915,ExpressionUUID->"6c9ae341-cfbc-497c-b6a0-68b762009430"],

Cell[TextData[{
 "First, let\[CloseCurlyQuote]s create two variables, an independent variable \
and a dependent variable. Below is a nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object that contains the values for each of these variables as pairs, one \
for each of the 10 subjects in a simulated experiment. We will add this \
object to a computer variable called ",
 Cell[BoxData[
 "data"], "InlineCodeText",ExpressionUUID->
  "9c57dd8b-52ae-4c03-acc4-b91c4bc80534"],
 ". We\[CloseCurlyQuote]ll also create a scatter plot, which we might \
intuitively interpret as some correlation existing between the variables."
}], "Text",
 CellChangeTimes->{
  3.7535838042415433`*^9, {3.7662280019133654`*^9, 3.76622800476165*^9}, 
   3.7662282281229844`*^9, {3.7662313125072556`*^9, 3.7662313290902553`*^9}, {
   3.8007253585133915`*^9, 3.800725360455694*^9}},
 CellID->809633173,ExpressionUUID->"06462e0c-1551-4c31-8de5-39e8abf8a280"],

Cell[TextData[{
 "Create 10 pairs of values and save them in the computer variable ",
 Cell[BoxData[
 "data"], "InlineCode",ExpressionUUID->"16331cf9-c3f5-49ce-bb82-56c749c63d76"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.75358384349774*^9, {
   3.766231337408255*^9, 3.766231349751255*^9}, {3.800723899051573*^9, 
   3.80072390140921*^9}, {3.8135027026735*^9, 3.813502703161127*^9}},
 CellID->482539679,ExpressionUUID->"bd82bdbc-b6d9-45cf-94fa-b737e4b15825"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5", ",", "1.8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.3", ",", "2.9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.5", ",", "4.9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.9", ",", "6.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.7", ",", "8.8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "8.7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.9", ",", "9.9"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->335801573,ExpressionUUID->"3299cc7f-1576-4800-be9e-b20b597feff8"],

Cell["Create a plot of the data points:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.7535838625645943`*^9, 
   3.7662280076319375`*^9, {3.7662313541672554`*^9, 3.766231359256255*^9}},
 CellID->186498751,ExpressionUUID->"2e1ff906-504c-4c56-8e29-a5c5c1af61b7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"data", ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Red"}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7857237534897976`*^9, 3.7857237841627893`*^9}, {
  3.785723816399597*^9, 3.7857238340972834`*^9}},
 CellLabel->"In[4]:=",
 CellID->66683801,ExpressionUUID->"fc463ee1-6ead-42f0-b18d-4f14415504e5"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[1, 0, 0], PointSize[Medium], AbsoluteThickness[1.6], 
    PointBox[{{0., 1.}, {0.5, 1.8}, {1., 2.}, {1.3, 2.9}, {2.1, 3.}, {2.5, 
     4.9}, {2.9, 6.1}, {3.7, 8.8}, {4., 8.7}, {4.9, 9.9}}]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 4.9}, {0, 9.9}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.753583869225718*^9, 3.7857238348193483`*^9, 
  3.802441651839532*^9, 3.810662209370471*^9},
 CellLabel->"Out[4]=",
 CellID->1941852813,ExpressionUUID->"2bfc7c7e-9d30-4513-b5c7-51afd3a90ec8"]
}, Open  ]],

Cell[TextData[{
 "Now we use the ",
 ButtonBox["LinearModelFit ",
  BaseStyle->"Link"],
 "function and pass the data point values. Note the full list of arguments \
that contain two ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "8efb2dda-ce40-4dc8-9526-2e2526f6f6c0"],
 "\[CloseCurlyQuote]s. Let\[CloseCurlyQuote]s call the computer variable ",
 Cell[BoxData[
 "linearModel"], "InlineCodeText",ExpressionUUID->
  "0e09e846-3da1-484a-acd4-ca58ca46ac5e"],
 "."
}], "Text",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, {3.75358388876443*^9, 
   3.7535839021531954`*^9}, {3.7662280111782923`*^9, 3.766228014570631*^9}, {
   3.766231367992255*^9, 3.7662314221492553`*^9}, {3.7662314725212555`*^9, 
   3.7662314816602554`*^9}, 3.777814949193432*^9},
 CellID->183259585,ExpressionUUID->"a563e677-8ab2-4303-866c-2351cf84265b"],

Cell["Create a single independent variable linear model:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, {3.7535839249649215`*^9, 
   3.7535839401526704`*^9}, {3.7662314848322554`*^9, 3.766231512932863*^9}, {
   3.7663165568208227`*^9, 3.766316562986822*^9}},
 CellID->764674018,ExpressionUUID->"a796cc93-41ce-4d0d-a26c-c5e2efd63611"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"linearModel", "=", 
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"data", ",", "x", ",", "x"}], "]"}]}]], "Input",
 CellLabel->"In[5]:=",
 CellID->575761922,ExpressionUUID->"b9d1f252-3b24-43c5-a0ee-8d58f9f7559a"],

Cell[BoxData[
 TagBox[
  RowBox[{"FittedModel", "[", 
   TagBox[
    PanelBox[
     TagBox[
      RowBox[{"0.3493875972323725`", "\[VeryThinSpace]", "+", 
       RowBox[{"1.9915338003352088`", " ", "x"}]}],
      Short[#, 2]& ],
     FrameMargins->5],
    Editable -> False], "]"}],
  InterpretTemplate[
  FittedModel[{
    "Linear", {0.3493875972323725, 
     1.9915338003352088`}, {{$CellContext`x}, {1, $CellContext`x}}, {0, 
     0}}, {{1., 1., 1., 1., 1., 1., 1., 1., 1., 
    1.}}, {{0, 1}, {0.5, 1.8}, {1, 2}, {1.3, 2.9}, {2.1, 3}, {2.5, 4.9}, {2.9,
      6.1}, {3.7, 8.8}, {4, 8.7}, {4.9, 9.9}}, {{1., 0.}, {1., 0.5}, {1., 
    1.}, {1., 1.3}, {1., 2.1}, {1., 2.5}, {1., 2.9}, {1., 3.7}, {1., 4.}, {1.,
     4.9}}, 
    Function[Null, 
     Internal`LocalizedBlock[{$CellContext`x}, #], {HoldAll}]]& ],
  Editable->False,
  SelectWithContents->True,
  Selectable->True]], "Output",
 CellChangeTimes->{3.7535839486810493`*^9, 3.8024416526925316`*^9, 
  3.8106622094655743`*^9},
 CellLabel->"Out[5]=",
 CellID->1411244632,ExpressionUUID->"3d640bd9-03a1-41bc-a4a4-d981f161cb49"]
}, Open  ]],

Cell["\<\
The model that we created has many properties that we can examine.\
\>", "Text",
 CellChangeTimes->{
  3.753583971206575*^9, 3.766228017273902*^9, {3.7662493893038464`*^9, 
   3.7662493898148975`*^9}},
 CellID->340573988,ExpressionUUID->"bf269a07-58bf-420a-89d2-e7fd69ce307b"],

Cell["List all the properties for our model:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753583981582554*^9, {
   3.7662494395068665`*^9, 3.7662494450184174`*^9}},
 CellID->746837725,ExpressionUUID->"eff2f88b-76b9-45ba-8b16-af4c044cfca8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"linearModel", "[", "\"\<Properties\>\"", "]"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->153790460,ExpressionUUID->"562258b7-3446-44c8-b3e6-9304ce307b44"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"AdjustedRSquared\"\>", ",", "\<\"AIC\"\>", ",", "\<\"AICc\"\>",
    ",", "\<\"ANOVATable\"\>", ",", "\<\"ANOVATableDegreesOfFreedom\"\>", 
   ",", "\<\"ANOVATableEntries\"\>", ",", "\<\"ANOVATableFStatistics\"\>", 
   ",", "\<\"ANOVATableMeanSquares\"\>", ",", "\<\"ANOVATablePValues\"\>", 
   ",", "\<\"ANOVATableSumsOfSquares\"\>", ",", "\<\"BasisFunctions\"\>", 
   ",", "\<\"BetaDifferences\"\>", ",", "\<\"BestFit\"\>", 
   ",", "\<\"BestFitParameters\"\>", ",", "\<\"BIC\"\>", 
   ",", "\<\"CatcherMatrix\"\>", ",", "\<\"CoefficientOfVariation\"\>", 
   ",", "\<\"CookDistances\"\>", ",", "\<\"CorrelationMatrix\"\>", 
   ",", "\<\"CovarianceMatrix\"\>", ",", "\<\"CovarianceRatios\"\>", 
   ",", "\<\"Data\"\>", ",", "\<\"DesignMatrix\"\>", 
   ",", "\<\"DurbinWatsonD\"\>", ",", "\<\"EigenstructureTable\"\>", 
   ",", "\<\"EigenstructureTableEigenvalues\"\>", 
   ",", "\<\"EigenstructureTableEntries\"\>", 
   ",", "\<\"EigenstructureTableIndexes\"\>", 
   ",", "\<\"EigenstructureTablePartitions\"\>", 
   ",", "\<\"EstimatedVariance\"\>", ",", "\<\"FitDifferences\"\>", 
   ",", "\<\"FitResiduals\"\>", ",", "\<\"Function\"\>", 
   ",", "\<\"FVarianceRatios\"\>", ",", "\<\"HatDiagonal\"\>", 
   ",", "\<\"MeanPredictionBands\"\>", 
   ",", "\<\"MeanPredictionConfidenceIntervals\"\>", 
   ",", "\<\"MeanPredictionConfidenceIntervalTable\"\>", 
   ",", "\<\"MeanPredictionConfidenceIntervalTableEntries\"\>", 
   ",", "\<\"MeanPredictionErrors\"\>", 
   ",", "\<\"ParameterConfidenceIntervals\"\>", 
   ",", "\<\"ParameterConfidenceIntervalTable\"\>", 
   ",", "\<\"ParameterConfidenceIntervalTableEntries\"\>", 
   ",", "\<\"ParameterConfidenceRegion\"\>", ",", "\<\"ParameterErrors\"\>", 
   ",", "\<\"ParameterPValues\"\>", ",", "\<\"ParameterTable\"\>", 
   ",", "\<\"ParameterTableEntries\"\>", ",", "\<\"ParameterTStatistics\"\>", 
   ",", "\<\"PartialSumOfSquares\"\>", ",", "\<\"PredictedResponse\"\>", 
   ",", "\<\"Properties\"\>", ",", "\<\"Response\"\>", 
   ",", "\<\"RSquared\"\>", ",", "\<\"SequentialSumOfSquares\"\>", 
   ",", "\<\"SingleDeletionVariances\"\>", 
   ",", "\<\"SinglePredictionBands\"\>", 
   ",", "\<\"SinglePredictionConfidenceIntervals\"\>", 
   ",", "\<\"SinglePredictionConfidenceIntervalTable\"\>", 
   ",", "\<\"SinglePredictionConfidenceIntervalTableEntries\"\>", 
   ",", "\<\"SinglePredictionErrors\"\>", 
   ",", "\<\"StandardizedResiduals\"\>", ",", "\<\"StudentizedResiduals\"\>", 
   ",", "\<\"VarianceInflationFactors\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.753583989864606*^9, 3.802441653146532*^9, 
  3.8106622094834433`*^9},
 CellLabel->"Out[6]=",
 CellID->1979132556,ExpressionUUID->"e73b420b-e6f3-45dd-8403-d562dae6e766"]
}, Open  ]],

Cell[TextData[{
 "One of these properties is ",
 Cell[BoxData[
 "\"\<\!\(\*ButtonBox[\"ParameterTable\",BaseStyle->\"CodeLink\"]\)\>\""], 
  "InlineCodeText",ExpressionUUID->"6a2573c7-de7f-4248-b6b2-3cadc30b582c"],
 ". The estimate in the first row is our ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "b2f6363d-f99d-42a5-ad4b-11c31c2dfc88"],
 " intercept and the estimate in the second row is the slope. As you can see, \
there is a lot more interesting information in this table."
}], "Text",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, {3.7535840001709785`*^9, 
   3.7535840134870725`*^9}, {3.766228019690143*^9, 3.766228022547429*^9}, 
   3.7662505105549603`*^9, {3.7662505797638807`*^9, 3.7662506131252165`*^9}, {
   3.766250660207924*^9, 3.766250662976201*^9}, {3.766251719126325*^9, 
   3.7662517293263254`*^9}, {3.7776631838715153`*^9, 3.777663185497126*^9}, {
   3.77781501112471*^9, 3.777815014604415*^9}, {3.8007240267953386`*^9, 
   3.80072402706549*^9}, {3.8160878215436*^9, 3.8160878215436277`*^9}},
 CellID->5021495,ExpressionUUID->"8ca73f93-4fb0-42d9-9723-768287b91750"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s see where the property ",
 Cell[BoxData[
 "\"\<\!\(\*ButtonBox[\"ParameterTable\",BaseStyle->\"CodeLink\"]\)\>\""], 
  "InlineCode",ExpressionUUID->"7124d734-4489-4585-b3ce-697db71a7576"],
 " gets us:"
}], "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, {3.7535840001709785`*^9, 
   3.7535840134870725`*^9}, {3.766228019690143*^9, 3.766228022547429*^9}, 
   3.7662505105549603`*^9, {3.7662505797638807`*^9, 3.7662506131252165`*^9}, {
   3.766250660207924*^9, 3.766250662976201*^9}, {3.766251719126325*^9, 
   3.7662517293263254`*^9}, {3.7776631838715153`*^9, 3.777663190799099*^9}, {
   3.777815026556711*^9, 3.777815038009019*^9}, {3.816087793207967*^9, 
   3.816087812831253*^9}},
 CellID->767228924,ExpressionUUID->"92d2453a-227a-428e-9210-6caac5c2e384"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"linearModel", "[", "\"\<ParameterTable\>\"", "]"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->349877746,ExpressionUUID->"6fa894de-9c7d-465a-b5dd-5ccea7df94e2"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\>", "\<\"t\
\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"1", "0.3493875972323725`", "0.43438068268724545`", 
      "0.8043350249162253`", "0.4444463118197933`"},
     {"x", "1.9915338003352088`", "0.15786791764129457`", 
      "12.615190154470435`", "1.463368690304395`*^-6"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.785723974778137*^9, 3.802441653689532*^9, 
  3.8106622095123873`*^9},
 CellLabel->"Out[7]=",
 CellID->1940022519,ExpressionUUID->"e3ee1065-c9a5-4b38-aa8c-4f029082fd20"]
}, Open  ]],

Cell[TextData[{
 "Concentrating on the two estimates, we now have a value for each of our two \
required regression coefficients. We now have a ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "b22211d5-ecfd-4b74-80f3-f393cc7c8129"],
 " intercept, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "0"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "812c0fa6-d234-488b-b9bc-9d389dc0e86d"],
 ", and a slope, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "1"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "ed236fa6-43d3-496d-939e-2afa69324de6"],
 " (the estimate values for 1 and ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "8e7049d8-f162-458d-b5cb-de889e03c527"],
 " above), so we can plot this straight line model."
}], "Text",
 CellChangeTimes->{{3.753584066871488*^9, 3.753584073638114*^9}, {
  3.766228025770751*^9, 3.766228028546029*^9}, {3.7662526051403255`*^9, 
  3.766252605452325*^9}, {3.766252754219325*^9, 3.7662527843383255`*^9}, {
  3.8007245026809835`*^9, 3.8007245028845463`*^9}, {3.800725373268758*^9, 
  3.800725375554305*^9}},
 CellID->275657595,ExpressionUUID->"88528118-8fc6-4eb8-ac59-8409277c3610"],

Cell["Plot our data point values and linear model:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, {3.7535840989012003`*^9, 
   3.753584099307392*^9}, {3.7662527886963253`*^9, 3.766252789792325*^9}, 
   3.7662528785243254`*^9},
 CellID->210639227,ExpressionUUID->"da38ca9a-bbc8-4688-a9a6-a354ec3e28f0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{"data", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Red"}], "}"}]}]}], 
    "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"linearModel", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "5"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7857238694058733`*^9, 3.785723908013646*^9}},
 CellLabel->"In[8]:=",
 CellID->78827591,ExpressionUUID->"4bd90a96-175e-47c5-a05d-72366b6bfcfa"],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[1, 0, 0], PointSize[Medium], AbsoluteThickness[1.6], 
     PointBox[{{0., 1.}, {0.5, 1.8}, {1., 2.}, {1.3, 2.9}, {2.1, 3.}, {2.5, 
      4.9}, {2.9, 6.1}, {3.7, 8.8}, {4., 8.7}, {4.9, 
      9.9}}]}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVznk41HkcwHEaR2YmZvzaatYxg69GQ44txxR9Px37VJLNomN0GWe5YtPj
yuYKkaMsocmVNOtxtDspkkpqooxlWlZmSyYrlp4yDUbKtn+8n/e/LxN+xI8B
S9TU1HZ/7f8LEvladv7xmzwSza4dPtiPO6Qst32sA7hG77hmcE4/XnzclsJi
HcNfyhv9I+/3Y8H980xNViyufehilooGcKhLdNgsMxNr6ewvF04OYOmn4IL3
zGJ852J2yceEQaw9NMKeYgqxuVCZc04gwxVdZZH/Mpvx53H5Rp+I17i+IXMo
1LoLb1PJRfaOb3EQ7i2ejJLiypb4Oe3sdzh8dI1cVD+IDVyLY9OPTmOySSr7
ldMwZgopmN+mxDm0p5yKo3Js/bpz/PbIHOYPed0jPfsHn6KUyQJdF3Dko1R+
BHsCDz4gWdpULuIbJ6ieq3ZO4SoLXgP3qDpUxIdM2O57j2PGXcK06SRILlvw
+Dj5AfcVio2Iag1Qkw5Da5wCc8mMBUs7LVh9MjDGi6PEd2eiE9+/1IY3yqK9
lLsz+HFPjGI6QgdcR4+fvhA5hydN0qkVphRwf5NnaWw8j1kbDnke7KbCxEP+
mSd1n/DgpsFsbx9dsKb3G2098hnvO2xrf1qTBmSs9JUpvuBUYrvgnYQG26d4
s6beagBpfgP2Qjr81e6vzrNSB9ILv+spP+vDzYyOwyylOiw1vxV1YjsBgZrR
wxLJErhsRdNbx1oOflHxN6klJIjitF4tmFgONkGWEjdfDdhDcetdaPwGevSt
KNFcTWi9/rpnQ8YKuFOfXGpF0oLjzl3ilR4rIV6ds+fZ31pQk307v4uzCsiy
uB3hIm2YuHduOkWNAaPXTArKEpZC5HiDm0zMgAILhkaztw6k9byIIZd/C3kl
gWJfFhle1u6/MnDMAHgFhyTUMTI4h7Twam0MYW5btaqsjQIWYybjXlpGIB/d
EtOeToUDB2QnBBIjqHSxM+j2XQYrMy533akxhrq0aHrQWl1g1DUYxUYxId3b
bxdJqQv5PGnKFUMW2MsqhOndeiBr7fUNyWDBpTWldd27aLCzJLZVe4oFP98/
f2lXMw0WvJGaHs8Edht4V3chOqwjbc5lPDKBzeFiH3omHbIstUsVFqZQZshH
z5R04Hz3R67TL6aAHtYUuvvow+TvW9R3z5tC3tp2Tl+bPtix2W3+h8wgUKHR
28khoDVG13/siRnwb0yzMnMJOPZ92VnuWgShyZ4LrvkExBeciVNZI4j2FA1Q
LxKQLfcNb7ZFkKGMzskrJKAxCe3lrkdQz1V9KhIQMHNXaM7diED1YLH/Wi0B
SQ6iDqedCPL6qOc7xAQUszuXOAUgKKkKCz7bSUDtqV9nZgMRVJ2UbN3x9Kvn
UdbErWAETSvy5p9KCHjl597nGIpAxiOCpX8SYF4urXD8CQFbztg6IifgxqqX
4JiEwFYUZ3x1lID2oHvrZ5MRbEgbUgWMEfC8qdziVioCN7agcXziq8/Lj+aY
gSAqhGX84QMBzvlvXznkIkhwTlL9piDAfbhTOpOHIG3ZyPOTSgKO2NSKmy4g
uNRQlTU3R0Byd1iDQyGCyjMaQS3zBBQY/lA1U4Sg1iNgS8ICAdUhtkVNxQhE
po+NNn0hoKmFnnWqFEGbYrVqcZGATh1FooMAwX9odCf8
        "]]},
      Annotation[#, "Charting`Private`Tag$5615#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 4.9}, {0, 9.9}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.753584107433692*^9, {3.7857238921829734`*^9, 3.7857239086489477`*^9}, 
   3.8024416549355316`*^9, 3.810662209617777*^9},
 CellLabel->"Out[8]=",
 CellID->2072380931,ExpressionUUID->"b7448d36-a114-44c2-8cdd-9952f1d8d890"]
}, Open  ]],

Cell[TextData[{
 "If we draw an imaginary line straight up or down from a given ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath",ExpressionUUID->
  "afaab985-a3c0-4624-86dd-3fe9c6d4a90f"],
 " axis (independent variable) value on our model line, we get a predicted ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "28b681b7-18a4-402d-a020-ce85b8dc79dc"],
 " axis (dependent variable) value. Drawing two imaginary lines, one from the \
actual marker and one from the point on the line to the left (the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath",ExpressionUUID->
  "08d03432-4c1d-4c3b-a384-4754292e89c6"],
 " axis), produces two points on the axis. The difference between these is \
our residual or error, that is, the difference between the true and the \
predicted values, or the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CurlyEpsilon]", "i"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"6e5e8fb0-382d-40fa-8cab-f065a9d49cba"],
 " in equation (1)."
}], "Text",
 CellChangeTimes->{{3.753584128725508*^9, 3.753584417910466*^9}, {
  3.753584470890232*^9, 3.7535845035758705`*^9}, {3.7535849035195646`*^9, 
  3.7535849380485353`*^9}, {3.76622804276245*^9, 3.7662280480979834`*^9}, {
  3.7663161274918222`*^9, 3.766316127611822*^9}, {3.7663161748978224`*^9, 
  3.7663162557898226`*^9}},
 CellID->190667454,ExpressionUUID->"b01bb1f6-fae1-4e6a-9c0e-395ab6de3337"],

Cell[TextData[{
 "We can use the ",
 Cell[BoxData[
 "\"\<FitResiduals\>\""], "InlineCodeText",ExpressionUUID->
  "30dc23cf-2c5c-4732-9086-32e4ef7d9214"],
 " property to show the error for each predicted versus actual dependent \
variable data point value and then plot them."
}], "Text",
 CellChangeTimes->{
  3.753584432044099*^9, {3.7535845087640247`*^9, 3.753584515020152*^9}, {
   3.7663162669498224`*^9, 3.7663162889308224`*^9}, {3.7663163541268225`*^9, 
   3.766316355151822*^9}},
 CellID->169435173,ExpressionUUID->"bb76ea94-03d5-485e-ad22-f2a15cfe723c"],

Cell["\<\
List the residuals, the actual value minus the predicted value:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, {3.753584530635892*^9, 
   3.7535845472836375`*^9}, {3.7663163584708223`*^9, 3.7663163626148224`*^9}},
 CellID->25522701,ExpressionUUID->"ce50d8b1-ed8a-4c29-8775-9f27020ce98d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"linearModel", "[", "\"\<FitResiduals\>\"", "]"}]], "Input",
 CellLabel->"In[9]:=",
 CellID->10643873,ExpressionUUID->"a9972a45-e084-427b-b461-c148c11809bb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.6506124027676274`", ",", "0.4548455026000231`", ",", 
   RowBox[{"-", "0.34092139756758133`"}], ",", 
   RowBox[{"-", "0.038381537668144006`"}], ",", 
   RowBox[{"-", "1.5316085779363107`"}], ",", 
   RowBox[{"-", "0.42822209807039346`"}], ",", 
   RowBox[{"-", "0.024835618204477328`"}], ",", "1.0819373415273557`", ",", 
   "0.3844772014267921`", ",", 
   RowBox[{"-", "0.20790321887489505`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.753584570895235*^9, 3.802441655380532*^9, 
  3.810662209636161*^9},
 CellLabel->"Out[9]=",
 CellID->469036624,ExpressionUUID->"be31c5fd-7116-4640-a487-47be3d212aa4"]
}, Open  ]],

Cell["\<\
The plot of the residuals shows their magnitude and whether they were lower \
or higher than the actual values. \
\>", "Text",
 CellChangeTimes->{3.7535845810324483`*^9, 3.7663163671978226`*^9},
 CellID->182775425,ExpressionUUID->"84e5fa26-a8fa-4d54-83a4-a619bbb474c9"],

Cell["Plot the residuals:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753584589830434*^9, {
   3.7663163774368224`*^9, 3.7663163803648224`*^9}},
 CellID->327813223,ExpressionUUID->"eefa2b3d-8efe-4c04-b526-c180fb690b56"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"linearModel", "[", "\"\<FitResiduals\>\"", "]"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellLabel->"In[10]:=",
 CellID->82682811,ExpressionUUID->"eb4a3fea-62d2-4448-ab32-4559e7aaecf8"],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7G08OaQuXnxiDxVw4Jg2099A5i6Uz+Fw4Yzz
7+UXr+6H8AUcGCRkNu1bthjKF3FgUOf4X974A8qXcBA4tGLF3/TbUL6MA0PA
bfmmvJlQvoKDxLNF7XP9P0LNV3JQeNTt7Db7BpSv4nCg4dmsSXNO7Ye5jwEV
OKByOdD4Amh8ETS+BBpfBo2vgMZXQuOroPEHb/gBAEQRYmU=
    "], {{{}, {}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], LineBox[{13, 3}],
        LineBox[{14, 4}], LineBox[{15, 5}], LineBox[{16, 6}], 
       LineBox[{17, 7}], LineBox[{20, 10}]}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], LineBox[{11, 1}],
        LineBox[{12, 2}], LineBox[{18, 8}], LineBox[{19, 9}]}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{21, 22, 23, 24, 25, 26, 27, 28, 29, 30}]}}], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 10.}, {-1.5316085779363107`, 1.0819373415273557`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.753584598025555*^9, 3.802441656057532*^9, 
  3.810662209699226*^9},
 CellLabel->"Out[10]=",
 CellID->1179214309,ExpressionUUID->"d03801de-feb3-4e15-98a0-2f50537aca87"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculating How Well the Model Fits the Data", "Subsection",
 CellChangeTimes->{{3.75358461951995*^9, 3.753584631804031*^9}, {
  3.7535846626002097`*^9, 3.7535846631470685`*^9}, {3.766230726475255*^9, 
  3.766230735275255*^9}},
 CellID->378113321,ExpressionUUID->"66a94133-0792-4923-8ec0-d70101b475db"],

Cell[TextData[{
 "Now that we have a model, we need to know how good it is. We cheated a bit \
with our model above. The data point values for the variables were chosen to \
show a very good correlation. Things can look a lot worse. Next is an example \
of some random values. In keeping with the explanation, we will call the ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object ",
 Cell[BoxData[
 "badData"], "InlineCodeText",ExpressionUUID->
  "7cb9a43e-14db-4ac5-951a-e1049e815940"],
 ". Even such data can have a model fitted to it though."
}], "Text",
 CellChangeTimes->{
  3.7535846715700626`*^9, {3.7662280515153255`*^9, 3.766228063555529*^9}, 
   3.7662282313143034`*^9, {3.7663164002288227`*^9, 3.7663164587128224`*^9}, {
   3.777663462015424*^9, 3.7776634657689857`*^9}, {3.816087879990245*^9, 
   3.816087880101726*^9}},
 CellID->403958779,ExpressionUUID->"55255aaf-39c9-4666-991e-fc450803c2b8"],

Cell["\<\
Create 20 pairs of integer values in the domain 1 through 10:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753584702568737*^9, {
   3.7663164671288223`*^9, 3.7663164758718224`*^9}},
 CellID->225021055,ExpressionUUID->"41062a33-52a6-4f4c-8864-dcb04bd7d200"],

Cell[BoxData[
 RowBox[{
  RowBox[{"badData", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "8"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7535847127939663`*^9, 3.7535847191542654`*^9}},
 CellLabel->"In[11]:=",
 CellID->35706567,ExpressionUUID->"74174c10-bfc9-4e9c-9f08-268d305d4d92"],

Cell["A scatter plot for this looks a bit chaotic.", "Text",
 CellChangeTimes->{{3.753584748557644*^9, 3.753584762681856*^9}},
 CellID->439796814,ExpressionUUID->"e60a5449-c8bf-4d59-8203-efc4a6053d72"],

Cell["Create a plot of the data point pairs:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753584771046358*^9, {
   3.7663164812878227`*^9, 3.7663164843118224`*^9}},
 CellID->140308752,ExpressionUUID->"6eb60c20-ab06-4a3d-a819-fccbb9a24eaf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"badData", ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Red"}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.753584772874665*^9, 3.7535847775703554`*^9}, {
  3.7857240667432785`*^9, 3.7857240919114494`*^9}},
 CellLabel->"In[12]:=",
 CellID->22597667,ExpressionUUID->"b453c6b6-a516-453e-a402-6f16dd181da0"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[1, 0, 0], PointSize[Medium], AbsoluteThickness[1.6], 
    PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQUOqDQHlFbCIa4CpRWgtAiaehkc6kXQ5D/Yo+qD
qYeZC7MXpk8Ah350vgqaOpg5MHtU0MRxmYeuH0Yj/A8A8eESZg==
     "]]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1.8333333333333337`, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{1.8333333333333337`, 10.}, {0, 9.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.785724092167766*^9, 3.802441656882532*^9, 
  3.810662209774294*^9},
 CellLabel->"Out[12]=",
 CellID->2075796847,ExpressionUUID->"58637a53-9171-44d7-93f4-ab3fad5d61bb"]
}, Open  ]],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s create a linear model and call it ",
 Cell[BoxData[
 "badLinearModel"], "InlineCodeText",ExpressionUUID->
  "e5956a05-c965-4a51-8fdf-37fccab5da61"],
 ", which we will plot."
}], "Text",
 CellChangeTimes->{
  3.7535847891204233`*^9, {3.7663164936318226`*^9, 3.7663165067258224`*^9}},
 CellID->249203623,ExpressionUUID->"87274e67-1098-4c26-9a39-b0bd4188467e"],

Cell["Create a linear model:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.7535848071890583`*^9, {
   3.7663165106938224`*^9, 3.7663165143258224`*^9}},
 CellID->8054230,ExpressionUUID->"301c6a43-5c4e-4619-8c8d-8cb7f068ae95"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"badLinearModel", "=", 
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"badData", ",", "x", ",", "x"}], "]"}]}]], "Input",
 CellLabel->"In[13]:=",
 CellID->626729576,ExpressionUUID->"4b39beca-6082-4850-b04f-31497ff7bdd9"],

Cell[BoxData[
 TagBox[
  RowBox[{"FittedModel", "[", 
   TagBox[
    PanelBox[
     TagBox[
      RowBox[{"4.369230769230768`", "\[VeryThinSpace]", "-", 
       RowBox[{"0.002958579881656618`", " ", "x"}]}],
      Short[#, 2]& ],
     FrameMargins->5],
    Editable -> False], "]"}],
  InterpretTemplate[
  FittedModel[{
    "Linear", {
     4.369230769230768, -0.002958579881656618}, {{$CellContext`x}, {
      1, $CellContext`x}}, {0, 0}}, {{1., 1., 1., 1., 1., 1., 1., 1., 1., 1., 
    1., 1., 1., 1., 1., 1., 1., 1., 1., 1.}}, {{2, 2}, {3, 9}, {2, 3}, {10, 
    8}, {5, 9}, {7, 3}, {10, 5}, {7, 1}, {9, 3}, {8, 2}, {5, 4}, {7, 1}, {7, 
    1}, {10, 7}, {2, 9}, {10, 2}, {7, 1}, {7, 7}, {2, 2}, {10, 
    8}}, CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEf7KEMB1Q+hwN+eRU0vggaX4aAenR5JTS+Aonm
E7KPkPsJmYepHwA+IyA8
    "], 
    Function[Null, 
     Internal`LocalizedBlock[{$CellContext`x}, #], {HoldAll}]]& ],
  Editable->False,
  SelectWithContents->True,
  Selectable->True]], "Output",
 CellChangeTimes->{3.753584816483138*^9, 3.802441657250532*^9, 
  3.810662209793345*^9},
 CellLabel->"Out[13]=",
 CellID->2045762014,ExpressionUUID->"c262c3b0-2cd6-4b04-a62c-bd8dcff78b69"]
}, Open  ]],

Cell["Plot the model:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753584826008539*^9, {
   3.7663165212458224`*^9, 3.7663165251168222`*^9}},
 CellID->115183275,ExpressionUUID->"ccd86ec4-4e74-4963-8858-da3b927a63a1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", "badData", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"badLinearModel", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[14]:=",
 CellID->434121749,ExpressionUUID->"4e2369e9-22af-4e59-a5e4-88ba3b4b8588"],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQUOqDQHlFbCIa4CpRWgtAiaehkc6kXQ5D/Yo+qD
qYeZC7MXpk8Ah350vgqaOpg5MHtU0MRxmYeuH0Yj/A8A8eESZg==
      "]]}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV03s01GkYB3BC7WGyXrmGmd94y0R0Oa3u+T2yZ1Mup0JtrNuIoXEZmuli
qLaapFapHLnkOGrZdTpRLSGbinI3kdjWqOSyDmU3O0ZI2Wf/eM5zPv99n+c8
D18Ytzt8npaWlhfW/z3vmHD+6v3nXXiVcQXmiQSedDKee5kodkR2HEzRc/U1
pxjmKHt3zcU3xui8R2k8PSaV/a60xMYQHb1FFvORl83GFI1l66I7P0VmfOAV
s9UZ4svjRwksUPULxnhV7PfxolMt6ILm/Ph3vCb2kkNw+HF0SWmqKnpFD0tN
VgX0HCEgYjuy3ycMsAutewDQsUP2A2UlI+xl/RDH4sME9PmnBW/Wf2DXSRq2
66EvGLU4FISoWeeJBXujDxEQqnwf6rROsrv/sc+slxGIf3paGCeYYQ06BCqK
viPh+Fhs/8xadXz5+icp5pGLR1ft1QJP94pDwwcJnMyf3TXxXhtevHJv80Jr
dfbB74k68HHfPfuKBAJ20ogjvg56sMlLr3IRelBzdY/Bg/nQHeS0Vh5PYMfQ
geTL8V/BleG1f3VJCHgPpi/ncvVhZI/1tTXo0TrhicZbBpA12ON6LY7ACtJt
4xa8EEQjiZZTsTgfqwntVRtCGmeiLwi9bcz/o62fEXQVefdUxhB4Wbtf29+R
QIVA8acpuvzskyBGQ2C8PqMxOZpAhJ6sT6k0Bo9XipGXYgJhCfJyTs4i+Ex2
zrigV4qWKz1DTWCH06TRrwcIPDN2NJBtMIWKh8n7dNHVJSdzHXXMIEny+pI4
ioBc22Fn6yszEGYxs08jMV9vontsmTn0F7lEU/RQET8jP8kC7nc6t54XEchY
Zqlb5WcJvx02DBqOIJCeE9EQyiwGnY2P3nih/TMClZzhxfB3v5eoIpzA1LeF
0/k1VjAz7wFjgh4Y2nqkNsUaAl31muX7CVzfstqqLdQG3k6uKOwOI3BLISMi
Jy48aF4t2YxO8Qvz0NFwYY3CyLVQSMC5t6A4pY0Hzffa3bTRWfa5t9o8GKia
f2BtZCiB44/SsjyqGGhsG/SvDSHgZeVX2LyEDwnyTQoe2jW2IYCk8kG6TZyf
Ekwg31q4pFXDh8xzSe/6gwgsqfsl0zvAFozeRwi2o9Odah2e19jC0m+cou4G
4v7Vuh1NDhT81S96DdHCO/8yqRcpDLf7waEf8F9O+szuuERhnt1Q5kG0zKfs
D84VCly5dEyCPquRXUjPpOC79EqOGF2yYfrT1TwKj4+2T4Sgpx/PdRfdpJBr
61HsgU5/zkl70kDBWwrGfHTOjZjIM00UopqeRXLRN6RKN/cWCqe5wQ+t0PfM
0mdalBSq8VrM0L3+iyI7uygss6muN0ALBizd+gcoaNc7yycDCKwqS+T+PETB
xupphxq9UaGaDh+msF7iu2wc7SnIuz0ySiF28cGud+gEMcMdH6egir298i06
afOP03fVFCbr2DOv0YqF/S+kGgrE8lmvCp1VeuP81BQF97qx1G709RO6ovsz
FMIskvs60Td3hW9NmqVwLIazrgNdZltv4/KFQnZtbpoSXaO2m56bo1Buvnyw
Bf0fDnYMrw==
        "]]},
      Annotation[#, "Charting`Private`Tag$6029#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1.8333333333333337`, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{1.8333333333333337`, 10.}, {0, 9.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7535848342083654`*^9, 3.8024416585065317`*^9, 
  3.810662209894313*^9},
 CellLabel->"Out[14]=",
 CellID->1291787548,ExpressionUUID->"caf7880e-dcf2-47c3-9a78-1665d708c1b7"]
}, Open  ]],

Cell["The residual plot shows large errors.", "Text",
 CellChangeTimes->{{3.7535848475093317`*^9, 3.753584867220614*^9}, 
   3.7663165868018227`*^9, {3.80061402725101*^9, 3.80061402766922*^9}},
 CellID->92389390,ExpressionUUID->"8375ef3e-fdad-4e13-9881-8560acd8fcf5"],

Cell["Plot the residuals:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753584878677626*^9, {
   3.7663165894648223`*^9, 3.766316593064822*^9}},
 CellID->627371110,ExpressionUUID->"b92421e1-cddc-43d9-9cf5-c253deff3849"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"badLinearModel", "[", "\"\<FitResiduals\>\"", "]"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.753584888618145*^9, 3.7535848886337686`*^9}},
 CellLabel->"In[15]:=",
 CellID->331605132,ExpressionUUID->"1927e8aa-26c2-4a68-aad8-aad79eba4044"],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGCwAWIQDQEf7B9dNfsu8ILpAFTAIf11sPj/PiEHCJfD4cjq
3HeKF77uh/AFHGb07zPP8OCFyos4iM0wsuWbClMv4fDiza7irskw9TIOCXa/
7i1QfGoP4Ss4lJTdtTx6kgtqn5KDjpXDHd9qmHoVh2Mn/wlvOwxzj5rDgrpr
OjLrr0HlNdD0a6HxdaDuY4W6R8+Bf2pKy/dumPsMHDIKHE9M3w4z3xBNv5FD
T6fSMSszmH5jB9TwMUHz/wd7BlTggMrlQOMLoPFF0PgSaHwZNL4CGl8Jja+C
xldD42ug8bXQ+DpofD00vgEa3xCNb4TGN0bjm6DxR9MfuekPAGpXvHU=
    "], {{{}, {}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], LineBox[{21, 1}],
        LineBox[{23, 3}], LineBox[{26, 6}], LineBox[{28, 8}], 
       LineBox[{29, 9}], LineBox[{30, 10}], LineBox[{31, 11}], 
       LineBox[{32, 12}], LineBox[{33, 13}], LineBox[{36, 16}], 
       LineBox[{37, 17}], LineBox[{39, 19}]}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], LineBox[{22, 2}],
        LineBox[{24, 4}], LineBox[{25, 5}], LineBox[{27, 7}], 
       LineBox[{34, 14}], LineBox[{35, 15}], LineBox[{38, 18}], 
       LineBox[{40, 20}]}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 
       56, 57, 58, 59, 60}]}}], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 20.}, {-3.348520710059171, 4.645562130177515}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7535848893528337`*^9, 3.802441659313532*^9, 
  3.810662210037925*^9},
 CellLabel->"Out[15]=",
 CellID->13648066,ExpressionUUID->"6423244b-f7f5-4ee3-95c5-25b682a00608"]
}, Open  ]],

Cell[TextData[{
 "One way to assess how good our model is at predicting the dependent \
variable is by calculating the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "1ad76639-34e6-4439-a77d-ab9ba3983088"],
 " value, called the ",
 StyleBox["coefficient of determination",
  FontSlant->"Italic"],
 ". This is a property in the model object itself. Look below at the \
difference between the ",
 Cell[BoxData[
 "badLinearModel"], "InlineCodeText",ExpressionUUID->
  "4c0221d9-3e3a-43f1-bdf4-1d13083cce2d"],
 " and the ",
 Cell[BoxData[
 "linearModel"], "InlineCodeText",ExpressionUUID->
  "5ca77e5f-e43b-483b-abd3-3f6d13d6237e"],
 " examples."
}], "Text",
 CellChangeTimes->{
  3.7535849539297047`*^9, {3.7662280668598595`*^9, 3.7662280703872128`*^9}, {
   3.777664062345842*^9, 3.777664075525331*^9}, 3.816087950741555*^9},
 CellID->253370098,ExpressionUUID->"72699dc3-c372-406c-89d3-431b3851d7d3"],

Cell[TextData[{
 Cell[BoxData[
  SuperscriptBox[
   StyleBox["R",
    FontSlant->"Italic"], "2"]], "InlineMath",ExpressionUUID->
  "e888ff13-539e-4bcf-87a6-8ece78f7a206"],
 " for the bad model:"
}], "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753584885321148*^9, 
   3.75358497242216*^9, {3.7663195748646984`*^9, 3.766319616095821*^9}, 
   3.777664093439657*^9, {3.816087973962254*^9, 3.816087973967682*^9}},
 CellID->381760457,ExpressionUUID->"2746bf3e-e532-4865-882e-56f0d5ac9fa5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"badLinearModel", "[", "\"\<RSquared\>\"", "]"}]], "Input",
 CellLabel->"In[16]:=",
 CellID->55688303,ExpressionUUID->"504e80d1-691a-4d9f-93fb-92f7a9542061"],

Cell[BoxData["8.285017870565028`*^-6"], "Output",
 CellChangeTimes->{3.753584979521045*^9, 3.8024416596475315`*^9, 
  3.810662210056041*^9},
 CellLabel->"Out[16]=",
 CellID->1749778680,ExpressionUUID->"b4977b61-40f7-48fd-aaa4-e2b86fb64e39"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  SuperscriptBox[
   StyleBox["R",
    FontSlant->"Italic"], "2"]], "InlineMath",ExpressionUUID->
  "42369837-76a1-4076-ba81-0c3a5ba52b65"],
 " for the good model:"
}], "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.7535849956989393`*^9, {
   3.766319618154027*^9, 3.7663196387930903`*^9}, 3.816087991918352*^9},
 CellID->162297051,ExpressionUUID->"570b10d6-080a-4401-a94f-cf259d85e342"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"linearModel", "[", "\"\<RSquared\>\"", "]"}]], "Input",
 CellLabel->"In[17]:=",
 CellID->115188634,ExpressionUUID->"7b34fb5a-7f79-46e1-a32c-01c82f44c9ed"],

Cell[BoxData["0.952136799526808`"], "Output",
 CellChangeTimes->{3.753585004637293*^9, 3.802441660136532*^9, 
  3.810662210082654*^9},
 CellLabel->"Out[17]=",
 CellID->58067908,ExpressionUUID->"fe68bba4-1bcb-46ca-9e31-f6dd3eb0b828"]
}, Open  ]],

Cell[TextData[{
 "An ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "615b0ac2-53f7-446a-ab19-b58357582bb2"],
 " value closer to ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "cca5cc69-622c-468b-9fd1-68103cc68da5"],
 " relates to a much better predictive model while a value closer to 0 is, in \
essence, just random."
}], "Text",
 CellChangeTimes->{
  3.7535850165024347`*^9, 3.7663197242226324`*^9, {3.8007252797103252`*^9, 
   3.8007252844135795`*^9}},
 CellID->299061696,ExpressionUUID->"c9c38012-cf41-4c15-86bd-135628e5ecc4"],

Cell[TextData[{
 "How is this ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "6eb1c936-5ff8-4aec-a991-e64a316c7149"],
 " value calculated? It is basically a comparison of our model with a model \
based on the mean of the dependent variable. Let\[CloseCurlyQuote]s look at \
our first model\[CloseCurlyQuote]s data point value pairs for its two \
variables. Remember that the first value in the pair was the independent \
variable and the second was the dependent variable. Represented as a Wolfram \
Language nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object, these 10 pairs represent the data point values for two variables \
for 10 subjects in an experiment, as we discussed previously."
}], "Text",
 CellChangeTimes->{{3.7535850275094023`*^9, 3.7535850526630726`*^9}, {
  3.7662280731494884`*^9, 3.766228082707444*^9}, {3.7663199409535847`*^9, 
  3.766319951009585*^9}, {3.800725270572028*^9, 3.800725277286739*^9}, {
  3.8007254243172235`*^9, 3.8007254270148106`*^9}},
 CellID->196980976,ExpressionUUID->"7a53626f-64fb-4f49-b7cd-a63a96791b4f"],

Cell[TextData[{
 "Our first job is to isolate the dependent variable as a list using index \
addressing. We\[CloseCurlyQuote]ll call the computer variable ",
 Cell[BoxData[
 "dataOutcome"], "InlineCodeText",ExpressionUUID->
  "2297157e-4441-4c0f-ac2a-267f06bd7969"],
 "."
}], "Text",
 CellChangeTimes->{
  3.753585069403865*^9, 3.7662280877479486`*^9, {3.7663199580805845`*^9, 
   3.7663199740545845`*^9}},
 CellID->355444164,ExpressionUUID->"e54d11ee-1187-4611-9702-dd02949d12a1"],

Cell["Index all of the second elements:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.7535850842858295`*^9, {
   3.766319977134585*^9, 3.766319983086585*^9}},
 CellID->24244953,ExpressionUUID->"c74198a7-741d-476c-aef4-155c52615455"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dataOutcome", "=", 
  RowBox[{"data", "\[LeftDoubleBracket]", 
   RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}]}]], "Input",
 CellLabel->"In[18]:=",
 CellID->33078522,ExpressionUUID->"bf25b2f6-f086-4f5a-8b0e-f3ca4388f503"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1.8`", ",", "2", ",", "2.9`", ",", "3", ",", "4.9`", ",", "6.1`",
    ",", "8.8`", ",", "8.7`", ",", "9.9`"}], "}"}]], "Output",
 CellChangeTimes->{3.753585091427498*^9, 3.802441660516532*^9, 
  3.810662210100552*^9},
 CellLabel->"Out[18]=",
 CellID->989754018,ExpressionUUID->"c4867f57-7f1d-4847-a528-f4f4b939c5a9"]
}, Open  ]],

Cell[TextData[{
 "Now we calculate the mean of this new ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object and attach it to the computer variable ",
 Cell[BoxData[
 "meanOutcome"], "InlineCodeText",ExpressionUUID->
  "08914562-8f52-4e6b-a909-92abc721a8f7"],
 "."
}], "Text",
 CellChangeTimes->{{3.753585103522602*^9, 3.753585113114053*^9}, {
  3.766319991003585*^9, 3.766320006589585*^9}},
 CellID->20519494,ExpressionUUID->"4390106e-de37-4d1a-b3af-4e186d41676a"],

Cell["Find the mean of the dependent variable:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.7535851231466417`*^9, {
   3.766320017148585*^9, 3.766320022916585*^9}},
 CellID->316931834,ExpressionUUID->"5806de94-75b3-4ae2-8bf1-38b799e1dd29"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"meanOutcome", "=", 
  RowBox[{"Mean", "[", "dataOutcome", "]"}]}]], "Input",
 CellLabel->"In[19]:=",
 CellID->117702483,ExpressionUUID->"df151fee-476a-4ba1-a0da-f6a89195aa16"],

Cell[BoxData["4.910000000000001`"], "Output",
 CellChangeTimes->{3.753585130277391*^9, 3.8024416609075317`*^9, 
  3.810662210128755*^9},
 CellLabel->"Out[19]=",
 CellID->1991713774,ExpressionUUID->"d61d9d75-1b78-4742-9984-579a44a8122e"]
}, Open  ]],

Cell[TextData[{
 "Now we have to calculate the ",
 StyleBox["total sum of squares",
  FontSlant->"Italic"],
 ", which is similar to calculating residuals, but instead of using the \
predicted values, we subtract the mean from every observed value and square \
each of these differences. Finally, we sum all of the squared terms. We use \
the ",
 ButtonBox["Table",
  BaseStyle->"Link"],
 " function and run through each of the elements in ",
 Cell[BoxData[
 "dataOutcome"], "InlineCodeText",ExpressionUUID->
  "3f73bd89-b64d-4399-b4b6-b3195879f856"],
 ". We subtract the mean from each value and square the difference. Notice \
the use of the ",
 ButtonBox["Length ",
  BaseStyle->"Link"],
 "function to ensure that we iterate through all the elements. All of these \
are wrapped as arguments in the ",
 ButtonBox["Total ",
  BaseStyle->"Link"],
 Cell[BoxData[
 " "], "InlineCodeText",ExpressionUUID->
  "24ba999c-ee4e-4514-8fb9-e25bb8498656"],
 "function, which sums the elements in the ",
 Cell[BoxData[
  ButtonBox["List",
   BaseStyle->"CodeLink"]], "InlineCodeText",ExpressionUUID->
  "e4da1d0c-8425-4b75-8ac1-bfaf9282ac7b"],
 " object. We\[CloseCurlyQuote]ll call the List object ",
 Cell[BoxData[
 "totalSumOfSquares"], "InlineCodeText",ExpressionUUID->
  "0bb2048f-9de9-43fe-bf6b-6409a0bee4c9"],
 "."
}], "Text",
 CellChangeTimes->{{3.7535851487190094`*^9, 3.75358524360279*^9}, {
  3.766228091678341*^9, 3.766228104925666*^9}, {3.766322515805979*^9, 
  3.7663225573991375`*^9}, {3.7663226012285204`*^9, 3.766322626780075*^9}, {
  3.766322847703165*^9, 3.7663228755929537`*^9}, {3.7663229386172557`*^9, 
  3.766322963548749*^9}},
 CellID->94158951,ExpressionUUID->"4ca72f50-164d-4e8b-9696-b3a79150790f"],

Cell["Calculate the total sum of squares:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.7535852267788353`*^9, {
   3.7663229659279866`*^9, 3.7663229690082946`*^9}},
 CellID->27511919,ExpressionUUID->"3c795bc0-4d0a-45ac-8c23-f13380409e5e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"totalSumOfSquares", "=", 
  RowBox[{"Total", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "dataOutcome", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
         "-", "meanOutcome"}], ")"}], "2"], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", 
       RowBox[{"Length", "[", "dataOutcome", "]"}]}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellLabel->"In[20]:=",
 CellID->95936322,ExpressionUUID->"2bddb696-8016-42e6-aae2-550debcc3199"],

Cell[BoxData["96.929`"], "Output",
 CellChangeTimes->{3.753585255983217*^9, 3.802441661281532*^9, 
  3.8106622101459503`*^9},
 CellLabel->"Out[20]=",
 CellID->1905793829,ExpressionUUID->"c47d8045-cd0f-4ce0-b7b2-281993f9c933"]
}, Open  ]],

Cell[TextData[{
 "While using the ",
 ButtonBox["Table",
  BaseStyle->"Link"],
 " function as an iterator works well for a relatively small number of data \
point values, it is much more efficient to use ",
 StyleBox["vectorized",
  FontSlant->"Italic"],
 " functions, especially with large datasets. Next we simply subtract the two \
",
 ButtonBox["List",
  BaseStyle->"Link"],
 " objects from each other. This will be done elementwise. The results of \
these elementwise subtractions will be squared. "
}], "Text",
 CellChangeTimes->{{3.7857243001586266`*^9, 3.7857245070995674`*^9}, {
   3.8006142524184*^9, 3.800614286971278*^9}, 3.8006143362309275`*^9, {
   3.8006143819615974`*^9, 3.800614412396494*^9}, 3.810662837498898*^9},
 CellID->159338362,ExpressionUUID->"d2f58b40-cd42-4cbd-aa8f-07c095c679a1"],

Cell[TextData[{
 "The ",
 ButtonBox["Total",
  BaseStyle->"Link"],
 " function will finally add all of these squared elements:"
}], "CodeCaption",
 CellChangeTimes->{{3.7857243001586266`*^9, 3.7857245070995674`*^9}, {
   3.8006142524184*^9, 3.800614286971278*^9}, 3.8006143362309275`*^9, {
   3.8006143819615974`*^9, 3.800614412396494*^9}, {3.810662843211811*^9, 
   3.810662843755406*^9}},
 CellID->1134388968,ExpressionUUID->"11f66712-18b8-4125-a1a6-9576800d673c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"totalSumOfSquares", "=", 
  RowBox[{"Total", "[", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"dataOutcome", "-", "meanOutcome"}], ")"}], "2"], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.7857242038446693`*^9, 3.785724251646286*^9}},
 CellLabel->"In[21]:=",
 CellID->166742431,ExpressionUUID->"36244a35-5bd3-4d35-9258-55b47579500c"],

Cell[BoxData["96.929`"], "Output",
 CellChangeTimes->{3.7857242530401387`*^9, 3.8024416616445317`*^9, 
  3.810662210172641*^9},
 CellLabel->"Out[21]=",
 CellID->192727105,ExpressionUUID->"413bc5ed-534b-4bfa-9da3-baf1c9dbe8e8"]
}, Open  ]],

Cell[TextData[{
 "Remember the ",
 Cell[BoxData[
 "\"\<FitResidual\>\""], "InlineCodeText",ExpressionUUID->
  "4fa57e06-00a2-44b4-b7c3-676ec82331e6"],
 " property of our model? It was an easy way to get a ",
 Cell[BoxData[
  ButtonBox["List",
   BaseStyle->"CodeLink"]], "InlineCodeText",ExpressionUUID->
  "a00e739c-b812-4618-9c9e-d7391a2ab006"],
 " object of all the errors (difference between predicted and observed values \
of the dependent variable). We attach it to the computer variable ",
 Cell[BoxData[
 "residuals"], "InlineCodeText",ExpressionUUID->
  "c3f52d28-4abd-49d1-87b1-255372bb23ad"],
 ". Note that we could also construct Wolfram Language code to get this ",
 Cell[BoxData[
  ButtonBox["List",
   BaseStyle->"CodeLink"]], "InlineCodeText",ExpressionUUID->
  "aad96f67-27e3-449f-b00d-6690fdfc7153"],
 " object as with the ",
 Cell[BoxData[
 "totalSumOfSquares"], "InlineCodeText",ExpressionUUID->
  "8020f10e-3575-4bd8-bb61-4d67f1866150"],
 "."
}], "Text",
 CellChangeTimes->{{3.75358528324895*^9, 3.7535853109463973`*^9}, {
  3.766228111175291*^9, 3.766228117631936*^9}, {3.7663230100023937`*^9, 
  3.766323079653358*^9}},
 CellID->432340437,ExpressionUUID->"ae9cb619-2ffc-44d6-a1fc-e28185e0c935"],

Cell["Save the model residuals:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, {3.7535853567790914`*^9, 
   3.753585363014227*^9}, {3.7663230836367564`*^9, 3.7663230874371367`*^9}},
 CellID->822406541,ExpressionUUID->"76948662-6a4b-4a02-8273-251111c10159"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"residuals", "=", 
  RowBox[{"linearModel", "[", "\"\<FitResiduals\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.7095240763075*^9, 3.709524116316738*^9}, {
  3.7095241641091576`*^9, 3.709524166871616*^9}},
 CellLabel->"In[22]:=",
 CellID->321561374,ExpressionUUID->"773b13e1-c4d5-4203-bf92-15833f8b9ee8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.6506124027676274`", ",", "0.4548455026000231`", ",", 
   RowBox[{"-", "0.34092139756758133`"}], ",", 
   RowBox[{"-", "0.038381537668144006`"}], ",", 
   RowBox[{"-", "1.5316085779363107`"}], ",", 
   RowBox[{"-", "0.42822209807039346`"}], ",", 
   RowBox[{"-", "0.024835618204477328`"}], ",", "1.0819373415273557`", ",", 
   "0.3844772014267921`", ",", 
   RowBox[{"-", "0.20790321887489505`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.753585324594265*^9, 3.8024416620265317`*^9, 
  3.810662210189893*^9},
 CellLabel->"Out[22]=",
 CellID->759114059,ExpressionUUID->"9ab804ef-08ce-4f7e-91f6-5b8f448bc736"]
}, Open  ]],

Cell[TextData[{
 "Now we need to square each of these values and add all of them. We\
\[CloseCurlyQuote]ll call the result ",
 Cell[BoxData[
 "residualSumOfSquares"], "InlineCodeText",ExpressionUUID->
  "0703d25a-30ee-4e2e-a205-2d30cd7f118c"],
 ". In the next example, we use a vectorized function instead of iterating \
over all of the elements using the ",
 ButtonBox["Table",
  BaseStyle->"Link"],
 " function. "
}], "Text",
 CellChangeTimes->{
  3.75358534494457*^9, 3.7662281305822315`*^9, {3.7663232086752586`*^9, 
   3.7663232232347145`*^9}, {3.8006153724050226`*^9, 3.800615411135955*^9}},
 CellID->394175513,ExpressionUUID->"8725b740-d7ce-48ed-9150-aa4f03ed1550"],

Cell["Calculate the residual sum of squares for the model:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, {3.75358537795763*^9, 
   3.7535853911847553`*^9}, {3.766323226099001*^9, 3.7663232293233232`*^9}},
 CellID->920033576,ExpressionUUID->"ef4571c7-9fac-45f3-b781-5b1091841586"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"residualSumOfSquares", "=", 
  RowBox[{"Total", "[", 
   SuperscriptBox["residuals", "2"], "]"}]}]], "Input",
 CellChangeTimes->{{3.785724543646375*^9, 3.7857245676388397`*^9}},
 CellLabel->"In[23]:=",
 CellID->457957315,ExpressionUUID->"f08d48b6-de54-4225-bbb7-00e779fa2246"],

Cell[BoxData["4.639332158666035`"], "Output",
 CellChangeTimes->{3.7857245695657663`*^9, 3.8024416624405317`*^9, 
  3.810662210216447*^9},
 CellLabel->"Out[23]=",
 CellID->1479302636,ExpressionUUID->"15ec1dcd-8de4-4899-842e-9a6aa2e62e10"]
}, Open  ]],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "74f3eeca-dbd5-40cd-a10d-07c3ef4db5c2"],
 " value is the difference between the total sum of squares and the residual \
sum of squares divided by the total sum of squares. It is a ratio comparing \
our model to a very basic model that uses the mean of the dependent variable \
as the sole predictor value for all the subjects."
}], "Text",
 CellChangeTimes->{
  3.753585680687294*^9, {3.7535857462778463`*^9, 3.7535857843395586`*^9}, 
   3.7662281373739104`*^9, {3.766325852865373*^9, 3.7663258627123733`*^9}},
 CellID->733067274,ExpressionUUID->"b148a0c8-2743-4d8a-998c-17873a6759d8"],

Cell[TextData[{
 "Calculate the ",
 Cell[BoxData[
  SuperscriptBox[
   StyleBox["R",
    FontSlant->"Italic"], "2"]], "InlineMath",ExpressionUUID->
  "bbe9d2ae-a611-4dbe-b28a-aa5d6d500b4a"],
 " value:"
}], "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753585698383134*^9, {
   3.7663258689613733`*^9, 3.766325886786373*^9}, 3.816088075365559*^9},
 CellID->72707663,ExpressionUUID->"a3eaec10-2e7c-45da-8aaa-b643af8e3214"],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox[
  RowBox[{"totalSumOfSquares", "-", "residualSumOfSquares"}], 
  "totalSumOfSquares",
  FractionLine->0.2]], "Input",
 CellChangeTimes->{{3.753585712935498*^9, 3.753585717576315*^9}},
 CellLabel->"In[24]:=",
 CellID->231977743,ExpressionUUID->"f3dca617-c744-4a78-804e-1722e47371dc"],

Cell[BoxData["0.952136799526808`"], "Output",
 CellChangeTimes->{3.7535857181075*^9, 3.8024416627915316`*^9, 
  3.8106622102336397`*^9},
 CellLabel->"Out[24]=",
 CellID->1221221933,ExpressionUUID->"2a248d4f-dd80-40be-9850-2172094a8473"]
}, Open  ]],

Cell[TextData[{
 "What is the meaning of the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["R", "2"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "314e8e17-0da5-4cbf-9ca0-88c21b2ab310"],
 " value? Well, it represents the variance in the dependent variable \
explained by the model (difference between the total sum of squares and the \
residual sum of squares) relative to how much variance there was to begin \
with (the total sum of squares). "
}], "Text",
 CellChangeTimes->{3.7535857943945503`*^9, 3.76622814047022*^9},
 CellID->549739797,ExpressionUUID->"86b30a96-6595-47a5-9f24-79b6fdebf308"],

Cell["\<\
We can express it as a percentage and indeed view it as the percentage of the \
variation in the outcome that the model explains.\
\>", "Text",
 CellChangeTimes->{3.7535858180907516`*^9},
 CellID->27290344,ExpressionUUID->"454b927f-1186-447d-a7dd-97d2317b2582"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "ee236de1-5706-4da1-8bc5-df7fa2c0ded7"],
 "-value for the coefficient of determination can also be calculated. To do \
this, we first need Fisher\[CloseCurlyQuote]s ratio, usually denoted as the \
F-ratio. This ratio is shown in equation (6)."
}], "Text",
 CellChangeTimes->{{3.75358583989779*^9, 3.753585865191161*^9}, {
   3.7662281441115837`*^9, 3.7662281471598887`*^9}, {3.766326271354145*^9, 
   3.766326271514161*^9}, {3.766326908435847*^9, 3.7663269184698505`*^9}, 
   3.7663272771113663`*^9, {3.8006176172672405`*^9, 3.800617620064333*^9}},
 CellID->425786575,ExpressionUUID->"e263f658-bfcb-448e-aed5-733d38d52e4f"],

Cell[BoxData[
 FormBox[
  RowBox[{"F", "=", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"n", "-", "k", "-", "1"}], ")"}], 
     SuperscriptBox["R", "2"]}], 
    RowBox[{"k", "(", 
     RowBox[{"1", "-", 
      SuperscriptBox["R", "2"]}], ")"}],
    FractionLine->0.2]}], TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.777664363147476*^9, 3.777664370657859*^9}},
 CellID->1675270599,ExpressionUUID->"440ed62c-0b5e-4b8c-9069-429ad8e25d78"],

Cell[TextData[{
 "Here, ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]], "InlineMath",ExpressionUUID->
  "d83a7246-c5d5-4274-a51d-6d1654b5abcc"],
 " is the total number of subjects in the study and ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]], "InlineMath",ExpressionUUID->
  "79bb0bc8-a0b2-4285-9866-5076adfedcd1"],
 " is the number of independent (predictor) variables."
}], "Text",
 CellChangeTimes->{{3.7535858987658553`*^9, 3.7535859035946445`*^9}, 
   3.8160880938770027`*^9},
 CellID->287431049,ExpressionUUID->"fcacda89-c38d-4fc6-9645-ca96359dd2aa"],

Cell[TextData[{
 "Use the previously calculated ",
 Cell[BoxData[
  SuperscriptBox[
   StyleBox["R",
    FontSlant->"Italic"], "2"]], "InlineMath",ExpressionUUID->
  "ccb8261c-e209-41f4-afde-eac8f3671460"],
 " value:"
}], "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753585916334708*^9, {
   3.7663271593839393`*^9, 3.7663271966726675`*^9}, {3.7663277187273664`*^9, 
   3.7663277333413663`*^9}, 3.816088111149232*^9},
 CellID->9685744,ExpressionUUID->"6a8472f1-8291-4d91-b72f-dec9e7879ce0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "=", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"10", "-", "1", "-", "1"}], ")"}], "*", "0.952137"}], 
   RowBox[{"1", "*", 
    RowBox[{"(", 
     RowBox[{"1", "-", "0.952137"}], ")"}]}],
   FractionLine->0.2]}]], "Input",
 CellLabel->"In[25]:=",
 CellID->109753015,ExpressionUUID->"06b22f08-3045-4b08-b9f9-60a6f520866b"],

Cell[BoxData["159.14372270856407`"], "Output",
 CellChangeTimes->{3.7535859252936635`*^9, 3.8024416631665316`*^9, 
  3.810662210260766*^9},
 CellLabel->"Out[25]=",
 CellID->1456551714,ExpressionUUID->"f2a9bf9a-6f1d-4f37-b801-84c27eef2cce"]
}, Open  ]],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "d252835e-b785-45e1-8217-6c6a04742645"],
 "-value for the F-statistic can be calculated using the ",
 ButtonBox["CDF",
  BaseStyle->"Link"],
 " function. Here we use ",
 ButtonBox["FRatioDistribution",
  BaseStyle->"Link"],
 ". It takes two arguments, both indicating degrees of freedom. The first \
indicates the total number of independent variables (add 1 for the \
intercept), and the second is the total number of subjects minus the number \
of independent variables (add 1 for the intercept)."
}], "Text",
 CellChangeTimes->{{3.7535859371563034`*^9, 3.7535859670444317`*^9}, {
   3.766228152015374*^9, 3.7662281540235753`*^9}, 3.7662282342816*^9, {
   3.76632721179418*^9, 3.7663272119791985`*^9}, {3.7663273284973664`*^9, 
   3.7663273941943665`*^9}, {3.8006184982052393`*^9, 3.800618498437386*^9}},
 CellID->512077095,ExpressionUUID->"161934aa-c337-4f33-b771-a1897d872b98"],

Cell[TextData[{
 "We use ",
 Cell[BoxData[
  RowBox[{"1", "-", 
   ButtonBox["CDF",
    BaseStyle->"CodeLink"]}]], "InlineCodeText",ExpressionUUID->
  "8b463fb0-56df-4626-8d74-26cd087ac5ad"],
 " in calculating the ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "832689d3-b7d0-44aa-a329-f51570d97c05"],
 "-value and multiply by 2 for a two-tailed hypothesis. "
}], "Text",
 CellChangeTimes->{{3.7535859963556986`*^9, 3.7535860460508327`*^9}, {
   3.7662281591770906`*^9, 3.7662281620633793`*^9}, {3.766327401778366*^9, 
   3.7663274682303667`*^9}, {3.7663275199233665`*^9, 
   3.7663275549373665`*^9}, {3.7663276191713667`*^9, 
   3.7663276191713667`*^9}, {3.8006170569885464`*^9, 3.8006171031153517`*^9}, 
   3.8106642408298597`*^9},
 CellID->227682970,ExpressionUUID->"6dd96978-1159-4bc7-af04-997f444d32d0"],

Cell[TextData[{
 "Calculate the ",
 Cell[BoxData[
  StyleBox["p",
   FontSlant->"Italic"]], "InlineMath",ExpressionUUID->
  "c5ae2d6f-186a-4a01-8364-43192eaac31d"],
 "-value:"
}], "CodeCaption",
 CellChangeTimes->{{3.7663276404533663`*^9, 3.7663276530483665`*^9}, {
  3.766327705752366*^9, 3.7663277116953664`*^9}, {3.816088140583911*^9, 
  3.81608814058591*^9}},
 CellID->19220559,ExpressionUUID->"1202bfa9-b4fe-4c7f-a3c9-c5bf7734b288"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"1", "-", 
    RowBox[{"CDF", "[", 
     RowBox[{
      RowBox[{"FRatioDistribution", "[", 
       RowBox[{"2", ",", "8"}], "]"}], ",", "F"}], "]"}]}], ")"}], "*", 
  "2"}]], "Input",
 CellChangeTimes->{{3.7095258815486317`*^9, 3.7095259158000154`*^9}, {
   3.709543834096643*^9, 3.70954385984744*^9}, {3.7095453983281794`*^9, 
   3.7095454007018857`*^9}, {3.7095459991070642`*^9, 3.709546002145909*^9}, {
   3.7166141043581657`*^9, 3.7166141111985226`*^9}, 3.785729518811839*^9, {
   3.7857295575272045`*^9, 3.785729558977753*^9}},
 CellLabel->"In[26]:=",
 CellID->30188552,ExpressionUUID->"1b7bc9c9-df80-433d-bd6a-c057b5bc58dc"],

Cell[BoxData["7.227506462204047`*^-7"], "Output",
 CellChangeTimes->{3.8024416193835316`*^9, 3.802441663551532*^9, 
  3.8106622102777767`*^9},
 CellLabel->"Out[26]=",
 CellID->1098565045,ExpressionUUID->"03c0378b-19a8-4ed6-80c1-82dae3d18ad8"]
}, Open  ]],

Cell[TextData[{
 "We have found a significant ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "c2b1648f-95cc-4980-8f57-6586d95516f9"],
 "-value, as expected."
}], "Text",
 CellChangeTimes->{
  3.7535860676701083`*^9, {3.7663275652963667`*^9, 3.7663275681763663`*^9}},
 CellID->1007354765,ExpressionUUID->"d7e3e4de-41da-4dce-af82-5aa8f71bea47"],

Cell[TextData[{
 "In the next plot, we note just how ",
 StyleBox["extreme",
  FontSlant->"Italic"],
 " this particular F-statistic is. Remember that the ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "556b492d-0303-4c11-bddf-c6cb743f4d3c"],
 "-value is represented by the area under the curve to the right of the \
F-statistic (marked by the vertical line)."
}], "Text",
 CellChangeTimes->{{3.7857300090681577`*^9, 3.785730081059428*^9}, {
   3.8006171777717776`*^9, 3.800617233231661*^9}, {3.80061757130884*^9, 
   3.8006175922891417`*^9}, {3.8006184870649824`*^9, 3.8006184943071313`*^9}, 
   3.816088187309263*^9},
 CellID->116876853,ExpressionUUID->"ad8a7f4b-c572-4bfb-b644-a11a85799da3"],

Cell[TextData[{
 "Use ",
 ButtonBox["PlotStyle",
  BaseStyle->"Link"],
 " to note the F-statistic:"
}], "CodeCaption",
 CellChangeTimes->{{3.802441131905532*^9, 3.8024411328355317`*^9}, {
  3.8024443492823863`*^9, 3.802444367491207*^9}, {3.816088209741252*^9, 
  3.816088211252358*^9}},
 CellID->509844772,ExpressionUUID->"936373c1-9588-4b1c-ac43-c9f41b3c1b32"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"PDF", "[", 
      RowBox[{
       RowBox[{"FRatioDistribution", "[", 
        RowBox[{"2", ",", "8"}], "]"}], ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "165"}], "}"}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], ",", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"F", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"F", ",", "0.00007"}], "}"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Orange"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.785729439656989*^9, 3.785729458236087*^9}, {
  3.7857295412608423`*^9, 3.7857295866816473`*^9}, {3.7857299544162145`*^9, 
  3.785729996938068*^9}, {3.8024416839335318`*^9, 3.802441691583532*^9}, {
  3.802444316296088*^9, 3.802444323987857*^9}},
 CellLabel->"In[27]:=",
 CellID->9210788,ExpressionUUID->"97413c44-ac8e-41f0-a9eb-22a07cfc16c6"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJw1WHc4FY77tUeSUUZWUtGwUtm9971kr3uvPSK6pKEQhWTvlS1bskm2kkQf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     "], {{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
        GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1FW0VGUAhuE5dHf3obtDULokpQTplA4REFG6u6RTOiWkUbpDuhvpUlEU
AQGfDRfPev/5/jWz5mLPhLfoUqtzhFAoFEaxsPcNXkckN0UNUfiAM15H1iIs
cD5NJOfCdHOewzHeks/2sbZgDNv4jXT2XJqTHGQnG1nJQmYykZEMpCc8eB9p
SUNqKtKc0fzMk+DeZ6fSCjRjFD/xOHifu5RanqaMZCuPgs9zl0LL0YQRbOEh
qdwl17I0ZjibeUBKd8m0DI0Yxibuk8JdUi1NQ4aykXskd5dES9GAIWzgLsnc
JdaS1Gcw67lDUneJ9Etm8wtvyGsvoZ8xiHXcJok9oXZlFkd5TR57ca3HQH7k
FontCfQLZnKE/4LnwP6R1mUAa/mVRPb42oUZHOYVuewf6qf0Zw03SWiPp52Z
ziFeBs+CvZjWoR+ruUECe1ztxDQO8iJ4buxFtTZ9WcV14tvjaEemcoB/yR48
v1qLPvzANeLZY2sHprCf52QLnnGtSW9WcpW49ljansns4x+yBr8BrcG3rOAK
cewxtR2T2MvfZLEX0k/4huVcJrY9hrblO/bwjMz2glqdXizjErHs0bUNE9nN
X2SyF9BqfM1SLhLTHk1bM4Fd/ElGe36dzykiBt+Pqs49WcIFYtii6ueMZydP
yWDPp/M4SYTg+1LF+SsWc57owX+JtmIcO/iD9Pa8+j0nCAu+P5Wde7CIc0Sz
RdaWjGU7vxNuz6NzOR4KvfsTy08lx+4s5CxRbZFC7//n/gfiVYhb
          "]]]}, {}, {}}, {{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], LineBox[CompressedData["
1:eJwl1He4DWQcB/ArKyuUrFKufW9xr5EV2XtGKEkZSciKFBpk7122EqmUGSKj
jKKiIkU7o+yZQsnn9/TH53zf9/ue857fec55TmLHXi16pklISKjgoTLprDPK
b+Qb9KMBZeJJ7BHzSSHR/ozcxAQ6kZ4b9fvlIvrTkLK6NHxpvYBUCtmflZuZ
SGcykEn/rVzMMzSinO4GvrJ+jdIUtj8ntzCJx2N2Muu/k28ygMbco0vL19av
x+ehiP15+RGT6RKzk0V/QC7hWZrE/BTVX5AfM4UnYlay6g/Kt3iOpjEvxfQX
5Vam0jVmI5v+e/k2A2kW81Fc/6fcxjSejFm4Sf+DfIdBNKc8JfSX5Ham0y1m
Ibv+R7mUwdwf3y9J+r/kDmbQPWYhh/4n+S7P04KKJOv/lp/wCj1iFnLqf5bv
8QItqcRd+svyU17lqZiFm/W/yGW8yANU5m79FbmTmfSMWbhF/6tczku04l5K
6q/KXcyiV8xCLv1vcgVDaE0VSun/kZ8xm94xC7fqD8mVDKUNVUnR/ys/Zw59
YhZy6w/LVbzMg9xHqv6a/IK59I1ZyKM/IlczjIeoFu9LXmdH5fsMpy3V4z3I
5+x3uYYRPEyNuI/8zv6QaxlJO2rGfdzm7JhcxygeoVbcx+3OjssPGE17asd9
FHB2Qq5nDI9SJ+7jDmcn5QbG8hh14z7udHZKfsg4OlAv7ovXxTkFSaQQhSlC
UYpRnBIkkRy/m/gtxPcbr3P3abmR8XSkPqX1/8ndzONpysf/FXutFyb8/x+W
nn3WFWUGKlHK/jqTvIhQ
          "]]},
        Annotation[#, "Charting`Private`Tag$6367#1"]& ]}}], {}}, {{}, {{}, {}, 
     {RGBColor[1, 0.5, 0], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], AbsoluteThickness[1.6], 
      LineBox[{{159.14372270856407`, 0.}, {159.14372270856407`, 
       0.00007}}]}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotRange->{{0, 165}, {0., 0.00006734171344882499}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.802441950150488*^9, 3.802444325795038*^9, 
  3.8106622104517527`*^9},
 CellLabel->"Out[27]=",
 CellID->819655764,ExpressionUUID->"9ca5e915-2fdf-414e-b779-852564f806fe"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Assessing Bias", "Subsection",
 CellChangeTimes->{{3.7535861068118434`*^9, 3.753586109593628*^9}, {
  3.7662307429552555`*^9, 3.766230743203255*^9}},
 CellID->486921423,ExpressionUUID->"ea101c4e-b498-4a38-908d-3246e548d495"],

Cell["\<\
As part of inferential statistics, the goal of linear regression is to \
generalize to the wider population from which a research sample was taken and \
that constitutes the data we have to work with. We might have an excellent \
fit for our model, but if bias was introduced when selecting the sample, our \
hard work in generating a model means very little.\
\>", "Text",
 CellChangeTimes->{
  3.7535861191415143`*^9, 3.7662281658077536`*^9, {3.7663277530853662`*^9, 
   3.7663277541963663`*^9}},
 CellID->268387195,ExpressionUUID->"73e9ff46-f988-4613-b25d-ca8c9d97d6de"],

Cell[TextData[{
 "In a common form of bias, our model is influenced by a small number of data \
point values. These influential cases are called ",
 StyleBox["outliers",
  FontSlant->"Italic"],
 ". Below we create two experiments that differ only in a single dependent \
data point value."
}], "Text",
 CellChangeTimes->{
  3.753586150001941*^9, {3.766228169855158*^9, 3.766228171063279*^9}, {
   3.766228237146887*^9, 3.7662282404192142`*^9}, {3.7663280776343665`*^9, 
   3.7663280947133665`*^9}},
 CellID->144308778,ExpressionUUID->"7fdde9c5-5506-4c46-b2f8-3ad40a6e0126"],

Cell["Our good example data:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.7535861713374796`*^9, {
   3.766328098776366*^9, 3.7663281011363664`*^9}},
 CellID->723830614,ExpressionUUID->"72d12ae2-7189-46e8-8168-696ed2b754b6"],

Cell[CellGroupData[{

Cell[BoxData["data"], "Input",
 CellChangeTimes->{{3.7535861776038857`*^9, 3.7535861780256777`*^9}},
 CellLabel->"In[28]:=",
 CellID->318269249,ExpressionUUID->"cf105bfd-e805-4881-a1b0-cd560a571d99"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5`", ",", "1.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.3`", ",", "2.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.1`", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.5`", ",", "4.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.9`", ",", "6.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.7`", ",", "8.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "8.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.9`", ",", "9.9`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7535861786350327`*^9, 3.8024416652465315`*^9, 
  3.810662210471272*^9},
 CellLabel->"Out[28]=",
 CellID->1994313690,ExpressionUUID->"62e76f93-bef4-4433-b2bc-854329dcd4cb"]
}, Open  ]],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s only change the last dependent variable data point \
value from 9.9 to 1.2. We\[CloseCurlyQuote]ll call this ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object ",
 Cell[BoxData[
 "dataOutlier"], "InlineCodeText",ExpressionUUID->
  "c706dcdb-0761-4e98-bb8d-53f9a8a57475"],
 "."
}], "Text",
 CellChangeTimes->{
  3.75358619001166*^9, {3.766228174304603*^9, 3.766228175064679*^9}, {
   3.7663281107203665`*^9, 3.7663281136243663`*^9}, {3.7663281448673663`*^9, 
   3.766328157566366*^9}},
 CellID->46323786,ExpressionUUID->"22dbd6eb-eafc-4d0d-a878-38e19b7b2cdf"],

Cell["Create a single outlier:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.7535862132783937`*^9, {
   3.7663281606853666`*^9, 3.7663281646293664`*^9}},
 CellID->445033500,ExpressionUUID->"1c1a353d-03f6-4bb8-953c-7a65cbe76e98"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dataOutlier", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5", ",", "1.8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.3", ",", "2.9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.5", ",", "4.9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.9", ",", "6.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.7", ",", "8.8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "8.7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.9", ",", "1.2"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[29]:=",
 CellID->99837753,ExpressionUUID->"c8613fc4-3e5d-4c03-b793-93bcd62995b6"],

Cell[TextData[{
 "We can create another linear model, ",
 Cell[BoxData[
 "linearModelOutlier"], "InlineCodeText",ExpressionUUID->
  "c106e98f-f311-4d07-b14b-9aaa26befa4f"],
 "."
}], "Text",
 CellChangeTimes->{
  3.753586241000518*^9, {3.7663281682203665`*^9, 3.7663281834193664`*^9}},
 CellID->37484792,ExpressionUUID->"83ce6b13-4ac1-446c-8aea-664503ad4383"],

Cell["Create a new linear model:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753586252968443*^9, {
   3.7663281879003663`*^9, 3.7663281929383664`*^9}},
 CellID->194815872,ExpressionUUID->"4f010e84-94ae-4a16-be7c-56386b15fabd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"linearModelOutlier", "=", 
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"dataOutlier", ",", "x", ",", "x"}], "]"}]}]], "Input",
 CellLabel->"In[30]:=",
 CellID->742500592,ExpressionUUID->"488607d7-0ee5-4e8d-8b64-e13dc23c5f02"],

Cell[BoxData[
 TagBox[
  RowBox[{"FittedModel", "[", 
   TagBox[
    PanelBox[
     TagBox[
      RowBox[{"1.7140788173105888`", "\[VeryThinSpace]", "+", 
       RowBox[{"1.0156861059779092`", " ", "x"}]}],
      Short[#, 2]& ],
     FrameMargins->5],
    Editable -> False], "]"}],
  InterpretTemplate[
  FittedModel[{
    "Linear", {1.7140788173105888`, 
     1.0156861059779092`}, {{$CellContext`x}, {1, $CellContext`x}}, {0, 
     0}}, {{1., 1., 1., 1., 1., 1., 1., 1., 1., 
    1.}}, {{0, 1}, {0.5, 1.8}, {1, 2}, {1.3, 2.9}, {2.1, 3}, {2.5, 4.9}, {2.9,
      6.1}, {3.7, 8.8}, {4, 8.7}, {4.9, 1.2}}, {{1., 0.}, {1., 0.5}, {1., 
    1.}, {1., 1.3}, {1., 2.1}, {1., 2.5}, {1., 2.9}, {1., 3.7}, {1., 4.}, {1.,
     4.9}}, 
    Function[Null, 
     Internal`LocalizedBlock[{$CellContext`x}, #], {HoldAll}]]& ],
  Editable->False,
  SelectWithContents->True,
  Selectable->True]], "Output",
 CellChangeTimes->{3.753586261641436*^9, 3.8024416655955315`*^9, 
  3.81066221051525*^9},
 CellLabel->"Out[30]=",
 CellID->32729681,ExpressionUUID->"f0470589-616b-491b-a35b-6fe6d7239729"]
}, Open  ]],

Cell["\<\
Now have a look at the difference between the two models (the model with the \
outlier is in red).\
\>", "Text",
 CellChangeTimes->{
  3.7535862796167803`*^9, {3.7663281995553665`*^9, 3.7663282023713665`*^9}, {
   3.8160882795808363`*^9, 3.816088280972088*^9}},
 CellID->511049931,ExpressionUUID->"f0e6ddbd-b214-45cb-936c-1078d914a7eb"],

Cell["Plot a model for each of the datasets:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.7535862907011504`*^9, {
   3.7663282055713663`*^9, 3.7663282105703664`*^9}},
 CellID->208820815,ExpressionUUID->"8b0b311e-eabb-4a3e-b7fe-3585b8bd345d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"data", ",", "dataOutlier"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"PointSize", "[", "Medium", "]"}]}]}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"linearModel", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "5"}], "}"}]}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"linearModelOutlier", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "5"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"4.9", ",", "1.2"}], "}"}], "}"}], ",", 
     RowBox[{"PlotMarkers", "\[Rule]", "Red"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7857250218733225`*^9, 3.7857250376062927`*^9}, {
  3.7857250728412366`*^9, 3.7857251080568447`*^9}},
 CellLabel->"In[31]:=",
 CellID->443163234,ExpressionUUID->"d11dcd1f-3884-4b95-aae6-6bc227834449"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Medium], 
      AbsoluteThickness[1.6], 
      PointBox[{{0., 1.}, {0.5, 1.8}, {1., 2.}, {1.3, 2.9}, {2.1, 3.}, {2.5, 
       4.9}, {2.9, 6.1}, {3.7, 8.8}, {4., 8.7}, {4.9, 9.9}}]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[Medium], 
      AbsoluteThickness[1.6], 
      PointBox[{{0., 1.}, {0.5, 1.8}, {1., 2.}, {1.3, 2.9}, {2.1, 3.}, {2.5, 
       4.9}, {2.9, 6.1}, {3.7, 8.8}, {4., 8.7}, {4.9, 
       1.2}}]}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVznk41HkcwHEaR2YmZvzaatYxg69GQ44txxR9Px37VJLNomN0GWe5YtPj
yuYKkaMsocmVNOtxtDspkkpqooxlWlZmSyYrlp4yDUbKtn+8n/e/LxN+xI8B
S9TU1HZ/7f8LEvladv7xmzwSza4dPtiPO6Qst32sA7hG77hmcE4/XnzclsJi
HcNfyhv9I+/3Y8H980xNViyufehilooGcKhLdNgsMxNr6ewvF04OYOmn4IL3
zGJ852J2yceEQaw9NMKeYgqxuVCZc04gwxVdZZH/Mpvx53H5Rp+I17i+IXMo
1LoLb1PJRfaOb3EQ7i2ejJLiypb4Oe3sdzh8dI1cVD+IDVyLY9OPTmOySSr7
ldMwZgopmN+mxDm0p5yKo3Js/bpz/PbIHOYPed0jPfsHn6KUyQJdF3Dko1R+
BHsCDz4gWdpULuIbJ6ieq3ZO4SoLXgP3qDpUxIdM2O57j2PGXcK06SRILlvw
+Dj5AfcVio2Iag1Qkw5Da5wCc8mMBUs7LVh9MjDGi6PEd2eiE9+/1IY3yqK9
lLsz+HFPjGI6QgdcR4+fvhA5hydN0qkVphRwf5NnaWw8j1kbDnke7KbCxEP+
mSd1n/DgpsFsbx9dsKb3G2098hnvO2xrf1qTBmSs9JUpvuBUYrvgnYQG26d4
s6beagBpfgP2Qjr81e6vzrNSB9ILv+spP+vDzYyOwyylOiw1vxV1YjsBgZrR
wxLJErhsRdNbx1oOflHxN6klJIjitF4tmFgONkGWEjdfDdhDcetdaPwGevSt
KNFcTWi9/rpnQ8YKuFOfXGpF0oLjzl3ilR4rIV6ds+fZ31pQk307v4uzCsiy
uB3hIm2YuHduOkWNAaPXTArKEpZC5HiDm0zMgAILhkaztw6k9byIIZd/C3kl
gWJfFhle1u6/MnDMAHgFhyTUMTI4h7Twam0MYW5btaqsjQIWYybjXlpGIB/d
EtOeToUDB2QnBBIjqHSxM+j2XQYrMy533akxhrq0aHrQWl1g1DUYxUYxId3b
bxdJqQv5PGnKFUMW2MsqhOndeiBr7fUNyWDBpTWldd27aLCzJLZVe4oFP98/
f2lXMw0WvJGaHs8Edht4V3chOqwjbc5lPDKBzeFiH3omHbIstUsVFqZQZshH
z5R04Hz3R67TL6aAHtYUuvvow+TvW9R3z5tC3tp2Tl+bPtix2W3+h8wgUKHR
28khoDVG13/siRnwb0yzMnMJOPZ92VnuWgShyZ4LrvkExBeciVNZI4j2FA1Q
LxKQLfcNb7ZFkKGMzskrJKAxCe3lrkdQz1V9KhIQMHNXaM7diED1YLH/Wi0B
SQ6iDqedCPL6qOc7xAQUszuXOAUgKKkKCz7bSUDtqV9nZgMRVJ2UbN3x9Kvn
UdbErWAETSvy5p9KCHjl597nGIpAxiOCpX8SYF4urXD8CQFbztg6IifgxqqX
4JiEwFYUZ3x1lID2oHvrZ5MRbEgbUgWMEfC8qdziVioCN7agcXziq8/Lj+aY
gSAqhGX84QMBzvlvXznkIkhwTlL9piDAfbhTOpOHIG3ZyPOTSgKO2NSKmy4g
uNRQlTU3R0Byd1iDQyGCyjMaQS3zBBQY/lA1U4Sg1iNgS8ICAdUhtkVNxQhE
po+NNn0hoKmFnnWqFEGbYrVqcZGATh1FooMAwX9odCf8
        "]]},
      Annotation[#, "Charting`Private`Tag$7555#1"]& ]}, {}}, {{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], 
       LineBox[CompressedData["
1:eJwVkX081HcAxw+HcOHu5/F+uCMv5ynLaEsv+n4Wr01FT6jwapuThyIiWmHN
9CArMllFk45qyjw1KpHnGOWUQ3mRylOlboVuOedh7Y/36/3/+20ujN4aosxg
MLw/8b/zDgvVHHclrnml3sIcilSQFgnfazvfn7TMuq8i+xVksbXuCJ+/m1yS
NkdcOqQgeQ3pPFX+IeIvae4WHleQSLf4vR95aaT9YvOll/kKIlGEZ7/n5ZDi
lc2uk90Koj4wLJDyrpGo4KY4psscEXXkx7zhVZPpuoZRW9V5UlqWNhDp0EGc
qid6u+oXSBh5lPM2VkJaWv3vnHZgIGrMZqSytJ/8VJbQaiNnQNP8qODZquek
x+XzgXc9SsjQvW8r+n6EODtWf61VoAzhgG+9yoNx4tDRd2drsgpi7h0VRgsm
yO0X5RGnApio2MfyMVonJV6hAftpK1WIEiMmVmx/TxJP5R7pU1ZDSv7clg9v
J0kV7/rE+EM1MCTPUZswTQ47Hsh4nasOq7jQg762MjI8+mS10YElGJWd26Z1
91+yWVVrze9rNbB+bM+PWTEzxL9Nss6Lr4mNo5l2ZmazZErdP+sfuSYmmoXJ
f5coyG9VJY7jLVpwYPeZun83T7qZOf0aIhY0iSxocHqBcBt9nqRELcU30oCP
Fn4MzJtdeSbw1saTpl1KAfZKiFbcWFYv0EHViZZv+TIlvPXIrCue1kGoavxz
sVgZykbKjsJwXQTHJlaxclXAaVnmkNOli8/C7MReQUxElhWua3dmo4tjrxXv
ooqsN1G7TxewUVOacsFeRQ1uQyJnhgYHiUq2mx88VcNNcz5T/SAHmoMJnlGV
6jhweW5SbYyDsavm2flJS1D7FCcr1lPItjZmVvtpoCvsofXUbQqZuaFtQZ86
hBe1xTzl6SEge6eY9VITntam/Y1H9TDjcUWeX6cF2cxdD9cpPYyMrT3YlMqC
dXJrYNAOfRS4OdKdQUthvYP7g0mbPkqOxbPDlmujdLzXLcXBAKl+wRtUZNpI
qnxn8eKMAVYOiq6ldurAUOLL6lMyxHmbCyWdG3TxZZG5KD7cED81pJ/fUK0L
S7HL6uLHhvCm/a50WLLh71Q+2e9hhK+i2gLZaWxQmzJ8/7puhHwToeUDGRu5
NbdqLIyNYdn8x9mNgRwUDXmKXZONkbm8yba7joN5rFrcNGaM0Gnmo3ZbCrwP
sc7yrVwIK6b4aacptO7U1/eu5iIyxWdu/a8UTL6QLujXcBHvU/mYdYbCPu17
r4ZquTghi8/IPEuBWx9Xu6+Bi1IXueJcHoUofk9wdhsX8sbFvqvFFPRGsm4M
9HKR2c1Kb2mj8On15j1TXOQW7g0/3k7hFl65OH3gojBO7O55nwLLuGHZnIyL
mwaZs/fFFKraoz+my7kYDKDCJb0UNOy6LlYwaAhGjN2HRyiUSdOlM9o0VlQm
mF0eo8BsDXncqEtj9bEBechLCv4X3Rp/4dDwEuSVv56goLxJmm1iQCM2gm82
OUlhW7mXK0xpJLn+LL8xTaH4hKWVBo/GsaXDPXEyCoygOZ1uPo3zZYUnZ2Yo
XGP/ORJsSaMgmRl2Z5bC4usjnfZWNIq3hKxNmqPg0xR4SyagUWnRarpmgUJR
rpOozoZG3bSVfHGRwnys1slUOxr/ASpaJ74=
        "]]},
      Annotation[#, "Charting`Private`Tag$7837#1"]& ]}, {}}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], GeometricTransformationBox[InsetBox[
       StyleBox[
        InterpretationBox[
         ButtonBox[
          TooltipBox[
           GraphicsBox[{
             {GrayLevel[0], RectangleBox[{0, 0}]}, 
             {GrayLevel[0], RectangleBox[{1, -1}]}, 
             {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}},
            AspectRatio->1,
            DefaultBaseStyle->"ColorSwatchGraphics",
            Frame->True,
            FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
            FrameTicks->None,
            
            ImageSize->
             Dynamic[{
              Automatic, 1.35 CurrentValue["FontCapHeight"]/
               AbsoluteCurrentValue[Magnification]}],
            PlotRangePadding->None],
           StyleBox[
            RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> False]],
          Appearance->None,
          BaseStyle->{},
          BaselinePosition->Baseline,
          ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
            If[
             Not[
              AbsoluteCurrentValue["Deployed"]], 
             SelectionMove[Typeset`box$, All, Expression]; 
             FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
             FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
             FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
             MathLink`CallFrontEnd[
               FrontEnd`AttachCell[Typeset`box$, 
                FrontEndResource["RGBColorValueSelector"], {
                0, {Left, Bottom}}, {Left, Top}, 
                "ClosingActions" -> {
                 "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
          DefaultBaseStyle->{},
          Evaluator->Automatic,
          Method->"Preemptive"],
         RGBColor[1, 0, 0],
         Editable->False,
         Selectable->False],
        StripOnInput->False,
        GraphicsBoxOptions->{DefaultBaseStyle->Directive[
          PointSize[0.012833333333333334`], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]]}], {0., 0.}], {{{4.9, 1.2}}, {{4.9, 
      1.2}}}]}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 4.9}, {0, 9.9}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.785725082317603*^9, 3.7857251091742363`*^9}, 
   3.802441667403532*^9, 3.810662210699574*^9},
 CellLabel->"Out[31]=",
 CellID->337897226,ExpressionUUID->"74c563c5-1b09-40e5-bef3-b7e44b5fffdf"]
}, Open  ]],

Cell["\<\
Note that the residual for an outlier will be bigger than the rest.\
\>", "Text",
 CellChangeTimes->{{3.75358631327542*^9, 3.7535863251673374`*^9}},
 CellID->110488516,ExpressionUUID->"6d45bf3e-6f91-43eb-a1c4-4de12de422af"],

Cell["Calculate the residuals:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753586327042473*^9, {
   3.7663282195063667`*^9, 3.7663282242413664`*^9}},
 CellID->81021178,ExpressionUUID->"8f51486f-b176-4dc5-bdb4-6521f3c72c86"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"linearModelOutlier", "[", "\"\<FitResiduals\>\"", "]"}]], "Input",
 CellLabel->"In[32]:=",
 CellID->939343010,ExpressionUUID->"6c7948c7-0749-4658-a2a8-dbe22979325a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.7140788173105888`"}], ",", 
   RowBox[{"-", "0.42192187029954353`"}], ",", 
   RowBox[{"-", "0.729764923288498`"}], ",", 
   RowBox[{"-", "0.13447075508187067`"}], ",", 
   RowBox[{"-", "0.847019639864198`"}], ",", "0.6467059177446384`", ",", 
   "1.4404314753534742`", ",", "3.327882590571148`", ",", 
   "2.9231767587777737`", ",", 
   RowBox[{"-", "5.490940736602344`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7535863340004797`*^9, 3.802441667790532*^9, 
  3.810662210719089*^9},
 CellLabel->"Out[32]=",
 CellID->1091914714,ExpressionUUID->"5eac35a5-dd7a-4d5f-bcea-5da929b24154"]
}, Open  ]],

Cell["\<\
While the observed value was 1.2, the predicted (calculated) data point value \
is 6.69094. We can calculate this by simply passing the independent variable \
data point value to the model object.\
\>", "Text",
 CellChangeTimes->{
  3.753586354869445*^9, 3.766228180801253*^9, {3.800789885162512*^9, 
   3.8007898981706686`*^9}, {3.8007900095972834`*^9, 3.8007900103007355`*^9}},
 CellID->558091818,ExpressionUUID->"460cafad-24e4-4810-9e0d-885ae3ee5370"],

Cell["Calculate the predicted dependent value:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753586366906678*^9, {
   3.7663283043973665`*^9, 3.7663283078053665`*^9}},
 CellID->151261206,ExpressionUUID->"9f275829-d860-46ff-bfb9-07f43fa9661c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"linearModelOutlier", "[", "4.9", "]"}]], "Input",
 CellLabel->"In[33]:=",
 CellID->190199310,ExpressionUUID->"39c621ae-7109-4fc8-8d6f-f0bac2253953"],

Cell[BoxData["6.690940736602344`"], "Output",
 CellChangeTimes->{3.7535863743659596`*^9, 3.802441668172532*^9, 
  3.810662210745549*^9},
 CellLabel->"Out[33]=",
 CellID->1503909242,ExpressionUUID->"e313a907-0d0a-426c-bc1c-48df5d8411b0"]
}, Open  ]],

Cell["\<\
The difference between the actual and predicted value is as we see in the \
last item of the list above.\
\>", "Text",
 CellChangeTimes->{3.753586400957173*^9},
 CellID->351751944,ExpressionUUID->"910e01f8-34e6-4fa2-a07d-b2dba2a0ef05"],

Cell["Calculate the difference manually:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753586409971478*^9, {
   3.766328318125366*^9, 3.7663283220203667`*^9}},
 CellID->663306639,ExpressionUUID->"951c5cf5-b700-4556-943a-a829ea0e79cd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"1.2", "-", "6.69094"}]], "Input",
 CellLabel->"In[34]:=",
 CellID->260421157,ExpressionUUID->"dcb8887c-817a-47e6-b41a-8e2c2e920337"],

Cell[BoxData[
 RowBox[{"-", "5.49094`"}]], "Output",
 CellChangeTimes->{3.7535864162498198`*^9, 3.802441668523532*^9, 
  3.810662210762583*^9},
 CellLabel->"Out[34]=",
 CellID->320105104,ExpressionUUID->"d2714906-bf38-4af3-a299-e2d8397954ee"]
}, Open  ]],

Cell[TextData[{
 "We need a way of deciding if this is out of keeping with the rest of the \
residuals. Unfortunately, the residuals are measured in the same units as the \
variables. We need to standardize them, which means centralizing and \
expressing them in units of standard deviation. This is simply a property of \
our model object called ",
 Cell[BoxData[
 "\"\<StandardizedResiduals\>\""], "InlineCodeText",ExpressionUUID->
  "33ebd436-1769-4e6d-9def-cc5b5120a50b"],
 "."
}], "Text",
 CellChangeTimes->{{3.7535864250258904`*^9, 3.7535864553808856`*^9}, {
  3.7662281841295853`*^9, 3.766228191697342*^9}, {3.7663283449073668`*^9, 
  3.7663283602983665`*^9}, {3.8006186795152817`*^9, 3.80061871741658*^9}},
 CellID->117499423,ExpressionUUID->"2b908312-aa31-484d-818e-92819a5f8f21"],

Cell["Calculate the standardized residuals:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, 3.753586463435828*^9, {
   3.7663283634733667`*^9, 3.766328370441366*^9}},
 CellID->42162518,ExpressionUUID->"c5b5486c-b2d8-4cc5-8de2-00a82009522c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"linearModelOutlier", "[", "\"\<StandardizedResiduals\>\"", 
  "]"}]], "Input",
 CellLabel->"In[35]:=",
 CellID->659306264,ExpressionUUID->"391362eb-1e45-4699-9b92-c72083be60e9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.3339496478309659`"}], ",", 
   RowBox[{"-", "0.18562510584723937`"}], ",", 
   RowBox[{"-", "0.307970415422909`"}], ",", 
   RowBox[{"-", "0.05576771109895215`"}], ",", 
   RowBox[{"-", "0.3432535277942842`"}], ",", "0.26212682947958216`", ",", 
   "0.5884810180311487`", ",", "1.4163629561165196`", ",", 
   "1.2760238381904165`", ",", 
   RowBox[{"-", "2.7066535972616084`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7535864708586674`*^9, 3.8024416689025316`*^9, 
  3.810662210789044*^9},
 CellLabel->"Out[35]=",
 CellID->524403952,ExpressionUUID->"ebcef8da-fa1e-49d3-ba7e-0feb98522afc"]
}, Open  ]],

Cell["Plotting these clearly shows the outlier.", "Text",
 CellChangeTimes->{3.7535864797076783`*^9},
 CellID->50135691,ExpressionUUID->"501c44a2-f90b-43a7-b1eb-53e9c32d3c3c"],

Cell["Plot the standardized residuals:", "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, {3.7535864917181253`*^9, 
   3.7535864921832867`*^9}, {3.7663285544873667`*^9, 3.7663285593583665`*^9}},
 CellID->54167954,ExpressionUUID->"45d656b0-8faf-4a90-8acf-348de14999f2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"linearModelOutlier", "[", "\"\<StandardizedResiduals\>\"", "]"}], 
   ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellLabel->"In[36]:=",
 CellID->283344401,ExpressionUUID->"991ed19f-d8f2-4fb4-80e7-b959b88e23e9"],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7K3K/oTnxV/dDxVwSJQot59w6DiUz+EwXX5G
98mtl6F8AQefhvX3pvaugfJFHFbZsC+9+x2mX8LhvhnjnPXHLthD+DIO08Nu
qFy78gjKV3C4MuWPcc7Kb1C+ksM06fs/pmd9gfJVHFi2+zFYLWc9AHMfAypw
QOVyoPEF0PgiaHwJNL4MGl8Bja+ExldB4w/e8AMAnQlnPw==
    "], {{{}, {}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], LineBox[{11, 1}],
        LineBox[{12, 2}], LineBox[{13, 3}], LineBox[{14, 4}], 
       LineBox[{15, 5}], LineBox[{20, 10}]}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], LineBox[{16, 6}],
        LineBox[{17, 7}], LineBox[{18, 8}], LineBox[{19, 9}]}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{21, 22, 23, 24, 25, 26, 27, 28, 29, 30}]}}], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.8125000000000003, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0.8125000000000003, 10.}, {-2.7066535972616084`, 
   1.4163629561165196`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7535865006685247`*^9, 3.802441669665532*^9, 
  3.810662210854303*^9},
 CellLabel->"Out[36]=",
 CellID->1707386492,ExpressionUUID->"e630bd2f-f390-45ed-8e4b-15398626f317"]
}, Open  ]],

Cell[TextData[{
 "The standardized residuals follow the standard normal distribution with a \
mean of ",
 Cell[BoxData[
  FormBox["0", TraditionalForm]],ExpressionUUID->
  "baf48b1f-375d-415d-9a20-7f82fd834fc7"],
 " and a standard deviation of ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "2941c2a9-f70a-4b00-b6ad-b5e8edd8cfab"],
 ". With the standardized residual being ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "2.70665"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "4d57979c-4f9f-4293-9b7b-6e94e8b69c70"],
 " (below zero), we can calculate the probability of such a low value using ",
 ButtonBox["CDF",
  BaseStyle->"Link"],
 ". If the value was greater than 0, we would use ",
 Cell[BoxData[
  RowBox[{"1", "-", 
   ButtonBox["CDF",
    BaseStyle->"CodeLink"]}]], "InlineCodeText",ExpressionUUID->
  "0cc551dc-9d95-4255-b35e-656c3618553a"],
 ". We pass as arguments the distribution we require and the value."
}], "Text",
 CellChangeTimes->{{3.7535865234154367`*^9, 3.753586534166679*^9}, {
  3.7662281953137035`*^9, 3.7662281978419566`*^9}, {3.7663285804463663`*^9, 
  3.7663285932723665`*^9}, {3.766328717967366*^9, 3.766328736158366*^9}},
 CellID->334053806,ExpressionUUID->"814ddae1-1f0a-4181-8cde-762aa44388a5"],

Cell[TextData[{
 "Omit arguments for the ",
 ButtonBox["NormalDistribution",
  BaseStyle->"Link"],
 " function to indicate standard normal distribution:"
}], "CodeCaption",
 CellID->553642112,ExpressionUUID->"ed289338-9c9f-42c8-a8a1-b2f2a19006a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CDF", "[", 
  RowBox[{
   RowBox[{"NormalDistribution", "[", "]"}], ",", 
   RowBox[{"-", "2.70665"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7535865977872477`*^9, 3.753586614422531*^9}, 
   3.7535866639582777`*^9},
 CellLabel->"In[37]:=",
 CellID->166307994,ExpressionUUID->"8ab63f8e-b966-4660-9538-e5f1b299d773"],

Cell[BoxData["0.003398293517356468`"], "Output",
 CellChangeTimes->{3.753586579330286*^9, 3.753586615516223*^9, 
  3.7535866646144376`*^9, 3.8024416701385317`*^9, 3.810662210872929*^9},
 CellLabel->"Out[37]=",
 CellID->1368279830,ExpressionUUID->"0f6d8081-5ca9-433c-a1c5-f3905452a90d"]
}, Open  ]],

Cell["\<\
This is a low probability indeed. In general, we would call our model a bad \
generalization under the following circumstances:\
\>", "Text",
 CellChangeTimes->{3.7535866592233925`*^9, 3.7662282026734395`*^9, 
  3.7663289504313664`*^9},
 CellID->468343211,ExpressionUUID->"e789512c-7560-4851-9912-0477ba794bd6"],

Cell[CellGroupData[{

Cell[TextData[{
 "A standardized residual less than ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "3.29"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "201015a1-ab4d-4bdc-921a-f65331202c53"],
 " or more than 3.29"
}], "ItemNumbered",
 CellChangeTimes->{{3.7535867252845607`*^9, 3.753586761867737*^9}, {
  3.800789193475849*^9, 3.800789196102318*^9}},
 CellID->686236266,ExpressionUUID->"6490126e-65a0-4dfd-83c4-01e961e02276"],

Cell[TextData[{
 "If more than ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "b42fc413-28c0-4e84-a266-3618d657e9cf"],
 "% of the cases have a standardized residual of less than ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "2.58"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "9c7281fc-b5dc-4cb4-bd04-33cd03aad73b"],
 " or more than 2.58"
}], "ItemNumbered",
 CellChangeTimes->{{3.7535867252845607`*^9, 3.753586812335346*^9}, {
  3.7663289640643663`*^9, 3.7663289906213665`*^9}},
 CellID->47074909,ExpressionUUID->"31ffc64f-6850-42bb-a172-1ca4eb4c3c18"],

Cell[TextData[{
 "If more than 5% of the cases have a standardized residuals of less than ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1.96`"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "f0a75191-4d7f-4bf7-96ef-3f156538a034"],
 " or more than 1.96"
}], "ItemNumbered",
 CellChangeTimes->{{3.7535867252845607`*^9, 3.75358684222538*^9}, 
   3.7663289821473665`*^9},
 CellID->585609119,ExpressionUUID->"fadd970d-c7c3-42d0-b5b3-c9706ee5b29d"]
}, Open  ]],

Cell["\<\
These values are based on the PDF of the standard normal distribution:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7857254446934586`*^9, 3.7857254648851204`*^9}, {
  3.81350301110369*^9, 3.8135030115993958`*^9}},
 CellID->654441110,ExpressionUUID->"88afd701-2baa-4766-ab64-aa94144bdb54"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"PDF", "[", 
    RowBox[{
     RowBox[{"NormalDistribution", "[", "]"}], ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.785725470226899*^9, 3.7857255481678033`*^9}},
 CellLabel->"In[38]:=",
 CellID->22500944,ExpressionUUID->"159eae33-3e8a-453c-ad47-598d3340d402"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJw1mnc419///+09XqOBllFkJiKVno+DMkoZlZaSXVSyFS0rScgqhbfsFaVk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    "], {{{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1ne4j3Ucx+HjmNl7k5mZVWSPyt5771UhIRklKVIhm2QTSdl779mgrdCi
lNKiSen+5I/7er7v1znW+T3PcynYa3CrhxMTEhKS8F7ireu7ibfOFZxPu1bl
OG/4YgXX/dzhvIQ7nDfH13zvKruM825u2I/ZN3jB7mJnc55KNns5z2qv2CWd
t/OR3cL+iD52ebuo82KK2pt4XbvOcO06z2ud7azOL5LVXsYE7UOaax/SWytn
F3FeRBF7I6u1v3lU+5vntE52FucpZLGXMl77gGbaB/TSytqFnRdS2N7Aa9pf
DNP+YqLW0c7sPJnM9hKe0d6nqfY+PbUydiHnBRSy17NK+5Oh2p88q3WwMzlP
IpO9mKfj86OJ9h49tDvtgs7zKWiv41XtD4ZofzBBa29njM+JjPYixsV9QGPt
Xbprpe0Czi9TwF7LSu13HtF+Z7zWzs4Qnw0Z7IU8FfcSjbTTdNNK2Sv4jcHa
bzyjt7XTx2dBensBY7VTNNRO0VUrGfcP13hYu8bTehs7XfzsSWfP50ntHRpo
79BFK2Ev5yqDtKuM01vbaeNnTVr7ZcZob1Nfe5vOWnF7Gb8yUPuVp/RWdpr4
2ZLGnscT2lvU096ik1bMXsovDNB+Yaze0n6cN6mrvUnHeObsJfzMQ9rPPKm3
sEdzkvu1k3TQi9qL+YkHtZ8Yoze3R3GC+7QTtNeL2Iv4kQe0H3lCb2aP5Dj3
asdppxe2F3KF/toVHteb2iM4Rh3tGG31QvYCfqCf9gOj9SbxruAotbWjtNEL
xv3G7eQnX9yP8exzhFq+7witfW9eez7f01f7nlF6o3i2OUxN7TCt9Dzx+zrP
43Z7TXzO2mX6aJcZqTW0U8d9TWr7JYbFfWOXcN7GIbuGfYiWdm77defyzvvI
71zJ9XD8euf88b6M+8L3VXY9Gs9lfM7xzLKL7+J+c72bg/SOzym66wjXBvE8
uFbhWLx34r6KdxJ7uC3uc9eK8feL903cF9GZy1C//h7XI/G+9LXirlvjz9Lv
cj1Adf0gLZxz6audyznvJZ/zXPLFOzn+Xb6+0i7tvJNv7V72tzxm17dTxfNJ
KnsOQ7QDVNMO0FzLac/lEj21SwzX68U7hv1U1fbTTM9hz+Ebemjf8KheN94p
7KOKto+menY7G1nJEs9LvDvYG5+F79lLE9+XOZ6NeC+wJ35W+h4a+1qmeA7i
mWc3lfTdNPK1jPZsvqa79jXD9DrxjLOLitouGuoZ7FlcpJt2kaF67XjG2cnd
2k4a6OntmVygq3aBIXqteMbZEZ+ftoP6ejp7Bl/RRfuKR/Sa8YyznQradurp
ae3pfEln7UsG6zXslPF+JKU9m/7aNspr26irpbGn8QWdtC+I/2BUt1PE+5EU
9iz6aVspp23lfi21PZXP6ah9ziC9mp083o8kt2fSV9tCWW0L98X9bb/IZ3TQ
PmOgXtVOFu9Lktkz6KNtpoy2mXu1VHZe5znktVczRTtPe+08A+K5s5PG+5Sk
9vR4RrVN3Kltoo6W0s7jPJs88ZwyWTtHO+0cD2mV7cR435JoT6OXtpHS2kZq
ayns3M6zyG2vYpJ2lrbaWR7U7rGTxPuYJPZUemobKKVtoJaW3M7lPJNc8R7i
Be1T2mif8oBWKSHh//8cjk4Sf1E/Y3o4rqektp6aWjI7p/MMctoreV77hNba
J/SP95J9k1H2TaZo3e11lLDXUUNLaudwnk4OewXPaSvsUs47OGO3ss/QL96Z
9r+MtP9lstbNXupczHkLa+3i9lqqJ/7/T0rI7jyN7MYrTNQ+pqX2MX21u+x/
GGH/wyStq72GYvYaqmn/AUt8Wso=
         "]]]}, {}, {}}, {{}, {}, 
      TagBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        Opacity[1.], LineBox[CompressedData["
1:eJwl1ne8znUYxvFjlLL3KOLYe0sqZJOKjr05Rkal0Day9yhEw96y9wpllJld
mqSpPajM3verPz6+1/V5Hjy/+3s/53USk/smPZkiISHhWMqEhDjvc64UimGl
3gHjuev6c7iuV0J37iP9UXykj8ZCLiemcDkhJtzvj1VycazSN+rFME/vqE+Q
b8jP44ZeGT24j/UkfKxv1UthkT5GXyTnwit6LqTiquur5RJYrXfCRO6m/gJu
6lXwGHdWb4az+lgs5nLjVS43UnM19DVySazRO2NSPBBejEHhbkdP/RO5OT7R
x2EJlwdTuTy4haupr5VLYa3eBZNj5niJS4GqXC/9U7kFPo3ZYyl3B6Zxd+BW
7gF9nVwa6/RkTOFSYmDMHvdwvfXP5Jb4LOaNZdydmM7diTRcLX29XAbr9a54
hUuFQTFjVOP66J/LrfB5zBjLubx4jcuL27ja+ga5LDbo3fAqlxqDY8a4l3tc
/0JujS9ixrgddfiNXDlsjH3DVO4WDImZ4j7uCf1LuQ2+jJkiLerym7jy2BQ7
hWncrXg5Zoj7uSf1c3JbnIsZIh3q8Zu5Ctgce4PpXBoMjZmhOtdXPy+3w/mY
GdKjPr+Fq4gtsSexU3iK/4prj69iJsiABvxWrhK2xh7EzuBp/gLXARdiBsiI
hvw2rjK2xT3HTqAf/3V8t/B1PDMyoRG/nauC7XGPcefoz3/DdcI38YzIjAf5
HbHj2BH3FHeKLGjstXdiX/FO3EHcF7LiIa/tjN3Dzphv3AWyITtyICce9r5d
sVPYFXOMmWMA/y3XGd/qryEXHuF3x85gd8wxZoxn+O+4LvhOn4HcaMK/GzuC
d2OO8W9xt2FY7CgacM/q38vJ+F7fppfGYn2m/racDzP0fPFMcnksj++215vK
78Uuxf8jV4rOb3IWx3x+n7Mq+sXnc96OgxjutT3OKjgaPubpLIfDWKa/76yG
D9HQ33/O+QN/wNnV+Z6zMo6E9/p2ZxkcwhKv73feg9e9tsJ5F2bye513R4/5
Oyvg7fj54n2Pyntiv+Pz6Zv1Elig99dnymkxQk+LRtzz+kW5Gy7qb2Allz/+
by5//KzhkvS9co34DHHfsWt4gf+R644f9TeRF834fVzNmGPcd+wf8uEu5EcB
JKK59+73vgfiueNuYx/xIv8T1wM/6W+hIFrw73O1Ys4x29hLvMT/zD2Gn/VZ
KISW/AdcbXwQzxx7iYH8L1xP/KLPRmG04g9wdeK+4hljLzGI/5XrhV/1OSiC
1rEXXF0cjM8d+4XB/G9cb/ymz0VRtIl75urhUHzuuDsM4X/n+uB3fR6KoW3s
FVcfh+Nz43UuHUZy6ZDEvaz/IT+OP/T5KI52sWfxvcGReI64Zy49RnHp0Ywb
qv8pP4E/9QUogfax51xDHI3ninvmMmA0lwHNuWH6X3L8YvKXvhAl0SG+B7Fv
+DCeM+6Sy4gxXEa04Ibrl+S+uKQvQil05I9xD+JYPGfcLZcJY7lMaMmN0C/L
T+GyvhiruAJ4gyuA0lwn/bjcGMfjuePuucwYx2VGK26k/rf8NP7Wl2A1l4g3
uUSU4TrrJ+SHcCLmELvBZcF4Lgtac6P0f+R++EdfijVcQbzFFURZrot+Un4Y
J2MusTtcVkzgsqINN1r/N77b+FdfhrVcIcziCqEcl6yfkh/BqZhT7BaXDRO5
bGjLjdGvyANwRV+OdVxhzOYKozzXVT8tN8HpmFPsGpcdk7jsaMeN1a/Kz+Bq
/EzGeq4I5nBFUIHrpp+Rm+KMvkUviYX6qNhDOQcm6znQnhunX5OfxTV9h14W
S/UV+ga5KObqRbFbrogV8TPAeW/K/393rui9/wEFgFkf
         "]]},
       Annotation[#, "Charting`Private`Tag$8216#1"]& ]}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotRange->{{-5, 5}, {0., 0.39894216224307616`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.785725548548731*^9, 3.802441671129532*^9, 
  3.8106622110291023`*^9},
 CellLabel->"Out[38]=",
 CellID->77078645,ExpressionUUID->"51566b8e-3561-4610-8745-783a294287b5"]
}, Open  ]],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s consider the ",
 Cell[BoxData[
  FormBox["95", TraditionalForm]],ExpressionUUID->
  "01b0ffda-5af1-49f6-b5c6-e428d01f2755"],
 "% quantile values. This would be the values at ",
 Cell[BoxData[
  FormBox["0.025", TraditionalForm]],ExpressionUUID->
  "99c5e0f6-21e9-4fb0-9a24-46e3669ef7f2"],
 " and at 0.975."
}], "Text",
 CellChangeTimes->{{3.7857256070186114`*^9, 3.785725671610606*^9}, 
   3.8006189231730366`*^9, {3.8007900276956973`*^9, 3.8007900358349743`*^9}},
 CellID->48644513,ExpressionUUID->"298291b4-64ac-4013-990f-ec4c5d393d24"],

Cell[TextData[{
 "The quantile values are saved as ",
 Cell[BoxData[
 "lL"], "InlineCode",ExpressionUUID->"d685ef3c-3228-4e44-9434-0c98ffcd292e"],
 " and ",
 Cell[BoxData[
 "uL"], "InlineCode",ExpressionUUID->"acb932f1-cb42-4b02-b7e8-8f61601f88a7"],
 " for use in the plot:"
}], "CodeCaption",
 CellChangeTimes->{{3.7270988078629246`*^9, 3.7270988245702534`*^9}, 
   3.7270988961329637`*^9, {3.7464411651040597`*^9, 3.7464411663750596`*^9}, 
   3.7464433799318533`*^9, {3.7464549145722275`*^9, 3.746454922050976*^9}, {
   3.747756866972815*^9, 3.747756873256716*^9}, {3.7535007873522835`*^9, 
   3.7535007934768295`*^9}, {3.7535010647152877`*^9, 3.753501074847219*^9}, {
   3.753582472404866*^9, 3.753582475436247*^9}, {3.753586554726424*^9, 
   3.753586568451247*^9}, {3.7857265965496564`*^9, 3.7857266235403166`*^9}, {
   3.8006217684956846`*^9, 3.800621803121344*^9}, {3.800621891829544*^9, 
   3.8006219582492185`*^9}},
 CellID->671652695,ExpressionUUID->"ad8d5f60-af73-43bc-8839-29ad68d0a413"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"lL", ",", "uL"}], "}"}], "=", 
  RowBox[{"Quantile", "[", 
   RowBox[{
    RowBox[{"NormalDistribution", "[", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.025", ",", "0.975"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7857253225881405`*^9, 3.785725346243761*^9}, {
  3.785725390592002*^9, 3.785725397297847*^9}, {3.7857265252136884`*^9, 
  3.785726534061022*^9}},
 CellLabel->"In[39]:=",
 CellID->99764144,ExpressionUUID->"fe011e19-665e-430e-9b4a-cce8d49bb230"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.9599639845400545`"}], ",", "1.9599639845400538`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7857253464984922`*^9, {3.785725391198349*^9, 3.785725397774573*^9}, 
   3.785726535573721*^9, 3.802441671584532*^9, 3.81066221108897*^9},
 CellLabel->"Out[39]=",
 CellID->528147374,ExpressionUUID->"a0c874ef-762d-4e40-9897-954809494963"]
}, Open  ]],

Cell[TextData[{
 "In the next plot, we note these quantile values as vertical lines. The area \
under the curve to the left of the blue line plus the area to the right of \
the orange line together represents 0.05 (",
 Cell[BoxData[
  FormBox["5", TraditionalForm]],ExpressionUUID->
  "824af3a8-3490-4917-903c-ad49d5da8e15"],
 "%) of the total area under the curve."
}], "Text",
 CellChangeTimes->{{3.7857260283697624`*^9, 3.785726130771989*^9}, 
   3.785730130715131*^9, 3.8006189272753525`*^9, {3.8006219612155657`*^9, 
   3.8006219693122635`*^9}, {3.8007900496331944`*^9, 3.800790055781438*^9}},
 CellID->164340674,ExpressionUUID->"e6c5c010-db78-4388-afc6-63b784b3d3c1"],

Cell[TextData[{
 ButtonBox["Show",
  BaseStyle->"Link"],
 " combines the ",
 ButtonBox["Plot",
  BaseStyle->"Link"],
 " with the ",
 ButtonBox["List",
  BaseStyle->"Link"],
 ",  showing the specific area desired:"
}], "CodeCaption",
 CellChangeTimes->{{3.8019175580139284`*^9, 3.8019175814675827`*^9}, {
  3.80191766748398*^9, 3.8019177270130672`*^9}, {3.813503041720687*^9, 
  3.813503049505272*^9}},
 CellID->296261279,ExpressionUUID->"989b67b7-0f8d-468c-888b-174a74f26897"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"PDF", "[", 
      RowBox[{
       RowBox[{"NormalDistribution", "[", "]"}], ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], ",", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"lL", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"lL", ",", "0.4"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"uL", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"uL", ",", "0.4"}], "}"}]}], "}"}]}], "}"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.785725842052242*^9, 3.785725903072687*^9}, {
  3.785725953277458*^9, 3.785725987751423*^9}, {3.785726552494026*^9, 
  3.7857265730839896`*^9}},
 CellLabel->"In[40]:=",
 CellID->772854414,ExpressionUUID->"8bc746b2-7f37-43b6-91ed-d9a6155308ef"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJw1mnc419///+09XqOBllFkJiKVno+DMkoZlZaSXVSyFS0rScgqhbfsFaVk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     "], {{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
        GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1ne4j3Ucx+HjmNl7k5mZVWSPyt5771UhIRklKVIhm2QTSdl779mgrdCi
lNKiSen+5I/7er7v1znW+T3PcynYa3CrhxMTEhKS8F7ireu7ibfOFZxPu1bl
OG/4YgXX/dzhvIQ7nDfH13zvKruM825u2I/ZN3jB7mJnc55KNns5z2qv2CWd
t/OR3cL+iD52ebuo82KK2pt4XbvOcO06z2ud7azOL5LVXsYE7UOaax/SWytn
F3FeRBF7I6u1v3lU+5vntE52FucpZLGXMl77gGbaB/TSytqFnRdS2N7Aa9pf
DNP+YqLW0c7sPJnM9hKe0d6nqfY+PbUydiHnBRSy17NK+5Oh2p88q3WwMzlP
IpO9mKfj86OJ9h49tDvtgs7zKWiv41XtD4ZofzBBa29njM+JjPYixsV9QGPt
Xbprpe0Czi9TwF7LSu13HtF+Z7zWzs4Qnw0Z7IU8FfcSjbTTdNNK2Sv4jcHa
bzyjt7XTx2dBensBY7VTNNRO0VUrGfcP13hYu8bTehs7XfzsSWfP50ntHRpo
79BFK2Ev5yqDtKuM01vbaeNnTVr7ZcZob1Nfe5vOWnF7Gb8yUPuVp/RWdpr4
2ZLGnscT2lvU096ik1bMXsovDNB+Yaze0n6cN6mrvUnHeObsJfzMQ9rPPKm3
sEdzkvu1k3TQi9qL+YkHtZ8Yoze3R3GC+7QTtNeL2Iv4kQe0H3lCb2aP5Dj3
asdppxe2F3KF/toVHteb2iM4Rh3tGG31QvYCfqCf9gOj9SbxruAotbWjtNEL
xv3G7eQnX9yP8exzhFq+7witfW9eez7f01f7nlF6o3i2OUxN7TCt9Dzx+zrP
43Z7TXzO2mX6aJcZqTW0U8d9TWr7JYbFfWOXcN7GIbuGfYiWdm77defyzvvI
71zJ9XD8euf88b6M+8L3VXY9Gs9lfM7xzLKL7+J+c72bg/SOzym66wjXBvE8
uFbhWLx34r6KdxJ7uC3uc9eK8feL903cF9GZy1C//h7XI/G+9LXirlvjz9Lv
cj1Adf0gLZxz6audyznvJZ/zXPLFOzn+Xb6+0i7tvJNv7V72tzxm17dTxfNJ
KnsOQ7QDVNMO0FzLac/lEj21SwzX68U7hv1U1fbTTM9hz+Ebemjf8KheN94p
7KOKto+menY7G1nJEs9LvDvYG5+F79lLE9+XOZ6NeC+wJ35W+h4a+1qmeA7i
mWc3lfTdNPK1jPZsvqa79jXD9DrxjLOLitouGuoZ7FlcpJt2kaF67XjG2cnd
2k4a6OntmVygq3aBIXqteMbZEZ+ftoP6ejp7Bl/RRfuKR/Sa8YyznQradurp
ae3pfEln7UsG6zXslPF+JKU9m/7aNspr26irpbGn8QWdtC+I/2BUt1PE+5EU
9iz6aVspp23lfi21PZXP6ah9ziC9mp083o8kt2fSV9tCWW0L98X9bb/IZ3TQ
PmOgXtVOFu9Lktkz6KNtpoy2mXu1VHZe5znktVczRTtPe+08A+K5s5PG+5Sk
9vR4RrVN3Kltoo6W0s7jPJs88ZwyWTtHO+0cD2mV7cR435JoT6OXtpHS2kZq
ayns3M6zyG2vYpJ2lrbaWR7U7rGTxPuYJPZUemobKKVtoJaW3M7lPJNc8R7i
Be1T2mif8oBWKSHh//8cjk4Sf1E/Y3o4rqektp6aWjI7p/MMctoreV77hNba
J/SP95J9k1H2TaZo3e11lLDXUUNLaudwnk4OewXPaSvsUs47OGO3ss/QL96Z
9r+MtP9lstbNXupczHkLa+3i9lqqJ/7/T0rI7jyN7MYrTNQ+pqX2MX21u+x/
GGH/wyStq72GYvYaqmn/AUt8Wso=
          "]]]}, {}, {}}, {{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], LineBox[CompressedData["
1:eJwl1ne8znUYxvFjlLL3KOLYe0sqZJOKjr05Rkal0Day9yhEw96y9wpllJld
mqSpPajM3verPz6+1/V5Hjy/+3s/53USk/smPZkiISHhWMqEhDjvc64UimGl
3gHjuev6c7iuV0J37iP9UXykj8ZCLiemcDkhJtzvj1VycazSN+rFME/vqE+Q
b8jP44ZeGT24j/UkfKxv1UthkT5GXyTnwit6LqTiquur5RJYrXfCRO6m/gJu
6lXwGHdWb4az+lgs5nLjVS43UnM19DVySazRO2NSPBBejEHhbkdP/RO5OT7R
x2EJlwdTuTy4haupr5VLYa3eBZNj5niJS4GqXC/9U7kFPo3ZYyl3B6Zxd+BW
7gF9nVwa6/RkTOFSYmDMHvdwvfXP5Jb4LOaNZdydmM7diTRcLX29XAbr9a54
hUuFQTFjVOP66J/LrfB5zBjLubx4jcuL27ja+ga5LDbo3fAqlxqDY8a4l3tc
/0JujS9ixrgddfiNXDlsjH3DVO4WDImZ4j7uCf1LuQ2+jJkiLerym7jy2BQ7
hWncrXg5Zoj7uSf1c3JbnIsZIh3q8Zu5Ctgce4PpXBoMjZmhOtdXPy+3w/mY
GdKjPr+Fq4gtsSexU3iK/4prj69iJsiABvxWrhK2xh7EzuBp/gLXARdiBsiI
hvw2rjK2xT3HTqAf/3V8t/B1PDMyoRG/nauC7XGPcefoz3/DdcI38YzIjAf5
HbHj2BH3FHeKLGjstXdiX/FO3EHcF7LiIa/tjN3Dzphv3AWyITtyICce9r5d
sVPYFXOMmWMA/y3XGd/qryEXHuF3x85gd8wxZoxn+O+4LvhOn4HcaMK/GzuC
d2OO8W9xt2FY7CgacM/q38vJ+F7fppfGYn2m/racDzP0fPFMcnksj++215vK
78Uuxf8jV4rOb3IWx3x+n7Mq+sXnc96OgxjutT3OKjgaPubpLIfDWKa/76yG
D9HQ33/O+QN/wNnV+Z6zMo6E9/p2ZxkcwhKv73feg9e9tsJ5F2bye513R4/5
Oyvg7fj54n2Pyntiv+Pz6Zv1Elig99dnymkxQk+LRtzz+kW5Gy7qb2Allz/+
by5//KzhkvS9co34DHHfsWt4gf+R644f9TeRF834fVzNmGPcd+wf8uEu5EcB
JKK59+73vgfiueNuYx/xIv8T1wM/6W+hIFrw73O1Ys4x29hLvMT/zD2Gn/VZ
KISW/AdcbXwQzxx7iYH8L1xP/KLPRmG04g9wdeK+4hljLzGI/5XrhV/1OSiC
1rEXXF0cjM8d+4XB/G9cb/ymz0VRtIl75urhUHzuuDsM4X/n+uB3fR6KoW3s
FVcfh+Nz43UuHUZy6ZDEvaz/IT+OP/T5KI52sWfxvcGReI64Zy49RnHp0Ywb
qv8pP4E/9QUogfax51xDHI3ninvmMmA0lwHNuWH6X3L8YvKXvhAl0SG+B7Fv
+DCeM+6Sy4gxXEa04Ibrl+S+uKQvQil05I9xD+JYPGfcLZcJY7lMaMmN0C/L
T+GyvhiruAJ4gyuA0lwn/bjcGMfjuePuucwYx2VGK26k/rf8NP7Wl2A1l4g3
uUSU4TrrJ+SHcCLmELvBZcF4Lgtac6P0f+R++EdfijVcQbzFFURZrot+Un4Y
J2MusTtcVkzgsqINN1r/N77b+FdfhrVcIcziCqEcl6yfkh/BqZhT7BaXDRO5
bGjLjdGvyANwRV+OdVxhzOYKozzXVT8tN8HpmFPsGpcdk7jsaMeN1a/Kz+Bq
/EzGeq4I5nBFUIHrpp+Rm+KMvkUviYX6qNhDOQcm6znQnhunX5OfxTV9h14W
S/UV+ga5KObqRbFbrogV8TPAeW/K/393rui9/wEFgFkf
          "]]},
        Annotation[#, "Charting`Private`Tag$9706#1"]& ]}}], {}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], AbsoluteThickness[1.6], 
      LineBox[{{-1.9599639845400545`, 0.}, {-1.9599639845400545`, 
       0.4}, {-1.9599639845400545`, 0.4}}]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       NCache[
        Rational[7, 360], 0.019444444444444445`]], AbsoluteThickness[1.6], 
      LineBox[{{1.9599639845400538`, 0.}, {1.9599639845400538`, 0.4}, {
       1.9599639845400538`, 0.4}}]}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotRange->{{-5, 5}, {0., 0.39894216224307616`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7857259041263447`*^9, 3.785725988475337*^9, 
  3.785726573820387*^9, 3.802441672943532*^9, 3.810662211279235*^9},
 CellLabel->"Out[40]=",
 CellID->1632352378,ExpressionUUID->"25fef1b8-6b43-48a3-95f9-cf5572614646"]
}, Open  ]],

Cell["\<\
The quantile values for 99% are shown below, followed by the values for \
99.95%:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7857261663083887`*^9, 3.7857261854936447`*^9}, {
  3.7857262240200863`*^9, 3.785726225457713*^9}, {3.7857264097859554`*^9, 
  3.7857264226173306`*^9}, {3.800790065967523*^9, 3.8007900799474382`*^9}, {
  3.801917822465068*^9, 3.8019178329930677`*^9}},
 CellID->312796831,ExpressionUUID->"235870bb-54b4-46f3-bea5-64b31046127e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Quantile", "[", 
  RowBox[{
   RowBox[{"NormalDistribution", "[", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.005", ",", "0.997"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7857262414666667`*^9, 3.785726275992014*^9}},
 CellLabel->"In[41]:=",
 CellID->333252504,ExpressionUUID->"bdb78ac5-e9d6-4710-b82b-7a48cdab60e8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "2.575829303548901`"}], ",", "2.747781385444993`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7857262499840517`*^9, 3.7857262768560543`*^9}, 
   3.802441673332532*^9, 3.810662211297576*^9},
 CellLabel->"Out[41]=",
 CellID->842826621,ExpressionUUID->"f26ab4fe-2653-42b7-bff7-0a4407ae28f0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Quantile", "[", 
  RowBox[{
   RowBox[{"NormalDistribution", "[", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.0005", ",", "0.9995"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.785726188124504*^9, 3.785726219162511*^9}, {
  3.7857262928744726`*^9, 3.78572629581814*^9}, {3.785726333062768*^9, 
  3.7857263468111067`*^9}},
 CellLabel->"In[42]:=",
 CellID->160409477,ExpressionUUID->"31cdc1bd-0a49-49cb-a7a8-a3cdf3d94db1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "3.2905267314918945`"}], ",", "3.2905267314919255`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.785726219554431*^9, 3.7857262961034074`*^9, {3.7857263409010024`*^9, 
   3.785726347728739*^9}, 3.802441673721532*^9, 3.810662211324395*^9},
 CellLabel->"Out[42]=",
 CellID->340402704,ExpressionUUID->"136e1e0f-c1b3-4b11-ba21-4d4856dddc59"]
}, Open  ]],

Cell["\<\
Linear regression can be a powerful predictive tool and forms the basis of \
many machine learning algorithms.\
\>", "Text",
 CellChangeTimes->{3.753586849788975*^9},
 CellID->552837096,ExpressionUUID->"6e04e0cc-6c73-4970-a746-9d60b0929372"],

Cell[CellGroupData[{

Cell[BoxData["Exercises"], "ExerciseSection",
 CellChangeTimes->{{3.7535037873392963`*^9, 3.7535037959303627`*^9}, {
  3.7535869844920387`*^9, 3.75358700537521*^9}, {3.7663303547923665`*^9, 
  3.7663303556483665`*^9}},
 CellLabel->"In[43]:=",
 CellID->566065673,ExpressionUUID->"66299430-d3ed-42c9-9db5-e29aaa2063d2"],

Cell[TextData[{
 "You can find the notebooks for this textbook at ",
 ButtonBox["wolfr.am/klopper",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/klopper"], None},
  ButtonNote->"https://wolfr.am/klopper"],
 ". All relevant ",
 Cell[BoxData[
  FormBox[
   RowBox[{".", "csv"}], TraditionalForm]], "InlineCode",
  FormatType->"TraditionalForm",ExpressionUUID->
  "ddb7e24f-fb33-4908-820d-8ec0f6d1d824"],
 " files are stored in the downloadable ",
 Cell[BoxData[
  FormBox[
   RowBox[{".", "zip"}], TraditionalForm]], "InlineCode",
  FormatType->"TraditionalForm",ExpressionUUID->
  "138c1ad0-c656-4c0f-834d-139636f06c24"],
 " file. If you are using a fresh notebook, make sure to have the ",
 Cell[BoxData[
  FormBox[
   RowBox[{".", "csv"}], TraditionalForm]], "InlineCode",
  FormatType->"TraditionalForm",ExpressionUUID->
  "9be914a9-9a7e-45da-a6b4-6f5898ef63c9"],
 " stored in the same folder."
}], "ExerciseNote",
 CellChangeTimes->{
  3.813503154304234*^9, {3.813503191944503*^9, 3.8135031919457693`*^9}, {
   3.8160884433814697`*^9, 3.816088458270122*^9}},
 CellID->1299166670,ExpressionUUID->"f040da89-6c4d-4374-81d4-ecea16ae62c7"],

Cell[TextData[{
 "Import the ",
 StyleBox["LinearRegression.csv",
  FontSlant->"Italic"],
 " file using the ",
 ButtonBox["SemanticImport",
  BaseStyle->"Link"],
 " function. Save the imported dataset as the computer variable ",
 Cell[BoxData[
 "data"], "InlineCode",ExpressionUUID->"570d7be1-c0b2-4aa5-8655-f0e3e92ff537"],
 ". (Hint: if the import fails, use the ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Delimiters",
    BaseStyle->"CodeLink"], "->", "\"\<,\>\""}]], "InlineCode",ExpressionUUID->
  "e468d894-f363-47e7-acd4-71e488fee52f"],
 " argument.)"
}], "Exercise",
 CellChangeTimes->{{3.7262286590360723`*^9, 3.72622873894293*^9}, {
   3.7262287716961455`*^9, 3.7262287754399443`*^9}, {3.726228865544318*^9, 
   3.7262288824469132`*^9}, {3.7262290096722617`*^9, 
   3.7262290542473125`*^9}, {3.7262295602878523`*^9, 3.726229562391164*^9}, 
   3.726842073467464*^9, {3.726842199040183*^9, 3.726842199141012*^9}, {
   3.7477659616730633`*^9, 3.74776596922626*^9}, {3.747766013016721*^9, 
   3.7477660144880943`*^9}, {3.7535037976739645`*^9, 
   3.7535038097756343`*^9}, {3.753586871097089*^9, 3.7535868794886837`*^9}, {
   3.7662282097541475`*^9, 3.76622821468264*^9}, {3.7663290345483665`*^9, 
   3.7663291113683662`*^9}, {3.7663292736303663`*^9, 3.766329281974366*^9}},
 CellID->123280140,ExpressionUUID->"8ec1bcad-04ff-46b4-b01a-4a59bd4b4dfd"],

Cell["View the first five rows of data.", "Exercise",
 CellChangeTimes->{{3.726228748018307*^9, 3.7262288631760774`*^9}, {
   3.7262288935428853`*^9, 3.726228921543979*^9}, {3.746529695196211*^9, 
   3.746529695627211*^9}, 3.7535038231930275`*^9, 3.7535868865719275`*^9},
 CellID->141359314,ExpressionUUID->"a7b048f9-4397-4b15-9fc2-2e34e2685ca7"],

Cell["\<\
Create a scatter plot of the input versus the output variable.\
\>", "Exercise",
 CellChangeTimes->{{3.7262289295702744`*^9, 3.726228976510738*^9}, {
   3.7262298270959935`*^9, 3.726229839750589*^9}, {3.726842199208551*^9, 
   3.7268421992586803`*^9}, 3.747765975313822*^9, 3.753503832167759*^9, 
   3.753503903017989*^9, 3.753586893170168*^9, {3.7663292383833666`*^9, 
   3.7663292395603666`*^9}},
 CellID->64011863,ExpressionUUID->"957969d8-a68f-424b-8c80-29f3e9c8e11e"],

Cell[TextData[{
 "Extract both variables as lists and save them individually as computer \
variables named ",
 Cell[BoxData[
 "inputVariable"], "InlineCode",ExpressionUUID->
  "783765d6-51c7-4cbd-988f-6b36ff5e76a6"],
 " and ",
 Cell[BoxData[
 "outputVariable"], "InlineCode",ExpressionUUID->
  "91106bcc-9303-443f-8874-afa6404ff4fe"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.726229157842061*^9, 3.7262291993992033`*^9}, {
   3.746530166713211*^9, 3.7465301668482113`*^9}, 3.7477659791690283`*^9, 
   3.7535038402103934`*^9, 3.7535039068153744`*^9, 3.753586899409522*^9, {
   3.7663292485363665`*^9, 3.7663293227873664`*^9}},
 CellID->416311685,ExpressionUUID->"754ce739-ad30-44fa-a448-a4dee5b45a27"],

Cell[TextData[{
 "Use ",
 ButtonBox["Table",
  BaseStyle->"Link"],
 " or ",
 ButtonBox["Transpose",
  BaseStyle->"Link"],
 " to create a nested list of pairs from the two ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " objects above. Name the object ",
 Cell[BoxData[
 "pairedVariables"], "InlineCode",ExpressionUUID->
  "69503b6f-fd12-45e6-b616-03207d28dc87"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.7262289854750276`*^9, 3.7262290027998576`*^9}, {
   3.7262290588479567`*^9, 3.726229071255257*^9}, {3.7262291247517605`*^9, 
   3.7262291444871144`*^9}, {3.726842199308242*^9, 3.7268421993580112`*^9}, {
   3.746440260987338*^9, 3.746440261211383*^9}, 3.747765986481744*^9, 
   3.7535038491802187`*^9, 3.753503894481763*^9, {3.7535869065237217`*^9, 
   3.7535869168361454`*^9}, 3.766228218514024*^9, {3.766329592139366*^9, 
   3.766329628851366*^9}, {3.8024380050149045`*^9, 3.8024380115819044`*^9}},
 CellID->33034166,ExpressionUUID->"62b659ae-6584-4ff3-9b86-3b1a96908de1"],

Cell[TextData[{
 "Create a linear model object named ",
 Cell[BoxData[
 "linearModel"], "InlineCode",ExpressionUUID->
  "5fd0efd6-fdfb-46a4-81d7-c9d3466a37cd"],
 " from ",
 Cell[BoxData[
 "pairedVariables"], "InlineCode",ExpressionUUID->
  "8c21a592-bfe8-47f2-b96b-1ef0eadddb07"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.7262290793221188`*^9, 3.726229098193971*^9}, {
   3.746530047904211*^9, 3.7465300490732107`*^9}, 3.7535038591626306`*^9, 
   3.753586927509095*^9, {3.7663296595573664`*^9, 3.7663296775203667`*^9}, {
   3.7663297196693664`*^9, 3.7663297630413666`*^9}, {3.816090800749094*^9, 
   3.8160908009726477`*^9}},
 CellID->482980621,ExpressionUUID->"4cbdf192-8f25-428a-bc9e-266c87b24f01"],

Cell[TextData[{
 "Show the parameter table for ",
 Cell[BoxData[
 "linearModel"], "InlineCode",ExpressionUUID->
  "5baec062-7114-419f-846c-4cd29a37be2a"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.726229233770355*^9, 3.726229294103078*^9}, {
   3.726230215439643*^9, 3.7262302247748566`*^9}, 3.726842136959337*^9, {
   3.746530212767211*^9, 3.7465302165582113`*^9}, 3.7535038660699406`*^9, 
   3.753586940791834*^9, {3.7663298906103663`*^9, 3.7663299027223663`*^9}},
 CellID->135554252,ExpressionUUID->"3411e31a-3688-4282-928b-59569f8ad515"],

Cell[TextData[{
 "Use ",
 ButtonBox["Show",
  BaseStyle->"Link"],
 " to plot both the paired data point values (",
 Cell[BoxData[
 "pairedVariables"], "InlineCode",ExpressionUUID->
  "50c860ad-7c4e-46c2-991a-361350fb59bd"],
 ") and the fitted line (",
 Cell[BoxData[
 "linearModel"], "InlineCode",ExpressionUUID->
  "e8a798f8-2974-4c82-be23-6165ae5e20b9"],
 ")."
}], "Exercise",
 CellChangeTimes->{{3.726229327482026*^9, 3.726229437287052*^9}, {
   3.726842099061895*^9, 3.726842101914075*^9}, {3.72684219942413*^9, 
   3.726842199476267*^9}, {3.7465303105142107`*^9, 3.746530310865211*^9}, {
   3.746530392909211*^9, 3.746530393957211*^9}, {3.747765998234042*^9, 
   3.747766007954041*^9}, 3.7535038730376973`*^9, {3.7535869490372763`*^9, 
   3.753586960777512*^9}, {3.7663299063383665`*^9, 3.7663299631103663`*^9}},
 CellID->196921243,ExpressionUUID->"fec0f7b2-18ef-4158-9529-a170ec968dee"],

Cell[TextData[{
 "Create a smooth histogram of the residuals ",
 Cell[BoxData[
 "linearModel"], "InlineCode",ExpressionUUID->
  "60368bec-d9d0-4da5-ab46-3029b52ca8e7"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.726229327482026*^9, 3.726229437287052*^9}, {
   3.726842099061895*^9, 3.726842101914075*^9}, {3.72684219942413*^9, 
   3.726842199476267*^9}, {3.7465303105142107`*^9, 3.746530310865211*^9}, {
   3.746530392909211*^9, 3.746530393957211*^9}, {3.747765998234042*^9, 
   3.747766007954041*^9}, 3.7535038730376973`*^9, {3.7535869490372763`*^9, 
   3.753586973083559*^9}, {3.7663299673743663`*^9, 3.7663299910363665`*^9}},
 CellID->285234496,ExpressionUUID->"b015a27d-90a0-4cbc-ab93-524d615c01c6"],

Cell[TextData[{
 "Calculate the ",
 Cell[BoxData[
  SuperscriptBox[
   StyleBox["R",
    FontSlant->"Italic"], "2"]], "InlineMath",ExpressionUUID->
  "12eee549-c381-445d-a5ce-980c594d71a3"],
 " value for ",
 Cell[BoxData[
 "linearModel"], "InlineCode",ExpressionUUID->
  "5de4562d-8846-4747-adbe-8d1f7fda5cfa"],
 " using its properties."
}], "Exercise",
 CellChangeTimes->{{3.726229327482026*^9, 3.726229437287052*^9}, {
   3.726842099061895*^9, 3.726842101914075*^9}, {3.72684219942413*^9, 
   3.726842199476267*^9}, {3.7465303105142107`*^9, 3.746530310865211*^9}, {
   3.746530392909211*^9, 3.746530393957211*^9}, {3.747765998234042*^9, 
   3.747766007954041*^9}, 3.7535038730376973`*^9, {3.7535869490372763`*^9, 
   3.7535869818342047`*^9}, {3.7663299975013666`*^9, 
   3.7663300075083666`*^9}, {3.7663301361883664`*^9, 3.7663301364843664`*^9}, 
   3.8160885406207647`*^9},
 CellID->560632314,ExpressionUUID->"900b2cf8-93ff-45ed-887b-872d55dfde14"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tech Notes", "TechNoteSection",
 CellID->805757751,ExpressionUUID->"a2a71bb7-08ce-4793-a0f8-83ee73f78331"],

Cell[TextData[{
 ButtonBox["Delimiter",
  BaseStyle->"Link"],
 " is an option for various functions that specifies what delimiters to use \
or look for.\n",
 ButtonBox["reference.wolfram.com/language/ref/Delimiter.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/language/ref/Delimiter.html"], None},
  ButtonNote->"http://reference.wolfram.com/language/ref/Delimiter.html"]
}], "TechNote",
 CellChangeTimes->{{3.651515120816633*^9, 3.651515125814807*^9}, 
   3.6515155174947033`*^9, 3.777657231474063*^9, 3.7776573075216665`*^9, {
   3.777814174246015*^9, 3.777814178891873*^9}, {3.800790372896389*^9, 
   3.8007903893513603`*^9}},
 CellID->477255672,ExpressionUUID->"41c3b6be-ef39-4e11-bd24-067d8c942837"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 CellID->19888384,ExpressionUUID->"65a82294-ef4e-4181-ae0e-6268d4051bf7"],

Cell[TextData[{
 StyleBox[ButtonBox["The Wolfram|Alpha page on regression analysis provides \
some fun demonstrations for students ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.wolframalpha.com/examples/mathematics/statistics/\
regression-analysis/"], None},
  ButtonNote->
   "https://www.wolframalpha.com/examples/mathematics/statistics/regression-\
analysis/"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/regression-analysis",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/regression-analysis"], None},
  ButtonNote->"https://wolfr.am/regression-analysis"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{{3.800790404666837*^9, 3.8007904070833683`*^9}},
 CellID->26626102,ExpressionUUID->"d3d9342c-54a7-49fa-8f6b-c379f1ed9b8c"],

Cell[TextData[{
 StyleBox[ButtonBox["For a visual proof of Lagrange\[CloseCurlyQuote]s sum of \
squares, try this Wolfram Demonstration by M. Schreiber ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/RepresentationsByASumOfSquares/"], 
    None},
  ButtonNote->
   "http://demonstrations.wolfram.com/RepresentationsByASumOfSquares/"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/SumOfSquares",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/SumOfSquares"], None},
  ButtonNote->"https://wolfr.am/SumOfSquares"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{{3.8007906274234347`*^9, 3.8007906297169476`*^9}},
 CellID->254588533,ExpressionUUID->"ee991bfb-043c-4a7e-82c1-50764a51474a"],

Cell[TextData[{
 StyleBox[ButtonBox["For the advanced, read about using artificial neural \
nets for statistical discovery and clinical trial data in the open access \
journal ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.complex-systems.com/abstracts/v03_i03_a05/"], None},
  ButtonNote->"https://www.complex-systems.com/abstracts/v03_i03_a05/"],
  BaseStyle -> "Hyperlink"],
 StyleBox[ButtonBox["Complex Systems",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.complex-systems.com/abstracts/v03_i03_a05/"], None},
  ButtonNote->"https://www.complex-systems.com/abstracts/v03_i03_a05/"],
  FontSlant->"Italic",
  BaseStyle -> "Hyperlink"],
 StyleBox[ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.complex-systems.com/abstracts/v03_i03_a05/"], None},
  ButtonNote->"https://www.complex-systems.com/abstracts/v03_i03_a05/"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/v03_i03_a05",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/v03_i03_a05"], None},
  ButtonNote->"https://wolfr.am/v03_i03_a05"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{{3.8007930486862926`*^9, 3.8007930534407463`*^9}},
 CellID->1082049307,ExpressionUUID->"e0b4da9c-27d7-4785-a1e4-32ef851c46e1"]
}, Open  ]]
}, Open  ]]
},
Editable->False,
Saveable->False,
WindowSize->{808, 911},
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{"\[ThinSpace]", "\[ThinSpace]", 
          StyleBox[
          "Introduction to Statistics\t\t\t\t\t\nwith the Wolfram Language", 
           LineSpacing -> {1, 1}, FontFamily -> "Source Sans Pro", FontSize -> 
           24, FontColor -> GrayLevel[1]], "\[ThinSpace]"}, 
         "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {65, 75}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"11-Klopper-Correlation.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"11-Klopper-Correlation.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> GrayLevel[0.2], Evaluator -> Automatic, 
                  Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Chapter 11\"", TooltipDelay -> 0.15, 
              LabelStyle -> "TextStyling"], 
             Annotation[#, "Chapter 11", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{
                    "13-Klopper-ComparingCategoricalVariables.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{
                    "13-Klopper-ComparingCategoricalVariables.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  GrayLevel[0.2], Evaluator -> Automatic, Method -> 
                  "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Chapter 13\"", TooltipDelay -> 0.15, 
              LabelStyle -> "TextStyling"], 
             Annotation[#, "Chapter 13", "Tooltip"]& ]}, "RowWithSeparators"],
           Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> GrayLevel[0.2], 
             ImageSize -> {35, 30}, Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> RGBColor[0.12, 0.18, 0.26], 
             ImageSize -> {35, 30}, Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "1 | Introduction" :> 
          NotebookLocate[{"01-Klopper-IntroDataAnalysis.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "2 | Evaluating Basic Math" :> 
          NotebookLocate[{"02-Klopper-BasicMath.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "3 | Collections" :> 
          NotebookLocate[{"03-Klopper-Collections.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "4 | Working with Datasets" :> 
          NotebookLocate[{"04-Klopper-WorkingWithData.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "5 | Data Types" :> 
          NotebookLocate[{"05-Klopper-DataTypes.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "6 | Simple Descriptive Statistics" :> 
          NotebookLocate[{"06-Klopper-DescriptiveStatistics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "7 | Visualizing Data" :> 
          NotebookLocate[{"07-Klopper-VisualizingData.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "8 | Distributions" :> 
          NotebookLocate[{"08-Klopper-Distributions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "9 | Hypothesis Testing" :> 
          NotebookLocate[{"09-Klopper-HypothesisTesting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10 | Parametric Tests, Comparing Means" :> 
          NotebookLocate[{"10-Klopper-ParametricTests.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "11 | Correlation" :> 
          NotebookLocate[{"11-Klopper-Correlation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "12 | Linear Regression" :> 
          NotebookLocate[{"12-Klopper-LinearRegression.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "13 | Comparing Categorical Variables" :> 
          NotebookLocate[{"13-Klopper-ComparingCategoricalVariables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "14 | Nonparametric Tests" :> 
          NotebookLocate[{"14-Klopper-NonparametricTests.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "15 | A Research Project Demonstration" :> 
          NotebookLocate[{"15-Klopper-ResearchProject.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> RGBColor[0.12, 0.18, 0.26], 
   CellMargins -> {{0, 0}, {0, -1}}, CellFrameMargins -> {{27, 0}, {1, 7}}, 
   Background -> RGBColor[0.12, 0.18, 0.26], CellTags -> 
   "DockedCellLogoCell"], 
  Cell["JUAN H. KLOPPER", "Text", FontFamily -> "Source Sans Pro", FontWeight -> 
   "Light", FontSize -> 15, CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> 
   False, CellMargins -> {{0, 0}, {-1, -1}}, 
   CellFrameMargins -> {{27, 0}, {2, 4}}, CellFrameColor -> 
   RGBColor[1., 0.7, 0.1], FontTracking -> "Extended", FontColor -> 
   GrayLevel[1], Background -> RGBColor[0.9, 0.4, 0.], CellTags -> 
   "DockedCellLogoCell"]},
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    Introduction to Statistics with the Wolfram Language", "Header"]}],
     "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], 
   None, None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["  |  Linear Regression", "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 34}, {Inherited, Inherited}}]}},
ShowAutoSpellCheck->False,
FrontEndVersion->"12.2 for Mac OS X x86 (64-bit) (December 12, 2020)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> 
       "Source San Pro", FontSize -> 8, FontWeight -> "Plain", FontSlant -> 
       "Plain", FontColor -> GrayLevel[0.45]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Source San Pro", FontSize -> 
       8, FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth :> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, 
       AutoStyleOptions -> {
        "FormattingErrorTooltips" -> False, "HighlightComments" -> False, 
         "HighlightEmphasizedSyntaxErrors" -> False, 
         "HighlightExcessArguments" -> False, "HighlightFormattingErrors" -> 
         False, "HighlightGlobalToLocalScopeConflicts" -> False, 
         "HighlightGraphicsCompatibilityProblems" -> False, 
         "HighlightLocalScopeConflicts" -> False, "HighlightMissingArguments" -> 
         False, "HighlightNoKernelPresent" -> False, 
         "HighlightOrderOfEvaluationConflicts" -> False, "HighlightStrings" -> 
         True, "HighlightSymbolContexts" -> False, "HighlightSymbolShadowing" -> 
         False, "HighlightSyntaxErrors" -> False, "HighlightUndefinedSymbols" -> 
         False, "HighlightUnknownOptions" -> False, 
         "HighlightUnwantedAssignments" -> False}, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey :> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Open]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey :> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey :> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 64}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["GrayPointSix"], FontColor -> GrayLevel[0.6]], 
         Cell[
          StyleData["GrayPointSix", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, DefaultNewCellStyle -> 
          "ExerciseInput", CounterIncrements -> "Exercise", MenuSortingValue -> 
          10020, MenuCommandKey :> "2", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth :> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, DefaultReturnCreatedCellStyle -> 
          "Answer", CounterIncrements -> "Question", MenuSortingValue -> 
          10030, MenuCommandKey :> "3", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth :> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, ReturnCreatesNewCell -> True, 
          DefaultReturnCreatedCellStyle -> "Question", 
          LineSpacing -> {1.125, 1., 2.}, MenuSortingValue -> 10032, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          ReturnCreatesNewCell -> True, CellFrameLabelMargins -> 3, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 12}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Baskerville", FontSize -> 
          18, FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Italic", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", StripStyleOnPaste -> True, PageBreakWithin -> False, 
          GroupPageBreakWithin -> False, GeneratedCell -> True, 
          CellAutoOverwrite -> True, ShowCellLabel -> False, 
          DefaultFormatType -> DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221]], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, 
          GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, 
          ShowCellLabel -> False, SpanMaxSize -> 1, FontSize -> 14], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Comment"], FontFamily -> "Verdana", FontSize -> 13, 
          FontColor -> RGBColor[0.3, 0.3, 0.2], Background -> 
          RGBColor[1, 0.9, 0.8]], 
         Cell[
          StyleData["Comment", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Suggestion"], 
          CellFrameLabels -> {{Inherited, Inherited}, {Inherited, 
             Cell[
              BoxData[
               TagBox[
                GridBox[{{
                   ButtonBox[
                   "\"  Insert  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`ReplaceWithSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    ContentPadding -> False, Appearance -> Automatic, Method -> 
                    "Queued"], 
                   ButtonBox[
                   "\"  Stet  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; DocuTools`StetSuggestion[]), 
                    Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "    ", 
                   ButtonBox[
                   "\"  Next  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindNextSuggestion[]), Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], 
                   ButtonBox[
                   "\"  Previous  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindPreviousSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "\"\""}}, 
                 AutoDelete -> False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
                "Grid"]], ShowStringCharacters -> False, Background -> 
              None]}}, Background -> RGBColor[1, 0.8, 0.8]], 
         Cell[
          StyleData["Suggestion", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Tentative"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[
             0.30000000000000016`, 0.6000000000000003, 0.7000000000000003], 
            "Thickness" -> 5}, Evaluatable -> False, CellFrameMargins -> 4, 
          StyleMenuListing -> None, Background -> 
          RGBColor[0.8500000000000003, 0.9500000000000003, 1]], 
         Cell[
          StyleData["Tentative", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["WebOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.91, 0.92, 0.9], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.91, 0.92, 0.86]], 
         Cell[
          StyleData["WebOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Lockdown"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.8, 0.5, 0.4], "Thickness" -> 3}, Evaluatable -> 
       False, StyleMenuListing -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["IndexField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["IndexField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExplanationField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["ExplanationField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EnglishHighlight"], FontFamily -> "WolframCodeSans"], 
         Cell[
          StyleData["EnglishHighlight", "Printout"]]}, Open]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth :> Infinity, TextAlignment -> Left, 
       LineSpacing -> {0.6, 1}, AutoQuoteCharacters -> {}, 
       PasteAutoQuoteCharacters -> {}, StyleMenuListing -> None, FontFamily -> 
       "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth :> Infinity, 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Link", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (Function[
             t, NotebookFind[t, "Notes", All, CellStyle]; 
              NotebookFind[
               t, "NotesSection", All, CellStyle, AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Crosslink"], 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               
               NotebookLocate[#2, "OpenInNewWindow" -> 
                CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None,
             Method -> "Queued"}], 
         Cell[
          StyleData["Crosslink", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeLink"], 
          ButtonBoxOptions -> {
           Appearance -> None, ButtonFunction :> (Documentation`HelpLookup[
              Part[#, 1]]& ), ButtonSource -> ButtonContents, Evaluator -> 
            Automatic}], 
         Cell[
          StyleData["CodeLink", "Printout"]]}, Open]], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 0, FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 0, FontFamily -> 
       "Source Sans Pro", FontSize -> Inherited 0.95], 
      Cell[
       StyleData["NoLabel"], 
       GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, ShowCellLabel -> 
       False], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariable"], FontFamily -> "Times", FontSize -> 
          Inherited 1.05, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariable", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariableLrg"], FontFamily -> "Times", FontSize -> 
          Inherited 1.1, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariableLrg", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "WolframCodeSans", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "WolframCodeSans", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {0.5, 3}}, 
               ImageMargins -> {{2, 2}, {1, 1}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Open]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Specialized for Klopper", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9, {3.7114709033696413`*^9, 
         3.711470909048764*^9}, {3.73531219927332*^9, 3.735312227736931*^9}, {
         3.745680245296091*^9, 3.7456802496393538`*^9}, {3.745930022124992*^9,
          3.7459300236362534`*^9}, {3.746546663993486*^9, 
         3.7465466650968523`*^9}}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {2, 32}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> "Italic", 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 14}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], LineSpacing -> {1.3, 1., 2.}, 
          MenuSortingValue -> 10010, MenuCommandKey :> "1", FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"], 
          CellMargins -> {{99, Inherited}, {2, 12}}, StripStyleOnPaste -> 
          True, DefaultFormatType -> DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           LanguageCategory -> "Formula", ScriptLevel -> 0, 
          SingleLetterItalics -> True, MenuSortingValue -> 1700, FontFamily -> 
          "Baskerville", FontSize -> 16, FontWeight -> "Regular", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[0.2], 
          UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}], 
              "DisplayFormulaEquationNumber"]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered", MenuSortingValue -> 
          1710, FontFamily -> "Baskerville", FontSize -> 16, FontWeight -> 
          "Regular", FontSlant -> "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       StyleData["InitializationCell"], Background -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Print"], CellMargins -> {{99, 10}, {4, 4}}, FontSize -> 
          15], 
         Cell[
          StyleData["Print", "Presentation"], 
          CellMargins -> {{100, Inherited}, {1.5 Inherited, 1.5 Inherited}}], 
         Cell[
          StyleData["Print", "SlideShow"], 
          CellMargins -> {{
            0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.01 
             FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {8, 15}}, 
          FontSize -> 18], 
         Cell[
          StyleData["Print", "Condensed"], 
          CellMargins -> {{18, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "Printout"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "PrintoutGray"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            RGBColor[0.8, 0.043, 0.008]], CellMargins -> {{81, 10}, {4, 8}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            GrayLevel[0.2]], 
          CellMargins -> {{80, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemParagraph"], CellMargins -> {{81, 10}, {4, 1}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["ItemParagraph", "Printout"], 
          CellMargins -> {{80, Inherited}, {Inherited, 0.5 Inherited}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemNumbered"], CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontWeight -> "Bold"], 
          CellMargins -> {{85, 10}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "ItemNumbered", 
          CounterAssignments -> {{"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> 1630, FontFamily -> 
          "Source Sans Pro", FontSize -> 15], 
         Cell[
          StyleData["ItemNumbered", "Printout"], 
          CellMargins -> {{90, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteItem"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontSize -> 12, FontWeight -> 
            Bold, FontColor -> GrayLevel[0.25]], 
          CellMargins -> {{93, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, CellFrameLabelMargins -> 4, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          CounterIncrements -> "ItemNumbered", MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNoteItem", "Printout"], 
          CellMargins -> {{93, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Epigraph"], CellMargins -> {{100, 78}, {6, 24}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, TextAlignment -> Left, Hyphenation -> 
          True, HyphenationOptions -> {"HyphenationMinLengths" -> {3, 5}}, 
          LineSpacing -> {1, 2}, TabSpacings -> {1.2, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontWeight -> "Plain", FontSlant -> 
          "Plain"], 
         Cell[
          StyleData["Epigraph", "Printout", StyleDefinitions -> None]]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EpigraphAuthor"], CellMargins -> {{125, 100}, {12, 12}}, 
          TextAlignment -> Left, LineSpacing -> {1, 2}, 
          ParagraphIndent -> -17, TabSpacings -> {1.5, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontTracking -> -0.05], 
         Cell[
          StyleData["EpigraphAuthor", "Printout", StyleDefinitions -> None]]},
         Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ReferenceSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ReferenceSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Reference"], CellDingbat -> Cell[
            TextData[{
              CounterBox["Reference"]}], "SR", FontSize -> 13, 
            CellSize -> {30, Inherited}, TextAlignment -> Right], 
          CellMargins -> {{80, 10}, {3, 4}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, 
          CellChangeTimes -> {{3.7385995432110577`*^9, 3.738599549834622*^9}},
           LineSpacing -> {1, 2}, ParagraphIndent -> -8, 
          TabSpacings -> {0.7, 2.5}, CounterIncrements -> "Reference", 
          MenuSortingValue -> 1870, FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["Reference", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{66, 10}, {3, 4}}, TabSpacings -> {1.2, 2.5}]}, 
        Open]]}, Closed]]}, Visible -> False, FrontEndVersion -> 
  "12.2 for Mac OS X x86 (64-bit) (December 12, 2020)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"e0f53abf-bb03-4c09-95ad-ebd9586e16dd"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "C:12"->{
  Cell[580, 22, 558, 12, 113, "Section",ExpressionUUID->"9efbf9d7-0dc9-4f5d-bf16-aafac152024b",
   CounterAssignments->{{"Section", 11}, {"Subsection", 11}, {"Subsubsection", 11}, {"Exercise", 11}},
   CellTags->"C:12",
   CellID->868451339]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"C:12", 301114, 6672}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 558, 12, 113, "Section",ExpressionUUID->"9efbf9d7-0dc9-4f5d-bf16-aafac152024b",
 CounterAssignments->{{"Section", 11}, {"Subsection", 11}, {"Subsubsection", 11}, {"Exercise", 11}},
 CellTags->"C:12",
 CellID->868451339],
Cell[1141, 36, 766, 16, 88, "Text",ExpressionUUID->"42a7cd27-7536-467d-b918-d0f4dd2e1b75",
 CellID->477014819],
Cell[1910, 54, 520, 8, 113, "Text",ExpressionUUID->"003f658a-7a5b-4825-8bf2-7dc7f0a5492a",
 CellID->210260908],
Cell[2433, 64, 376, 7, 38, "Text",ExpressionUUID->"76b1d43a-f246-4b02-bf7d-4108f2e50b7b",
 CellID->328828069],
Cell[2812, 73, 428, 12, 34, "DisplayFormulaNumbered",ExpressionUUID->"7592531c-5596-4594-adcb-37e5e4ef693b",
 CellID->774087943],
Cell[3243, 87, 1615, 39, 94, "Text",ExpressionUUID->"7da03f94-b6d8-425b-a241-a6365f6732d0",
 CellID->254026257],
Cell[4861, 128, 2127, 60, 121, "Text",ExpressionUUID->"fbd92688-de46-4163-a410-b628477e049b",
 CellID->350556872],
Cell[6991, 190, 735, 13, 37, "CodeCaption",ExpressionUUID->"f70a77d7-c42a-42f6-b396-fed90c5eb110",
 CellID->121526939],
Cell[CellGroupData[{
Cell[7751, 207, 586, 18, 50, "Input",ExpressionUUID->"7089f44e-9c2c-45a4-a3eb-3a23c25a97cb",
 CellID->489446090],
Cell[8340, 227, 5830, 131, 323, "Output",ExpressionUUID->"b286ea6c-4d11-444e-839f-8c9a13e955f0",
 CellID->528293010]
}, Open  ]],
Cell[14185, 361, 2078, 49, 123, "Text",ExpressionUUID->"3a9e471d-458f-452b-9bdb-41abc519d7f2",
 CellID->1969182359],
Cell[16266, 412, 874, 25, 65, "Text",ExpressionUUID->"a4818449-f5ac-44df-8fc7-c3390c6534fb",
 CellID->105609684],
Cell[17143, 439, 609, 10, 113, "Text",ExpressionUUID->"a7bb4433-9088-4e61-88c8-ed719a00c733",
 CellID->365430473],
Cell[17755, 451, 511, 15, 34, "DisplayFormulaNumbered",ExpressionUUID->"976ef2c1-aa3a-460f-9848-dd5d070f7da1",
 CellID->2146816857]
}, Open  ]],
Cell[CellGroupData[{
Cell[18303, 471, 255, 3, 57, "Subsection",ExpressionUUID->"bb26fa75-76e0-46ff-b995-21723ab6696d",
 CellID->123957802],
Cell[18561, 476, 519, 9, 88, "Text",ExpressionUUID->"fb935305-2755-457e-bc48-5d3c7a3168ae",
 CellID->372258150],
Cell[19083, 487, 568, 10, 113, "Text",ExpressionUUID->"ab8b95f2-1c73-41ec-8246-4a8a84e9c0f2",
 CellID->129569525],
Cell[19654, 499, 1049, 27, 140, "Text",ExpressionUUID->"d22bdaa7-d645-42cd-bbea-799e9faf3829",
 CellID->95670558],
Cell[20706, 528, 539, 15, 80, "DisplayFormulaNumbered",ExpressionUUID->"3525970f-66a8-4336-9231-a178f3764345",
 CellID->438405120],
Cell[21248, 545, 1014, 22, 66, "CodeCaption",ExpressionUUID->"6ad0798b-e523-434e-93e7-cc9054726682",
 CellID->751527036],
Cell[CellGroupData[{
Cell[22287, 571, 1052, 31, 54, "Input",ExpressionUUID->"5ce92946-8b60-4864-ba6b-aa13c2860bd6",
 CellID->16031443],
Cell[23342, 604, 8437, 175, 180, "Output",ExpressionUUID->"20d150d3-c507-4f21-8503-9ddbda6740a6",
 CellID->1315156991]
}, Open  ]],
Cell[31794, 782, 663, 16, 65, "Text",ExpressionUUID->"6e2bc18b-eeb6-4eed-88c0-9762f4040791",
 CellID->58404393],
Cell[32460, 800, 867, 20, 138, "Text",ExpressionUUID->"2a1ef63b-9e74-4fa6-8955-49a9666e32ba",
 CellID->304492099],
Cell[33330, 822, 405, 7, 88, "Text",ExpressionUUID->"d924658b-5b52-43c7-97ae-2fb6ec03815b",
 CellID->37962401],
Cell[33738, 831, 502, 9, 88, "Text",ExpressionUUID->"6c9ae341-cfbc-497c-b6a0-68b762009430",
 CellID->131348915],
Cell[34243, 842, 936, 18, 138, "Text",ExpressionUUID->"06462e0c-1551-4c31-8de5-39e8abf8a280",
 CellID->809633173],
Cell[35182, 862, 869, 14, 37, "CodeCaption",ExpressionUUID->"bd82bdbc-b6d9-45cf-94fa-b737e4b15825",
 CellID->482539679],
Cell[36054, 878, 855, 26, 54, "Input",ExpressionUUID->"3299cc7f-1576-4800-be9e-b20b597feff8",
 CellID->335801573],
Cell[36912, 906, 657, 8, 37, "CodeCaption",ExpressionUUID->"2e1ff906-504c-4c56-8e29-a5c5c1af61b7",
 CellID->186498751],
Cell[CellGroupData[{
Cell[37594, 918, 444, 11, 29, "Input",ExpressionUUID->"fc463ee1-6ead-42f0-b18d-4f14415504e5",
 CellID->66683801],
Cell[38041, 931, 1401, 38, 176, "Output",ExpressionUUID->"2bfc7c7e-9d30-4513-b5c7-51afd3a90ec8",
 CellID->1941852813]
}, Open  ]],
Cell[39457, 972, 1236, 24, 64, "Text",ExpressionUUID->"a563e677-8ab2-4303-866c-2351cf84265b",
 CellID->183259585],
Cell[40696, 998, 728, 9, 37, "CodeCaption",ExpressionUUID->"a796cc93-41ce-4d0d-a26c-c5e2efd63611",
 CellID->764674018],
Cell[CellGroupData[{
Cell[41449, 1011, 235, 5, 29, "Input",ExpressionUUID->"b9d1f252-3b24-43c5-a0ee-8d58f9f7559a",
 CellID->575761922],
Cell[41687, 1018, 1083, 28, 49, "Output",ExpressionUUID->"3d640bd9-03a1-41bc-a4a4-d981f161cb49",
 CellID->1411244632]
}, Open  ]],
Cell[42785, 1049, 286, 6, 38, "Text",ExpressionUUID->"bf269a07-58bf-420a-89d2-e7fd69ce307b",
 CellID->340573988],
Cell[43074, 1057, 638, 8, 37, "CodeCaption",ExpressionUUID->"eff2f88b-76b9-45ba-8b16-af4c044cfca8",
 CellID->746837725],
Cell[CellGroupData[{
Cell[43737, 1069, 179, 3, 29, "Input",ExpressionUUID->"562258b7-3446-44c8-b3e6-9304ce307b44",
 CellID->153790460],
Cell[43919, 1074, 2736, 46, 449, "Output",ExpressionUUID->"e73b420b-e6f3-45dd-8403-d562dae6e766",
 CellID->1979132556]
}, Open  ]],
Cell[46670, 1123, 1505, 24, 90, "Text",ExpressionUUID->"8ca73f93-4fb0-42d9-9723-768287b91750",
 CellID->5021495],
Cell[48178, 1149, 1190, 19, 39, "CodeCaption",ExpressionUUID->"92d2453a-227a-428e-9210-6caac5c2e384",
 CellID->767228924],
Cell[CellGroupData[{
Cell[49393, 1172, 183, 3, 29, "Input",ExpressionUUID->"6fa894de-9c7d-465a-b5dd-5ccea7df94e2",
 CellID->349877746],
Cell[49579, 1177, 1033, 23, 69, "Output",ExpressionUUID->"e3ee1065-c9a5-4b38-aa8c-4f029082fd20",
 CellID->1940022519]
}, Open  ]],
Cell[50627, 1203, 1210, 27, 91, "Text",ExpressionUUID->"88528118-8fc6-4eb8-ac59-8409277c3610",
 CellID->275657595],
Cell[51840, 1232, 696, 9, 37, "CodeCaption",ExpressionUUID->"da38ca9a-bbc8-4688-a9a6-a354ec3e28f0",
 CellID->210639227],
Cell[CellGroupData[{
Cell[52561, 1245, 619, 17, 29, "Input",ExpressionUUID->"4bd90a96-175e-47c5-a05d-72366b6bfcfa",
 CellID->78827591],
Cell[53183, 1264, 3355, 73, 176, "Output",ExpressionUUID->"b7448d36-a114-44c2-8cdd-9952f1d8d890",
 CellID->2072380931]
}, Open  ]],
Cell[56553, 1340, 1442, 28, 170, "Text",ExpressionUUID->"b01bb1f6-fae1-4e6a-9c0e-395ab6de3337",
 CellID->190667454],
Cell[57998, 1370, 561, 12, 63, "Text",ExpressionUUID->"bb76ea94-03d5-485e-ad22-f2a15cfe723c",
 CellID->169435173],
Cell[58562, 1384, 696, 10, 37, "CodeCaption",ExpressionUUID->"ce50d8b1-ed8a-4c29-8775-9f27020ce98d",
 CellID->25522701],
Cell[CellGroupData[{
Cell[59283, 1398, 180, 3, 29, "Input",ExpressionUUID->"a9972a45-e084-427b-b461-c148c11809bb",
 CellID->10643873],
Cell[59466, 1403, 645, 13, 65, "Output",ExpressionUUID->"be31c5fd-7116-4640-a487-47be3d212aa4",
 CellID->469036624]
}, Open  ]],
Cell[60126, 1419, 279, 5, 63, "Text",ExpressionUUID->"84e5fa26-a8fa-4d54-83a4-a619bbb474c9",
 CellID->182775425],
Cell[60408, 1426, 619, 8, 37, "CodeCaption",ExpressionUUID->"eefa2b3d-8efe-4c04-b526-c180fb690b56",
 CellID->327813223],
Cell[CellGroupData[{
Cell[61052, 1438, 279, 6, 29, "Input",ExpressionUUID->"eb4a3fea-62d2-4448-ab32-4559e7aaecf8",
 CellID->82682811],
Cell[61334, 1446, 2008, 48, 159, "Output",ExpressionUUID->"d03801de-feb3-4e15-98a0-2f50537aca87",
 CellID->1179214309]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[63391, 1500, 308, 4, 57, "Subsection",ExpressionUUID->"66a94133-0792-4923-8ec0-d70101b475db",
 CellID->378113321],
Cell[63702, 1506, 908, 18, 138, "Text",ExpressionUUID->"55255aaf-39c9-4666-991e-fc450803c2b8",
 CellID->403958779],
Cell[64613, 1526, 669, 10, 37, "CodeCaption",ExpressionUUID->"41062a33-52a6-4f4c-8864-dcb04bd7d200",
 CellID->225021055],
Cell[65285, 1538, 1535, 47, 54, "Input",ExpressionUUID->"74174c10-bfc9-4e9c-9f08-268d305d4d92",
 CellID->35706567],
Cell[66823, 1587, 201, 2, 38, "Text",ExpressionUUID->"e60a5449-c8bf-4d59-8203-efc4a6053d72",
 CellID->439796814],
Cell[67027, 1591, 638, 8, 37, "CodeCaption",ExpressionUUID->"6eb60c20-ab06-4a3d-a819-fccbb9a24eaf",
 CellID->140308752],
Cell[CellGroupData[{
Cell[67690, 1603, 448, 11, 29, "Input",ExpressionUUID->"b453c6b6-a516-453e-a402-6f16dd181da0",
 CellID->22597667],
Cell[68141, 1616, 1433, 40, 180, "Output",ExpressionUUID->"58637a53-9171-44d7-93f4-ab3fad5d61bb",
 CellID->2075796847]
}, Open  ]],
Cell[69589, 1659, 398, 9, 38, "Text",ExpressionUUID->"87274e67-1098-4c26-9a39-b0bd4188467e",
 CellID->249203623],
Cell[69990, 1670, 622, 8, 37, "CodeCaption",ExpressionUUID->"301c6a43-5c4e-4619-8c8d-8cb7f068ae95",
 CellID->8054230],
Cell[CellGroupData[{
Cell[70637, 1682, 242, 5, 29, "Input",ExpressionUUID->"4b39beca-6082-4850-b04f-31497ff7bdd9",
 CellID->626729576],
Cell[70882, 1689, 1177, 31, 49, "Output",ExpressionUUID->"c262c3b0-2cd6-4b04-a62c-bd8dcff78b69",
 CellID->2045762014]
}, Open  ]],
Cell[72074, 1723, 615, 8, 37, "CodeCaption",ExpressionUUID->"ccd86ec4-4e74-4963-8858-da3b927a63a1",
 CellID->115183275],
Cell[CellGroupData[{
Cell[72714, 1735, 386, 10, 29, "Input",ExpressionUUID->"4e2369e9-22af-4e59-a5e4-88ba3b4b8588",
 CellID->434121749],
Cell[73103, 1747, 3295, 72, 180, "Output",ExpressionUUID->"caf7880e-dcf2-47c3-9a78-1665d708c1b7",
 CellID->1291787548]
}, Open  ]],
Cell[76413, 1822, 267, 3, 38, "Text",ExpressionUUID->"8375ef3e-fdad-4e13-9881-8560acd8fcf5",
 CellID->92389390],
Cell[76683, 1827, 617, 8, 37, "CodeCaption",ExpressionUUID->"b92421e1-cddc-43d9-9cf5-c253deff3849",
 CellID->627371110],
Cell[CellGroupData[{
Cell[77325, 1839, 351, 7, 29, "Input",ExpressionUUID->"1927e8aa-26c2-4a68-aad8-aad79eba4044",
 CellID->331605132],
Cell[77679, 1848, 2404, 55, 164, "Output",ExpressionUUID->"6423244b-f7f5-4ee3-95c5-25b682a00608",
 CellID->13648066]
}, Open  ]],
Cell[80098, 1906, 960, 24, 114, "Text",ExpressionUUID->"72699dc3-c372-406c-89d3-431b3851d7d3",
 CellID->253370098],
Cell[81061, 1932, 881, 16, 37, "CodeCaption",ExpressionUUID->"2746bf3e-e532-4865-882e-56f0d5ac9fa5",
 CellID->381760457],
Cell[CellGroupData[{
Cell[81967, 1952, 180, 3, 29, "Input",ExpressionUUID->"504e80d1-691a-4d9f-93fb-92f7a9542061",
 CellID->55688303],
Cell[82150, 1957, 240, 4, 40, "Output",ExpressionUUID->"b4977b61-40f7-48fd-aaa4-e2b86fb64e39",
 CellID->1749778680]
}, Open  ]],
Cell[82405, 1964, 813, 15, 37, "CodeCaption",ExpressionUUID->"570b10d6-080a-4401-a94f-cf259d85e342",
 CellID->162297051],
Cell[CellGroupData[{
Cell[83243, 1983, 178, 3, 29, "Input",ExpressionUUID->"7b34fb5a-7f79-46e1-a32c-01c82f44c9ed",
 CellID->115188634],
Cell[83424, 1988, 232, 4, 40, "Output",ExpressionUUID->"fe68bba4-1bcb-46ca-9e31-f6dd3eb0b828",
 CellID->58067908]
}, Open  ]],
Cell[83671, 1995, 615, 16, 64, "Text",ExpressionUUID->"c9c38012-cf41-4c15-86bd-135628e5ecc4",
 CellID->299061696],
Cell[84289, 2013, 1120, 21, 189, "Text",ExpressionUUID->"7a53626f-64fb-4f49-b7cd-a63a96791b4f",
 CellID->196980976],
Cell[85412, 2036, 481, 11, 63, "Text",ExpressionUUID->"e54d11ee-1187-4611-9702-dd02949d12a1",
 CellID->355444164],
Cell[85896, 2049, 630, 8, 37, "CodeCaption",ExpressionUUID->"c74198a7-741d-476c-aef4-155c52615455",
 CellID->24244953],
Cell[CellGroupData[{
Cell[86551, 2061, 253, 5, 29, "Input",ExpressionUUID->"bf25b2f6-f086-4f5a-8b0e-f3ca4388f503",
 CellID->33078522],
Cell[86807, 2068, 369, 8, 40, "Output",ExpressionUUID->"c4867f57-7f1d-4847-a528-f4f4b939c5a9",
 CellID->989754018]
}, Open  ]],
Cell[87191, 2079, 466, 12, 63, "Text",ExpressionUUID->"4390106e-de37-4d1a-b3af-4e186d41676a",
 CellID->20519494],
Cell[87660, 2093, 638, 8, 37, "CodeCaption",ExpressionUUID->"5806de94-75b3-4ae2-8bf1-38b799e1dd29",
 CellID->316931834],
Cell[CellGroupData[{
Cell[88323, 2105, 199, 4, 29, "Input",ExpressionUUID->"df151fee-476a-4ba1-a0da-f6a89195aa16",
 CellID->117702483],
Cell[88525, 2111, 236, 4, 40, "Output",ExpressionUUID->"d61d9d75-1b78-4742-9984-579a44a8122e",
 CellID->1991713774]
}, Open  ]],
Cell[88776, 2118, 1711, 41, 214, "Text",ExpressionUUID->"4ca72f50-164d-4e8b-9696-b3a79150790f",
 CellID->94158951],
Cell[90490, 2161, 636, 8, 37, "CodeCaption",ExpressionUUID->"3c795bc0-4d0a-45ac-8c23-f13380409e5e",
 CellID->27511919],
Cell[CellGroupData[{
Cell[91151, 2173, 561, 16, 54, "Input",ExpressionUUID->"2bddb696-8016-42e6-aae2-550debcc3199",
 CellID->95936322],
Cell[91715, 2191, 225, 4, 40, "Output",ExpressionUUID->"c47d8045-cd0f-4ce0-b7b2-281993f9c933",
 CellID->1905793829]
}, Open  ]],
Cell[91955, 2198, 807, 18, 113, "Text",ExpressionUUID->"d2f58b40-cd42-4cbd-aa8f-07c095c679a1",
 CellID->159338362],
Cell[92765, 2218, 466, 10, 37, "CodeCaption",ExpressionUUID->"11f66712-18b8-4125-a1a6-9576800d673c",
 CellID->1134388968],
Cell[CellGroupData[{
Cell[93256, 2232, 364, 9, 29, "Input",ExpressionUUID->"36244a35-5bd3-4d35-9258-55b47579500c",
 CellID->166742431],
Cell[93623, 2243, 226, 4, 40, "Output",ExpressionUUID->"413bc5ed-534b-4bfa-9da3-baf1c9dbe8e8",
 CellID->192727105]
}, Open  ]],
Cell[93864, 2250, 1217, 29, 140, "Text",ExpressionUUID->"ae9cb619-2ffc-44d6-a1fc-e28185e0c935",
 CellID->432340437],
Cell[95084, 2281, 651, 8, 37, "CodeCaption",ExpressionUUID->"76948662-6a4b-4a02-8273-251111c10159",
 CellID->822406541],
Cell[CellGroupData[{
Cell[95760, 2293, 328, 6, 29, "Input",ExpressionUUID->"773b13e1-c4d5-4203-bf92-15833f8b9ee8",
 CellID->321561374],
Cell[96091, 2301, 648, 13, 65, "Output",ExpressionUUID->"9ab804ef-08ce-4f7e-91f6-5b8f448bc736",
 CellID->759114059]
}, Open  ]],
Cell[96754, 2317, 672, 15, 88, "Text",ExpressionUUID->"8725b740-d7ce-48ed-9150-aa4f03ed1550",
 CellID->394175513],
Cell[97429, 2334, 675, 8, 37, "CodeCaption",ExpressionUUID->"ef4571c7-9fac-45f3-b781-5b1091841586",
 CellID->920033576],
Cell[CellGroupData[{
Cell[98129, 2346, 300, 6, 29, "Input",ExpressionUUID->"f08d48b6-de54-4225-bbb7-00e779fa2246",
 CellID->457957315],
Cell[98432, 2354, 238, 4, 40, "Output",ExpressionUUID->"15ec1dcd-8de4-4899-842e-9a6aa2e62e10",
 CellID->1479302636]
}, Open  ]],
Cell[98685, 2361, 716, 14, 114, "Text",ExpressionUUID->"b148a0c8-2743-4d8a-998c-17873a6759d8",
 CellID->733067274],
Cell[99404, 2377, 816, 16, 37, "CodeCaption",ExpressionUUID->"a3eaec10-2e7c-45da-8aaa-b643af8e3214",
 CellID->72707663],
Cell[CellGroupData[{
Cell[100245, 2397, 310, 7, 54, "Input",ExpressionUUID->"f3dca617-c744-4a78-804e-1722e47371dc",
 CellID->231977743],
Cell[100558, 2406, 236, 4, 40, "Output",ExpressionUUID->"2a248d4f-dd80-40be-9850-2172094a8473",
 CellID->1221221933]
}, Open  ]],
Cell[100809, 2413, 606, 12, 114, "Text",ExpressionUUID->"86b30a96-6595-47a5-9f24-79b6fdebf308",
 CellID->549739797],
Cell[101418, 2427, 271, 5, 63, "Text",ExpressionUUID->"454b927f-1186-447d-a7dd-97d2317b2582",
 CellID->27290344],
Cell[101692, 2434, 715, 13, 90, "Text",ExpressionUUID->"e263f658-bfcb-448e-aed5-733d38d52e4f",
 CellID->425786575],
Cell[102410, 2449, 476, 13, 61, "DisplayFormulaNumbered",ExpressionUUID->"440ed62c-0b5e-4b8c-9069-429ad8e25d78",
 CellID->1675270599],
Cell[102889, 2464, 566, 13, 64, "Text",ExpressionUUID->"fcacda89-c38d-4fc6-9645-ca96359dd2aa",
 CellID->287431049],
Cell[103458, 2479, 887, 17, 37, "CodeCaption",ExpressionUUID->"6a8472f1-8291-4d91-b72f-dec9e7879ce0",
 CellID->9685744],
Cell[CellGroupData[{
Cell[104370, 2500, 366, 11, 53, "Input",ExpressionUUID->"06b22f08-3045-4b08-b9f9-60a6f520866b",
 CellID->109753015],
Cell[104739, 2513, 239, 4, 40, "Output",ExpressionUUID->"f2a9bf9a-6f1d-4f37-b801-84c27eef2cce",
 CellID->1456551714]
}, Open  ]],
Cell[104993, 2520, 987, 20, 140, "Text",ExpressionUUID->"161934aa-c337-4f33-b771-a1897d872b98",
 CellID->512077095],
Cell[105983, 2542, 845, 19, 65, "Text",ExpressionUUID->"6dd96978-1159-4bc7-af04-997f444d32d0",
 CellID->227682970],
Cell[106831, 2563, 437, 11, 37, "CodeCaption",ExpressionUUID->"1202bfa9-b4fe-4c7f-a3c9-c5bf7734b288",
 CellID->19220559],
Cell[CellGroupData[{
Cell[107293, 2578, 681, 15, 29, "Input",ExpressionUUID->"1b7bc9c9-df80-433d-bd6a-c057b5bc58dc",
 CellID->30188552],
Cell[107977, 2595, 242, 4, 40, "Output",ExpressionUUID->"03c0378b-19a8-4ed6-80c1-82dae3d18ad8",
 CellID->1098565045]
}, Open  ]],
Cell[108234, 2602, 379, 9, 40, "Text",ExpressionUUID->"d7e3e4de-41da-4dce-af82-5aa8f71bea47",
 CellID->1007354765],
Cell[108616, 2613, 730, 15, 90, "Text",ExpressionUUID->"ad8a7f4b-c572-4bfb-b644-a11a85799da3",
 CellID->116876853],
Cell[109349, 2630, 361, 9, 37, "CodeCaption",ExpressionUUID->"936373c1-9588-4b1c-ac43-c9f41b3c1b32",
 CellID->509844772],
Cell[CellGroupData[{
Cell[109735, 2643, 1039, 26, 54, "Input",ExpressionUUID->"97413c44-ac8e-41f0-a9eb-22a07cfc16c6",
 CellID->9210788],
Cell[110777, 2671, 10482, 193, 162, "Output",ExpressionUUID->"9ca5e915-2fdf-414e-b779-852564f806fe",
 CellID->819655764]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[121308, 2870, 230, 3, 57, "Subsection",ExpressionUUID->"ea101c4e-b498-4a38-908d-3246e548d495",
 CellID->486921423],
Cell[121541, 2875, 583, 10, 138, "Text",ExpressionUUID->"73e9ff46-f988-4613-b25d-ca8c9d97d6de",
 CellID->268387195],
Cell[122127, 2887, 573, 12, 88, "Text",ExpressionUUID->"7fdde9c5-5506-4c46-b2f8-3ad40a6e0126",
 CellID->144308778],
Cell[122703, 2901, 622, 8, 37, "CodeCaption",ExpressionUUID->"72d12ae2-7189-46e8-8168-696ed2b754b6",
 CellID->723830614],
Cell[CellGroupData[{
Cell[123350, 2913, 199, 3, 29, "Input",ExpressionUUID->"cf105bfd-e805-4881-a1b0-cd560a571d99",
 CellID->318269249],
Cell[123552, 2918, 878, 26, 40, "Output",ExpressionUUID->"62e76f93-bef4-4433-b2bc-854329dcd4cb",
 CellID->1994313690]
}, Open  ]],
Cell[124445, 2947, 602, 15, 63, "Text",ExpressionUUID->"22dbd6eb-eafc-4d0d-a878-38e19b7b2cdf",
 CellID->46323786],
Cell[125050, 2964, 626, 8, 37, "CodeCaption",ExpressionUUID->"1c1a353d-03f6-4bb8-953c-7a65cbe76e98",
 CellID->445033500],
Cell[125679, 2974, 862, 26, 54, "Input",ExpressionUUID->"c8613fc4-3e5d-4c03-b793-93bcd62995b6",
 CellID->99837753],
Cell[126544, 3002, 358, 9, 38, "Text",ExpressionUUID->"83ce6b13-4ac1-446c-8aea-664503ad4383",
 CellID->37484792],
Cell[126905, 3013, 626, 8, 37, "CodeCaption",ExpressionUUID->"4f010e84-94ae-4a16-be7c-56386b15fabd",
 CellID->194815872],
Cell[CellGroupData[{
Cell[127556, 3025, 250, 5, 29, "Input",ExpressionUUID->"488607d7-0ee5-4e8d-8b64-e13dc23c5f02",
 CellID->742500592],
Cell[127809, 3032, 1078, 28, 49, "Output",ExpressionUUID->"f0470589-616b-491b-a35b-6fe6d7239729",
 CellID->32729681]
}, Open  ]],
Cell[128902, 3063, 346, 7, 63, "Text",ExpressionUUID->"f0e6ddbd-b214-45cb-936c-1078d914a7eb",
 CellID->511049931],
Cell[129251, 3072, 640, 8, 37, "CodeCaption",ExpressionUUID->"8b0b311e-eabb-4a3e-b7fe-3585b8bd345d",
 CellID->208820815],
Cell[CellGroupData[{
Cell[129916, 3084, 1164, 31, 102, "Input",ExpressionUUID->"d11dcd1f-3884-4b95-aae6-6bc227834449",
 CellID->443163234],
Cell[131083, 3117, 7740, 163, 176, "Output",ExpressionUUID->"74c563c5-1b09-40e5-bef3-b7e44b5fffdf",
 CellID->337897226]
}, Open  ]],
Cell[138838, 3283, 233, 4, 38, "Text",ExpressionUUID->"6d45bf3e-6f91-43eb-a1c4-4de12de422af",
 CellID->110488516],
Cell[139074, 3289, 623, 8, 37, "CodeCaption",ExpressionUUID->"8f51486f-b176-4dc5-bdb4-6521f3c72c86",
 CellID->81021178],
Cell[CellGroupData[{
Cell[139722, 3301, 189, 3, 29, "Input",ExpressionUUID->"6c7948c7-0749-4658-a2a8-dbe22979325a",
 CellID->939343010],
Cell[139914, 3306, 644, 14, 65, "Output",ExpressionUUID->"5eac35a5-dd7a-4d5f-bcea-5da929b24154",
 CellID->1091914714]
}, Open  ]],
Cell[140573, 3323, 464, 8, 88, "Text",ExpressionUUID->"460cafad-24e4-4810-9e0d-885ae3ee5370",
 CellID->558091818],
Cell[141040, 3333, 640, 8, 37, "CodeCaption",ExpressionUUID->"9f275829-d860-46ff-bfb9-07f43fa9661c",
 CellID->151261206],
Cell[CellGroupData[{
Cell[141705, 3345, 172, 3, 29, "Input",ExpressionUUID->"39c621ae-7109-4fc8-8d6f-f0bac2253953",
 CellID->190199310],
Cell[141880, 3350, 236, 4, 40, "Output",ExpressionUUID->"e313a907-0d0a-426c-bc1c-48df5d8411b0",
 CellID->1503909242]
}, Open  ]],
Cell[142131, 3357, 245, 5, 63, "Text",ExpressionUUID->"910e01f8-34e6-4fa2-a07d-b2dba2a0ef05",
 CellID->351751944],
Cell[142379, 3364, 632, 8, 37, "CodeCaption",ExpressionUUID->"951c5cf5-b700-4556-943a-a829ea0e79cd",
 CellID->663306639],
Cell[CellGroupData[{
Cell[143036, 3376, 156, 3, 29, "Input",ExpressionUUID->"dcb8887c-817a-47e6-b41a-8e2c2e920337",
 CellID->260421157],
Cell[143195, 3381, 242, 5, 40, "Output",ExpressionUUID->"d2714906-bf38-4af3-a299-e2d8397954ee",
 CellID->320105104]
}, Open  ]],
Cell[143452, 3389, 789, 14, 138, "Text",ExpressionUUID->"2b908312-aa31-484d-818e-92819a5f8f21",
 CellID->117499423],
Cell[144244, 3405, 634, 8, 37, "CodeCaption",ExpressionUUID->"c5b5486c-b2d8-4cc5-8de2-00a82009522c",
 CellID->42162518],
Cell[CellGroupData[{
Cell[144903, 3417, 201, 4, 29, "Input",ExpressionUUID->"391362eb-1e45-4699-9b92-c72083be60e9",
 CellID->659306264],
Cell[145107, 3423, 649, 14, 65, "Output",ExpressionUUID->"ebcef8da-fa1e-49d3-ba7e-0feb98522afc",
 CellID->524403952]
}, Open  ]],
Cell[145771, 3440, 175, 2, 38, "Text",ExpressionUUID->"501c44a2-f90b-43a7-b1eb-53e9c32d3c3c",
 CellID->50135691],
Cell[145949, 3444, 659, 8, 37, "CodeCaption",ExpressionUUID->"45d656b0-8faf-4a90-8acf-348de14999f2",
 CellID->54167954],
Cell[CellGroupData[{
Cell[146633, 3456, 350, 8, 54, "Input",ExpressionUUID->"991ed19f-d8f2-4fb4-80e7-b959b88e23e9",
 CellID->283344401],
Cell[146986, 3466, 2046, 49, 164, "Output",ExpressionUUID->"e630bd2f-f390-45ed-8e4b-15398626f317",
 CellID->1707386492]
}, Open  ]],
Cell[149047, 3518, 1257, 29, 141, "Text",ExpressionUUID->"814ddae1-1f0a-4181-8cde-762aa44388a5",
 CellID->334053806],
Cell[150307, 3549, 247, 6, 66, "CodeCaption",ExpressionUUID->"ed289338-9c9f-42c8-a8a1-b2f2a19006a4",
 CellID->553642112],
Cell[CellGroupData[{
Cell[150579, 3559, 340, 8, 29, "Input",ExpressionUUID->"8ab63f8e-b966-4660-9538-e5f1b299d773",
 CellID->166307994],
Cell[150922, 3569, 285, 4, 40, "Output",ExpressionUUID->"0f6d8081-5ca9-433c-a1c5-f3905452a90d",
 CellID->1368279830]
}, Open  ]],
Cell[151222, 3576, 321, 6, 63, "Text",ExpressionUUID->"e789512c-7560-4851-9912-0477ba794bd6",
 CellID->468343211],
Cell[CellGroupData[{
Cell[151568, 3586, 432, 10, 32, "ItemNumbered",ExpressionUUID->"6490126e-65a0-4dfd-83c4-01e961e02276",
 CellID->686236266],
Cell[152003, 3598, 584, 14, 32, "ItemNumbered",ExpressionUUID->"31ffc64f-6850-42bb-a172-1ca4eb4c3c18",
 CellID->47074909],
Cell[152590, 3614, 449, 10, 32, "ItemNumbered",ExpressionUUID->"fadd970d-c7c3-42d0-b5b3-c9706ee5b29d",
 CellID->585609119]
}, Open  ]],
Cell[153054, 3627, 296, 5, 37, "CodeCaption",ExpressionUUID->"88afd701-2baa-4766-ab64-aa94144bdb54",
 CellID->654441110],
Cell[CellGroupData[{
Cell[153375, 3636, 474, 12, 29, "Input",ExpressionUUID->"159eae33-3e8a-453c-ad47-598d3340d402",
 CellID->22500944],
Cell[153852, 3650, 20991, 365, 178, "Output",ExpressionUUID->"51566b8e-3561-4610-8745-783a294287b5",
 CellID->77078645]
}, Open  ]],
Cell[174858, 4018, 579, 13, 64, "Text",ExpressionUUID->"298291b4-64ac-4013-990f-ec4c5d393d24",
 CellID->48644513],
Cell[175440, 4033, 998, 18, 37, "CodeCaption",ExpressionUUID->"ad8d5f60-af73-43bc-8839-29ad68d0a413",
 CellID->671652695],
Cell[CellGroupData[{
Cell[176463, 4055, 524, 13, 29, "Input",ExpressionUUID->"fe011e19-665e-430e-9b4a-cce8d49bb230",
 CellID->99764144],
Cell[176990, 4070, 392, 9, 40, "Output",ExpressionUUID->"a0c874ef-762d-4e40-9897-954809494963",
 CellID->528147374]
}, Open  ]],
Cell[177397, 4082, 673, 12, 89, "Text",ExpressionUUID->"e6c5c010-db78-4388-afc6-63b784b3d3c1",
 CellID->164340674],
Cell[178073, 4096, 476, 14, 37, "CodeCaption",ExpressionUUID->"989b67b7-0f8d-468c-888b-174a74f26897",
 CellID->296261279],
Cell[CellGroupData[{
Cell[178574, 4114, 1092, 32, 54, "Input",ExpressionUUID->"8bc746b2-7f37-43b6-91ed-d9a6155308ef",
 CellID->772854414],
Cell[179669, 4148, 21593, 375, 178, "Output",ExpressionUUID->"25fef1b8-6b43-48a3-95f9-cf5572614646",
 CellID->1632352378]
}, Open  ]],
Cell[201277, 4526, 460, 8, 37, "CodeCaption",ExpressionUUID->"235870bb-54b4-46f3-bea5-64b31046127e",
 CellID->312796831],
Cell[CellGroupData[{
Cell[201762, 4538, 349, 8, 29, "Input",ExpressionUUID->"bdb78ac5-e9d6-4710-b82b-7a48cdab60e8",
 CellID->333252504],
Cell[202114, 4548, 346, 8, 40, "Output",ExpressionUUID->"f26ab4fe-2653-42b7-bff7-0a4407ae28f0",
 CellID->842826621]
}, Open  ]],
Cell[CellGroupData[{
Cell[202497, 4561, 450, 10, 29, "Input",ExpressionUUID->"31cdc1bd-0a49-49cb-a7a8-a3cdf3d94db1",
 CellID->160409477],
Cell[202950, 4573, 395, 9, 40, "Output",ExpressionUUID->"136e1e0f-c1b3-4b11-ba21-4d4856dddc59",
 CellID->340402704]
}, Open  ]],
Cell[203360, 4585, 251, 5, 63, "Text",ExpressionUUID->"6e04e0cc-6c73-4970-a746-9d60b0929372",
 CellID->552837096],
Cell[CellGroupData[{
Cell[203636, 4594, 317, 5, 71, "ExerciseSection",ExpressionUUID->"66299430-d3ed-42c9-9db5-e29aaa2063d2",
 CellID->566065673],
Cell[203956, 4601, 1160, 30, 70, "ExerciseNote",ExpressionUUID->"f040da89-6c4d-4374-81d4-ecea16ae62c7",
 CellID->1299166670],
Cell[205119, 4633, 1353, 28, 51, "Exercise",ExpressionUUID->"8ec1bcad-04ff-46b4-b01a-4a59bd4b4dfd",
 CellID->123280140],
Cell[206475, 4663, 346, 4, 26, "Exercise",ExpressionUUID->"a7b048f9-4397-4b15-9fc2-2e34e2685ca7",
 CellID->141359314],
Cell[206824, 4669, 482, 8, 26, "Exercise",ExpressionUUID->"957969d8-a68f-424b-8c80-29f3e9c8e11e",
 CellID->64011863],
Cell[207309, 4679, 702, 16, 47, "Exercise",ExpressionUUID->"754ce739-ad30-44fa-a448-a4dee5b45a27",
 CellID->416311685],
Cell[208014, 4697, 977, 23, 46, "Exercise",ExpressionUUID->"62b659ae-6584-4ff3-9b86-3b1a96908de1",
 CellID->33034166],
Cell[208994, 4722, 702, 16, 27, "Exercise",ExpressionUUID->"4cbdf192-8f25-428a-bc9e-266c87b24f01",
 CellID->482980621],
Cell[209699, 4740, 542, 11, 27, "Exercise",ExpressionUUID->"3411e31a-3688-4282-928b-59569f8ad515",
 CellID->135554252],
Cell[210244, 4753, 892, 20, 47, "Exercise",ExpressionUUID->"fec0f7b2-18ef-4158-9529-a170ec968dee",
 CellID->196921243],
Cell[211139, 4775, 703, 13, 27, "Exercise",ExpressionUUID->"b015a27d-90a0-4cbc-ab93-524d615c01c6",
 CellID->285234496],
Cell[211845, 4790, 951, 21, 27, "Exercise",ExpressionUUID->"900b2cf8-93ff-45ed-887b-872d55dfde14",
 CellID->560632314]
}, Open  ]],
Cell[CellGroupData[{
Cell[212833, 4816, 112, 1, 70, "TechNoteSection",ExpressionUUID->"a2a71bb7-08ce-4793-a0f8-83ee73f78331",
 CellID->805757751],
Cell[212948, 4819, 745, 15, 54, "TechNote",ExpressionUUID->"41c3b6be-ef39-4e11-bd24-067d8c942837",
 CellID->477255672]
}, Open  ]],
Cell[CellGroupData[{
Cell[213730, 4839, 119, 1, 100, "MoreExploreSection",ExpressionUUID->"65a82294-ef4e-4181-ae0e-6268d4051bf7",
 CellID->19888384],
Cell[213852, 4842, 908, 21, 49, "MoreExplore",ExpressionUUID->"d3d9342c-54a7-49fa-8f6b-c379f1ed9b8c",
 CellID->26626102],
Cell[214763, 4865, 880, 20, 49, "MoreExplore",ExpressionUUID->"ee991bfb-043c-4a7e-82c1-50764a51474a",
 CellID->254588533],
Cell[215646, 4887, 1394, 32, 49, "MoreExplore",ExpressionUUID->"e0b4da9c-27d7-4785-a1e4-32ef851c46e1",
 CellID->1082049307]
}, Open  ]]
}, Open  ]]
}
]
*)

