(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    497833,      10556]
NotebookOptionsPosition[    389695,       8330]
NotebookOutlinePosition[    474038,      10090]
CellTagsIndexPosition[    473968,      10085]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 InterpretationBox[Cell[
  "A Research Project Demonstration", "SectionInline",ExpressionUUID->
   "84ecf054-15c4-40ed-b555-e56fe4ff0307"],
  $Line = 0; Null]], "Section",
 CounterAssignments->{{"Section", 14}, {"Subsection", 14}, {
   "Subsubsection", 14}, {"Exercise", 14}},
 CellTags->"C:15",
 CellLabel->"In[1]:=",
 CellID->868451339,ExpressionUUID->"129eafe9-cb43-4ba8-a5aa-31a86c927661"],

Cell["\<\
In this chapter, we consider a research project with simulated data. The aim \
is to bring together all of the knowledge in the previous chapters. This \
chapter also serves as an example of a computational essay. This forms the \
basis of research projects in many research institutions. A computational \
essay, such as what we create with a Mathematica notebook is the ideal format \
to share statistical analysis with individuals in a research group. A \
notebook allows for rich content including stylized text, computation, and \
the output of the computation.\
\>", "Text",
 CellChangeTimes->{{3.769934423105397*^9, 3.7699344551629343`*^9}, 
   3.777213396825014*^9, 3.7942058185117283`*^9, 3.813565715338776*^9, {
   3.8135657582389402`*^9, 3.8135657726928587`*^9}},
 CellID->113786317,ExpressionUUID->"0ff7ffe3-b100-4a51-bbfb-eb94f402deeb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Research Question", "Subsection",
 CellChangeTimes->{{3.693037992567856*^9, 3.6930379974276085`*^9}, {
  3.7247840133527436`*^9, 3.724784013898853*^9}, {3.7699346102867236`*^9, 
  3.769934616192512*^9}, {3.777213685273014*^9, 3.777213687553014*^9}},
 CellID->581766946,ExpressionUUID->"92cd6af6-73ce-49fe-80c8-07759da5af2f"],

Cell["\<\
Statistical analysis follows data collection, which is preceded by a research \
question. The scientific method and inferential statistics shown in this book \
are based on a hypothesis question.\
\>", "Text",
 CellChangeTimes->{{3.7699346200073786`*^9, 3.7699346668442974`*^9}, 
   3.777213389905014*^9, {3.7772139244983625`*^9, 3.777213924666379*^9}, {
   3.8135683301055193`*^9, 3.813568330825091*^9}},
 CellID->727016178,ExpressionUUID->"a01c9569-474a-4818-a6c0-506de93ad508"],

Cell["\<\
A research question must be stated clearly, such that we can have a null and \
an alternative hypothesis.\
\>", "Text",
 CellChangeTimes->{{3.7699346681488485`*^9, 3.76993469387547*^9}},
 CellID->1520483,ExpressionUUID->"75691a12-2fb0-49f6-813c-a9d969eab519"],

Cell["\<\
Most research projects will have more than one research question. Some have a \
main research question with one or more secondary questions.\
\>", "Text",
 CellChangeTimes->{{3.7699346995218463`*^9, 3.769934733182061*^9}, 
   3.777213404704014*^9, 3.777213940267939*^9},
 CellID->424683243,ExpressionUUID->"3296013b-9fd5-4c89-b9d7-005e0311fd8b"],

Cell["\<\
In the example for this chapter, we consider two groups of patients. All the \
subjects in this simulated project are admitted with airway disease. Group A \
subjects are admitted with chronic obstructive airway disease (COAD) and \
group B with chronic bronchitis (CB). For the sake of argument, we will \
assume that there are no confounding factors and no bias in the selection of \
the subjects.\
\>", "Text",
 CellChangeTimes->{{3.769934734587025*^9, 3.7699348879617352`*^9}, {
   3.76993780742445*^9, 3.769937814160329*^9}, {3.777213407288014*^9, 
   3.777213415240014*^9}, {3.777213945155428*^9, 3.7772139461165237`*^9}, {
   3.7772143243163404`*^9, 3.7772143246363726`*^9}, 3.816097421792602*^9},
 CellID->183011568,ExpressionUUID->"653aa2dd-3700-489c-8b13-d8d4a738387f"],

Cell["\<\
Our primary research question is whether there is a difference in in-hospital \
mortality between these two groups. In health-care research literature, \
in-hospital mortality refers to death occurring in the hospital during the \
admission of the patients. Our null hypothesis is that there is no difference \
between the groups and our alternative hypothesis is that there is a \
difference.\
\>", "Text",
 CellChangeTimes->{{3.7699348895053124`*^9, 3.769934944037206*^9}, {
   3.7699350445916615`*^9, 3.769935092199958*^9}, {3.777213420879014*^9, 
   3.777213423767014*^9}, {3.777214347388647*^9, 3.777214350237932*^9}, {
   3.7772143911430225`*^9, 3.777214391375046*^9}, 3.813568361030019*^9, {
   3.813568429846653*^9, 3.813568430264943*^9}},
 CellID->13119533,ExpressionUUID->"e0ef61ee-f607-4836-82d4-9ae9e7f9de66"],

Cell["\<\
How would we measure our research questions though? How do we measure \
mortality? Well, mortality is a nominal categorical variable with a sample \
space of \[OpenCurlyDoubleQuote]Yes\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]No\[CloseCurlyDoubleQuote]. A subject either died in \
the hospital or they did not.\
\>", "Text",
 CellChangeTimes->{{3.7699349458424625`*^9, 3.769935034654811*^9}, {
  3.777213426471014*^9, 3.777213431479014*^9}, {3.7772143669015985`*^9, 
  3.7772143942243304`*^9}, {3.789821261996993*^9, 3.789821273269075*^9}},
 CellID->735514005,ExpressionUUID->"1a84708b-0ca1-4c67-af93-7642fe592035"],

Cell["\<\
Our secondary research questions will look at differences between the \
following variables:\
\>", "Text",
 CellChangeTimes->{{3.7699351120908937`*^9, 3.7699351381611586`*^9}},
 CellID->331792210,ExpressionUUID->"e01be72e-ad01-45aa-9d44-26a23bf59519"],

Cell[CellGroupData[{

Cell["Age", "ItemNumbered",
 CellChangeTimes->{{3.7699351532259083`*^9, 3.769935154144871*^9}},
 CellID->246422531,ExpressionUUID->"33cdc560-ae12-4254-ae3f-53ea3ce2cf71"],

Cell["\<\
Correlation between overall admission lactate levels and white cell counts\
\>", "ItemNumbered",
 CellChangeTimes->{{3.7699351532259083`*^9, 3.7699352194978914`*^9}, 
   3.769935310528542*^9, {3.7699477888669333`*^9, 3.769947817786093*^9}},
 CellID->7232440,ExpressionUUID->"756dd3cb-3c53-4151-8f5f-bbe1d2503d53"]
}, Open  ]],

Cell["\<\
We will look at the definition of these variables, their sample space, and \
the hypotheses for each question when we analyze these questions.\
\>", "Text",
 CellChangeTimes->{{3.7699352225550427`*^9, 3.769935272378607*^9}, {
  3.7699353435312276`*^9, 3.769935356906139*^9}, {3.8160975129936943`*^9, 
  3.816097513401114*^9}},
 CellID->478003943,ExpressionUUID->"37ad54e2-5ac5-4067-8cb3-9a28a216c49b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Data Import", "Subsection",
 CellChangeTimes->{{3.693037992567856*^9, 3.6930379974276085`*^9}, {
  3.7247840133527436`*^9, 3.724784013898853*^9}, {3.7699346102867236`*^9, 
  3.769934616192512*^9}, {3.7699354035532627`*^9, 3.7699354049876184`*^9}, {
  3.7772136951844335`*^9, 3.777213696889604*^9}},
 CellID->20336226,ExpressionUUID->"0efcebca-8371-4aa2-9b92-f3953abea407"],

Cell["\<\
We take for granted that this notebook and the spreadsheet file containing \
our data is located in the same folder.\
\>", "Text",
 CellChangeTimes->{{3.7699354134468904`*^9, 3.769935449228568*^9}, 
   3.777213434279014*^9, 3.777215023223009*^9, 3.7898204926969137`*^9},
 CellID->46677548,ExpressionUUID->"d03fc395-e076-44b9-a1e5-dc1fd58004b1"],

Cell["We start by setting the working directory:", "CodeCaption",
 CellChangeTimes->{{3.777215014503009*^9, 3.777215020744009*^9}},
 CellID->452614806,ExpressionUUID->"b5315fe4-d22c-462b-84d6-6fc54e90c263"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.7699354511827707`*^9, 3.7699354613166933`*^9}},
 CellLabel->"In[1]:=",
 CellID->284265542,ExpressionUUID->"8c8473d7-a7d0-43e5-bcf3-7878b73fb6b1"],

Cell[TextData[{
 "The data exists in a spreadsheet saved as a comma-separated values (",
 Cell[BoxData[
  FormBox[
   RowBox[{".", "cvs"}], TraditionalForm]], "InlineCodeText",
  FormatType->"TraditionalForm",ExpressionUUID->
  "48ba4f4f-04fd-469b-baec-f7f919a643c5"],
 ") file named ",
 StyleBox["SimulatedData.csv",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.7699354765783052`*^9, 3.7699355093618083`*^9}, {
   3.777215117917009*^9, 3.7772151543680086`*^9}, 3.816097549075029*^9},
 CellID->620449441,ExpressionUUID->"f1d0956e-0886-43bd-ae78-d113f227afca"],

Cell[TextData[{
 "Use the ",
 ButtonBox["SemanticImport",
  BaseStyle->"Link"],
 " function to import the data file:"
}], "CodeCaption",
 CellChangeTimes->{{3.7699355276193347`*^9, 3.7699355385218053`*^9}, {
  3.769936649808089*^9, 3.7699366501574116`*^9}, {3.777215160391009*^9, 
  3.777215165381009*^9}},
 CellID->69220379,ExpressionUUID->"9eea528f-0445-4a9c-bc37-47175b414bde"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"SemanticImport", "[", "\"\<SimulatedData.csv\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.769935540999977*^9, 3.7699355516358604`*^9}},
 CellLabel->"In[2]:=",
 CellID->203768166,ExpressionUUID->"04f6da4a-99f4-40d0-aee6-7ecf6acc722c"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s inspect the ",
 ButtonBox["Dataset",
  BaseStyle->"Link"],
 " object to see that it imported correctly and how many subjects and \
variables it contains."
}], "Text",
 CellChangeTimes->{{3.7699359750747623`*^9, 3.7699360181439*^9}, {
   3.7699360656542697`*^9, 3.769936066556909*^9}, 3.777215174225009*^9},
 CellID->56010151,ExpressionUUID->"39e577ef-62d4-4412-b031-48eeccbfd540"],

Cell[TextData[{
 "View the first five rows using ",
 ButtonBox["Part",
  BaseStyle->"Link"],
 " notation, ",
 Cell[BoxData[
  RowBox[{"\[LeftDoubleBracket]", "\[NegativeThinSpace]", 
   StyleBox["...",
    FontColor->GrayLevel[0.6]], "\[RightDoubleBracket]"}]], "InlineCode",
  ExpressionUUID->"15e46c50-bc65-4cd9-9a93-5da311f8eed3"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7699358387829175`*^9, 3.769935856753853*^9}, {
   3.7699360233260875`*^9, 3.769936045620364*^9}, {3.76993664641486*^9, 
   3.769936646769026*^9}, {3.7772151841650085`*^9, 3.7772152845510087`*^9}, {
   3.7772162682680087`*^9, 3.777216269442009*^9}, {3.777216301249009*^9, 
   3.777216343911009*^9}, {3.789498680944096*^9, 3.78949868798879*^9}, 
   3.816097610265295*^9},
 CellID->426761083,ExpressionUUID->"6f87b2ce-be8d-4217-bad4-93f6bb51c463"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "\[LeftDoubleBracket]", 
  RowBox[{";;", "5"}], "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.7699358611243887`*^9, 3.7699358655552263`*^9}},
 CellLabel->"In[3]:=",
 CellID->64376173,ExpressionUUID->"5578d6c5-b8d8-4abb-b07c-2860f73c12b7"],

Cell[BoxData[
 TagBox[
  TagBox[
   DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = 
    Association["InitialData" -> {
       Association[
       "Group" -> "COAD", "Age" -> 70, "BMI" -> 21, "SOB" -> "Mild", "Shock" -> 
        "Yes", "MechanicalVentilation" -> "Yes", "Lactate" -> 42, "WCC" -> 
        11.6, "InHospitalMortality" -> "No"], 
       Association[
       "Group" -> "CB", "Age" -> 66, "BMI" -> 33, "SOB" -> "Moderate", 
        "Shock" -> "No", "MechanicalVentilation" -> "Yes", "Lactate" -> 54, 
        "WCC" -> 11.4, "InHospitalMortality" -> "Yes"], 
       Association[
       "Group" -> "COAD", "Age" -> 69, "BMI" -> 29, "SOB" -> "Severe", 
        "Shock" -> "No", "MechanicalVentilation" -> "Yes", "Lactate" -> 34, 
        "WCC" -> 11.5, "InHospitalMortality" -> "No"], 
       Association[
       "Group" -> "COAD", "Age" -> 40, "BMI" -> 28, "SOB" -> "Moderate", 
        "Shock" -> "Yes", "MechanicalVentilation" -> "Yes", "Lactate" -> 50, 
        "WCC" -> 11.8, "InHospitalMortality" -> "No"], 
       Association[
       "Group" -> "COAD", "Age" -> 61, "BMI" -> 31, "SOB" -> "Moderate", 
        "Shock" -> "Yes", "MechanicalVentilation" -> "Yes", "Lactate" -> 53, 
        "WCC" -> 10.4, "InHospitalMortality" -> "No"]}, "InitialShape" -> 
     TypeSystem`PackageScope`HeaderShape[
       Association[{All, "Group"} -> 1, {All, "Age"} -> 1, {All, "BMI"} -> 
        1, {All, "SOB"} -> 1, {All, "Shock"} -> 
        1, {All, "MechanicalVentilation"} -> 1, {All, "Lactate"} -> 
        1, {All, "WCC"} -> 1, {All, "InHospitalMortality"} -> 1], 
       TypeSystem`PackageScope`Limited[
        TypeSystem`PackageScope`ColumnShape[
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`RowShape[
           Association[
           "Group" -> TypeSystem`PackageScope`AtomShape[36.], "Age" -> 
            TypeSystem`PackageScope`AtomShape[34], "BMI" -> 
            TypeSystem`PackageScope`AtomShape[34], "SOB" -> 
            TypeSystem`PackageScope`AtomShape[72.], "Shock" -> 
            TypeSystem`PackageScope`AtomShape[27.], "MechanicalVentilation" -> 
            TypeSystem`PackageScope`AtomShape[27.], "Lactate" -> 
            TypeSystem`PackageScope`AtomShape[34], "WCC" -> 
            TypeSystem`PackageScope`AtomShape[60], "InHospitalMortality" -> 
            TypeSystem`PackageScope`AtomShape[27.]]], 
          DirectedInfinity[1], 9, {All}]], 5, 
        DirectedInfinity[1], {}]], "InitialType" -> TypeSystem`Vector[
       TypeSystem`Struct[{
        "Group", "Age", "BMI", "SOB", "Shock", "MechanicalVentilation", 
         "Lactate", "WCC", "InHospitalMortality"}, {
         TypeSystem`Atom[
          TypeSystem`Enumeration["CB", "COAD"]], 
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[
          TypeSystem`Enumeration["Mild", "Moderate", "Severe"]], 
         TypeSystem`Atom[
          TypeSystem`Enumeration["No", "Yes"]], 
         TypeSystem`Atom[
          TypeSystem`Enumeration["Yes"]], 
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[Real], 
         TypeSystem`Atom[
          TypeSystem`Enumeration["No", "Yes"]]}], 5], "Meta" -> 
     Association["ID" -> 131967381155569], "RowTarget" -> 20, "ColumnTarget" -> 
     10, "Shape" -> TypeSystem`PackageScope`HeaderShape[
       Association[{All, "Group"} -> 1, {All, "Age"} -> 1, {All, "BMI"} -> 
        1, {All, "SOB"} -> 1, {All, "Shock"} -> 
        1, {All, "MechanicalVentilation"} -> 1, {All, "Lactate"} -> 
        1, {All, "WCC"} -> 1, {All, "InHospitalMortality"} -> 1], 
       TypeSystem`PackageScope`Limited[
        TypeSystem`PackageScope`ColumnShape[
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`RowShape[
           Association[
           "Group" -> TypeSystem`PackageScope`AtomShape[36.], "Age" -> 
            TypeSystem`PackageScope`AtomShape[34], "BMI" -> 
            TypeSystem`PackageScope`AtomShape[34], "SOB" -> 
            TypeSystem`PackageScope`AtomShape[72.], "Shock" -> 
            TypeSystem`PackageScope`AtomShape[27.], "MechanicalVentilation" -> 
            TypeSystem`PackageScope`AtomShape[27.], "Lactate" -> 
            TypeSystem`PackageScope`AtomShape[34], "WCC" -> 
            TypeSystem`PackageScope`AtomShape[60], "InHospitalMortality" -> 
            TypeSystem`PackageScope`AtomShape[27.]]], 
          DirectedInfinity[1], 9, {All}]], 5, 
        DirectedInfinity[1], {}]], "Type" -> TypeSystem`Vector[
       TypeSystem`Struct[{
        "Group", "Age", "BMI", "SOB", "Shock", "MechanicalVentilation", 
         "Lactate", "WCC", "InHospitalMortality"}, {
         TypeSystem`Atom[
          TypeSystem`Enumeration["CB", "COAD"]], 
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[
          TypeSystem`Enumeration["Mild", "Moderate", "Severe"]], 
         TypeSystem`Atom[
          TypeSystem`Enumeration["No", "Yes"]], 
         TypeSystem`Atom[
          TypeSystem`Enumeration["Yes"]], 
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[Real], 
         TypeSystem`Atom[
          TypeSystem`Enumeration["No", "Yes"]]}], 5], "Path" -> {}, 
     "BaseIndices" -> {}, "DisplayedRowCount" -> 5, "DisplayedColumnCount" -> 
     9, "DataRowCount" -> 5, "DataColumnCount" -> 9, "SortPaths" -> {}, 
     "SortDirections" -> {}, "HiddenItemsMap" -> Null, "UpdateType" -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`$outputID$$, 
    TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
    TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
    DynamicModule[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
        Style[
         Grid[{{
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["Group", 
                  Style[
                  "Group", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "Group"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "Group"}, "ColumnHeader", True], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["Age", 
                  Style[
                  "Age", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "Age"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "Age"}, "ColumnHeader", True], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["BMI", 
                  Style[
                  "BMI", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "BMI"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "BMI"}, "ColumnHeader", True], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["SOB", 
                  Style[
                  "SOB", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "SOB"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "SOB"}, "ColumnHeader", True], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["Shock", 
                  Style[
                  "Shock", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "Shock"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "Shock"}, "ColumnHeader", True], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["MechanicalVentilation", 
                  Style[
                  "MechanicalVentilation", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "MechanicalVentilation"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "MechanicalVentilation"}, "ColumnHeader", True], 
               "Mouse"], ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["Lactate", 
                  Style[
                  "Lactate", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "Lactate"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "Lactate"}, "ColumnHeader", True], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["WCC", 
                  Style[
                  "WCC", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "WCC"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "WCC"}, "ColumnHeader", True], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["InHospitalMortality", 
                  Style[
                  "InHospitalMortality", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                  All, "InHospitalMortality"}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                All, "InHospitalMortality"}, "ColumnHeader", True], "Mouse"], 
              ImageSize -> {{1, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}]}, {
            Item[
             Pane[
              Annotation["COAD", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["Group"]}, "Item", False], "Mouse"], 
              ImageSize -> {{36., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["70"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["Age"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["21"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["BMI"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Mild", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["SOB"]}, "Item", False], "Mouse"], 
              ImageSize -> {{72., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Yes", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["Shock"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Yes", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["MechanicalVentilation"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["42"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["Lactate"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["11.6"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["WCC"]}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 
                 Key["InHospitalMortality"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation["CB", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["Group"]}, "Item", False], "Mouse"], 
              ImageSize -> {{36., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["66"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["Age"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["33"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["BMI"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Moderate", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["SOB"]}, "Item", False], "Mouse"], 
              ImageSize -> {{72., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["Shock"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Yes", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["MechanicalVentilation"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["54"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["Lactate"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["11.4"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["WCC"]}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Yes", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 
                 Key["InHospitalMortality"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation["COAD", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["Group"]}, "Item", False], "Mouse"], 
              ImageSize -> {{36., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["69"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["Age"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["29"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["BMI"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Severe", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["SOB"]}, "Item", False], "Mouse"], 
              ImageSize -> {{72., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["Shock"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Yes", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["MechanicalVentilation"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["34"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["Lactate"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["11.5"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["WCC"]}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{3, 
                 Key["InHospitalMortality"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation["COAD", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["Group"]}, "Item", False], "Mouse"], 
              ImageSize -> {{36., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["40"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["Age"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["28"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["BMI"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Moderate", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["SOB"]}, "Item", False], "Mouse"], 
              ImageSize -> {{72., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Yes", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["Shock"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Yes", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["MechanicalVentilation"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["50"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["Lactate"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["11.8"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["WCC"]}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{4, 
                 Key["InHospitalMortality"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation["COAD", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["Group"]}, "Item", False], "Mouse"], 
              ImageSize -> {{36., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["61"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["Age"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["31"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["BMI"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Moderate", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["SOB"]}, "Item", False], "Mouse"], 
              ImageSize -> {{72., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Yes", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["Shock"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["Yes", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["MechanicalVentilation"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["53"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["Lactate"]}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["10.4"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["WCC"]}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{5, 
                 Key["InHospitalMortality"]}, "Item", False], "Mouse"], 
              ImageSize -> {{27., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}}, 
          BaseStyle -> {
           ContextMenu -> 
            Dynamic[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
              Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                 TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu, True, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger = 
                 TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                 Block[{TypeSystem`NestedGrid`PackagePrivate`$globalScrollPos = \
{TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                   
                   With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Show ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Hide ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic]}]]]]], FontFamily -> 
            "Verdana", FontSize -> 12}, Spacings -> {0, 0}, Alignment -> Left,
           Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
          BaseStyle -> {FontFamily -> "Verdana", FontSize -> 12}], 
         LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> False, 
         ShowAutoStyles -> False]], 
      TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
     Dynamic[
      TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
         Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
         Module[{
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
           TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
           TypeSystem`NestedGrid`PackagePrivate`datasetData[
            TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
             TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
             TypeSystem`NestedGrid`PackagePrivate`renderGrid[
             TypeSystem`NestedGrid`PackagePrivate`$state$$, 
              TypeSystem`NestedGrid`PackagePrivate`$path$$, 
              TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
              TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
             TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
            Not[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
            TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
       TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
       TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
         FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
         TypeSystem`SparseGrid[
          TypeSystem`H["(data no longer present)"]], 
         If[GeneralUtilities`$DebugMode, 
          Row[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid, "  ", 
            TypeSystem`NestedGrid`PackagePrivate`formatState[
            TypeSystem`NestedGrid`PackagePrivate`$state$$, 
             TypeSystem`NestedGrid`PackagePrivate`$path$$, 
             TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
             TypeSystem`NestedGrid`PackagePrivate`$hPos$$]}], 
          TypeSystem`NestedGrid`PackagePrivate`renderedGrid]]], 
      TrackedSymbols :> {
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
     DynamicModuleValues :> {}], 
    TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
     TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
      TypeSystem`PackageScope`SubViewPathbar[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, 
       TypeSystem`NestedGrid`PackagePrivate`updateState[
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$path$$, 
        TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
        TypeSystem`NestedGrid`PackagePrivate`localHold[
        TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
     TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
    TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
     Framed[
      Dynamic[
       Replace[
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
        TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
           Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
           Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
            Blank[]]] :> (
          Increment[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
           TypeSystem`NestedGrid`PackagePrivate`path$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
           TypeSystem`NestedGrid`PackagePrivate`pathType$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
           TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
           TypeSystem`NestedGrid`PackagePrivate`localHold[
            TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
          TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
           TypeSystem`NestedGrid`PackagePrivate`path$, 
            TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
         Spacer[10], Blank[] :> Spacer[10]}], 
       TrackedSymbols :> {
        TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], FrameStyle -> 
      None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> Top, 
      ImageSize -> {Automatic, 15}], FontSize -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
    DynamicWrapperBox[
     DynamicBox[ToBoxes[
       Dataset`DatasetContent[
       2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
        "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], "State" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], "VPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], "HPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], "TopBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], "BottomBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
        Hold[
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
      ImageSizeCache->{602., {89.8837890625, 97.1162109375}},
      TrackedSymbols:>{
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
     TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
     MouseAnnotation[],
     ImageSizeCache->{602., {89.8837890625, 97.1162109375}}],
    BaseStyle->{LineBreakWithin -> False},
    DynamicModuleValues:>{},
    Initialization:>
     Block[{$ContextPath = $ContextPath}, Needs["TypeSystem`"]; 
      Needs["Dataset`"]; 
      TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = CreateUUID[]],
    UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Dataset`InterpretDataset[1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.76993586612608*^9, 3.769940615688794*^9, 
  3.76994822588566*^9, 3.769952610133484*^9, 3.769952794110679*^9, 
  3.7701786185040255`*^9, 3.79420616262836*^9, 3.8135698700074253`*^9, 
  3.813570673225354*^9},
 CellLabel->"Out[3]=",
 CellID->639738530,ExpressionUUID->"079b84e6-e7f6-46f0-bbfd-f4c802f2ddfa"]
}, Open  ]],

Cell[TextData[{
 "Use the ",
 ButtonBox["Dimensions",
  BaseStyle->"Link"],
 " function to interrogate the number of subjects and the number of variables \
(columns):"
}], "CodeCaption",
 CellChangeTimes->{{3.769935893901474*^9, 3.7699359201973734`*^9}, {
  3.769936642957639*^9, 3.769936643289461*^9}, {3.777216714815009*^9, 
  3.7772167186060085`*^9}},
 CellID->24592878,ExpressionUUID->"06673565-5e97-4d35-ad56-f7d71754c1a0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", "data", "]"}]], "Input",
 CellChangeTimes->{{3.7699359365720596`*^9, 3.7699359396594534`*^9}},
 CellLabel->"In[4]:=",
 CellID->157153682,ExpressionUUID->"ac48279e-2446-45df-9e7a-b6d373d81d3b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"120", ",", "9"}], "}"}]], "Output",
 CellChangeTimes->{3.7699359402141876`*^9, 3.770178618656619*^9, 
  3.7942061689118967`*^9, 3.813569870130062*^9, 3.8135706733485403`*^9},
 CellLabel->"Out[4]=",
 CellID->1782336828,ExpressionUUID->"543e5027-bed0-493f-b795-6a30fc712106"]
}, Open  ]],

Cell[TextData[{
 "There are ",
 Cell[BoxData[
  FormBox["120", TraditionalForm]],ExpressionUUID->
  "acd22db9-1971-44d5-9505-b422fcf9d50a"],
 " subjects and eight variables. The ",
 Cell[BoxData[
  ButtonBox["\"\<Group\>\"",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/menuitem/Group"]], "InlineCodeText",ExpressionUUID->
  "03d9d0e8-f1d5-432c-8a4c-317fba8fcb95"],
 " variable contains the data point values that we will use to separate the \
patients into groups A and B."
}], "Text",
 CellChangeTimes->{{3.7699359442598457`*^9, 3.7699359656455593`*^9}, {
   3.7699360756718893`*^9, 3.7699361293901043`*^9}, 3.7772134375340137`*^9, {
   3.7772167425510087`*^9, 3.7772167485840087`*^9}},
 CellID->897888979,ExpressionUUID->"1fe3f1a2-5b4b-4561-a1e0-ced0a8000b45"],

Cell[TextData[{
 "Use ",
 ButtonBox["Dataset",
  BaseStyle->"Link"],
 " object notation to count the number of individuals in each group:"
}], "CodeCaption",
 CellChangeTimes->{{3.769936151799658*^9, 3.7699361687355876`*^9}, {
  3.7699366397930737`*^9, 3.769936640083911*^9}, {3.7772167715310087`*^9, 
  3.777216776074009*^9}},
 CellID->229633178,ExpressionUUID->"c3806381-66a1-406e-92c1-974be25c4d5a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{"Tally", ",", "\"\<Group\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.7699361331035576`*^9, 3.7699361395725784`*^9}},
 CellLabel->"In[5]:=",
 CellID->1231097,ExpressionUUID->"2b3a16f3-1f3e-4385-b7fc-45e5eb5eb234"],

Cell[BoxData[
 TagBox[
  TagBox[
   DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = 
    Association[
    "InitialData" -> {{"COAD", 56}, {"CB", 64}}, "InitialShape" -> 
     TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`MatrixShape[2, 2], 2, 2, {All}], "InitialType" -> 
     TypeSystem`Vector[
       TypeSystem`Vector[TypeSystem`AnyType, 2], 2], "Meta" -> 
     Association["ID" -> 131971676122865], "RowTarget" -> 20, "ColumnTarget" -> 
     10, "Shape" -> TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`MatrixShape[2, 2], 2, 2, {All}], "Type" -> 
     TypeSystem`Vector[
       TypeSystem`Vector[TypeSystem`AnyType, 2], 2], "Path" -> {}, 
     "BaseIndices" -> {}, "DisplayedRowCount" -> 2, "DisplayedColumnCount" -> 
     2, "DataRowCount" -> 2, "DataColumnCount" -> 2, "SortPaths" -> {}, 
     "SortDirections" -> {}, "HiddenItemsMap" -> Null, "UpdateType" -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`$outputID$$, 
    TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
    TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
    DynamicModule[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
        Style[
         Grid[{{
            Item[
             Pane[
              Annotation["COAD", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 1}, 
                "Item", False], "Mouse"], 
              ImageSize -> {{38.400000000000006`, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["56"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{1, 2}, 
                "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation["CB", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 1}, 
                "Item", False], "Mouse"], 
              ImageSize -> {{19.200000000000003`, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["64"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{2, 2}, 
                "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}}, 
          BaseStyle -> {
           ContextMenu -> 
            Dynamic[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
              Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                 TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu, True, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger = 
                 TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                 Block[{TypeSystem`NestedGrid`PackagePrivate`$globalScrollPos = \
{TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                   
                   With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Show ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Hide ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic]}]]]]], FontFamily -> 
            "Verdana", FontSize -> 12}, Spacings -> {0, 0}, Alignment -> Left,
           Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
          BaseStyle -> {FontFamily -> "Verdana", FontSize -> 12}], 
         LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> False, 
         ShowAutoStyles -> False]], 
      TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
     Dynamic[
      TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
         Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
         Module[{
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
           TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
           TypeSystem`NestedGrid`PackagePrivate`datasetData[
            TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
             TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
             TypeSystem`NestedGrid`PackagePrivate`renderGrid[
             TypeSystem`NestedGrid`PackagePrivate`$state$$, 
              TypeSystem`NestedGrid`PackagePrivate`$path$$, 
              TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
              TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
             TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
            Not[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
            TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
       TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
       TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
         FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
         TypeSystem`SparseGrid[
          TypeSystem`H["(data no longer present)"]], 
         If[GeneralUtilities`$DebugMode, 
          Row[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid, "  ", 
            TypeSystem`NestedGrid`PackagePrivate`formatState[
            TypeSystem`NestedGrid`PackagePrivate`$state$$, 
             TypeSystem`NestedGrid`PackagePrivate`$path$$, 
             TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
             TypeSystem`NestedGrid`PackagePrivate`$hPos$$]}], 
          TypeSystem`NestedGrid`PackagePrivate`renderedGrid]]], 
      TrackedSymbols :> {
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
     DynamicModuleValues :> {}], 
    TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
     TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
      TypeSystem`PackageScope`SubViewPathbar[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, 
       TypeSystem`NestedGrid`PackagePrivate`updateState[
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$path$$, 
        TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
        TypeSystem`NestedGrid`PackagePrivate`localHold[
        TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
     TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
    TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
     Framed[
      Dynamic[
       Replace[
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
        TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
           Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
           Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
            Blank[]]] :> (
          Increment[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
           TypeSystem`NestedGrid`PackagePrivate`path$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
           TypeSystem`NestedGrid`PackagePrivate`pathType$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
           TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
           TypeSystem`NestedGrid`PackagePrivate`localHold[
            TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
          TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
           TypeSystem`NestedGrid`PackagePrivate`path$, 
            TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
         Spacer[10], Blank[] :> Spacer[10]}], 
       TrackedSymbols :> {
        TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], FrameStyle -> 
      None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> Top, 
      ImageSize -> {Automatic, 15}], FontSize -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
    DynamicWrapperBox[
     DynamicBox[ToBoxes[
       Dataset`DatasetContent[
       2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
        "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], "State" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], "VPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], "HPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], "TopBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], "BottomBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
        Hold[
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
      ImageSizeCache->{110., {39.8837890625, 47.1162109375}},
      TrackedSymbols:>{
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
     TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
     MouseAnnotation[],
     ImageSizeCache->{110., {39.8837890625, 47.1162109375}}],
    BaseStyle->{LineBreakWithin -> False},
    DynamicModuleValues:>{},
    Initialization:>
     Block[{$ContextPath = $ContextPath}, Needs["TypeSystem`"]; 
      Needs["Dataset`"]; 
      TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = CreateUUID[]],
    UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Dataset`InterpretDataset[1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.769936140443895*^9, 3.770178618696512*^9, 
  3.8135698701532707`*^9, 3.8135706733739157`*^9},
 CellLabel->"Out[5]=",
 CellID->485676193,ExpressionUUID->"4ceb2348-1613-4f09-87bd-1ff30493c05f"]
}, Open  ]],

Cell["We are ready to start answering our research questions.", "Text",
 CellChangeTimes->{{3.7699360808289804`*^9, 3.769936091537116*^9}},
 CellID->41768799,ExpressionUUID->"2d59d968-1193-420d-80ab-41961713ebf1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Primary Research Question", "Subsection",
 CellChangeTimes->{{3.693037992567856*^9, 3.6930379974276085`*^9}, {
  3.7247840133527436`*^9, 3.724784013898853*^9}, {3.7699346102867236`*^9, 
  3.769934616192512*^9}, {3.7699361920467234`*^9, 3.7699361931015687`*^9}, {
  3.7772137025131664`*^9, 3.777213707744689*^9}},
 CellID->28983898,ExpressionUUID->"e8dcfc08-f3b9-47f1-89a3-e5ba6b53eb60"],

Cell[TextData[{
 "Our primary research question involves a difference in mortality rate \
between the two groups. We can answer this question by looking at \
independence between these variables, i.e. a ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"82c97d2a-917c-4581-810e-efe7232d483b"],
 " test for independence. Our null hypothesis is that these two variables are \
independent and our alternative hypothesis is that they are indeed dependent."
}], "Text",
 CellChangeTimes->{{3.7699361954108067`*^9, 3.769936299791704*^9}, {
   3.7701829069173937`*^9, 3.7701829448659697`*^9}, {3.777213440422014*^9, 
   3.777213443414014*^9}, 3.7772167947710085`*^9},
 CellID->158144874,ExpressionUUID->"ba15f436-65ef-48fc-9d55-d56cdeedadc5"],

Cell["\<\
In order to conduct this test, we need a table of observed values:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7699363011586046`*^9, 3.7699363172458243`*^9}, {
  3.777216802865009*^9, 3.777216803145009*^9}, {3.816097814048305*^9, 
  3.8160978146160917`*^9}},
 CellID->81010172,ExpressionUUID->"049e770f-82d7-4d2c-82b6-94874a7312e5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{
   RowBox[{"GroupBy", "[", "\"\<Group\>\"", "]"}], ",", "Tally", ",", 
   "\"\<InHospitalMortality\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.7699363235536566`*^9, 3.7699363468263764`*^9}},
 CellLabel->"In[6]:=",
 CellID->143984191,ExpressionUUID->"90c4b294-cafe-46ec-8afa-2329a5e63dc2"],

Cell[BoxData[
 TagBox[
  TagBox[
   DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = 
    Association[
    "InitialData" -> 
     Association[
      "COAD" -> {{"No", 38}, {"Yes", 18}}, "CB" -> {{"Yes", 20}, {"No", 44}}],
      "InitialShape" -> TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`ColumnShape[
        TypeSystem`PackageScope`KeyValueShape[
         TypeSystem`PackageScope`AtomShape[36.], 
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`MatrixShape[2, 2], 2, 2, {All, All}]]], 2, 
       DirectedInfinity[1], {}], "InitialType" -> TypeSystem`Assoc[
       TypeSystem`Atom[
        TypeSystem`Enumeration["CB", "COAD"]], 
       TypeSystem`Vector[
        TypeSystem`Vector[TypeSystem`AnyType, 2], 2], 2], "Meta" -> 
     Association["ID" -> 131975971090161], "RowTarget" -> 20, "ColumnTarget" -> 
     10, "Shape" -> TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`ColumnShape[
        TypeSystem`PackageScope`KeyValueShape[
         TypeSystem`PackageScope`AtomShape[36.], 
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`MatrixShape[2, 2], 2, 2, {All, All}]]], 2, 
       DirectedInfinity[1], {}], "Type" -> TypeSystem`Assoc[
       TypeSystem`Atom[
        TypeSystem`Enumeration["CB", "COAD"]], 
       TypeSystem`Vector[
        TypeSystem`Vector[TypeSystem`AnyType, 2], 2], 2], "Path" -> {}, 
     "BaseIndices" -> {}, "DisplayedRowCount" -> 2, "DisplayedColumnCount" -> 
     2, "DataRowCount" -> 2, "DataColumnCount" -> 2, "SortPaths" -> {}, 
     "SortDirections" -> {}, "HiddenItemsMap" -> Null, "UpdateType" -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`$outputID$$, 
    TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
    TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
    DynamicModule[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
        Style[
         Grid[{{
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["COAD", 
                  Style[
                  "COAD", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["COAD"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"]}, "RowHeader", False], "Mouse"], 
              ImageSize -> {{36., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"], 1, 1}, "Item", False], "Mouse"], 
              ImageSize -> {{19.200000000000003`, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["38"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"], 1, 2}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {SpanFromAbove, 
            Item[
             Pane[
              Annotation["Yes", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"], 2, 1}, "Item", False], "Mouse"], 
              ImageSize -> {{28.800000000000004`, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["18"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"], 2, 2}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["CB", 
                  Style[
                  "CB", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["CB"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"]}, "RowHeader", False], "Mouse"], 
              ImageSize -> {{36., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation["Yes", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"], 1, 1}, "Item", False], "Mouse"], 
              ImageSize -> {{28.800000000000004`, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["20"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"], 1, 2}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {SpanFromAbove, 
            Item[
             Pane[
              Annotation["No", 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"], 2, 1}, "Item", False], "Mouse"], 
              ImageSize -> {{19.200000000000003`, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["44"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"], 2, 2}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}}, 
          BaseStyle -> {
           ContextMenu -> 
            Dynamic[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
              Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                 TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu, True, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger = 
                 TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                 Block[{TypeSystem`NestedGrid`PackagePrivate`$globalScrollPos = \
{TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                   
                   With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Show ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Hide ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic]}]]]]], FontFamily -> 
            "Verdana", FontSize -> 12}, Spacings -> {0, 0}, Alignment -> Left,
           Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
          BaseStyle -> {FontFamily -> "Verdana", FontSize -> 12}], 
         LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> False, 
         ShowAutoStyles -> False]], 
      TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
     Dynamic[
      TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
         Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
         Module[{
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
           TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
           TypeSystem`NestedGrid`PackagePrivate`datasetData[
            TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
             TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
             TypeSystem`NestedGrid`PackagePrivate`renderGrid[
             TypeSystem`NestedGrid`PackagePrivate`$state$$, 
              TypeSystem`NestedGrid`PackagePrivate`$path$$, 
              TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
              TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
             TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
            Not[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
            TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
       TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
       TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
         FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
         TypeSystem`SparseGrid[
          TypeSystem`H["(data no longer present)"]], 
         If[GeneralUtilities`$DebugMode, 
          Row[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid, "  ", 
            TypeSystem`NestedGrid`PackagePrivate`formatState[
            TypeSystem`NestedGrid`PackagePrivate`$state$$, 
             TypeSystem`NestedGrid`PackagePrivate`$path$$, 
             TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
             TypeSystem`NestedGrid`PackagePrivate`$hPos$$]}], 
          TypeSystem`NestedGrid`PackagePrivate`renderedGrid]]], 
      TrackedSymbols :> {
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
     DynamicModuleValues :> {}], 
    TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
     TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
      TypeSystem`PackageScope`SubViewPathbar[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, 
       TypeSystem`NestedGrid`PackagePrivate`updateState[
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$path$$, 
        TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
        TypeSystem`NestedGrid`PackagePrivate`localHold[
        TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
     TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
    TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
     Framed[
      Dynamic[
       Replace[
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
        TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
           Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
           Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
            Blank[]]] :> (
          Increment[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
           TypeSystem`NestedGrid`PackagePrivate`path$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
           TypeSystem`NestedGrid`PackagePrivate`pathType$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
           TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
           TypeSystem`NestedGrid`PackagePrivate`localHold[
            TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
          TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
           TypeSystem`NestedGrid`PackagePrivate`path$, 
            TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
         Spacer[10], Blank[] :> Spacer[10]}], 
       TrackedSymbols :> {
        TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], FrameStyle -> 
      None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> Top, 
      ImageSize -> {Automatic, 15}], FontSize -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
    DynamicWrapperBox[
     DynamicBox[ToBoxes[
       Dataset`DatasetContent[
       2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
        "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], "State" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], "VPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], "HPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], "TopBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], "BottomBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
        Hold[
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
      ImageSizeCache->{144., {64.8837890625, 72.1162109375}},
      TrackedSymbols:>{
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
     TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
     MouseAnnotation[],
     ImageSizeCache->{144., {64.8837890625, 72.1162109375}}],
    BaseStyle->{LineBreakWithin -> False},
    DynamicModuleValues:>{},
    Initialization:>
     Block[{$ContextPath = $ContextPath}, Needs["TypeSystem`"]; 
      Needs["Dataset`"]; 
      TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = CreateUUID[]],
    UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Dataset`InterpretDataset[1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.769936347328143*^9, 3.7701786187683544`*^9, 
  3.7942061770666103`*^9, 3.813569870216126*^9, 3.81357067343884*^9},
 CellLabel->"Out[6]=",
 CellID->174433504,ExpressionUUID->"fd7cd65e-0b77-4250-91bb-a33131f74bd5"]
}, Open  ]],

Cell["\<\
We will follow the steps shown in Chapter 13 on comparing categorical \
variables.\
\>", "Text",
 CellChangeTimes->{{3.7699363739373255`*^9, 3.769936410574778*^9}, {
  3.7772170587620087`*^9, 3.777217060282009*^9}},
 CellID->226541001,ExpressionUUID->"0e67c89f-15e0-49f7-b9a5-7531cb50297d"],

Cell[TextData[{
 "Create a table of observed values as a nested ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " object:"
}], "CodeCaption",
 CellChangeTimes->{{3.7699364466627684`*^9, 3.7699364716455183`*^9}, {
  3.769936631379959*^9, 3.769936631718447*^9}, {3.777217063714009*^9, 
  3.777217068362009*^9}},
 CellID->140824503,ExpressionUUID->"3ae668c2-ee03-4c3e-b7e8-cc88f99dde52"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"obs", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"18", ",", "38"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"20", ",", "44"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{3.769936480893683*^9},
 CellLabel->"In[7]:=",
 CellID->556169803,ExpressionUUID->"45dd7925-da81-49d2-b72e-603f3811e195"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"18", ",", "38"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"20", ",", "44"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769936481341254*^9, 3.770178618814637*^9, 
  3.794206180203543*^9, 3.813569870268127*^9, 3.813570673493355*^9},
 CellLabel->"Out[7]=",
 CellID->388723573,ExpressionUUID->"01708b10-4347-43d2-9933-ba21cf2a3e51"]
}, Open  ]],

Cell["\<\
Create row and column values to aid in reading the table. COAD refers to \
chronic obstructive airway disease and CB refers to chronic bronchitis:\
\>", "CodeCaption",
 CellChangeTimes->{
  3.7699365164130936`*^9, {3.769936557308199*^9, 3.7699365735440354`*^9}, {
   3.769936628892789*^9, 3.7699366292247567`*^9}, 3.7772134464630136`*^9, {
   3.7772173465380087`*^9, 3.777217347001009*^9}},
 CellID->240379572,ExpressionUUID->"10d6b3ce-53a5-45bd-ae04-5a8be020dbfc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rc", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<COAD\>\"", ",", "\"\<CB\>\""}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Died\>\"", ",", "\"\<Survived\>\""}], "}"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.769936545369994*^9, 3.769936553966814*^9}},
 CellLabel->"In[8]:=",
 CellID->260474416,ExpressionUUID->"0a6966d6-4bee-45cd-84cb-c2cde11defd3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"COAD\"\>", ",", "\<\"CB\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Died\"\>", ",", "\<\"Survived\"\>"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.769936554367736*^9, 3.7701786188458495`*^9, 
  3.79420618283505*^9, 3.8135698702837887`*^9, 3.8135706735169363`*^9},
 CellLabel->"Out[8]=",
 CellID->631837237,ExpressionUUID->"2d710fa2-8988-487f-becc-8120b52bfd0c"]
}, Open  ]],

Cell["View the contingency table:", "CodeCaption",
 CellChangeTimes->{{3.7699366082217965`*^9, 3.7699366195586696`*^9}, {
  3.7772173600570087`*^9, 3.777217360329009*^9}, {3.794205963872527*^9, 
  3.7942059703933067`*^9}},
 CellID->8429640,ExpressionUUID->"1e45c5c1-331a-4676-95f5-837f1d495546"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"obs", ",", 
   RowBox[{"TableHeadings", "\[Rule]", "rc"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769936412311714*^9, 3.7699364451200333`*^9}, 
   3.7699364764624057`*^9, {3.769936581326659*^9, 3.7699365856258163`*^9}},
 CellLabel->"In[9]:=",
 CellID->24917477,ExpressionUUID->"e5e26342-9f0c-4218-a91b-e52b08201c55"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"Died\"\>",
       HoldForm], 
      TagBox["\<\"Survived\"\>",
       HoldForm]},
     {
      TagBox["\<\"COAD\"\>",
       HoldForm], "18", "38"},
     {
      TagBox["\<\"CB\"\>",
       HoldForm], "20", "44"}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, 
      "Rows" -> {False, True, {False}, False}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{"COAD", "CB"}, {"Died", "Survived"}}]]]], "Output",
 CellChangeTimes->{3.7699365873159485`*^9, 3.7701786188695393`*^9, 
  3.794206188536978*^9, 3.813569870290848*^9, 3.813570673523876*^9},
 CellLabel->"Out[9]//TableForm=",
 CellID->2129291491,ExpressionUUID->"76b31cdc-78d4-4d45-a8b1-4e307ce4c341"]
}, Open  ]],

Cell["\<\
We now create our expected table (a table of expected values given the data):\
\>", "CodeCaption",
 CellChangeTimes->{{3.7699366716791563`*^9, 3.7699366807243385`*^9}, {
  3.777217827050023*^9, 3.7772178276351986`*^9}, {3.794206002233223*^9, 
  3.794206016952836*^9}},
 CellID->186606889,ExpressionUUID->"c1a99281-974b-4087-aaeb-95ed927f1737"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fit", "=", 
  RowBox[{
   RowBox[{"Outer", "[", 
    RowBox[{"Times", ",", 
     RowBox[{"Plus", "@@@", "obs"}], ",", 
     RowBox[{"Plus", "@@@", 
      RowBox[{"Transpose", "[", "obs", "]"}]}]}], "]"}], "/", 
   RowBox[{"Length", "[", "data", "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.769949843616313*^9, {3.7942061960576515`*^9, 3.794206206410412*^9}},
 CellLabel->"In[10]:=",
 CellID->34317681,ExpressionUUID->"ef101347-e14b-46bf-bbcf-3690c9e61d71"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["266", "15"], ",", 
     FractionBox["574", "15"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["304", "15"], ",", 
     FractionBox["656", "15"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.770178618900818*^9, 3.794206209396542*^9, 
  3.813569870307042*^9, 3.8135706735475492`*^9},
 CellLabel->"Out[10]=",
 CellID->1334595629,ExpressionUUID->"01cc5ad6-26c1-4c1a-8a13-c677b5eae545"]
}, Open  ]],

Cell["View the expected table in table form:", "CodeCaption",
 CellChangeTimes->{
  3.769936722027129*^9, {3.7772178398528624`*^9, 3.7772178427337265`*^9}},
 CellID->489639093,ExpressionUUID->"146dbee7-6e06-41b4-888c-83bbedd14ced"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TableForm", "[", 
   RowBox[{"fit", ",", 
    RowBox[{"TableHeadings", "\[Rule]", "rc"}]}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.769936701161989*^9, 3.769936737844915*^9}},
 CellLabel->"In[11]:=",
 CellID->560541313,ExpressionUUID->"e08adcad-97fc-4c97-9974-4f84b2275a75"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"Died\"\>",
       HoldForm], 
      TagBox["\<\"Survived\"\>",
       HoldForm]},
     {
      TagBox["\<\"COAD\"\>",
       HoldForm], "17.733333333333334`", "38.266666666666666`"},
     {
      TagBox["\<\"CB\"\>",
       HoldForm], "20.266666666666666`", "43.733333333333334`"}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, 
      "Rows" -> {False, True, {False}, False}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{"COAD", "CB"}, {"Died", "Survived"}}]]]], "Output",
 CellChangeTimes->{3.7699367390101748`*^9, 3.7701786189320307`*^9, 
  3.813569870313002*^9, 3.813570673554597*^9},
 CellLabel->"Out[11]//TableForm=",
 CellID->82043688,ExpressionUUID->"9645aecc-535b-49ac-9c05-ba6396ad4152"]
}, Open  ]],

Cell[TextData[{
 "Next, we complete the calculation of the residuals, the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"d11b45f1-44e7-465c-9854-57131f5f772f"],
 " array, and the degrees of freedom in order to calculate the ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "9a2e39a9-cf60-4f56-8184-7c4ff741e948"],
 "-value."
}], "Text",
 CellChangeTimes->{{3.7699367695556364`*^9, 3.7699368296665964`*^9}, {
  3.777218119771274*^9, 3.777218129920289*^9}, {3.7942062387360864`*^9, 
  3.794206239512783*^9}},
 CellID->291357908,ExpressionUUID->"0a295139-69d8-4eba-bc7f-d568b2dcfe00"],

Cell["Calculate the residuals:", "CodeCaption",
 CellChangeTimes->{{3.7699368474130015`*^9, 3.7699368568767743`*^9}, {
  3.777218132859583*^9, 3.7772181332756243`*^9}},
 CellID->231975037,ExpressionUUID->"cc71bcd0-0f15-4e05-b796-041dc888ad94"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"residual", "=", 
  RowBox[{"obs", "-", "fit"}]}]], "Input",
 CellChangeTimes->{{3.769936837772878*^9, 3.769936866089886*^9}},
 CellLabel->"In[12]:=",
 CellID->549547249,ExpressionUUID->"03e892ab-4a72-4f0d-9f1f-f69726ac3e8a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["4", "15"], ",", 
     RowBox[{"-", 
      FractionBox["4", "15"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["4", "15"]}], ",", 
     FractionBox["4", "15"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7699368665063667`*^9, 3.7701786189697804`*^9, 
  3.7942062917250338`*^9, 3.813569870318653*^9, 3.813570673561287*^9},
 CellLabel->"Out[12]=",
 CellID->223762842,ExpressionUUID->"c60d72c1-a9f0-4506-bf0d-4a6e0e585d90"]
}, Open  ]],

Cell[TextData[{
 "Calculate the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]],ExpressionUUID->
  "de0cd438-08c4-48b6-8c22-ed3de73f3a30"],
 " array:"
}], "CodeCaption",
 CellChangeTimes->{{3.769936878099419*^9, 3.769936886641637*^9}, {
  3.7772181353638334`*^9, 3.777218135803877*^9}},
 CellID->156193703,ExpressionUUID->"a54da5da-0a73-45fe-950b-2089763d6548"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Chi]2Array", "=", 
  FractionBox[
   SuperscriptBox["residual", "2"], "fit"]}]], "Input",
 CellChangeTimes->{3.769936891225763*^9},
 CellLabel->"In[13]:=",
 CellID->276006547,ExpressionUUID->"c538213c-878e-4a09-946a-48910d9d1bae"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["8", "1995"], ",", 
     FractionBox["8", "4305"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "285"], ",", 
     FractionBox["1", "615"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769936891780365*^9, 3.770178619002788*^9, 
  3.7942062946283493`*^9, 3.813569870336686*^9, 3.813570673584989*^9},
 CellLabel->"Out[13]=",
 CellID->538219597,ExpressionUUID->"df1ce645-9404-4213-9d18-ed0577499a0f"]
}, Open  ]],

Cell["Calculate the degrees of freedom:", "CodeCaption",
 CellChangeTimes->{{3.769936905350376*^9, 3.769936911652521*^9}, {
  3.7772181414434414`*^9, 3.7772181419474916`*^9}},
 CellID->210702086,ExpressionUUID->"a6b677ac-c2d8-448b-9f61-66b4dde5fa63"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dof", "=", 
  RowBox[{
   RowBox[{"Length", "[", 
    RowBox[{"Flatten", "[", "obs", "]"}], "]"}], "-", 
   RowBox[{"Length", "[", "obs", "]"}], "-", 
   RowBox[{"Length", "[", 
    RowBox[{"Transpose", "[", "obs", "]"}], "]"}], "+", "1"}]}]], "Input",
 CellChangeTimes->{3.7699369143939214`*^9},
 CellLabel->"In[14]:=",
 CellID->55316480,ExpressionUUID->"98adfc5e-a23e-4a10-babd-14a665e62a7d"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.7699369147324224`*^9, 3.770178619019003*^9, 
  3.794206298399887*^9, 3.813569870342507*^9, 3.813570673591628*^9},
 CellLabel->"Out[14]=",
 CellID->655645615,ExpressionUUID->"e6376b14-66a0-457b-9178-d243cd101a6d"]
}, Open  ]],

Cell[TextData[{
 "Now we calculate a ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"3351ef40-96d1-4299-a281-8e7e80708a52"],
 " value given our ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"6b022dfb-94c8-4fa4-bca3-81053d791433"],
 " array:"
}], "CodeCaption",
 CellChangeTimes->{{3.7699369629465184`*^9, 3.7699369993634696`*^9}, {
   3.777218148612158*^9, 3.7772181537246695`*^9}, 3.816097829560392*^9},
 CellID->427405668,ExpressionUUID->"6c71553c-000f-4300-b3cb-e4516b388cec"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Chi]2", "=", 
   RowBox[{"Plus", "@@", 
    RowBox[{"Flatten", "[", "\[Chi]2Array", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Chi]2", "//", "N"}]}], "Input",
 CellChangeTimes->{{3.769936954972126*^9, 3.7699369596199074`*^9}, {
  3.7699370130187874`*^9, 3.7699370258960543`*^9}, {3.813568970174802*^9, 
  3.813568972238592*^9}, {3.8135705257539997`*^9, 3.8135705330350246`*^9}},
 CellLabel->"In[15]:=",
 CellID->556182814,ExpressionUUID->"1f295bef-dc53-4128-8ee8-4b3edb4c62ad"],

Cell[BoxData["0.011003117549972493`"], "Output",
 CellChangeTimes->{3.7699370271000013`*^9, 3.7701786190502467`*^9, 
  3.794206302089226*^9, 3.813569870365404*^9, 3.813570673613873*^9},
 CellLabel->"Out[16]=",
 CellID->697258548,ExpressionUUID->"1054aff6-f60b-489c-b3d5-5fac03e61d50"]
}, Open  ]],

Cell[TextData[{
 "Finally, we calculate the area under the curve for our ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"b6fab972-c110-4ae2-aa89-e8e9b5b8d672"],
 " value given a ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"aa237684-460f-43a8-9fc3-0bafefa5b8eb"],
 " distribution for a single degree of freedom."
}], "Text",
 CellChangeTimes->{{3.7699370386573963`*^9, 3.769937084570191*^9}},
 CellID->359938689,ExpressionUUID->"4d1615e5-848b-4034-953f-235bdb1add5f"],

Cell[TextData[{
 "Use ",
 ButtonBox["CDF",
  BaseStyle->"Link"],
 " and ",
 ButtonBox["ChiSquareDistribution",
  BaseStyle->"Link"],
 " to calculate the area under the curve (",
 Cell[BoxData[
  FormBox[
   StyleBox["p", "TI"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "c0de256b-0164-4328-921d-0c5b5f7527e9"],
 "-value):"
}], "CodeCaption",
 CellChangeTimes->{{3.769937113450742*^9, 3.7699371455014763`*^9}, {
  3.7772181646527615`*^9, 3.77721821704*^9}, {3.777218299636259*^9, 
  3.777218331438439*^9}},
 CellID->132657626,ExpressionUUID->"9e372a30-5833-438b-9549-6c8b579f824a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "-", 
   RowBox[{"CDF", "[", 
    RowBox[{
     RowBox[{"ChiSquareDistribution", "[", "dof", "]"}], ",", "\[Chi]2"}], 
    "]"}]}], "//", "N"}]], "Input",
 CellChangeTimes->{
  3.813568976134665*^9, {3.813570578243392*^9, 3.813570579538917*^9}},
 CellLabel->"In[17]:=",
 CellID->199653271,ExpressionUUID->"b15cd6cb-074a-4f22-a0c8-2a806a142161"],

Cell[BoxData["0.9164585344676583`"], "Output",
 CellChangeTimes->{3.769937097526586*^9, 3.7701786190854983`*^9, 
  3.7942063056972475`*^9, 3.813569870400062*^9, 3.813570673622162*^9},
 CellLabel->"Out[17]=",
 CellID->6154557,ExpressionUUID->"f18b7bb3-f4e6-4eea-8b72-1b95521ef0c8"]
}, Open  ]],

Cell[TextData[{
 "If we look at the plot below, we get an intuition of our large ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "9ecd8dff-55c2-42a2-aa85-617ac83ea12c"],
 "-value. It shows part of the graph of an ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"833aca4d-8de0-4d2c-97c0-c537cb27ae38"],
 " distribution with one degree of freedom (the probability distribution \
function). We also see a vertical line at our ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]], "InlineMath",
  ExpressionUUID->"3b499580-c494-4b68-a053-aeaa96cc8f56"],
 " value. The area under the curve that we are interested in lies to the \
right of this line. It is easy to see that this is the majority of the area \
under the curve."
}], "Text",
 CellChangeTimes->{{3.769937574319375*^9, 3.769937712053191*^9}, {
   3.777213448983014*^9, 3.777213459637014*^9}, {3.7772186386111526`*^9, 
   3.777218670475339*^9}, 3.8123076894669933`*^9},
 CellID->318146614,ExpressionUUID->"1f321afe-e098-4dcb-b3d8-aa77549cf082"],

Cell[TextData[{
 "Plotting ",
 ButtonBox["ChiSquareDistribution",
  BaseStyle->"Link"],
 " is easy, note axes settings and label naming:"
}], "CodeCaption",
 CellChangeTimes->{{3.7942219754054403`*^9, 3.7942220173516345`*^9}},
 CellID->235476410,ExpressionUUID->"8bc0b2cd-50d4-41bc-8129-de1d592e6a94"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"PDF", "[", 
      RowBox[{
       RowBox[{"ChiSquareDistribution", "[", "1", "]"}], ",", "x"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "0.4"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "5"}], "}"}]}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<\!\(\*SuperscriptBox[\(\[Chi]\), \(2\)]\) Distribution for a \
Single Degree of Freedom\>\""}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<Probability Density\>\""}], "}"}]}]}], 
    "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Line", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Chi]2", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Chi]2", ",", "5"}], "}"}]}], "}"}], "]"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.769937162017488*^9, 3.7699372105138283`*^9}, {
  3.769937281738039*^9, 3.769937407960223*^9}, {3.7699374864388285`*^9, 
  3.769937560879972*^9}, {3.7942063102898273`*^9, 3.7942063114494305`*^9}, {
  3.79420673867406*^9, 3.794206759760976*^9}, {3.794221696835586*^9, 
  3.794221698944797*^9}, {3.81230769863514*^9, 3.8123077124191236`*^9}, {
  3.813568978814788*^9, 3.8135689815748177`*^9}, {3.8135705904751863`*^9, 
  3.81357059465093*^9}},
 CellLabel->"In[18]:=",
 CellID->279258013,ExpressionUUID->"4e89eba6-8cf2-4856-95fc-ce79ead2a769"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwdlXk41HsDxRljCRVRSSQirm4lSlHd8yW6ueq2ylJCy6vVUloIEYXs+7UL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        "]]},
      Annotation[#, "Charting`Private`Tag$3578#1"]& ]}, {}}, 
   LineBox[
    NCache[{{Rational[60, 5453], 0}, {Rational[60, 5453], 5}}, {{
      0.011003117549972493`, 0}, {0.011003117549972493`, 5}}]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"Probability Density\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{466., Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"\\!\\(\\*SuperscriptBox[\\(\[Chi]\\), \\(2\\)]\\) Distribution for a \
Single Degree of Freedom\"", TraditionalForm],
  PlotRange->{{0., 0.39999999183673474`}, {0, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7699371800342045`*^9, 3.769937211007986*^9}, {
   3.7699372836677585`*^9, 3.769937314752638*^9}, 3.769937386786121*^9, {
   3.7699375265659885`*^9, 3.7699375616436567`*^9}, 3.7701786193641834`*^9, 
   3.813570673753581*^9},
 CellLabel->"Out[18]=",
 CellID->360424443,ExpressionUUID->"1b244716-ec2c-4465-b612-61c68afe9beb"]
}, Open  ]],

Cell[TextData[{
 "We can now finally write the following in our research manuscript: A total \
number of ",
 Cell[BoxData[
  FormBox["38", TraditionalForm]],ExpressionUUID->
  "43b24783-45d7-4355-80a2-da3b4278ea26"],
 " (",
 Cell[BoxData[
  FormBox["31.7", TraditionalForm]],ExpressionUUID->
  "1861dc6d-6302-488a-8f2c-e432dd21a9af"],
 "%) patients succumbed during their hospital admission, ",
 Cell[BoxData[
  FormBox["18", TraditionalForm]],ExpressionUUID->
  "d493ca80-7fc0-421a-9882-f6929d499da3"],
 " (",
 Cell[BoxData[
  FormBox["32.1", TraditionalForm]],ExpressionUUID->
  "4c659c79-9078-45d3-b3ca-0a9340801799"],
 "%) deaths for those with COAD and ",
 Cell[BoxData[
  FormBox["20", TraditionalForm]],ExpressionUUID->
  "4d4d45f6-f57a-4618-a890-31b9087595b1"],
 " (",
 Cell[BoxData[
  FormBox["31.3", TraditionalForm]],ExpressionUUID->
  "c08fd301-6cab-4be8-9886-fb079ce59002"],
 "%) for those with CB. There was, therefore, no significant difference in \
mortality between these two groups (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]],ExpressionUUID->
  "3a4231f3-e3db-4435-9a2a-6d0cb69cc6eb"],
 " 0.01, ",
 StyleBox["p",
  FontSlant->"Italic"],
 " 0.92)."
}], "Text",
 CellChangeTimes->{{3.769937730365888*^9, 3.769937786397583*^9}, {
   3.777213462454014*^9, 3.7772134676400137`*^9}, {3.777218715621853*^9, 
   3.7772187354378347`*^9}, 3.816097900368444*^9},
 CellID->114771420,ExpressionUUID->"fa1aa5c9-84b7-4e35-adcd-e6db1c8929fe"],

Cell["Our secondary research questions are waiting.", "Text",
 CellChangeTimes->{{3.7699378497298403`*^9, 3.769937861799509*^9}},
 CellID->262180176,ExpressionUUID->"7c772da4-0946-4194-87df-5d593605b7db"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Difference in Age between the Two Groups", "Subsection",
 CellChangeTimes->{{3.693037992567856*^9, 3.6930379974276085`*^9}, {
  3.7247840133527436`*^9, 3.724784013898853*^9}, {3.7699346102867236`*^9, 
  3.769934616192512*^9}, {3.7699361920467234`*^9, 3.7699361931015687`*^9}, {
  3.7699378390031443`*^9, 3.7699378751916056`*^9}, {3.777213714873402*^9, 
  3.7772137224581604`*^9}},
 CellID->348412897,ExpressionUUID->"5d27ae38-cd33-44df-a8e1-51b5e4db1f97"],

Cell[TextData[{
 "Age is a continuous numerical variable. The null hypothesis is that there \
is no difference between the mean ages for the two groups and the alternative \
hypothesis is that there is a difference in the mean values. Since we are \
comparing two independent groups, we can use the Student ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath",ExpressionUUID->
  "e14370e3-9462-4716-a5c9-416634e71c4b"],
 " test. This is a parametric test, and we need to check the assumptions for \
its use."
}], "Text",
 CellChangeTimes->{{3.769937880353511*^9, 3.7699380109767494`*^9}, {
  3.770182969692671*^9, 3.770183005586691*^9}, {3.7772134715730143`*^9, 
  3.7772134767640142`*^9}, {3.777219254836769*^9, 3.777219273077593*^9}, {
  3.816097971688698*^9, 3.81609797408797*^9}},
 CellID->832046646,ExpressionUUID->"0897739e-c309-43ec-8db8-485216fb79d3"],

Cell["\<\
Our first port of call, though, is to summarize our data using descriptive \
statistics.\
\>", "Text",
 CellChangeTimes->{{3.7699380189437246`*^9, 3.769938054231024*^9}, 
   3.777219279236209*^9, 3.816098000136424*^9},
 CellID->76186256,ExpressionUUID->"0b9c8b75-19b5-46d2-83a4-bd317d0bce55"],

Cell[TextData[{
 "Use the ",
 ButtonBox["GroupBy",
  BaseStyle->"Link"],
 " function and then a list of summary statistics:"
}], "CodeCaption",
 CellChangeTimes->{{3.769938115102972*^9, 3.7699381306742983`*^9}, {
  3.7772192813964252`*^9, 3.777219287126998*^9}},
 CellID->316623044,ExpressionUUID->"68042cbb-a6db-4ccc-9b1f-4c21192f3b69"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{
   RowBox[{"GroupBy", "[", "\"\<Group\>\"", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "Min", ",", "Max", ",", "Mean", ",", "Median", ",", "StandardDeviation", 
     ",", "InterquartileRange"}], "}"}], ",", "\"\<Age\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.7699380561028786`*^9, 3.769938093510317*^9}, {
  3.7699401547480783`*^9, 3.769940187539474*^9}},
 CellLabel->"In[19]:=",
 CellID->124555380,ExpressionUUID->"6d77deb6-dd6f-4830-9094-bd366f0956a8"],

Cell[BoxData[
 TagBox[
  TagBox[
   DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = 
    Association["InitialData" -> Association["COAD" -> {18, 74, 
         Rational[321, 7], 47, Rational[120378, 385]^Rational[1, 2], 
         Rational[63, 2]}, "CB" -> {19, 77, 
         Rational[807, 16], 53, Rational[1, 6] 
         Rational[78391, 7]^Rational[1, 2], 
         Rational[67, 2]}], "InitialShape" -> TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`ColumnShape[
        TypeSystem`PackageScope`KeyValueShape[
         TypeSystem`PackageScope`AtomShape[36.], 
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`RowShape[{
            TypeSystem`PackageScope`AtomShape[34], 
            TypeSystem`PackageScope`AtomShape[34], 
            TypeSystem`PackageScope`AtomShape[34], 
            TypeSystem`PackageScope`AtomShape[34], 
            TypeSystem`PackageScope`AtomShape[60], 
            TypeSystem`PackageScope`AtomShape[34]}], 
          DirectedInfinity[1], 6, {All}]]], 2, 
       DirectedInfinity[1], {}], "InitialType" -> TypeSystem`Assoc[
       TypeSystem`Atom[
        TypeSystem`Enumeration["CB", "COAD"]], 
       TypeSystem`Tuple[{
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[Rational], 
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[Real], 
         TypeSystem`Atom[Rational]}], 2], "Meta" -> 
     Association["ID" -> 131980266057458], "RowTarget" -> 20, "ColumnTarget" -> 
     10, "Shape" -> TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`ColumnShape[
        TypeSystem`PackageScope`KeyValueShape[
         TypeSystem`PackageScope`AtomShape[36.], 
         TypeSystem`PackageScope`Limited[
          TypeSystem`PackageScope`RowShape[{
            TypeSystem`PackageScope`AtomShape[34], 
            TypeSystem`PackageScope`AtomShape[34], 
            TypeSystem`PackageScope`AtomShape[34], 
            TypeSystem`PackageScope`AtomShape[34], 
            TypeSystem`PackageScope`AtomShape[60], 
            TypeSystem`PackageScope`AtomShape[34]}], 
          DirectedInfinity[1], 6, {All}]]], 2, 
       DirectedInfinity[1], {}], "Type" -> TypeSystem`Assoc[
       TypeSystem`Atom[
        TypeSystem`Enumeration["CB", "COAD"]], 
       TypeSystem`Tuple[{
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[Rational], 
         TypeSystem`Atom[Integer], 
         TypeSystem`Atom[Real], 
         TypeSystem`Atom[Rational]}], 2], "Path" -> {}, "BaseIndices" -> {}, 
     "DisplayedRowCount" -> 2, "DisplayedColumnCount" -> 6, "DataRowCount" -> 
     2, "DataColumnCount" -> 6, "SortPaths" -> {}, "SortDirections" -> {}, 
     "HiddenItemsMap" -> Null, "UpdateType" -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`$outputID$$, 
    TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
    TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
    DynamicModule[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
        Style[
         Grid[{{
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["COAD", 
                  Style[
                  "COAD", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["COAD"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"]}, "RowHeader", False], "Mouse"], 
              ImageSize -> {{36., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["18"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"], 1}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["74"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"], 2}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["45.8571"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"], 3}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["47"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"], 4}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["17.6825"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"], 5}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["63/2"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"], 6}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["CB", 
                  Style[
                  "CB", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["CB"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"]}, "RowHeader", False], "Mouse"], 
              ImageSize -> {{36., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["19"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"], 1}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["77"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"], 2}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["50.4375"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"], 3}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["53"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"], 4}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["17.6373"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"], 5}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}], 
            Item[
             Pane[
              Annotation[
               RawBoxes["67/2"], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"], 6}, "Item", False], "Mouse"], 
              ImageSize -> {{34, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}}, 
          BaseStyle -> {
           ContextMenu -> 
            Dynamic[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
              Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                 TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu, True, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger = 
                 TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                 Block[{TypeSystem`NestedGrid`PackagePrivate`$globalScrollPos = \
{TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                   
                   With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Show ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Hide ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic]}]]]]], FontFamily -> 
            "Verdana", FontSize -> 12}, Spacings -> {0, 0}, Alignment -> Left,
           Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
          BaseStyle -> {FontFamily -> "Verdana", FontSize -> 12}], 
         LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> False, 
         ShowAutoStyles -> False]], 
      TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
     Dynamic[
      TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
         Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
         Module[{
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
           TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
           TypeSystem`NestedGrid`PackagePrivate`datasetData[
            TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
             TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
             TypeSystem`NestedGrid`PackagePrivate`renderGrid[
             TypeSystem`NestedGrid`PackagePrivate`$state$$, 
              TypeSystem`NestedGrid`PackagePrivate`$path$$, 
              TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
              TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
             TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
            Not[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
            TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
       TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
       TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
         FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
         TypeSystem`SparseGrid[
          TypeSystem`H["(data no longer present)"]], 
         If[GeneralUtilities`$DebugMode, 
          Row[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid, "  ", 
            TypeSystem`NestedGrid`PackagePrivate`formatState[
            TypeSystem`NestedGrid`PackagePrivate`$state$$, 
             TypeSystem`NestedGrid`PackagePrivate`$path$$, 
             TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
             TypeSystem`NestedGrid`PackagePrivate`$hPos$$]}], 
          TypeSystem`NestedGrid`PackagePrivate`renderedGrid]]], 
      TrackedSymbols :> {
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
     DynamicModuleValues :> {}], 
    TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
     TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
      TypeSystem`PackageScope`SubViewPathbar[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, 
       TypeSystem`NestedGrid`PackagePrivate`updateState[
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$path$$, 
        TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
        TypeSystem`NestedGrid`PackagePrivate`localHold[
        TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
     TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
    TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
     Framed[
      Dynamic[
       Replace[
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
        TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
           Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
           Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
            Blank[]]] :> (
          Increment[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
           TypeSystem`NestedGrid`PackagePrivate`path$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
           TypeSystem`NestedGrid`PackagePrivate`pathType$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
           TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
           TypeSystem`NestedGrid`PackagePrivate`localHold[
            TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
          TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
           TypeSystem`NestedGrid`PackagePrivate`path$, 
            TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
         Spacer[10], Blank[] :> Spacer[10]}], 
       TrackedSymbols :> {
        TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], FrameStyle -> 
      None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> Top, 
      ImageSize -> {Automatic, 15}], FontSize -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
    DynamicWrapperBox[
     DynamicBox[ToBoxes[
       Dataset`DatasetContent[
       2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
        "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], "State" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], "VPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], "HPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], "TopBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], "BottomBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
        Hold[
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
      ImageSizeCache->{359., {39.8837890625, 47.1162109375}},
      TrackedSymbols:>{
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
     TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
     MouseAnnotation[],
     ImageSizeCache->{359., {39.8837890625, 47.1162109375}}],
    BaseStyle->{LineBreakWithin -> False},
    DynamicModuleValues:>{},
    Initialization:>
     Block[{$ContextPath = $ContextPath}, Needs["TypeSystem`"]; 
      Needs["Dataset`"]; 
      TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = CreateUUID[]],
    UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Dataset`InterpretDataset[1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{
  3.769938094099122*^9, {3.7699401597099323`*^9, 3.7699401802589636`*^9}, 
   3.7701786194020014`*^9, 3.7942068070351114`*^9, 3.813569870573247*^9, 
   3.813570673782414*^9},
 CellLabel->"Out[19]=",
 CellID->1749728961,ExpressionUUID->"3c6e6797-7679-42b8-8572-beb4c2169ae6"]
}, Open  ]],

Cell[TextData[{
 "To visualize the data, a box-and-whisker chart will be appropriate. We can \
divide our ",
 ButtonBox["Dataset",
  BaseStyle->"Link"],
 " object by the sample space elements of the ",
 Cell[BoxData[
 "\"\<Group\>\""], "InlineCodeText",ExpressionUUID->
  "513f82e5-3862-4df8-92a7-6033066d57e1"],
 " variable."
}], "Text",
 CellChangeTimes->{{3.769938542163905*^9, 3.7699385840491805`*^9}, 
   3.777213479381014*^9, {3.777219303409626*^9, 3.7772193097122564`*^9}, {
   3.8160980301093273`*^9, 3.8160980465266457`*^9}},
 CellID->11869537,ExpressionUUID->"26ec73d5-88d6-44e3-9477-cbecbf21699b"],

Cell[TextData[{
 "Use the ",
 ButtonBox["Select",
  BaseStyle->"Link"],
 " function to create two unique ",
 ButtonBox["Dataset",
  BaseStyle->"Link"],
 " objects:"
}], "CodeCaption",
 CellChangeTimes->{{3.769938628487242*^9, 3.769938641912054*^9}, {
  3.7772193130145864`*^9, 3.777219332405525*^9}},
 CellID->584887299,ExpressionUUID->"0878b761-73cf-45d0-858b-d6851601a412"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"coad", "=", 
   RowBox[{"data", "[", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"#Group", "\[Equal]", "\"\<COAD\>\""}], "&"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cb", "=", 
   RowBox[{"data", "[", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"#Group", "\[Equal]", "\"\<CB\>\""}], "&"}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7699385881733437`*^9, 3.7699386204455075`*^9}, {
  3.7699388771067934`*^9, 3.7699388825856357`*^9}},
 CellLabel->"In[20]:=",
 CellID->304891001,ExpressionUUID->"5a85c712-22ab-4dbd-9bc1-4aa3b9118fd7"],

Cell[TextData[{
 "By setting these definitions, we can then extract two separate ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " objects to hold all the age values for each group."
}], "Text",
 CellChangeTimes->{{3.7699386668814707`*^9, 3.769938685808613*^9}, 
   3.7772193487181563`*^9, 3.813569051643117*^9},
 CellID->398226518,ExpressionUUID->"278bdf48-e104-44d0-a48a-c5be66f108c8"],

Cell[TextData[{
 "Use the ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " function to extract ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " objects:"
}], "CodeCaption",
 CellChangeTimes->{{3.7699387458817005`*^9, 3.7699387551498823`*^9}, {
  3.777219352536538*^9, 3.777219360243309*^9}},
 CellID->415164823,ExpressionUUID->"d45e0d5e-62ab-4a9b-afae-d9beaaf81a60"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"coadAge", "=", 
   RowBox[{
    RowBox[{"Normal", "[", 
     RowBox[{"coad", "[", 
      RowBox[{"List", ",", "\"\<Age\>\""}], "]"}], "]"}], 
    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cbAge", "=", 
   RowBox[{
    RowBox[{"Normal", "[", 
     RowBox[{"cb", "[", 
      RowBox[{"List", ",", "\"\<Age\>\""}], "]"}], "]"}], 
    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7699386905011497`*^9, 3.7699387365993805`*^9}, {
  3.7699388594916296`*^9, 3.76993886365327*^9}},
 CellLabel->"In[22]:=",
 CellID->63692354,ExpressionUUID->"fcc1b231-b8c3-4e0c-adc4-1ee0d2e97907"],

Cell["We are now ready to create our data visualization.", "Text",
 CellChangeTimes->{{3.7699387772399273`*^9, 3.769938787346051*^9}},
 CellID->512262379,ExpressionUUID->"1ba473b7-835f-4e71-9642-f6fffd7477ec"],

Cell[TextData[{
 "Use the ",
 ButtonBox["BoxWhiskerChart",
  BaseStyle->"Link"],
 " function to visualize the data. Add a plot label and chart labels:"
}], "CodeCaption",
 CellChangeTimes->{{3.7699389654976935`*^9, 3.769938999837431*^9}, 
   3.7772134825000143`*^9, {3.7772193681370983`*^9, 3.777219376473932*^9}},
 CellID->221962001,ExpressionUUID->"19fa5065-e1ff-4fc6-ad6b-6c221ecb794a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BoxWhiskerChart", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"coadAge", ",", "cbAge"}], "}"}], ",", "\"\<Outliers\>\"", ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", "\"\<Age Difference Between Two Groups\>\""}], ",", 
   RowBox[{"ChartLabels", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<COAD\>\"", ",", "\"\<CB\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769938790197585*^9, 3.769938837807793*^9}, {
  3.769938912037232*^9, 3.7699389529732294`*^9}, {3.7699390157797513`*^9, 
  3.769939023823239*^9}, {3.813569260645709*^9, 3.8135692694774933`*^9}},
 CellLabel->"In[24]:=",
 CellID->21890781,ExpressionUUID->"ec01fced-fc24-4b24-97a3-4a7c17ffedee"],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], 
    PointBox[{{0.3836399216673073, 15.05}, {2.6163600783326926`, 79.95}}]}, 
   {RGBColor[0.982864, 0.7431472, 0.3262672], CapForm[None], {}, 
    {RGBColor[0.982864, 0.7431472, 0.3262672], 
     {RGBColor[0.982864, 0.7431472, 0.3262672], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           GraphicsGroupBox[{Antialiasing -> False, 
             PolygonBox[
              NCache[{{0.7754133086869819, 
                 Rational[121, 2]}, {1.2245866913130181`, 
                 Rational[121, 2]}, {1.2245866913130181`, 29}, {
                0.7754133086869819, 29}}, {{0.7754133086869819, 60.5}, {
                1.2245866913130181`, 60.5}, {1.2245866913130181`, 29}, {
                0.7754133086869819, 29}}]], {}, {{}, {}}, {}, {
              GrayLevel[0], 
              GrayLevel[1], 
              
              LineBox[{{1.2245866913130181`, 47}, {
                0.7754133086869819, 47}}]}, {}, {
              GrayLevel[0], 
              GrayLevel[0.5], 
              LineBox[
               NCache[{{{1., 29}, {1., 18}}, {{1., 
                   Rational[121, 2]}, {1., 74}}}, {{{1., 29}, {1., 18}}, {{1.,
                   60.5}, {1., 74}}}]]}, {
              GrayLevel[0], 
              GrayLevel[0.5], 
              
              LineBox[{{{1.112293345656509, 18}, {0.8877066543434909, 18}}, {{
                 1.112293345656509, 74}, {0.8877066543434909, 74}}}]}, {}}]},
          
          ImageSizeCache->{{98.5857864376269, 
           177.4142135623731}, {-98.4142135623731, 105.4142135623731}}],
         "DelayedMouseEffectStyle"],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], "74"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], 
             FractionBox["121", "2"]}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], "47"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], "29"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], "18"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 74}, {
            Style["75%", Bold], 
            Rational[121, 2]}, {
            Style["median", Bold], 47}, {
            Style["25%", Bold], 29}, {
            Style["min", Bold], 18}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           GraphicsGroupBox[{Antialiasing -> False, 
             PolygonBox[
              
              NCache[{{1.7754133086869819`, 66}, {2.224586691313018, 66}, {
                2.224586691313018, 
                 Rational[65, 2]}, {1.7754133086869819`, 
                 Rational[65, 2]}}, {{1.7754133086869819`, 66}, {
                2.224586691313018, 66}, {2.224586691313018, 32.5}, {
                1.7754133086869819`, 32.5}}]], {}, {{}, {}}, {}, {
              GrayLevel[0], 
              GrayLevel[1], 
              
              LineBox[{{2.224586691313018, 53}, {
                1.775413308686982, 53}}]}, {}, {
              GrayLevel[0], 
              GrayLevel[0.5], 
              LineBox[
               NCache[{{{2., 
                   Rational[65, 2]}, {2., 19}}, {{2., 66}, {2., 77}}}, {{{2., 
                  32.5}, {2., 19}}, {{2., 66}, {2., 77}}}]]}, {
              GrayLevel[0], 
              GrayLevel[0.5], 
              
              LineBox[{{{2.112293345656509, 19}, {1.887706654343491, 19}}, {{
                 2.112293345656509, 77}, {1.887706654343491, 77}}}]}, {}}]},
          
          ImageSizeCache->{{267.5857864376269, 
           346.4142135623731}, {-109.4142135623731, 101.4142135623731}}],
         "DelayedMouseEffectStyle"],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], "77"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], "66"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], "53"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], 
             FractionBox["65", "2"]}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], "19"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 77}, {
            Style["75%", Bold], 66}, {
            Style["median", Bold], 53}, {
            Style["25%", Bold], 
            Rational[65, 2]}, {
            Style["min", Bold], 19}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {}], 
        "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, \
{}}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0.70295463955568, 15.05},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {{{1., 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {1., 
       FormBox["\"COAD\"", TraditionalForm], 0}, {2., 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {2., 
       FormBox["\"CB\"", TraditionalForm], 0}, {0.7754133086869819, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {
      2.224586691313018, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, {{1., 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {2., 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {
      0.7754133086869819, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {
      2.224586691313018, 
       FormBox[
        TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{433., Automatic},
  PlotLabel->FormBox["\"Age Difference Between Two Groups\"", TraditionalForm],
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{{{1., 
      FormBox[
       TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {1., 
      FormBox["\"COAD\"", TraditionalForm], 0}, {2., 
      FormBox[
       TemplateBox[{0}, "Spacer1"], TraditionalForm], {0.008, 0}}, {2., 
      FormBox["\"CB\"", TraditionalForm], 0}, {0.7754133086869819, 
      FormBox[
       TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}, {
     2.224586691313018, 
      FormBox[
       TemplateBox[{0}, "Spacer1"], TraditionalForm], {0, 0}}}, 
    Automatic}]], "Output",
 CellChangeTimes->{
  3.7699388395715084`*^9, 3.769938889474828*^9, {3.7699389195856514`*^9, 
   3.7699389537290335`*^9}, 3.7699390251558*^9, 3.7701786196179504`*^9, 
   3.813569870708034*^9, 3.813570673923374*^9},
 CellLabel->"Out[24]=",
 CellID->53585509,ExpressionUUID->"8694f8ca-ee0a-4e8e-9362-a2644c926f78"]
}, Open  ]],

Cell[TextData[{
 "For a quick look at the two distributions, we can group the original ",
 ButtonBox["Dataset",
  BaseStyle->"Link"],
 " object by the ",
 ButtonBox["Group",
  BaseStyle->"Link"],
 " variable and plot the two histograms."
}], "Text",
 CellChangeTimes->{{3.769939047786327*^9, 3.7699390901845875`*^9}, {
  3.77721938436172*^9, 3.7772193918334675`*^9}},
 CellID->36409792,ExpressionUUID->"a2fea88d-72d0-4eff-8135-7a6ef1d0f9af"],

Cell["\<\
By clicking on one of the two histograms, a detailed version of it will \
appear.\
\>", "Text",
 CellChangeTimes->{{3.769939176840677*^9, 3.769939212550232*^9}},
 CellID->697675545,ExpressionUUID->"fdfc244b-af22-4814-91a4-c88956020330"],

Cell[TextData[{
 "Use ",
 ButtonBox["Slot",
  BaseStyle->"Link"],
 " notation, ",
 Cell[BoxData[
  ButtonBox["#",
   BaseStyle->"Link",
   ButtonData->"Slot"]], "InlineCode",ExpressionUUID->
  "1a12de3b-6e45-422e-a259-8355517a5981"],
 ",  to add a title and axes labels:"
}], "CodeCaption",
 CellChangeTimes->{{3.78981991574242*^9, 3.7898199855272284`*^9}, {
  3.789820022779044*^9, 3.7898200709815407`*^9}},
 CellID->441140419,ExpressionUUID->"ebe5180c-9b85-47b7-9ccb-c2a30172f20a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{
   RowBox[{"GroupBy", "[", "\"\<Group\>\"", "]"}], ",", 
   RowBox[{
    RowBox[{"Histogram", "[", 
     RowBox[{"#", ",", 
      RowBox[{"PlotLabel", "\[Rule]", "\"\<Distribution of Ages\>\""}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Age bracket\>\"", ",", "\"\<Count\>\""}], "}"}]}]}], 
     "]"}], "&"}], ",", "\"\<Age\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.769938155775231*^9, 3.7699381989269037`*^9}, {
   3.769938276117863*^9, 3.769938284045841*^9}, {3.769938337170971*^9, 
   3.769938338946576*^9}, {3.7699391066022463`*^9, 3.769939167191472*^9}, {
   3.769939232065588*^9, 3.769939236930661*^9}, {3.7699392695591087`*^9, 
   3.7699393049582663`*^9}, 3.813569247421672*^9},
 CellLabel->"In[25]:=",
 CellID->162965074,ExpressionUUID->"e8284d23-7ef2-4ff6-8452-0d4bf16852fe"],

Cell[BoxData[
 TagBox[
  TagBox[
   DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = 
    Association["InitialData" -> Association["COAD" -> Graphics[{{
           Directive[
            EdgeForm[
             Directive[
              Thickness[Small], 
              Opacity[0.6579999999999999]]], 
            RGBColor[
            0.987148, 0.8073604000000001, 0.49470040000000004`]], {{}, {
             Directive[
              EdgeForm[
               Directive[
                Thickness[Small], 
                Opacity[0.6579999999999999]]], 
              RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`]], {{
               Tooltip[
                StatusArea[{
                  Charting`DelayedMouseEffect[
                   Rectangle[{0., 0}, {20., 1.}, "RoundingRadius" -> 0], {
                   "Style", 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}]}]}, 1], 
                Style[1, {}]]}, {
               Tooltip[
                StatusArea[{
                  Charting`DelayedMouseEffect[
                   Rectangle[{20., 0}, {40., 22.}, "RoundingRadius" -> 0], {
                   "Style", 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}]}]}, 22], 
                Style[22, {}]]}, {
               Tooltip[
                StatusArea[{
                  Charting`DelayedMouseEffect[
                   Rectangle[{40., 0}, {60., 18.}, "RoundingRadius" -> 0], {
                   "Style", 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}]}]}, 18], 
                Style[18, {}]]}, {
               Tooltip[
                StatusArea[{
                  Charting`DelayedMouseEffect[
                   Rectangle[{60., 0}, {80., 15.}, "RoundingRadius" -> 0], {
                   "Style", 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}]}]}, 15], 
                Style[15, {}]]}}}, {}, {}}}, {{}, {}, {}, {}}}, {
         AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {"Age bracket", "Count"}, AxesOrigin -> {-1.6, 0}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], PlotLabel -> "Distribution of Ages", 
          PlotRange -> {{0., 80.}, {All, All}}, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], "CB" -> 
       Graphics[{{
           Directive[
            EdgeForm[
             Directive[
              Thickness[Small], 
              Opacity[0.6579999999999999]]], 
            RGBColor[
            0.987148, 0.8073604000000001, 0.49470040000000004`]], {{}, {
             Directive[
              EdgeForm[
               Directive[
                Thickness[Small], 
                Opacity[0.6579999999999999]]], 
              RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`]], {{
               Tooltip[
                StatusArea[{
                  Charting`DelayedMouseEffect[
                   Rectangle[{0., 0}, {20., 2.}, "RoundingRadius" -> 0], {
                   "Style", 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}]}]}, 2], 
                Style[2, {}]]}, {
               Tooltip[
                StatusArea[{
                  Charting`DelayedMouseEffect[
                   Rectangle[{20., 0}, {40., 18.}, "RoundingRadius" -> 0], {
                   "Style", 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}]}]}, 18], 
                Style[18, {}]]}, {
               Tooltip[
                StatusArea[{
                  Charting`DelayedMouseEffect[
                   Rectangle[{40., 0}, {60., 20.}, "RoundingRadius" -> 0], {
                   "Style", 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}]}]}, 20], 
                Style[20, {}]]}, {
               Tooltip[
                StatusArea[{
                  Charting`DelayedMouseEffect[
                   Rectangle[{60., 0}, {80., 24.}, "RoundingRadius" -> 0], {
                   "Style", 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}]}]}, 24], 
                Style[24, {}]]}}}, {}, {}}}, {{}, {}, {}, {}}}, {
         AspectRatio -> GoldenRatio^(-1), Axes -> {True, True}, 
          AxesLabel -> {"Age bracket", "Count"}, AxesOrigin -> {-1.6, 0}, 
          FrameLabel -> {{None, None}, {None, None}}, 
          FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
          GridLines -> {None, None}, GridLinesStyle -> Directive[
            GrayLevel[0.5, 0.4]], PlotLabel -> "Distribution of Ages", 
          PlotRange -> {{0., 80.}, {All, All}}, PlotRangePadding -> {{
             Scaled[0.02], 
             Scaled[0.02]}, {
             Scaled[0.02], 
             Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}]], 
     "InitialShape" -> TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`ColumnShape[
        TypeSystem`PackageScope`KeyValueShape[
         TypeSystem`PackageScope`AtomShape[36.], 
         TypeSystem`PackageScope`AtomShape[60]]], 2, 
       DirectedInfinity[1], {}], "InitialType" -> TypeSystem`Assoc[
       TypeSystem`Atom[
        TypeSystem`Enumeration["CB", "COAD"]], 
       TypeSystem`Atom[Graphics], 2], "Meta" -> 
     Association["ID" -> 132001740893938], "RowTarget" -> 20, "ColumnTarget" -> 
     10, "Shape" -> TypeSystem`PackageScope`Limited[
       TypeSystem`PackageScope`ColumnShape[
        TypeSystem`PackageScope`KeyValueShape[
         TypeSystem`PackageScope`AtomShape[36.], 
         TypeSystem`PackageScope`AtomShape[60]]], 2, 
       DirectedInfinity[1], {}], "Type" -> TypeSystem`Assoc[
       TypeSystem`Atom[
        TypeSystem`Enumeration["CB", "COAD"]], 
       TypeSystem`Atom[Graphics], 2], "Path" -> {}, "BaseIndices" -> {}, 
     "DisplayedRowCount" -> 2, "DisplayedColumnCount" -> 1, "DataRowCount" -> 
     2, "DataColumnCount" -> 1, "SortPaths" -> {}, "SortDirections" -> {}, 
     "HiddenItemsMap" -> Null, "UpdateType" -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`$outputID$$, 
    TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
    TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
    TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
    DynamicModule[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
        Style[
         Grid[{{
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["COAD", 
                  Style[
                  "COAD", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["COAD"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"]}, "RowHeader", False], "Mouse"], 
              ImageSize -> {{36., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               RawBoxes[
                GraphicsBox[{{
                   Directive[
                    EdgeForm[
                    Directive[
                    Thickness[Small], 
                    Opacity[0.6579999999999999]]], 
                    RGBColor[
                    0.987148, 0.8073604000000001, 
                    0.49470040000000004`]], {{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Thickness[Small], 
                    Opacity[0.6579999999999999]]], 
                    RGBColor[
                    0.987148, 0.8073604000000001, 0.49470040000000004`]], {{
                    TagBox[
                    TooltipBox[
                    TagBox[{
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    RectangleBox[{0., 0}, {20., 1.}, "RoundingRadius" -> 0]}],
                     "DelayedMouseEffectStyle"]}, StatusArea[#, 1]& , 
                    TagBoxNote -> "1"], 
                    StyleBox["1", {}, StripOnInput -> False]], Annotation[#, 
                    Style[1, {}], "Tooltip"]& ]}, {
                    TagBox[
                    TooltipBox[
                    TagBox[{
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{20., 0}, {40., 22.}, "RoundingRadius" -> 
                    0]}], "DelayedMouseEffectStyle"]}, StatusArea[#, 22]& , 
                    TagBoxNote -> "22"], 
                    StyleBox["22", {}, StripOnInput -> False]], Annotation[#, 
                    Style[22, {}], "Tooltip"]& ]}, {
                    TagBox[
                    TooltipBox[
                    TagBox[{
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{40., 0}, {60., 18.}, "RoundingRadius" -> 
                    0]}], "DelayedMouseEffectStyle"]}, StatusArea[#, 18]& , 
                    TagBoxNote -> "18"], 
                    StyleBox["18", {}, StripOnInput -> False]], Annotation[#, 
                    Style[18, {}], "Tooltip"]& ]}, {
                    TagBox[
                    TooltipBox[
                    TagBox[{
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{60., 0}, {80., 15.}, "RoundingRadius" -> 
                    0]}], "DelayedMouseEffectStyle"]}, StatusArea[#, 15]& , 
                    TagBoxNote -> "15"], 
                    StyleBox["15", {}, StripOnInput -> False]], Annotation[#, 
                    Style[15, {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{}, {}, {}, {}}}, {
                 PlotRangeClipping -> True, Frame -> True, FrameStyle -> 
                  GrayLevel[0.85], Ticks -> None, FrameTicks -> None, Axes -> 
                  None, ImageSize -> 96, AspectRatio -> 
                  NCache[GoldenRatio^(-1), 0.6180339887498948], 
                  Axes -> {True, True}, AxesLabel -> {
                    FormBox["\"Age bracket\"", TraditionalForm], 
                    FormBox["\"Count\"", TraditionalForm]}, 
                  AxesOrigin -> {-1.6, 0}, 
                  FrameLabel -> {{None, None}, {None, None}}, 
                  FrameTicks -> {{Automatic, Automatic}, {
                    Automatic, Automatic}}, GridLines -> {None, None}, 
                  GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], PlotLabel -> 
                  FormBox["\"Distribution of Ages\"", TraditionalForm], 
                  PlotRange -> {{0., 80.}, {All, All}}, PlotRangePadding -> {{
                    Scaled[0.02], 
                    Scaled[0.02]}, {
                    Scaled[0.02], 
                    Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["COAD"]}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}, {
            Item[
             Pane[
              Annotation[
               EventHandler[
                MouseAppearance[
                 Mouseover["CB", 
                  Style[
                  "CB", FontColor -> 
                   RGBColor[
                    0.27450980392156865`, 0.5372549019607843, 
                    0.792156862745098]]], "LinkHand"], {"MouseClicked", 1} :> 
                TypeSystem`NestedGrid`PackagePrivate`updateState[
                 TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                  TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                  TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`localHold[
                   TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][{
                   Key["CB"]}, 1]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"]}, "RowHeader", False], "Mouse"], 
              ImageSize -> {{36., Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], Background -> 
             GrayLevel[0.95], Alignment -> {Left, Baseline}], 
            Item[
             Pane[
              Annotation[
               RawBoxes[
                GraphicsBox[{{
                   Directive[
                    EdgeForm[
                    Directive[
                    Thickness[Small], 
                    Opacity[0.6579999999999999]]], 
                    RGBColor[
                    0.987148, 0.8073604000000001, 
                    0.49470040000000004`]], {{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Thickness[Small], 
                    Opacity[0.6579999999999999]]], 
                    RGBColor[
                    0.987148, 0.8073604000000001, 0.49470040000000004`]], {{
                    TagBox[
                    TooltipBox[
                    TagBox[{
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    RectangleBox[{0., 0}, {20., 2.}, "RoundingRadius" -> 0]}],
                     "DelayedMouseEffectStyle"]}, StatusArea[#, 2]& , 
                    TagBoxNote -> "2"], 
                    StyleBox["2", {}, StripOnInput -> False]], Annotation[#, 
                    Style[2, {}], "Tooltip"]& ]}, {
                    TagBox[
                    TooltipBox[
                    TagBox[{
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{20., 0}, {40., 18.}, "RoundingRadius" -> 
                    0]}], "DelayedMouseEffectStyle"]}, StatusArea[#, 18]& , 
                    TagBoxNote -> "18"], 
                    StyleBox["18", {}, StripOnInput -> False]], Annotation[#, 
                    Style[18, {}], "Tooltip"]& ]}, {
                    TagBox[
                    TooltipBox[
                    TagBox[{
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{40., 0}, {60., 20.}, "RoundingRadius" -> 
                    0]}], "DelayedMouseEffectStyle"]}, StatusArea[#, 20]& , 
                    TagBoxNote -> "20"], 
                    StyleBox["20", {}, StripOnInput -> False]], Annotation[#, 
                    Style[20, {}], "Tooltip"]& ]}, {
                    TagBox[
                    TooltipBox[
                    TagBox[{
                    TagBox[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    
                    RectangleBox[{60., 0}, {80., 24.}, "RoundingRadius" -> 
                    0]}], "DelayedMouseEffectStyle"]}, StatusArea[#, 24]& , 
                    TagBoxNote -> "24"], 
                    StyleBox["24", {}, StripOnInput -> False]], Annotation[#, 
                    Style[24, {}], 
                    "Tooltip"]& ]}}}, {}, {}}}, {{}, {}, {}, {}}}, {
                 PlotRangeClipping -> True, Frame -> True, FrameStyle -> 
                  GrayLevel[0.85], Ticks -> None, FrameTicks -> None, Axes -> 
                  None, ImageSize -> 96, AspectRatio -> 
                  NCache[GoldenRatio^(-1), 0.6180339887498948], 
                  Axes -> {True, True}, AxesLabel -> {
                    FormBox["\"Age bracket\"", TraditionalForm], 
                    FormBox["\"Count\"", TraditionalForm]}, 
                  AxesOrigin -> {-1.6, 0}, 
                  FrameLabel -> {{None, None}, {None, None}}, 
                  FrameTicks -> {{Automatic, Automatic}, {
                    Automatic, Automatic}}, GridLines -> {None, None}, 
                  GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], PlotLabel -> 
                  FormBox["\"Distribution of Ages\"", TraditionalForm], 
                  PlotRange -> {{0., 80.}, {All, All}}, PlotRangePadding -> {{
                    Scaled[0.02], 
                    Scaled[0.02]}, {
                    Scaled[0.02], 
                    Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}]], 
               TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][{
                 Key["CB"]}, "Item", False], "Mouse"], 
              ImageSize -> {{60, Full}, Automatic}, 
              ImageMargins -> {{5, 3}, {4, 5}}], 
             ItemSize -> {Full, Automatic}]}}, 
          BaseStyle -> {
           ContextMenu -> 
            Dynamic[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
              Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
                TypeSystem`NestedGrid`PackagePrivate`localHold[
                 TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
                TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu, True, 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger = 
                 TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
                TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                 Block[{TypeSystem`NestedGrid`PackagePrivate`$globalScrollPos = \
{TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                   
                   With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                    Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Show ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    StringJoin["Hide ", 
                    Which[
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""]], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic]}]]]]], FontFamily -> 
            "Verdana", FontSize -> 12}, Spacings -> {0, 0}, Alignment -> Left,
           Dividers -> All, FrameStyle -> GrayLevel[0.7490196078431373], 
          BaseStyle -> {FontFamily -> "Verdana", FontSize -> 12}], 
         LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> False, 
         ShowAutoStyles -> False]], 
      TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
     Dynamic[
      TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
         Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
         Module[{
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
           TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
           TypeSystem`NestedGrid`PackagePrivate`datasetData[
            TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
          TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
             TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
             TypeSystem`NestedGrid`PackagePrivate`renderGrid[
             TypeSystem`NestedGrid`PackagePrivate`$state$$, 
              TypeSystem`NestedGrid`PackagePrivate`$path$$, 
              TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
              TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
              TypeSystem`NestedGrid`PackagePrivate`localHold[
              TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
             TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
            Not[
             FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
            TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
       TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
       TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
         FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
         TypeSystem`SparseGrid[
          TypeSystem`H["(data no longer present)"]], 
         If[GeneralUtilities`$DebugMode, 
          Row[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid, "  ", 
            TypeSystem`NestedGrid`PackagePrivate`formatState[
            TypeSystem`NestedGrid`PackagePrivate`$state$$, 
             TypeSystem`NestedGrid`PackagePrivate`$path$$, 
             TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
             TypeSystem`NestedGrid`PackagePrivate`$hPos$$]}], 
          TypeSystem`NestedGrid`PackagePrivate`renderedGrid]]], 
      TrackedSymbols :> {
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
     DynamicModuleValues :> {}], 
    TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
     TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
      TypeSystem`PackageScope`SubViewPathbar[
      TypeSystem`NestedGrid`PackagePrivate`$path$$, 
       TypeSystem`NestedGrid`PackagePrivate`updateState[
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$path$$, 
        TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
        TypeSystem`NestedGrid`PackagePrivate`localHold[
        TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
     TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
    TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
     Framed[
      Dynamic[
       Replace[
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
        TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
           Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
           TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
           Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
            Blank[]], 
           Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
            Blank[]]] :> (
          Increment[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
           TypeSystem`NestedGrid`PackagePrivate`path$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
           TypeSystem`NestedGrid`PackagePrivate`pathType$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
           TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
          TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
           TypeSystem`NestedGrid`PackagePrivate`localHold[
            TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
          TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
           TypeSystem`NestedGrid`PackagePrivate`path$, 
            TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
         Spacer[10], Blank[] :> Spacer[10]}], 
       TrackedSymbols :> {
        TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], FrameStyle -> 
      None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> Top, 
      ImageSize -> {Automatic, 15}], FontSize -> 1], 
    TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
    DynamicWrapperBox[
     DynamicBox[ToBoxes[
       Dataset`DatasetContent[
       2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], 
        "Grid" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], "State" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], "VPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], "HPos" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], "TopBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], "BottomBar" -> 
        Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
        Hold[
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
      ImageSizeCache->{169., {99.8837890625, 107.1162109375}},
      TrackedSymbols:>{
       TypeSystem`NestedGrid`PackagePrivate`$state$$, 
        TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
     TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = 
     MouseAnnotation[],
     ImageSizeCache->{169., {99.8837890625, 107.1162109375}}],
    BaseStyle->{LineBreakWithin -> False},
    DynamicModuleValues:>{},
    Initialization:>
     Block[{$ContextPath = $ContextPath}, Needs["TypeSystem`"]; 
      Needs["Dataset`"]; 
      TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = CreateUUID[]],
    UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
   Deploy,
   DefaultBaseStyle->"Deploy"],
  Dataset`InterpretDataset[1],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{{3.7699390941941023`*^9, 3.769939168509556*^9}, {
   3.7699392773365183`*^9, 3.7699393061079874`*^9}, 3.7701786197494307`*^9, 
   3.794206909109995*^9, 3.813569870831397*^9, 3.813570674047153*^9},
 CellLabel->"Out[25]=",
 CellID->816001670,ExpressionUUID->"66f5fea1-37db-4486-8b2e-131d74ab5fc6"]
}, Open  ]],

Cell["\<\
We can also create a histogram that shows both sets of ages with appropriate \
legends. \
\>", "Text",
 CellChangeTimes->{{3.7942069314882684`*^9, 3.794206973616391*^9}, {
  3.794207035424202*^9, 3.794207039088498*^9}, {3.8160981756481857`*^9, 
  3.81609817728724*^9}},
 CellID->257038805,ExpressionUUID->"2b929bc6-f76c-4fbf-89f1-949cd2ba6d9f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"coadAge", ",", "cbAge"}], "}"}], ",", 
   RowBox[{"ChartLegends", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"\"\<COAD\>\"", ",", "\"\<CB\>\""}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Age Bracket\>\"", ",", "\"\<Count\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7942068713635883`*^9, 3.79420689155291*^9}, {
   3.7942069897876315`*^9, 3.794207023563116*^9}, 3.813569254045661*^9},
 CellLabel->"In[26]:=",
 CellID->113002102,ExpressionUUID->"fc072b82-1706-439c-9673-741cd40675d0"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{
      Directive[
       EdgeForm[
        Directive[
         Thickness[Small], 
         Opacity[0.637]]], 
       RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`]], {{{{}, {
          Directive[
           Opacity[0.5], 
           Directive[
            EdgeForm[
             Directive[
              Thickness[Small], 
              Opacity[0.637]]], 
            RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`]], 
           Directive[
            RGBColor[0.97858, 0.678934, 0.157834]]], {{
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{10., 0.}, {20., 1}, "RoundingRadius" -> 0]}],
                  "DelayedMouseEffectStyle"]}, StatusArea[#, 1]& , TagBoxNote -> 
               "1"], 
              StyleBox["1", {}, StripOnInput -> False]], Annotation[#, 
              Style[1, {}], "Tooltip"]& ]}, {
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{20., 0.}, {30., 14}, "RoundingRadius" -> 
                    0]}], "DelayedMouseEffectStyle"]}, StatusArea[#, 14]& , 
               TagBoxNote -> "14"], 
              StyleBox["14", {}, StripOnInput -> False]], Annotation[#, 
              Style[14, {}], "Tooltip"]& ]}, {
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{30., 0.}, {40., 8}, "RoundingRadius" -> 0]}],
                  "DelayedMouseEffectStyle"]}, StatusArea[#, 8]& , TagBoxNote -> 
               "8"], 
              StyleBox["8", {}, StripOnInput -> False]], Annotation[#, 
              Style[8, {}], "Tooltip"]& ]}, {
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{40., 0.}, {50., 6}, "RoundingRadius" -> 0]}],
                  "DelayedMouseEffectStyle"]}, StatusArea[#, 6]& , TagBoxNote -> 
               "6"], 
              StyleBox["6", {}, StripOnInput -> False]], Annotation[#, 
              Style[6, {}], "Tooltip"]& ]}, {
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{50., 0.}, {60., 12}, "RoundingRadius" -> 
                    0]}], "DelayedMouseEffectStyle"]}, StatusArea[#, 12]& , 
               TagBoxNote -> "12"], 
              StyleBox["12", {}, StripOnInput -> False]], Annotation[#, 
              Style[12, {}], "Tooltip"]& ]}, {
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{60., 0.}, {70., 10}, "RoundingRadius" -> 
                    0]}], "DelayedMouseEffectStyle"]}, StatusArea[#, 10]& , 
               TagBoxNote -> "10"], 
              StyleBox["10", {}, StripOnInput -> False]], Annotation[#, 
              Style[10, {}], "Tooltip"]& ]}, {
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{70., 0.}, {80., 5}, "RoundingRadius" -> 0]}],
                  "DelayedMouseEffectStyle"]}, StatusArea[#, 5]& , TagBoxNote -> 
               "5"], 
              StyleBox["5", {}, StripOnInput -> False]], Annotation[#, 
              Style[5, {}], "Tooltip"]& ]}}}, {}, {}}}, {{{}, {
          Directive[
           Opacity[0.5], 
           Directive[
            EdgeForm[
             Directive[
              Thickness[Small], 
              Opacity[0.637]]], 
            RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`]], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798]]], {{
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{10., 0.}, {20., 2}, "RoundingRadius" -> 0]}],
                  "DelayedMouseEffectStyle"]}, StatusArea[#, 2]& , TagBoxNote -> 
               "2"], 
              StyleBox["2", {}, StripOnInput -> False]], Annotation[#, 
              Style[2, {}], "Tooltip"]& ]}, {
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{20., 0.}, {30., 7}, "RoundingRadius" -> 0]}],
                  "DelayedMouseEffectStyle"]}, StatusArea[#, 7]& , TagBoxNote -> 
               "7"], 
              StyleBox["7", {}, StripOnInput -> False]], Annotation[#, 
              Style[7, {}], "Tooltip"]& ]}, {
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{30., 0.}, {40., 11}, "RoundingRadius" -> 
                    0]}], "DelayedMouseEffectStyle"]}, StatusArea[#, 11]& , 
               TagBoxNote -> "11"], 
              StyleBox["11", {}, StripOnInput -> False]], Annotation[#, 
              Style[11, {}], "Tooltip"]& ]}, {
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{40., 0.}, {50., 8}, "RoundingRadius" -> 0]}],
                  "DelayedMouseEffectStyle"]}, StatusArea[#, 8]& , TagBoxNote -> 
               "8"], 
              StyleBox["8", {}, StripOnInput -> False]], Annotation[#, 
              Style[8, {}], "Tooltip"]& ]}, {
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{50., 0.}, {60., 12}, "RoundingRadius" -> 
                    0]}], "DelayedMouseEffectStyle"]}, StatusArea[#, 12]& , 
               TagBoxNote -> "12"], 
              StyleBox["12", {}, StripOnInput -> False]], Annotation[#, 
              Style[12, {}], "Tooltip"]& ]}, {
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{60., 0.}, {70., 13}, "RoundingRadius" -> 
                    0]}], "DelayedMouseEffectStyle"]}, StatusArea[#, 13]& , 
               TagBoxNote -> "13"], 
              StyleBox["13", {}, StripOnInput -> False]], Annotation[#, 
              Style[13, {}], "Tooltip"]& ]}, {
            TagBox[
             TooltipBox[
              TagBox[{
                TagBox[
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   
                   RectangleBox[{70., 0.}, {80., 11}, "RoundingRadius" -> 
                    0]}], "DelayedMouseEffectStyle"]}, StatusArea[#, 11]& , 
               TagBoxNote -> "11"], 
              StyleBox["11", {}, StripOnInput -> False]], Annotation[#, 
              Style[11, {}], 
              "Tooltip"]& ]}}}, {}, {}}}}}, {{{{{}, {}, {}, {}, {}, {}, {}}, \
{}}}, {{{{}, {}, {}, {}, {}, {}, {}}, {}}}}}, {
    AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {
       FormBox["\"Age Bracket\"", TraditionalForm], 
       FormBox["\"Count\"", TraditionalForm]}, AxesOrigin -> {8.6, 0.}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], PlotRange -> {{10., 80.}, {All, All}}, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"COAD\"", "\"CB\""}, "SwatchLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.5], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Thickness[Small], 
                    Opacity[0.637]]], 
                    RGBColor[0.97858, 0.678934, 0.157834]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.5], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Thickness[Small], 
                    Opacity[0.637]]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.3}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Small", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.637`", "]"}]}], "]"}], "]"}], 
                    ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.97858, 0.678934, 0.157834], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.6523866666666667, 0.45262266666666673`, 
                    0.10522266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.97858`", ",", "0.678934`", ",", "0.157834`"}], 
                    "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.97858, 0.678934, 0.157834]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.97858, 0.678934, 0.157834], Editable -> False, 
                    Selectable -> False]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Small", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.637`", "]"}]}], "]"}], "]"}], 
                    ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Small", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.637`", "]"}]}], "]"}], "]"}], 
                    ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False]}], 
                    "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Small", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.637`", "]"}]}], "]"}], "]"}], 
                    ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False]}], 
                    "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Small", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.637`", "]"}]}], "]"}], "]"}], 
                    ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False]}], 
                    "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Small", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.637`", "]"}]}], "]"}], "]"}], 
                    ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False]}], 
                    "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Small", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.637`", "]"}]}], "]"}], "]"}], 
                    ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False]}], 
                    "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Small", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.637`", "]"}]}], "]"}], "]"}], 
                    ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False]}], 
                    "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Small", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.637`", "]"}]}], "]"}], "]"}], 
                    ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.6666666666666667], FrameTicks -> 
                    None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "1", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False]}], 
                    "]"}]}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"{", "}"}]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Automatic", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", "None", "}"}]}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.794207025112832*^9, 3.813569871075642*^9, 
  3.813570674291642*^9},
 CellLabel->"Out[26]=",
 CellID->709497948,ExpressionUUID->"17385892-e0d8-43c9-a225-1c4483ece81b"]
}, Open  ]],

Cell["\<\
The data does not seem normally distributed. The Shapiro\[Dash]Wilk test \
provides us with a probability that the data was taken from an underlying \
population in which the variable is normally distributed.\
\>", "Text",
 CellChangeTimes->{{3.769939338400363*^9, 3.7699393955415864`*^9}, 
   3.7772134853160143`*^9, {3.7772194601002936`*^9, 3.7772194709433775`*^9}},
 CellID->112250013,ExpressionUUID->"8de348da-87dc-4cad-826f-1ee773607c42"],

Cell[TextData[{
 "Use the ",
 ButtonBox["ShapiroWilkTest",
  BaseStyle->"Link"],
 " function to test for the assumption of normality:"
}], "CodeCaption",
 CellChangeTimes->{{3.7699393974991446`*^9, 3.769939429826248*^9}, {
  3.7772194776290464`*^9, 3.7772194840336866`*^9}},
 CellID->60481654,ExpressionUUID->"f0b2eab6-0ce3-4d2f-9f86-14a33060dc85"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ShapiroWilkTest", "/@", 
  RowBox[{"{", 
   RowBox[{"coadAge", ",", "cbAge"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.769939478340897*^9, 3.769939489059595*^9}},
 CellLabel->"In[27]:=",
 CellID->178765207,ExpressionUUID->"39755826-c6c1-4456-ab6f-20ca9b9d1fe9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.0010208668363233424`", ",", "0.001756432081372701`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.769939489582881*^9, 3.770178619918738*^9, 
  3.8135698712097893`*^9, 3.8135706744261436`*^9},
 CellLabel->"Out[27]=",
 CellID->1702803892,ExpressionUUID->"617943a4-589a-44ba-8de2-5c36f9230963"]
}, Open  ]],

Cell[TextData[{
 "Note the significant results for both groups (",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",
  FormatType->"TraditionalForm",ExpressionUUID->
  "21a14d4f-9639-4f8b-841c-b178d04a9985"],
 "-values less than 0.05). This means we fail the assumptions for the use of \
a parametric test. We will, therefore, use a nonparametric alternative."
}], "Text",
 CellChangeTimes->{{3.769939507136371*^9, 3.769939578033767*^9}, {
   3.777213487476014*^9, 3.777213490252014*^9}, 3.7772194919174747`*^9, 
   3.777219532703553*^9, {3.7942070924484525`*^9, 3.79420711165617*^9}, 
   3.81609824655329*^9},
 CellID->213335717,ExpressionUUID->"b5410845-2683-4a6a-b34f-b3b9f64f9ee1"],

Cell[TextData[{
 "Use the Mann\[Dash]Whitney ",
 Cell[BoxData[
  StyleBox["U",
   FontSlant->"Italic"]], "InlineCode",ExpressionUUID->
  "90753cee-9ddf-45a4-a264-cd23b32c760b"],
 "-test to compare the two ages:"
}], "CodeCaption",
 CellChangeTimes->{{3.769939559935929*^9, 3.769939580705947*^9}, {
   3.777219546799963*^9, 3.777219584498732*^9}, 3.816098255632474*^9},
 CellID->448181809,ExpressionUUID->"cafd806b-244e-4345-92ef-241070fae9ab"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MannWhitneyTest", "[", 
  RowBox[{"{", 
   RowBox[{"coadAge", ",", "cbAge"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.7699396141721983`*^9, 3.769939627051238*^9}},
 CellLabel->"In[28]:=",
 CellID->499844789,ExpressionUUID->"d985e697-c0dc-4ea3-8e16-fd161094999f"],

Cell[BoxData["0.14786708404418125`"], "Output",
 CellChangeTimes->{3.7699396273986983`*^9, 3.7701786199343596`*^9, 
  3.813569871215651*^9, 3.813570674433806*^9},
 CellLabel->"Out[28]=",
 CellID->1657932922,ExpressionUUID->"d24e3706-8eab-4ab4-998b-fdcc11f90066"]
}, Open  ]],

Cell["\<\
Since we used a nonparametric test, we were actually comparing median values. \
 We will express these next, together with the minimum and maximum ages.\
\>", "Text",
 CellChangeTimes->{{3.7699398903832846`*^9, 3.769939971128386*^9}, {
   3.777213492828014*^9, 3.777213495259014*^9}, {3.7772199409933777`*^9, 
   3.7772199492502036`*^9}, {3.794207156947199*^9, 3.7942071611531744`*^9}, {
   3.794207329264476*^9, 3.7942073304408984`*^9}, 3.794207366824463*^9},
 CellID->285543940,ExpressionUUID->"52d22ad5-d8ff-43b5-a833-b4f92bbf1484"],

Cell["\<\
Calculate the overall median (we have already calculated the median for the \
two groups):\
\>", "CodeCaption",
 CellChangeTimes->{{3.769939973548581*^9, 3.7699400362068205`*^9}, {
  3.777219958026081*^9, 3.7772199795542336`*^9}},
 CellID->214322229,ExpressionUUID->"15677c72-f57d-4ae0-b7c0-a0f76ce6b906"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "@", 
  RowBox[{"data", "[", 
   RowBox[{"Median", ",", "\"\<Age\>\""}], "]"}]}]], "Input",
 CellChangeTimes->{{3.769939985052251*^9, 3.7699399927140074`*^9}},
 CellLabel->"In[29]:=",
 CellID->8376257,ExpressionUUID->"28eb90ee-7fe1-4782-bf4d-155c5d4b3915"],

Cell[BoxData["51.5`"], "Output",
 CellChangeTimes->{3.76993999309982*^9, 3.77017861997211*^9, 
  3.8135698712313623`*^9, 3.813570674457005*^9},
 CellLabel->"Out[29]=",
 CellID->1278300229,ExpressionUUID->"6b83160f-e11f-4c22-8fac-7abc4a339333"]
}, Open  ]],

Cell[TextData[{
 "Given all of our previous analysis, we can now state the following in our \
research manuscript: The overall median age was 51.5 years with the youngest \
patient being ",
 Cell[BoxData[
  FormBox["18", TraditionalForm]],ExpressionUUID->
  "1abccbef-51e7-4bb0-aae4-9d40f4b6e9a2"],
 " and the oldest being ",
 Cell[BoxData[
  FormBox["77", TraditionalForm]],ExpressionUUID->
  "b78e0461-5f16-4e10-842a-7c581b2a04d6"],
 ". For the patients with COAD, the median age was 47 years (min ",
 Cell[BoxData[
  FormBox["18", TraditionalForm]],ExpressionUUID->
  "699ce348-2b43-44de-bbc1-a548c16602a8"],
 ", max ",
 Cell[BoxData[
  FormBox["74", TraditionalForm]],ExpressionUUID->
  "a75301ab-d327-4427-bb2c-afaa7aa077dd"],
 "). This was not significantly different from the CB group, with a median \
age of 53 years (min ",
 Cell[BoxData[
  FormBox["19", TraditionalForm]],ExpressionUUID->
  "0d18d673-cb86-4350-a570-3260bdd9a21e"],
 ", max ",
 Cell[BoxData[
  FormBox["77", TraditionalForm]],ExpressionUUID->
  "f050cf45-1825-4559-8ec3-8deae90babbb"],
 ") (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["p",
     FontSlant->"Italic"], "=", "0.14"}], TraditionalForm]],ExpressionUUID->
  "233acc90-1708-4a1e-b343-dc533916f9b9"],
 ")."
}], "Text",
 CellChangeTimes->{{3.7699396754245186`*^9, 3.7699396960131316`*^9}, 
   3.7699397324573374`*^9, {3.7699397876165094`*^9, 3.769939855883505*^9}, {
   3.777213501148014*^9, 3.777213505979014*^9}, {3.777219994484727*^9, 
   3.777220002180496*^9}, {3.813569106790719*^9, 3.813569109894148*^9}},
 CellID->129507313,ExpressionUUID->"427f75aa-68de-4da6-b4f9-697400e654d2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Correlation between Lactate and White Blood Cell Count", "Subsection",
 CellChangeTimes->{{3.693037992567856*^9, 3.6930379974276085`*^9}, {
  3.7247840133527436`*^9, 3.724784013898853*^9}, {3.7699346102867236`*^9, 
  3.769934616192512*^9}, {3.7699361920467234`*^9, 3.7699361931015687`*^9}, {
  3.7699378390031443`*^9, 3.7699378751916056`*^9}, {3.7699404398546724`*^9, 
  3.769940488417284*^9}, {3.777213730762991*^9, 3.7772137681397285`*^9}},
 CellID->33009933,ExpressionUUID->"29543d62-675e-4bc8-84d1-ea764d4113aa"],

Cell[TextData[{
 "Here we are looking at two different numerical variables: lactate and white \
cell count. Each subject in our dataset will have a value for each of the \
variables. Our aim is to see whether these ",
 StyleBox["pairs",
  FontSlant->"Italic"],
 " of values are correlated, if there is a change in one as the other changes."
}], "Text",
 CellChangeTimes->{{3.770178701127607*^9, 3.770178810580016*^9}, {
  3.777213508435014*^9, 3.777213536778014*^9}, {3.7772135674160137`*^9, 
  3.777213577695014*^9}, {3.777220137170994*^9, 3.777220144995776*^9}, {
  3.777220346291904*^9, 3.777220348643139*^9}, {3.7772204193742113`*^9, 
  3.7772204203653107`*^9}, {3.81609831881595*^9, 3.816098319039195*^9}},
 CellID->153765151,ExpressionUUID->"3f9438f4-6737-4d2a-b593-61ced4746949"],

Cell[TextData[{
 "The null hypothesis for this research question is that there is no \
correlation between the two variables and the alternative hypothesis is that \
there is a correlation between them. As always, we set an \[Alpha]-value of ",
 Cell[BoxData[
  FormBox["0.05", TraditionalForm]],ExpressionUUID->
  "1bdbaf19-c321-49b3-b5da-f7ce56541b05"],
 "."
}], "Text",
 CellChangeTimes->{{3.7701821304813013`*^9, 3.770182206213955*^9}, 
   3.777213528738014*^9, {3.77722016453973*^9, 3.7772201924195185`*^9}},
 CellID->540416205,ExpressionUUID->"684f9609-4b37-4d2f-b836-ea75607f326e"],

Cell[TextData[{
 "This question is answered by a correlation test. The result is the Pearson \
correlation coefficient, ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]], "InlineMath",ExpressionUUID->
  "52038a05-ddab-4659-bb62-ac0ce1dfd98e"],
 ". In Chapter 11, we calculated ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]], "InlineMath",ExpressionUUID->
  "475785eb-3406-4e03-966d-39cb00ec379f"],
 ", the ",
 Cell[BoxData[
  FormBox["95", TraditionalForm]],ExpressionUUID->
  "8761f1ee-d423-45e3-803e-a3b8517a4cf5"],
 "% confidence interval around ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]], "InlineMath",ExpressionUUID->
  "69afe174-6852-44bb-9a5d-f4c6ab3abeea"],
 ", and a ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "1efc9858-0bdf-4ce8-875c-47411d3c8c78"],
 "-value for this result. We learned that the correlation coefficient does \
not follow a normal distribution. In this chapter, though, we will use the \
fact that the Wolfram Language assumes ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]], "InlineMath",ExpressionUUID->
  "59708b80-8e22-4927-a1db-2a3ef8b5a1b0"],
 " to asymptotically follow the Student ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath",ExpressionUUID->
  "7fd5e7f3-841b-4879-a33e-9c50f5fd9e4d"],
 " distribution for a degree of freedom equal to the sample size minus ",
 Cell[BoxData[
  FormBox["2", TraditionalForm]],ExpressionUUID->
  "ff1c853c-ee65-4fda-a949-c28adb1fcee1"],
 ". This allows us to make use of the ",
 ButtonBox["PearsonCorrelationTest",
  BaseStyle->"Link"],
 " function and saves us some time in calculating the results that we \
require. As always, though, we start by describing and visualizing the data \
to get a better intuition for the results."
}], "Text",
 CellChangeTimes->{{3.7701788234862757`*^9, 3.7701789522645445`*^9}, {
   3.7701824470773315`*^9, 3.7701827309317265`*^9}, {3.7701828524858694`*^9, 
   3.7701828826392775`*^9}, 3.777213533105014*^9, {3.7772136385550137`*^9, 
   3.777213649484014*^9}, {3.7772202229345694`*^9, 3.7772203174350185`*^9}, 
   3.7898202769146633`*^9, {3.8160983325917883`*^9, 3.816098332775516*^9}},
 CellID->336696017,ExpressionUUID->"e8f3191f-f595-4236-8874-93d291e53357"],

Cell[TextData[{
 "Use ",
 ButtonBox["Mean",
  BaseStyle->"Link"],
 ", ",
 ButtonBox["StandardDeviation",
  BaseStyle->"Link"],
 ", ",
 ButtonBox["Min",
  BaseStyle->"Link"],
 ", ",
 ButtonBox["Max",
  BaseStyle->"Link"],
 ", ",
 ButtonBox["Median",
  BaseStyle->"Link"],
 ", and ",
 ButtonBox["InterquartileRange",
  BaseStyle->"Link"],
 " to calculate the summary statistics of the ",
 Cell[BoxData[
 "\"\<Lactate\>\""], "InlineCode",ExpressionUUID->
  "34ba050e-5024-418f-a82f-52513d8cdef5"],
 " and ",
 Cell[BoxData[
 "\"\<WCC\>\""], "InlineCode",ExpressionUUID->
  "b40f8f8a-aae1-4e19-b1a8-e6b808236699"],
 " variables:"
}], "CodeCaption",
 CellChangeTimes->{{3.770179011167111*^9, 3.7701790549431143`*^9}, {
   3.777220326328908*^9, 3.777220427909065*^9}, 3.813569170031608*^9},
 CellID->90795247,ExpressionUUID->"d0a94d81-e0a5-4622-beea-245f229cf2a1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"Normal", "[", 
   RowBox[{"data", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "Mean", ",", "StandardDeviation", ",", "Min", ",", "Max", ",", "Median",
        ",", "InterquartileRange"}], "}"}], ",", "\"\<Lactate\>\""}], "]"}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.770178958132845*^9, 3.7701789917759485`*^9}, {
  3.794207460025773*^9, 3.794207495665398*^9}},
 CellLabel->"In[30]:=",
 CellID->76605001,ExpressionUUID->"0d4b8842-0fca-4eba-ab46-dffb4a9b3e24"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "49.925`", ",", "9.309940923550482`", ",", "27.`", ",", "77.`", ",", "50.`",
    ",", "13.`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7701789924890566`*^9, {3.794207435938484*^9, 3.7942074964383316`*^9}, 
   3.813569871237899*^9, 3.813570674464512*^9},
 CellLabel->"Out[30]=",
 CellID->965544215,ExpressionUUID->"c541bf0c-40b8-4084-9f05-9faaa478ab7c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"Normal", "[", 
   RowBox[{"data", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "Mean", ",", "StandardDeviation", ",", "Min", ",", "Max", ",", "Median",
        ",", "InterquartileRange"}], "}"}], ",", "\"\<WCC\>\""}], "]"}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.770179003356982*^9, 3.770179005481306*^9}, {
  3.794207500993633*^9, 3.794207506808481*^9}},
 CellLabel->"In[31]:=",
 CellID->353755635,ExpressionUUID->"1fee989b-40bf-40fd-bc48-33481915ecde"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "11.778333333333334`", ",", "1.2907025859066474`", ",", "8.3`", ",", 
   "15.4`", ",", "11.8`", ",", "1.5500000000000007`"}], "}"}]], "Output",
 CellChangeTimes->{3.7701790058363905`*^9, 3.7942074429677696`*^9, 
  3.7942075078277555`*^9, 3.813569871253729*^9, 3.813570674487764*^9},
 CellLabel->"Out[31]=",
 CellID->1515184773,ExpressionUUID->"c51b90dd-98fb-4893-a5ec-747219bc8c45"]
}, Open  ]],

Cell[TextData[{
 "Use the ",
 ButtonBox["Histogram",
  BaseStyle->"Link"],
 " function to plot the frequency distribution of the ",
 Cell[BoxData[
 "\"\<Lactate\>\""], "InlineCode",ExpressionUUID->
  "3ffcb7ae-63aa-4048-8865-aa51af0bd151"],
 " and ",
 Cell[BoxData[
 "\"\<WCC\>\""], "InlineCode",ExpressionUUID->
  "658ce513-3bd6-4dad-88a3-b20bd0142471"],
 " variables:"
}], "CodeCaption",
 CellChangeTimes->{{3.7701791753393617`*^9, 3.7701792223756557`*^9}, {
  3.7772203827485495`*^9, 3.777220393276602*^9}, {3.777220430919366*^9, 
  3.7772204489201655`*^9}},
 CellID->339221956,ExpressionUUID->"0abd370a-f8db-4c0c-9ae8-cc6782120707"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Histogram", "[", 
     RowBox[{"#", ",", 
      RowBox[{
      "PlotLabel", "\[Rule]", 
       "\"\<Frequency Distribution of Lactate Levels\>\""}]}], "]"}], "&"}], 
   ",", "\"\<Lactate\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.7701790839765267`*^9, 3.7701791245301523`*^9}, {
  3.770179163483049*^9, 3.7701791691239567`*^9}, {3.813569231533461*^9, 
  3.813569237429677*^9}},
 CellLabel->"In[32]:=",
 CellID->57055865,ExpressionUUID->"c7edcb1f-a231-42b5-b307-c1333b4f8054"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.609], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.609], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{25., 0}, {30., 1.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{18.053921568627473`, 38.11720142602498}, {
           59.06381999537595, 64.51929260619875}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{30., 0}, {35., 6.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{37.61720142602498, 57.680481283422495`}, {
           34.28645694126196, 64.51929260619875}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 6]& ,
        TagBoxNote->"6"],
       StyleBox["6", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[6, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{35., 0}, {40., 8.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{57.180481283422495`, 77.24376114082}, {
           24.37551171961637, 64.51929260619875}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 8]& ,
        TagBoxNote->"8"],
       StyleBox["8", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[8, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{40., 0}, {45., 20.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{76.74376114082, 
           96.8070409982175}, {-35.09015961025719, 64.51929260619875}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 20]& ,
        TagBoxNote->"20"],
       StyleBox["20", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[20, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{45., 0}, {50., 22.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{96.3070409982175, 
           116.370320855615}, {-45.00110483190279, 64.51929260619875}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 22]& ,
        TagBoxNote->"22"],
       StyleBox["22", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[22, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{50., 0}, {55., 26.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{115.870320855615, 
           135.9336007130125}, {-64.82299527519399, 64.51929260619875}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 26]& ,
        TagBoxNote->"26"],
       StyleBox["26", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[26, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{55., 0}, {60., 18.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{135.4336007130125, 
           155.49688057041}, {-25.179214388611598`, 64.51929260619875}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 18]& ,
        TagBoxNote->"18"],
       StyleBox["18", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[18, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{60., 0}, {65., 14.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{154.99688057041, 
           175.06016042780752`}, {-5.357323945320417, 64.51929260619875}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 14]& ,
        TagBoxNote->"14"],
       StyleBox["14", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[14, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{65., 0}, {70., 2.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{174.56016042780752`, 194.62344028520505`}, {
           54.108347384553156`, 64.51929260619875}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 2]& ,
        TagBoxNote->"2"],
       StyleBox["2", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[2, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{70., 0}, {75., 2.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{194.12344028520505`, 214.18672014260255`}, {
           54.108347384553156`, 64.51929260619875}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 2]& ,
        TagBoxNote->"2"],
       StyleBox["2", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[2, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{75., 0}, {80., 1.}, "RoundingRadius" -> 0]},
          ImageSizeCache->{{213.68672014260255`, 233.75000000000006`}, {
           59.06381999537595, 64.51929260619875}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], 
       "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{23.9, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotLabel->FormBox[
   "\"Frequency Distribution of Lactate Levels\"", TraditionalForm],
  PlotRange->{{25., 80.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.77017911831076*^9, 3.7701791253320255`*^9}, 
   3.770179169883957*^9, 3.813569871305601*^9, 3.813570674541305*^9},
 CellLabel->"Out[32]=",
 CellID->849393685,ExpressionUUID->"f8cf8621-67c5-4944-9cc1-a05c50b287c5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Histogram", "[", 
     RowBox[{"#", ",", 
      RowBox[{
      "PlotLabel", "\[Rule]", 
       "\"\<Frequency Distribution of Lactate Levels\>\""}]}], "]"}], "&"}], 
   ",", "\"\<WCC\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.7701792303982105`*^9, 3.7701792325045843`*^9}, {
  3.8135692224458733`*^9, 3.8135692276215973`*^9}},
 CellLabel->"In[33]:=",
 CellID->530000948,ExpressionUUID->"7582a6d6-e81f-45d4-99c9-cd2161709c8b"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.63], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.63], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{8., 0}, {9., 3.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{18.05392156862746, 45.45343137254903}, {
           54.81627204324222, 64.51929260619885}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 3]& ,
        TagBoxNote->"3"],
       StyleBox["3", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[3, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{9., 0}, {10., 5.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{44.95343137254903, 72.35294117647061}, {
           48.680925001271135`, 64.51929260619885}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 5]& ,
        TagBoxNote->"5"],
       StyleBox["5", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[5, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{10., 0}, {11., 21.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{71.85294117647061, 
           99.25245098039215}, {-0.4018513344975361, 64.51929260619885}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 21]& ,
        TagBoxNote->"21"],
       StyleBox["21", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[21, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{11., 0}, {12., 42.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{98.75245098039215, 
           126.1519607843137}, {-64.82299527519392, 64.51929260619885}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 42]& ,
        TagBoxNote->"42"],
       StyleBox["42", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[42, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{12., 0}, {13., 31.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{125.6519607843137, 
           153.0514705882353}, {-31.07858654435296, 64.51929260619885}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 31]& ,
        TagBoxNote->"31"],
       StyleBox["31", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[31, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{13., 0}, {14., 12.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{152.5514705882353, 179.95098039215685`}, {
           27.207210354372343`, 64.51929260619885}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 12]& ,
        TagBoxNote->"12"],
       StyleBox["12", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[12, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{14., 0}, {15., 5.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{179.45098039215685`, 206.85049019607845`}, {
           48.680925001271135`, 64.51929260619885}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 5]& ,
        TagBoxNote->"5"],
       StyleBox["5", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[5, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           RectangleBox[{15., 0}, {16., 1.}, "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{206.35049019607845`, 233.75}, {60.9516190852133, 
           64.51929260619885}}],
         "DelayedMouseEffectStyle"],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], 
       "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{7.84, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotLabel->FormBox[
   "\"Frequency Distribution of Lactate Levels\"", TraditionalForm],
  PlotRange->{{8., 16.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7701792328785677`*^9, 3.8135698713606853`*^9, 
  3.813570674609086*^9},
 CellLabel->"Out[33]=",
 CellID->1435862186,ExpressionUUID->"e9412979-7849-4dfe-8587-e858b9f0a32e"]
}, Open  ]],

Cell["\<\
Both of these variables seem to be almost normally distributed. Let\
\[CloseCurlyQuote]s investigate the assumption of normality by using an \
appropriate test.\
\>", "Text",
 CellChangeTimes->{{3.770179236220682*^9, 3.7701792940740323`*^9}, 
   3.777213652491014*^9},
 CellID->99958486,ExpressionUUID->"268308c2-8cdc-45c5-b283-065d3ea99cd5"],

Cell[TextData[{
 "Extract two ",
 ButtonBox["List",
  BaseStyle->"Link"],
 " objects for the two variables using the ",
 ButtonBox["Normal",
  BaseStyle->"Link"],
 " function:"
}], "CodeCaption",
 CellChangeTimes->{{3.7701793555796914`*^9, 3.7701793729263086`*^9}, {
  3.7772204595752316`*^9, 3.7772204706093345`*^9}},
 CellID->110754988,ExpressionUUID->"0bc7f6d7-effc-47df-868e-4b41d9fa64db"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"lactate", "=", 
   RowBox[{
    RowBox[{"Normal", "[", 
     RowBox[{"data", "[", 
      RowBox[{"List", ",", "\"\<Lactate\>\""}], "]"}], "]"}], 
    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wcc", "=", 
   RowBox[{
    RowBox[{"Normal", "[", 
     RowBox[{"data", "[", 
      RowBox[{"List", ",", "\"\<WCC\>\""}], "]"}], "]"}], 
    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.769940859114023*^9, 3.769940900263402*^9}},
 CellLabel->"In[34]:=",
 CellID->354844629,ExpressionUUID->"bb9e2c6d-1adc-4c4a-abb0-bed005a4719c"],

Cell[TextData[{
 "Use the ",
 ButtonBox["ShapiroWilkTest",
  BaseStyle->"Link"],
 " function to test for the assumption of normality:"
}], "CodeCaption",
 CellChangeTimes->{{3.7701792960168667`*^9, 3.7701793261682615`*^9}, {
  3.7772204735196257`*^9, 3.777220482937567*^9}},
 CellID->64159907,ExpressionUUID->"d641d8b0-e24a-4f84-bea6-481d3731a0f5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ShapiroWilkTest", "/@", 
  RowBox[{"{", 
   RowBox[{"lactate", ",", "wcc"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.7701793123711205`*^9, 3.770179334243672*^9}, {
  3.770179399292821*^9, 3.770179404583691*^9}},
 CellLabel->"In[36]:=",
 CellID->255367720,ExpressionUUID->"67b14da1-1d5f-48a8-8547-96f2467fc968"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.8988583606255189`", ",", "0.6900179419700917`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.770179405260868*^9, 3.794207542559908*^9, 
  3.813569871375041*^9, 3.813570674639122*^9},
 CellLabel->"Out[36]=",
 CellID->1262018763,ExpressionUUID->"65ee056b-0bef-41ad-acac-56965815c179"]
}, Open  ]],

Cell[TextData[{
 "For both the lactate and white cell count we find ",
 StyleBox["p",
  FontSlant->"Italic"],
 "-values more than 0.05 and from this conclude that we cannot reject that \
the data comes from a population in which the variables are normally \
distributed."
}], "Text",
 CellChangeTimes->{{3.7942075946643453`*^9, 3.7942076370239344`*^9}, {
  3.7942076911286554`*^9, 3.7942077177524576`*^9}},
 CellID->246478032,ExpressionUUID->"1fbb3b42-96e9-4a0e-9737-f2652d196840"],

Cell[TextData[{
 "Next, we can visualize the data as a scatter plot, with the ",
 Cell[BoxData[
 "\"\<Lactate\>\""], "InlineCodeText",ExpressionUUID->
  "7988d750-a260-4f3e-86f3-7dacbc63484e"],
 " variable on the horizontal and the ",
 Cell[BoxData[
 "\"\<WCC\>\""], "InlineCodeText",ExpressionUUID->
  "f5b7a27c-2a62-425e-84e3-608fede96353"],
 " variable on the vertical axis."
}], "Text",
 CellChangeTimes->{{3.770179426661683*^9, 3.770179458752921*^9}, {
  3.7772207602612967`*^9, 3.777220791854456*^9}},
 CellID->325497123,ExpressionUUID->"27a979d0-1373-4433-bb2b-d45d17797d6a"],

Cell[TextData[{
 "Use the ",
 ButtonBox["Thread",
  BaseStyle->"Link"],
 " function to create nested List objects to use as values for each marker:"
}], "CodeCaption",
 CellChangeTimes->{{3.7701795109474297`*^9, 3.770179540711881*^9}, {
  3.7772209087151403`*^9, 3.7772209317654457`*^9}, {3.816098404351418*^9, 
  3.816098405111287*^9}},
 CellID->50061431,ExpressionUUID->"31296abb-b7a9-401a-ac9c-f58cf06237df"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{"lactate", ",", "wcc"}], "}"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"6", ",", "16"}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<Correlation between Lactate and White Cell Count Values\>\""}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Lacate\>\"", ",", "\"\<WCC\>\""}], "}"}]}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", " ", "Medium"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7699410670432405`*^9, 3.769941088458957*^9}, {
  3.769941153443535*^9, 3.769941240859396*^9}, {3.7699412983478785`*^9, 
  3.7699413190866833`*^9}, {3.7699499656072874`*^9, 3.7699499677775126`*^9}, {
  3.8135693715657043`*^9, 3.813569395197353*^9}},
 CellLabel->"In[37]:=",
 CellID->611368034,ExpressionUUID->"63de8351-a72f-46e0-bd4e-5d80142f3253"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
    AbsoluteThickness[1.6], GeometricTransformationBox[InsetBox[
      FormBox[
       StyleBox[
        GraphicsBox[
         {EdgeForm[None], DiskBox[{0, 0}]}],
        StripOnInput->False,
        GraphicsBoxOptions->{DefaultBaseStyle->Directive[
          PointSize[0.009166666666666668], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]]}],
       TraditionalForm], {0., 0.}, Automatic, Offset[10]], CompressedData["
1:eJxlVUtSAjEUjHoRERUUcePSBQMMzIeveAOrdOvWZa6hp+EAeieD6X7Ua1M1
leq8l/fpdDKdl/fd61kI4SN9J+k7DRyz4uFv9IqMF8XP92FcA48x094UX5+H
ARxb+F8C034jmPGY7yrj/RbrXfiXiNfHeo398A/0P9bj6o8VMPMv/H6rl/YN
4hCvxF5Jv3P43wLX8AcOI99v2u/rXUp85Wvq+U/1vP0N8ruRehhvgPhrz6/x
wfy18Mt+aG+Rr2d2n6+GHf0WW8930kv2Jz9T4bfx+VL9eT/1sUV9R76ynfVq
P3P4D83u+2uEP+qha/2689s/wa77qb8SWPWB+OHxH18ZD6z/nI/5Zz5/4svx
H5n/zvjNuGvx9f5lO/msPZ9xLXpZYaa/6muGddbXCL+s9wJ4gpl8UV99y59x
x/K5/FH4Tefjz38OzH6pz3Prx5/XWOJNJF7j7cWz6KsUPVeyfwQ8tPozP/fW
r9NfIJ+8n6L/qOdVyvvZYj7avT/7Id8rX2/y9/d1KXrfSX0bj+09Vj0d63N6
D/Kep37zOvmo/Htl95H5qRfys/H3IY59Pfa+Ml8r9U09P6GS+DN/f6L870Il
/yP+L6jnpfgvRC8r08svSonGZg==
     "]]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Lacate\"", TraditionalForm], 
    FormBox["\"WCC\"", TraditionalForm]},
  AxesOrigin->{25.958333333333336`, 6.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{428., Automatic},
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Correlation between Lactate and White Cell Count Values\"", 
    TraditionalForm],
  PlotRange->{{25.958333333333336`, 77.}, {6, 16}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7699410778611794`*^9, 3.76994108919938*^9}, {
   3.7699411668271685`*^9, 3.7699411845572653`*^9}, {3.769941217519507*^9, 
   3.769941241360173*^9}, {3.769941310488203*^9, 3.7699413196195393`*^9}, {
   3.7699499589142013`*^9, 3.769949968465686*^9}, 3.769952657100958*^9, 
   3.769952816830925*^9, 3.7701786201502953`*^9, 3.813569871427121*^9, 
   3.8135706746910143`*^9},
 CellLabel->"Out[37]=",
 CellID->53368322,ExpressionUUID->"1c910fff-7ed3-4f10-a9d9-ed502cfd282c"]
}, Open  ]],

Cell["\<\
We can now use a test to check the correlation between the two variables.\
\>", "Text",
 CellChangeTimes->{{3.7701795901317883`*^9, 3.7701796296481924`*^9}, 
   3.794207762434846*^9},
 CellID->48838305,ExpressionUUID->"a5fba6c1-d6bb-4a9c-a3e8-036cdd6621e4"],

Cell[TextData[{
 "Use the ",
 ButtonBox["PearsonCorrelationTest",
  BaseStyle->"Link"],
 " function with the ",
 Cell[BoxData[
 "\"\<TestDataTable\>\""], "InlineCode",ExpressionUUID->
  "e14d98cb-f931-4a1e-849b-9a1730ca02ac"],
 " property:"
}], "CodeCaption",
 CellChangeTimes->{{3.7701796333971586`*^9, 3.770179661715475*^9}, 
   3.7701796931125793`*^9, {3.777221111548422*^9, 3.777221132180485*^9}},
 CellID->68413677,ExpressionUUID->"5b4c5c7d-24f9-43bc-a783-ccb2aac75a92"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PearsonCorrelationTest", "[", 
  RowBox[{"lactate", ",", "wcc", ",", "\"\<TestDataTable\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.769953004589147*^9, 3.769953028419969*^9}, 
   3.769953115764927*^9, {3.769953189578311*^9, 3.7699532036257772`*^9}},
 CellLabel->"In[38]:=",
 CellID->157193721,ExpressionUUID->"0cd758ce-43b7-4dcd-b265-cc7af079a945"],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"\<\"Pearson Correlation\"\>", 
      RowBox[{"-", "0.12811310275406504`"}], "0.1631748788199066`"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.7699530289146614`*^9, 3.7699531164839525`*^9, 
  3.769953204976186*^9, 3.7701786206170225`*^9, 3.8135698714751797`*^9, 
  3.813570674733697*^9},
 CellLabel->"Out[38]=",
 CellID->1460707055,ExpressionUUID->"04508e30-e320-430e-a791-52e583e69890"]
}, Open  ]],

Cell[TextData[{
 "We note a correlation coefficient of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "0.13"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "cea93a17-1124-496c-b6f9-b5759496f12c"],
 ". This is a weak negative correlation. We see this reflected in the ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "d5d0ddd7-dd5c-4df0-891c-d4ea3c5c1c8e"],
 "-value, which is larger than the chosen ",
 Cell[BoxData[
  FormBox["\[Alpha]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "320537b0-edf9-44cc-9277-4f555ff608f0"],
 "-value of ",
 Cell[BoxData[
  FormBox["0.05", TraditionalForm]],ExpressionUUID->
  "2b73c221-3e08-494b-bda1-03234bd1a5ad"],
 ". This means that we cannot reject the null hypothesis that the two \
variables are correlated."
}], "Text",
 CellChangeTimes->{{3.7701805441711717`*^9, 3.770180624517455*^9}, {
   3.7701807533222113`*^9, 3.7701808096586485`*^9}, {3.777213654946014*^9, 
   3.777213659922014*^9}, {3.7772211450377703`*^9, 3.7772211528705535`*^9}, {
   3.789820367745558*^9, 3.7898203731161947`*^9}, 3.7942078049703836`*^9, {
   3.8160984624632587`*^9, 3.816098462702956*^9}},
 CellID->76838211,ExpressionUUID->"81b0d5a2-f79b-4694-bd4e-cb3666c7527d"],

Cell["\<\
Equation (1) below shows how we can calculate the correlation coefficient.\
\>", "Text",
 CellChangeTimes->{{3.770180833649448*^9, 3.770180868122317*^9}, {
  3.777221234072673*^9, 3.7772212380900745`*^9}, {3.777221292595525*^9, 
  3.7772212939226575`*^9}},
 CellID->80158902,ExpressionUUID->"3b76a2ec-c3c0-4d5d-9e04-2e02bc967750"],

Cell[BoxData[
 FormBox[
  RowBox[{"\[Rho]", "=", 
   FractionBox[
    RowBox[{"Cov", 
     RowBox[{"(", 
      RowBox[{"X", ",", "Y"}], ")"}]}], 
    RowBox[{
     SubscriptBox["\[Sigma]", "X"], 
     SubscriptBox["\[Sigma]", "Y"]}]]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.7898216014279957`*^9, 3.789821646834939*^9}},
 CellID->1823253885,ExpressionUUID->"082a76a4-0aa2-4cf9-8285-3103fe833424"],

Cell[TextData[{
 "Here ",
 Cell[BoxData[
  FormBox["Cov", TraditionalForm]], "InlineMath",ExpressionUUID->
  "44a7e97c-9b07-4f2c-a497-a184806f7a77"],
 " is the covariance between the two variables and ",
 Cell[BoxData[
  FormBox["\[Sigma]", TraditionalForm]], "InlineMath",ExpressionUUID->
  "ca428343-e670-4057-9811-2e6b44381f44"],
 " denotes the standard deviation of each."
}], "Text",
 CellChangeTimes->{{3.7701809164262366`*^9, 3.770180947702651*^9}, {
   3.777221307291994*^9, 3.7772213422894936`*^9}, {3.777221384103675*^9, 
   3.77722139125239*^9}, 3.7772214497382374`*^9, {3.789820430901408*^9, 
   3.7898204329235697`*^9}, {3.789821688037116*^9, 3.789821696622603*^9}},
 CellID->337207638,ExpressionUUID->"5e17e857-24ea-42c3-b8b5-904ac065f9c5"],

Cell[TextData[{
 "Calculate the correlation coefficient",
 ButtonBox[":",
  BaseStyle->"Link"]
}], "CodeCaption",
 CellChangeTimes->{{3.789821563480023*^9, 3.7898215821080027`*^9}, {
   3.794207958569723*^9, 3.7942079760488415`*^9}, 3.816098480535635*^9},
 CellID->2074113553,ExpressionUUID->"e56a37a6-c751-4806-947b-a3417a95ca9d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r", "=", 
  FractionBox[
   RowBox[{"Covariance", "[", 
    RowBox[{"lactate", ",", "wcc"}], "]"}], 
   RowBox[{
    RowBox[{"StandardDeviation", "[", "lactate", "]"}], " ", 
    RowBox[{"StandardDeviation", "[", "wcc", "]"}]}]]}]], "Input",
 CellChangeTimes->{{3.7701799561487007`*^9, 3.7701800117930293`*^9}, {
  3.770180485477086*^9, 3.7701804855747786`*^9}},
 CellLabel->"In[39]:=",
 CellID->245452443,ExpressionUUID->"22a18bc1-56ce-41b6-ac03-5612fee5d749"],

Cell[BoxData[
 RowBox[{"-", "0.12811310275406504`"}]], "Output",
 CellChangeTimes->{{3.7701799640226774`*^9, 3.770180013848482*^9}, 
   3.770180486503321*^9, 3.794208052293202*^9, 3.813569871481493*^9, 
   3.8135706747406816`*^9},
 CellLabel->"Out[39]=",
 CellID->70420881,ExpressionUUID->"71d40629-8f8e-4279-8776-23e08bcee9b2"]
}, Open  ]],

Cell[TextData[{
 "We can use the ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath",ExpressionUUID->
  "2d9c1a1f-18f5-429f-9a2c-ba67f2913852"],
 " distribution with degrees of freedom set to the sample size minus ",
 Cell[BoxData[
  FormBox["2", TraditionalForm]],ExpressionUUID->
  "1f5ed792-6f12-4daa-90a0-7ac36dddd0b4"],
 " to calculate the ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "55cf8676-f46b-4b4e-9c1e-33f327d7e4d2"],
 "-value. First, we use equation (2) to calculate a ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath",ExpressionUUID->
  "15d8d4c8-9da0-4555-80b4-aa28cd05f061"],
 " statistic."
}], "Text",
 CellChangeTimes->{{3.7701809696899357`*^9, 3.7701809726948557`*^9}, {
   3.7701810084014254`*^9, 3.770181089870693*^9}, 3.777213662570014*^9, {
   3.777221486707934*^9, 3.777221511419405*^9}, {3.816098572511023*^9, 
   3.816098576344084*^9}},
 CellID->137749338,ExpressionUUID->"1d8dc6f2-02e6-4bd6-a824-2eaf379e91df"],

Cell[BoxData[
 FormBox[
  RowBox[{"t", "=", 
   RowBox[{"r", 
    SqrtBox[
     FractionBox[
      RowBox[{"n", "-", "2"}], 
      RowBox[{"1", "-", 
       SuperscriptBox["r", "2"]}]]]}]}], 
  TraditionalForm]], "DisplayFormulaNumbered",
 CellChangeTimes->{{3.789821724048073*^9, 3.789821731619925*^9}},
 CellID->1794484812,ExpressionUUID->"1712fe63-a9ac-4927-9a7d-a43fe929fdf9"],

Cell[TextData[{
 "Calculate the ",
 Cell[BoxData[
  StyleBox["t",
   FontSlant->"Italic"]], "InlineCode",ExpressionUUID->
  "692c9493-6f66-4057-a807-4c572c930cf9"],
 "-statistic:"
}], "CodeCaption",
 CellChangeTimes->{{3.7701811411696*^9, 3.770181149690834*^9}, {
   3.7772215311483774`*^9, 3.7772215316764307`*^9}, {3.7772215775820208`*^9, 
   3.777221586695932*^9}, 3.816098569544736*^9},
 CellID->78447218,ExpressionUUID->"9ef17a38-8bf7-4f84-88eb-8aa4f802a049"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{"r", " ", 
   SqrtBox[
    FractionBox[
     RowBox[{"120", "-", "2"}], 
     RowBox[{"1", "-", 
      SuperscriptBox["r", "2"]}]]]}]}]], "Input",
 CellChangeTimes->{{3.7701804924793615`*^9, 3.770180514928377*^9}, 
   3.770181129747122*^9},
 CellLabel->"In[40]:=",
 CellID->147515281,ExpressionUUID->"191cd81a-50c0-410f-8708-cbc05ff12269"],

Cell[BoxData[
 RowBox[{"-", "1.4032277214127618`"}]], "Output",
 CellChangeTimes->{
  3.7701805165978613`*^9, 3.770181131904355*^9, {3.794208045102243*^9, 
   3.7942080562692785`*^9}, 3.8135698714972773`*^9, 3.8135706747636766`*^9},
 CellLabel->"Out[40]=",
 CellID->300257470,ExpressionUUID->"c835485e-782b-4124-a4b9-caf6ed71c707"]
}, Open  ]],

Cell[TextData[{
 "From the next plot, we can see where the ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath",ExpressionUUID->
  "81130a6c-e88a-4c91-bb10-648682c748b9"],
 "-statistic falls on the probability density curve for ",
 Cell[BoxData[
  FormBox["118", TraditionalForm]],ExpressionUUID->
  "b568cf20-45aa-4138-b0ae-cb061694f037"],
 " degrees of freedom."
}], "Text",
 CellChangeTimes->{{3.770181960530844*^9, 3.7701820242266345`*^9}, {
  3.7772215914324055`*^9, 3.777221602316494*^9}, {3.8135694659814034`*^9, 
  3.813569466156869*^9}},
 CellID->471512326,ExpressionUUID->"b767bd25-9eaa-4794-8d1f-c9d543698b7e"],

Cell[TextData[{
 "Note that the parameters in ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["StudentTDistribution",
    BaseStyle->"CodeLink"], "[", 
   RowBox[{"\[Mu]", ",", "\[Sigma]", ",", "\[Nu]"}], "]"}]], "InlineCode",
  ExpressionUUID->"816a7b9f-103e-4fd1-bd57-5a046e84cb52"],
 " are \[Mu] (location), \[Sigma] (scale), and \[Nu] (degrees of freedom):"
}], "CodeCaption",
 CellChangeTimes->{{3.816098660612001*^9, 3.816098671265057*^9}, {
   3.816098733462365*^9, 3.81609873346239*^9}, {3.8160987789677973`*^9, 
   3.81609880596673*^9}, {3.81609885184016*^9, 3.8160988625759*^9}, {
   3.816501970892549*^9, 3.816502005884838*^9}, {3.816502060584235*^9, 
   3.816502060585539*^9}, {3.816502100380952*^9, 3.816502104211691*^9}, 
   3.816502145595697*^9, {3.81902110740339*^9, 3.8190212221005793`*^9}, {
   3.8190212593049498`*^9, 3.819021259976378*^9}},
 CellID->2110711978,ExpressionUUID->"375bf757-7748-4cf0-883c-33cca9c4fb56"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"PDF", "[", 
      RowBox[{
       RowBox[{"StudentTDistribution", "[", 
        RowBox[{"120", "-", "2"}], "]"}], ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<\!\(\*StyleBox[\"t\",FontSlant->\"Italic\"]\) Distribution\>\""}], 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.4"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Line", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0.4"}], "}"}]}], "}"}], "]"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7701802506915207`*^9, 3.7701802945673075`*^9}, {
  3.770180418283616*^9, 3.770180457810029*^9}, {3.770181176878161*^9, 
  3.7701811937012396`*^9}, {3.7942080747619224`*^9, 3.7942080769857025`*^9}},
 CellLabel->"In[41]:=",
 CellID->310026798,ExpressionUUID->"3bfc6f07-d297-4ab9-9d6d-0067ce4c8bd0"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxEmPc/1u8b9+2993ZdF0n2Llzv93lSlIxEERllJVRGhEJFUpmRGVmhVGZI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     "], {{{}, 
       {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[None], 
        GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl2GXcVUUbxeEHeBAUKVEBpUE6VRAL6e5OEVSku0vp7lSR7m4DKRVBpRUQ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          "]]]}, {}, {}}, {{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], LineBox[CompressedData["
1:eJwl2GW4VVUbheGDdKPSIorS3Z0CFkp3N0qqCIKBBYqCYtFdSncoZdANCkhI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          "]]},
        Annotation[#, "Charting`Private`Tag$5137#1"]& ]}}], {}}, 
   LineBox[{{-1.4032277214127618`, 0}, {-1.4032277214127618`, 0.4}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}, "AxesInFront" -> True},
  PlotLabel->FormBox[
   "\"\\!\\(\\*StyleBox[\\\"t\\\",FontSlant->\\\"Italic\\\"]\\) \
Distribution\"", TraditionalForm],
  PlotRange->{{-9.999999591836735, 9.999999591836735}, {0, 0.4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7701811948082714`*^9, {3.794208038550545*^9, 3.7942080785602036`*^9}, 
   3.813569871802897*^9, 3.8135706750587587`*^9},
 CellLabel->"Out[41]=",
 CellID->1988211487,ExpressionUUID->"15f08718-df70-444a-adea-70b268eb3ca7"]
}, Open  ]],

Cell[TextData[{
 "Since we have a two-tailed alternative hypothesis, we multiply the ",
 ButtonBox["CDF",
  BaseStyle->"Link"],
 " by ",
 Cell[BoxData[
  FormBox["2", TraditionalForm]],ExpressionUUID->
  "0de22302-be2f-47aa-a4d6-01ef05201a06"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.770182035117553*^9, 3.770182068332401*^9}, {
  3.7772216258818502`*^9, 3.7772216403072925`*^9}},
 CellID->52103744,ExpressionUUID->"1fcafca0-2073-4da8-8463-994658e0693b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CDF", "[", 
   RowBox[{
    RowBox[{"NormalDistribution", "[", 
     RowBox[{"0", ",", "1"}], "]"}], ",", "z"}], "]"}], " ", "2"}]], "Input",
 CellChangeTimes->{{3.7699415654580364`*^9, 3.769941598380224*^9}, {
  3.769952846222377*^9, 3.769952846465778*^9}, {3.769952916860607*^9, 
  3.7699529269296975`*^9}, {3.770180027655637*^9, 3.770180059329934*^9}},
 CellLabel->"In[42]:=",
 CellID->475824172,ExpressionUUID->"b14542a7-940e-4fbe-8f16-6d402e708e91"],

Cell[BoxData[
 RowBox[{"Erfc", "[", 
  RowBox[{"-", 
   FractionBox["z", 
    SqrtBox["2"]]}], "]"}]], "Output",
 CellChangeTimes->{{3.769941591054859*^9, 3.7699415989813795`*^9}, {
   3.769952834041959*^9, 3.769952847353382*^9}, {3.769952917560748*^9, 
   3.769952927301715*^9}, 3.7701786203039484`*^9, {3.770180018297591*^9, 
   3.770180059985179*^9}, 3.7701805293288374`*^9, 3.8135698718108807`*^9, 
   3.813570675066874*^9},
 CellLabel->"Out[42]=",
 CellID->1024914689,ExpressionUUID->"76a605f6-41a0-4cc3-9c6b-a12c3fd266bb"]
}, Open  ]],

Cell[TextData[{
 "We can finally state that there is no correlation between the lactate and \
white cell count of our subjects (",
 Cell[BoxData[
  FormBox["r", TraditionalForm]], "InlineMath",ExpressionUUID->
  "7998aee8-1e8b-4557-9c19-d75bcb36c81e"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "0.13"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "61a7aacc-ea19-4056-9724-1570c8a1c475"],
 ", ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath",ExpressionUUID->
  "0f997dff-af6e-4e76-a5ad-68760c1a5ff0"],
 " = ",
 Cell[BoxData[
  FormBox["0.16", TraditionalForm]],ExpressionUUID->
  "460a76ef-3b8d-4159-9b3a-f59432779231"],
 ")."
}], "Text",
 CellChangeTimes->{{3.7701830597759027`*^9, 3.7701831330679855`*^9}, {
  3.7772216491791797`*^9, 3.777221653363598*^9}},
 CellID->257693548,ExpressionUUID->"a9433f1a-f383-46cb-901e-9817b9cc15e3"],

Cell[CellGroupData[{

Cell[BoxData["Exercises"], "ExerciseSection",
 CellChangeTimes->{{3.727191019258484*^9, 3.727191021664649*^9}},
 CellLabel->"In[43]:=",
 CellID->566065673,ExpressionUUID->"2fe2d798-8be3-4d01-85bc-a8ede58b8b1c"],

Cell[TextData[{
 "You can find the notebooks for this textbook at ",
 ButtonBox["wolfr.am/klopper",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/klopper"], None},
  ButtonNote->"https://wolfr.am/klopper"],
 ". All relevant ",
 Cell[BoxData[
  RowBox[{".", "csv"}]], "InlineCode",ExpressionUUID->
  "a5613b5b-1e22-437a-81b6-c69cdc978d71"],
 " files are stored in the downloadable ",
 Cell[BoxData[
  FormBox[
   RowBox[{".", "zip"}], TraditionalForm]], "InlineCode",
  FormatType->"TraditionalForm",ExpressionUUID->
  "33b497bf-7fcb-4c79-a972-a1d0b5d79459"],
 " file. If you are using a fresh notebook, make sure to have the ",
 Cell[BoxData[
  RowBox[{".", "csv"}]], "InlineCode",ExpressionUUID->
  "8ca520e0-5695-4058-a3fc-ed5289ca6457"],
 " stored in the same folder."
}], "ExerciseNote",
 CellChangeTimes->{
  3.8135695033689213`*^9, {3.813569625502149*^9, 3.81356962550334*^9}, {
   3.816098932587987*^9, 3.8160989555417547`*^9}},
 FontTracking->-0.05,
 CellID->1980862459,ExpressionUUID->"807c42aa-aa70-428e-9099-faf7e8f7ab2d"],

Cell["\<\
Create a notebook in the same directory (or folder) as the spreadsheet file \
below and set it as the working directory.\
\>", "Exercise",
 CellChangeTimes->{{3.7699485538826714`*^9, 3.7699485922740736`*^9}},
 CellID->166035477,ExpressionUUID->"b4bca651-2fa0-40d5-9d1b-f487ffffef36"],

Cell[TextData[{
 "Import the ",
 StyleBox["SimulatedData.csv",
  FontSlant->"Italic"],
 " file as a ",
 ButtonBox["Dataset",
  BaseStyle->"Link"],
 " object named ",
 Cell[BoxData[
 "data"], "InlineCode",ExpressionUUID->"2f931b57-6547-466a-b704-66b4334fb55d"],
 " and verify the integrity of the data by viewing the data from the first \
subject and also the number of subjects and variables."
}], "Exercise",
 CellChangeTimes->{{3.769948449962427*^9, 3.7699485326544003`*^9}, {
  3.777221675865848*^9, 3.7772216812303843`*^9}},
 CellID->584277686,ExpressionUUID->"3ccd0713-0110-4450-b818-d2af310c6e9b"],

Cell[TextData[{
 "Create a separate ",
 ButtonBox["Dataset",
  BaseStyle->"Link"],
 " object for each of the two sample space elements in the ",
 Cell[BoxData[
  ButtonBox["\"\<Group\>\"",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/menuitem/Group"]], "InlineCode",ExpressionUUID->
  "1eeebc8e-ac9f-48aa-aca0-1ff4fb01d90e"],
 " variable and name them ",
 Cell[BoxData[
 "coad"], "InlineCode",ExpressionUUID->"5624c413-ccbb-4b36-91a9-e0cb55e24764"],
 " and ",
 Cell[BoxData[
 "cb"], "InlineCode",ExpressionUUID->"c8c863c6-46a5-4dfc-973d-9d6578a3cbb5"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.769948860450972*^9, 3.7699489446513424`*^9}, {
  3.7772218039836583`*^9, 3.7772218372369833`*^9}},
 CellID->395600393,ExpressionUUID->"c580d4e3-7b90-42b0-b373-29f7a35f27a6"],

Cell[TextData[{
 "Perform the required descriptive statistical analysis and visualization for \
the body mass index for the two groups of subjects. Perform the appropriate \
test to calculate the ",
 Cell[BoxData[
  StyleBox["p",
   FontSlant->"Italic"]], "InlineMath",ExpressionUUID->
  "8e46893d-aca2-4164-8e16-61caad81bddf"],
 "-value for the difference in body mass indices between the two groups. What \
is the test conclusion for an ",
 Cell[BoxData[
 "\[Alpha]"], "InlineMath",ExpressionUUID->
  "7b553101-8c4f-4568-a1c5-f1824481fe12"],
 "-value of ",
 Cell[BoxData[
  FormBox["0.05", TraditionalForm]],ExpressionUUID->
  "ecf92e59-e18f-4b3b-a050-5384ee5b289c"],
 "?"
}], "Exercise",
 PageBreakAbove->True,
 CellChangeTimes->{{3.7699474615153627`*^9, 3.7699474855992327`*^9}, {
  3.76994754855812*^9, 3.769947711179647*^9}, {3.769949259838546*^9, 
  3.769949277156262*^9}, {3.777213665579014*^9, 3.7772136684270144`*^9}, {
  3.7772218428905487`*^9, 3.7772218902622857`*^9}, {3.7942080985021577`*^9, 
  3.7942080991364927`*^9}, {3.8160990021400003`*^9, 3.816099030018223*^9}},
 CellID->513284189,ExpressionUUID->"85d4c9b8-c0a9-4503-bc77-6f1e2ab451a9"],

Cell["\<\
Perform the relevant summary statistics and investigate the difference in \
levels of shortness of breath between the two groups.\
\>", "Exercise",
 CellChangeTimes->{{3.7699478620571737`*^9, 3.769947901289197*^9}},
 CellID->28284756,ExpressionUUID->"d7b9922a-77b4-4bc4-bd56-fe8f7bfde295"],

Cell["\<\
Use the appropriate tests to investigate the difference in correlation \
between admission lactate levels and white cell count between the two groups.\
\>", "Exercise",
 CellChangeTimes->{{3.7699479230055666`*^9, 3.7699479834006767`*^9}},
 CellID->258378502,ExpressionUUID->"be3ee1e9-f230-4f95-a5ae-79b8095df72c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final Assessment", "Subsection",
 CellChangeTimes->{{3.7537591316222167`*^9, 3.753759135174576*^9}, {
  3.768737145052994*^9, 3.7687371484183307`*^9}},
 CellID->73110728,ExpressionUUID->"814f0739-2817-42bc-9016-3b020fb83679"],

Cell["\<\
Well done. This text provides a good entry point to introductory statistics \
and the Wolfram Language. You do not need to be enrolled in a statistics \
course to gain enjoyment and use from this material\[LongDash]there are \
thousands of free databases filled with information that has likely never \
been analyzed.\
\>", "Text",
 CellChangeTimes->{
  3.753759108319598*^9, {3.7687371605985484`*^9, 3.768737225930081*^9}, {
   3.7687554898174925`*^9, 3.7687554951705627`*^9}, {3.768755536032734*^9, 
   3.7687556550995417`*^9}, {3.7687573932799234`*^9, 3.768757449000495*^9}, {
   3.77048618032205*^9, 3.7704861870500507`*^9}, {3.770555529079352*^9, 
   3.770555558196352*^9}, {3.7705556625823517`*^9, 3.770555675860352*^9}},
 CellID->215554612,ExpressionUUID->"174e69f8-8434-4b3e-bcfe-d5a06d56b6bf"],

Cell[TextData[{
 "Try some of the datasets at the ",
 ButtonBox["Wolfram Data Repository",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://datarepository.wolframcloud.com/"], None},
  ButtonNote->"https://datarepository.wolframcloud.com/"],
 ". All data at the repository has been cleaned for use with the Wolfram \
Language and is readily available for analysis. Use it to write an article or \
a blog post or use it at your office with internal data."
}], "Text",
 CellChangeTimes->{{3.7687557369379063`*^9, 3.7687558172153325`*^9}, {
   3.768757479296524*^9, 3.76875750755935*^9}, 3.7704861895870504`*^9, {
   3.7705556893653517`*^9, 3.770555711451352*^9}, {3.8160991024699574`*^9, 
   3.816099103701846*^9}, 3.8165302727086906`*^9},
 CellID->125622123,ExpressionUUID->"22da2da2-494f-4691-bfdd-74505290db6c"],

Cell[TextData[{
 "The Wolfram Language is used by thousands of academics in the physical and \
social sciences, and it\[CloseCurlyQuote]s well known to those who use other \
data science languages. There are hundreds of journals that accept \
Mathematica-based research, including Wolfram\[CloseCurlyQuote]s own \
journals, ",
 StyleBox[ButtonBox["The Mathematica Journal",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.mathematica-journal.com/"], None},
  ButtonNote->"https://www.mathematica-journal.com/"],
  FontSlant->"Italic"],
 " and ",
 StyleBox[ButtonBox["Complex Systems",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.complex-systems.com/"], None},
  ButtonNote->"https://www.complex-systems.com/"],
  FontSlant->"Italic"],
 ". If you end up creating a neat bit of code, try submitting it to the ",
 ButtonBox["Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{"demonstrations.wolfram.com", None}],
 ", or if you think your notebook is publishable in its own right, try \
submitting it to the ",
 ButtonBox["Computational Notebook Archive",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://notebookarchive.org/"], None},
  ButtonNote->"https://notebookarchive.org/"],
 ". If you get into trouble and need a little help, ",
 ButtonBox["Wolfram Community",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://community.wolfram.com/"], None},
  ButtonNote->"https://community.wolfram.com/"],
 " is a tight-knit group of Wolfram Language coders from all over the world \
who can help you with debugging."
}], "Text",
 CellChangeTimes->{{3.768755838608472*^9, 3.768756075893198*^9}, {
   3.768757538592453*^9, 3.7687575387854724`*^9}, 3.7704861924410505`*^9, {
   3.770555716642352*^9, 3.770555734458352*^9}, {3.7705557781003523`*^9, 
   3.770555786546352*^9}, {3.770555910121352*^9, 3.770555944279352*^9}, {
   3.770557070380352*^9, 3.770557095658352*^9}, {3.7705571935533524`*^9, 
   3.770557217842352*^9}, {3.7856805866100454`*^9, 3.785680590703046*^9}, 
   3.816530280893148*^9},
 CellID->237108180,ExpressionUUID->"0ae2b8ec-3802-4665-8514-b986f941e661"],

Cell[CellGroupData[{

Cell["Q&A", "QASection",
 CellID->35474018,ExpressionUUID->"997e06ae-0b0e-4224-ad38-49cc7e33a07a"],

Cell["What is the Wolfram Demonstrations Project?", "Question",
 CellChangeTimes->{{3.768756152000808*^9, 3.768756158496457*^9}},
 CellID->193396523,ExpressionUUID->"be4b7ac9-8daf-4ee3-95b4-b96c7b1f3f9e"],

Cell[TextData[{
 "You\[CloseCurlyQuote]ve probably seen links to the Wolfram Demonstrations \
Project all through this book in the More to Explore sections. The Wolfram \
Demonstrations Project is a site comprised of user-submitted Demonstrations \
that use the ",
 ButtonBox["Manipulate",
  BaseStyle->"Link"],
 " function to create interactive, visual representations on a wide range of \
topics. Currently there are over 12,000 Demonstrations available. "
}], "Answer",
 CellChangeTimes->{{3.7687561607926865`*^9, 3.768756211956803*^9}, {
   3.7687563232049265`*^9, 3.768756368558461*^9}, 3.7704861954650507`*^9, {
   3.770556104709352*^9, 3.770556109404352*^9}, {3.770556291121352*^9, 
   3.7705564555533524`*^9}, {3.770556794014352*^9, 3.770556797477352*^9}, 
   3.7856806158690453`*^9},
 CellID->613161291,ExpressionUUID->"29f32b32-0759-44d4-a8a1-2ce12c8084f9"],

Cell["What are the Wolfram journals?", "Question",
 CellChangeTimes->{{3.7687563881834235`*^9, 3.768756394399045*^9}},
 CellID->17500213,ExpressionUUID->"63943bd1-39e3-4587-9d42-02b3c50eeb3b"],

Cell[TextData[{
 "Wolfram Research runs two academic journals. The first is ",
 StyleBox["The Mathematica Journal",
  FontSlant->"Italic"],
 ", an online-only journal that publishes exemplary and novel uses of the \
Wolfram Language in various fields. The other is ",
 StyleBox["Complex Systems",
  FontSlant->"Italic"],
 ", a print journal with a more limited scope that focuses on \
\[OpenCurlyDoubleQuote]systems with simple components but complex overall \
behavior.\[CloseCurlyDoubleQuote] Neither journal requires submission fees."
}], "Answer",
 CellChangeTimes->{{3.7687568972133217`*^9, 3.768757023790978*^9}, {
  3.770556827745352*^9, 3.770556861097352*^9}, {3.785692350665018*^9, 
  3.785692352191018*^9}, {3.785692986387018*^9, 3.785692992380018*^9}, {
  3.7856931400360184`*^9, 3.7856931920010185`*^9}},
 CellID->698314370,ExpressionUUID->"1bff3695-8710-400b-827e-a44075c82994"],

Cell["What is the Computational Notebook Archive?", "Question",
 CellChangeTimes->{{3.7687569544880486`*^9, 3.768756956825282*^9}, {
  3.768757037989398*^9, 3.7687570466202607`*^9}, {3.770557127113352*^9, 
  3.7705571324103518`*^9}},
 CellID->290534271,ExpressionUUID->"917e2ce8-6de9-4bd0-85e3-d3950846fb75"],

Cell[TextData[{
 "It is a new service that publishes finished and unfinished notebooks that \
have value to the community and can be used in overlay journals like Elsevier\
\[CloseCurlyQuote]s ",
 StyleBox["SoftwareX",
  FontSlant->"Italic"],
 "."
}], "Answer",
 CellChangeTimes->{{3.768757055843183*^9, 3.7687570563252316`*^9}, {
   3.7687571713147287`*^9, 3.768757216863283*^9}, {3.770557137513352*^9, 
   3.7705571386663523`*^9}, 3.7705571855743523`*^9},
 CellID->348482271,ExpressionUUID->"4755bd72-872d-41e6-8117-9be60375ffb0"],

Cell["What is Wolfram Community?", "Question",
 CellChangeTimes->{{3.7687572358791847`*^9, 3.768757241151712*^9}, {
  3.770560109403654*^9, 3.7705601101065845`*^9}},
 CellID->602644645,ExpressionUUID->"e0cda5dc-6e84-43ce-bd2a-c8d6502c86be"],

Cell["\<\
It is a good place to post your questions. Professionals and academics from \
dozens of different fields post experimental, unfinished projects for review. \
Users may comment, borrow code, and add their own flair.\
\>", "Answer",
 CellChangeTimes->{{3.7687572512267194`*^9, 3.768757271044701*^9}, {
  3.7687573088214784`*^9, 3.76875736024262*^9}, {3.7704861985700502`*^9, 
  3.7704862010810504`*^9}, {3.7705601139631987`*^9, 3.7705601405755367`*^9}},
 CellID->109936451,ExpressionUUID->"ad5ba23f-69a4-4f65-b509-4c6806e1de94"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More to Explore", "MoreExploreSection",
 CellID->19888384,ExpressionUUID->"bbf0f155-f49d-42d5-97ef-090e2684502b"],

Cell[TextData[{
 StyleBox[ButtonBox["Check out the documentation pages on StandardVariation \
and StudentTDistribution for more details and interesting charts ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/"], None},
  ButtonNote->"https://reference.wolfram.com/language/"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/Documentation",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/Documentation"], None},
  ButtonNote->"https://wolfr.am/Documentation"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellID->1270860181,ExpressionUUID->"9ae75eb9-7626-43da-85cb-8ada57c46da5"],

Cell[TextData[{
 StyleBox[ButtonBox["Here\[CloseCurlyQuote]s an example of use from finance \
in a neat Wolfram Demonstration by P. Thiansathaporn ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://demonstrations.wolfram.com/\
GeneralizedExtremeValueDistributionsApplicationInFinancialRi/"], None},
  ButtonNote->
   "https://demonstrations.wolfram.com/\
GeneralizedExtremeValueDistributionsApplicationInFinancialRi/"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/ValueDistributions",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/ValueDistributions"], None},
  ButtonNote->"https://wolfr.am/ValueDistributions"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{3.813569661316978*^9},
 CellID->1695003484,ExpressionUUID->"10cca2be-63f1-4f56-a222-83149fa11d63"],

Cell[TextData[{
 StyleBox[ButtonBox["Another excellent resource for researchers and \
programmers is Wolfram Community. Here is the Community group for statistics ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://community.wolfram.com/content?curTag=statistics%20and%\
20probability"], None},
  ButtonNote->
   "https://community.wolfram.com/content?curTag=statistics%20and%\
20probability"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/Statistics",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/Statistics"], None},
  ButtonNote->"https://wolfr.am/Statisticss"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{{3.813569684324827*^9, 3.813569690172756*^9}, 
   3.813569764217814*^9},
 CellID->26626102,ExpressionUUID->"03c1ab8b-cc7e-4d9a-8cd5-e65480b4ca23"],

Cell[TextData[{
 StyleBox[ButtonBox["Try this demonstration on the Mann\[Dash]Whitney \
nonparametric test by O. E. Prokopchenko ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
TheMannWhitneyNonparametricTestInTheRoleOfALocationTest/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/\
TheMannWhitneyNonparametricTestInTheRoleOfALocationTest/"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/NonparametricTest",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://wolfr.am/NonparametricTest"], None},
  ButtonNote->"http://wolfr.am/NonparametricTest"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellID->115890670,ExpressionUUID->"3c336968-8616-48ca-a8cf-79200f49e97a"],

Cell[TextData[{
 StyleBox[ButtonBox["Here is another research project using publicly \
available data on power outages in the UK ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://community.wolfram.com/groups/-/m/t/1762584"], None},
  ButtonNote->"https://community.wolfram.com/groups/-/m/t/1762584"],
  BaseStyle -> "Hyperlink"],
 StyleBox["(", "MoreExploreShortURL"],
 StyleBox[ButtonBox["wolfr.am/PowerOutages",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/PowerOutages"], None},
  ButtonNote->"https://wolfr.am/PowerOutages"], "MoreExploreShortURL",
  BaseStyle -> "Hyperlink"],
 StyleBox[")", "MoreExploreShortURL"]
}], "MoreExplore",
 CellChangeTimes->{3.813569814916718*^9},
 CellID->6822861,ExpressionUUID->"56dd8848-d3fb-4a3a-9041-7e4aaad92bbf"]
}, Open  ]]
}, Open  ]]
},
Editable->False,
Saveable->False,
WindowSize->{808, 911},
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
DockedCells->{
  Cell[
   BoxData[
    TagBox[
     GridBox[{{
        TemplateBox[{"\[ThinSpace]", "\[ThinSpace]", 
          StyleBox[
          "Introduction to Statistics\t\t\t\t\t\nwith the Wolfram Language", 
           LineSpacing -> {1, 1}, FontFamily -> "Source Sans Pro", FontSize -> 
           24, FontColor -> GrayLevel[1]], "\[ThinSpace]"}, 
         "RowWithSeparators"], 
        PaneBox[
         StyleBox["\[VeryThinSpace]", ShowStringCharacters -> False], 
         Alignment -> Right, ImageSize -> {65, 75}], 
        PaneBox[
         PaneBox[
          TemplateBox[{"\[ThinSpace]", "\" \"", 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"14-Klopper-NonparametricTests.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
                ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"14-Klopper-NonparametricTests.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                  None, Background -> GrayLevel[0.2], Evaluator -> Automatic, 
                  Method -> "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Chapter 14\"", TooltipDelay -> 0.15, 
              LabelStyle -> "TextStyling"], 
             Annotation[#, "Chapter 14", "Tooltip"]& ], 
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[5], Selectable -> False], 
            TagBox[
             TooltipBox[
              PaneSelectorBox[{False -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"01-Klopper-IntroDataAnalysis.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                  Automatic, Method -> "Preemptive"], True -> ButtonBox[
                  PaneBox[
                   GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                     ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                    ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                   Alignment -> Center], 
                  ButtonFunction :> (
                   NotebookLocate[{"01-Klopper-IntroDataAnalysis.nb", ""}, 
                    FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                  GrayLevel[0.2], Evaluator -> Automatic, Method -> 
                  "Preemptive"]}, 
               Dynamic[
                CurrentValue["MouseOver"]], ImageSize -> Automatic, 
               FrameMargins -> 0], "\"Chapter 1\"", TooltipDelay -> 0.15, 
              LabelStyle -> "TextStyling"], 
             Annotation[#, "Chapter 1", "Tooltip"]& ]}, "RowWithSeparators"], 
          Alignment -> Right], ImageSize -> {100, 30}, 
         FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> GrayLevel[0.2], 
             ImageSize -> {35, 30}, Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> RGBColor[0.12, 0.18, 0.26], 
             ImageSize -> {35, 30}, Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "1 | Introduction" :> 
          NotebookLocate[{"01-Klopper-IntroDataAnalysis.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "2 | Evaluating Basic Math" :> 
          NotebookLocate[{"02-Klopper-BasicMath.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "3 | Collections" :> 
          NotebookLocate[{"03-Klopper-Collections.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "4 | Working with Datasets" :> 
          NotebookLocate[{"04-Klopper-WorkingWithData.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "5 | Data Types" :> 
          NotebookLocate[{"05-Klopper-DataTypes.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "6 | Simple Descriptive Statistics" :> 
          NotebookLocate[{"06-Klopper-DescriptiveStatistics.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "7 | Visualizing Data" :> 
          NotebookLocate[{"07-Klopper-VisualizingData.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "8 | Distributions" :> 
          NotebookLocate[{"08-Klopper-Distributions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "9 | Hypothesis Testing" :> 
          NotebookLocate[{"09-Klopper-HypothesisTesting.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], 
          "10 | Parametric Tests, Comparing Means" :> 
          NotebookLocate[{"10-Klopper-ParametricTests.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "11 | Correlation" :> 
          NotebookLocate[{"11-Klopper-Correlation.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "12 | Linear Regression" :> 
          NotebookLocate[{"12-Klopper-LinearRegression.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "13 | Comparing Categorical Variables" :> 
          NotebookLocate[{"13-Klopper-ComparingCategoricalVariables.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "14 | Nonparametric Tests" :> 
          NotebookLocate[{"14-Klopper-NonparametricTests.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "15 | A Research Project Demonstration" :> 
          NotebookLocate[{"15-Klopper-ResearchProject.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"]], 
   "Text", ShowCellBracket -> False, CellFrame -> {{0, 0}, {3, 0}}, 
   Selectable -> False, CellFrameColor -> RGBColor[0.12, 0.18, 0.26], 
   CellMargins -> {{0, 0}, {0, -1}}, CellFrameMargins -> {{27, 0}, {1, 7}}, 
   Background -> RGBColor[0.12, 0.18, 0.26], CellTags -> 
   "DockedCellLogoCell"], 
  Cell["JUAN H. KLOPPER", "Text", FontFamily -> "Source Sans Pro", FontWeight -> 
   "Light", FontSize -> 15, CellFrame -> {{0, 0}, {3, 0}}, ShowCellBracket -> 
   False, CellMargins -> {{0, 0}, {-1, -1}}, 
   CellFrameMargins -> {{27, 0}, {2, 4}}, CellFrameColor -> 
   RGBColor[1., 0.7, 0.1], FontTracking -> "Extended", FontColor -> 
   GrayLevel[1], Background -> RGBColor[0.9, 0.4, 0.], CellTags -> 
   "DockedCellLogoCell"]},
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    Introduction to Statistics with the Wolfram Language", "Header"]}],
     "Header", CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], 
   None, None}, {None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["  |  A Research Project Demonstration", "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 34}, {Inherited, Inherited}}]}},
ShowAutoSpellCheck->False,
FrontEndVersion->"12.2 for Mac OS X x86 (64-bit) (December 12, 2020)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CellInsertionPointCell -> 
       FEPrivate`FrontEndResource["FEExpressions", "CellInsertionMenu"], 
       CreateCellID -> True, $CellContext`GhostCellInEmptyNotebook -> False], 
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {
        "PageSize" -> {504, 720}, "PrintRegistrationMarks" -> True}, 
       Magnification -> 0.6]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], StyleMenuListing -> None, FontFamily -> 
       "Source San Pro", FontSize -> 8, FontWeight -> "Plain", FontSlant -> 
       "Plain", FontColor -> GrayLevel[0.45]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Source San Pro", FontSize -> 
       8, FontWeight -> "Bold", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth :> 700, 
       PrintingOptions -> {
        "InnerOuterMargins" -> {35, 16}, "PaperOrientation" -> "Portrait", 
         "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, 
       AutoStyleOptions -> {
        "FormattingErrorTooltips" -> False, "HighlightComments" -> False, 
         "HighlightEmphasizedSyntaxErrors" -> False, 
         "HighlightExcessArguments" -> False, "HighlightFormattingErrors" -> 
         False, "HighlightGlobalToLocalScopeConflicts" -> False, 
         "HighlightGraphicsCompatibilityProblems" -> False, 
         "HighlightLocalScopeConflicts" -> False, "HighlightMissingArguments" -> 
         False, "HighlightNoKernelPresent" -> False, 
         "HighlightOrderOfEvaluationConflicts" -> False, "HighlightStrings" -> 
         True, "HighlightSymbolContexts" -> False, "HighlightSymbolShadowing" -> 
         False, "HighlightSyntaxErrors" -> False, "HighlightUndefinedSymbols" -> 
         False, "HighlightUnknownOptions" -> False, 
         "HighlightUnwantedAssignments" -> False}, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey :> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Open]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey :> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey :> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, CellDingbat -> 
          Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{96, Inherited}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{96, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 64}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 24}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["GrayPointSix"], FontColor -> GrayLevel[0.6]], 
         Cell[
          StyleData["GrayPointSix", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{108, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, DefaultNewCellStyle -> 
          "ExerciseInput", CounterIncrements -> "Exercise", MenuSortingValue -> 
          10020, MenuCommandKey :> "2", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{110, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth :> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, DefaultReturnCreatedCellStyle -> 
          "Answer", CounterIncrements -> "Question", MenuSortingValue -> 
          10030, MenuCommandKey :> "3", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth :> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, ReturnCreatesNewCell -> True, 
          DefaultReturnCreatedCellStyle -> "Question", 
          LineSpacing -> {1.125, 1., 2.}, MenuSortingValue -> 10032, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSmallSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          ReturnCreatesNewCell -> True, CellFrameLabelMargins -> 3, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, PageBreakBelow -> False, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 12}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Baskerville", FontSize -> 
          18, FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          ReturnCreatesNewCell -> True, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Italic", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", StripStyleOnPaste -> True, PageBreakWithin -> False, 
          GroupPageBreakWithin -> False, GeneratedCell -> True, 
          CellAutoOverwrite -> True, ShowCellLabel -> False, 
          DefaultFormatType -> DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221]], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{88, 10}, {4, 7}}, 
          GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, 
          ShowCellLabel -> False, SpanMaxSize -> 1, FontSize -> 14], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{88, 10}, {4, 7}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{88, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{88, 10}, {10, 4}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Comment"], FontFamily -> "Verdana", FontSize -> 13, 
          FontColor -> RGBColor[0.3, 0.3, 0.2], Background -> 
          RGBColor[1, 0.9, 0.8]], 
         Cell[
          StyleData["Comment", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Suggestion"], 
          CellFrameLabels -> {{Inherited, Inherited}, {Inherited, 
             Cell[
              BoxData[
               TagBox[
                GridBox[{{
                   ButtonBox[
                   "\"  Insert  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`ReplaceWithSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    ContentPadding -> False, Appearance -> Automatic, Method -> 
                    "Queued"], 
                   ButtonBox[
                   "\"  Stet  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; DocuTools`StetSuggestion[]), 
                    Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "    ", 
                   ButtonBox[
                   "\"  Next  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindNextSuggestion[]), Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], 
                   ButtonBox[
                   "\"  Previous  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindPreviousSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "\"\""}}, 
                 AutoDelete -> False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
                "Grid"]], ShowStringCharacters -> False, Background -> 
              None]}}, Background -> RGBColor[1, 0.8, 0.8]], 
         Cell[
          StyleData["Suggestion", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Tentative"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[
             0.30000000000000016`, 0.6000000000000003, 0.7000000000000003], 
            "Thickness" -> 5}, Evaluatable -> False, CellFrameMargins -> 4, 
          StyleMenuListing -> None, Background -> 
          RGBColor[0.8500000000000003, 0.9500000000000003, 1]], 
         Cell[
          StyleData["Tentative", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["WebOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.91, 0.92, 0.9], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.91, 0.92, 0.86]], 
         Cell[
          StyleData["WebOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Lockdown"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.8, 0.5, 0.4], "Thickness" -> 3}, Evaluatable -> 
       False, StyleMenuListing -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["IndexField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["IndexField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExplanationField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["ExplanationField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EnglishHighlight"], FontFamily -> "WolframCodeSans"], 
         Cell[
          StyleData["EnglishHighlight", "Printout"]]}, Open]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       StyleData["StandardForm"], 
       InputAutoReplacements -> {
        "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> "\[LessEqual]", 
         ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", "==" -> "\[Equal]",
          "@>" -> "\\[InlinePart]", "<->" -> "\[UndirectedEdge]", ParentList},
        LineSpacing -> {1.25, 0, 2}, SingleLetterItalics -> False, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["OutputForm"], PageWidth :> Infinity, TextAlignment -> Left, 
       LineSpacing -> {0.6, 1}, AutoQuoteCharacters -> {}, 
       PasteAutoQuoteCharacters -> {}, StyleMenuListing -> None, FontFamily -> 
       "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       StyleData["InputForm"], PageWidth :> Infinity, 
       InputAutoReplacements -> {}, AllowInlineCells -> False, Hyphenation -> 
       False, AutoQuoteCharacters -> {}, PasteAutoQuoteCharacters -> {}, 
       AutoSpacing -> False, NumberMarks -> True, AutoNumberFormatting -> 
       False, StyleMenuListing -> None, FontFamily -> "Source Sans Pro", 
       PrivateFontOptions -> {"OperatorSubstitution" -> True}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Link", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (Function[
             t, NotebookFind[t, "Notes", All, CellStyle]; 
              NotebookFind[
               t, "NotesSection", All, CellStyle, AutoScroll -> Top]][
              Documentation`HelpLookup[
               StringJoin["ref/", #]]]& ), ButtonSource -> ButtonContents, 
            Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Crosslink"], 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               
               NotebookLocate[#2, "OpenInNewWindow" -> 
                CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None,
             Method -> "Queued"}], 
         Cell[
          StyleData["Crosslink", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeLink"], 
          ButtonBoxOptions -> {
           Appearance -> None, ButtonFunction :> (Documentation`HelpLookup[
              Part[#, 1]]& ), ButtonSource -> ButtonContents, Evaluator -> 
            Automatic}], 
         Cell[
          StyleData["CodeLink", "Printout"]]}, Open]], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 0, FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 0, FontFamily -> 
       "Source Sans Pro", FontSize -> Inherited 0.95], 
      Cell[
       StyleData["NoLabel"], 
       GeneratedCellStyles -> {"Output" -> "ExerciseOutput"}, ShowCellLabel -> 
       False], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariable"], FontFamily -> "Times", FontSize -> 
          Inherited 1.05, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariable", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariableLrg"], FontFamily -> "Times", FontSize -> 
          Inherited 1.1, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariableLrg", "Printout"]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Key Styles", "Subsubsection"], 
         Cell[
          StyleData["Key0"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {"Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key1"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
                  "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key2"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}], 
         Cell[
          StyleData["Key3"], 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              TagBox[
               GridBox[{{
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> 
                   GrayLevel[0.9333333333333333], StripOnInput -> False], 
                  ItemBox[
                   
                   TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                    "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                   False]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
                False, GridBoxDividers -> {
                 "ColumnsIndexed" -> {
                   2 -> GrayLevel[0.8352941176470589], 3 -> 
                    GrayLevel[0.8352941176470589], 4 -> 
                    GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}},
                 GridBoxSpacings -> {"Columns" -> {{0}}}, 
                BaselinePosition -> {{1, 1}, Baseline}], "Grid"], 
              RoundingRadius -> 4, Background -> 
              GrayLevel[0.9333333333333333], 
              FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
                GrayLevel[0.8352941176470589], 
                AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
              StripOnInput -> False]& )}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Entity styles", "Subsubsection"], 
         Cell[
          StyleData["Entity"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "WolframCodeSans", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "WolframCodeSans", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 1}], False -> 
                 PaneBox[#, 
                   BaseStyle -> {
                    FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                   BaselinePosition -> Baseline]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {0.5, 3}}, 
               ImageMargins -> {{2, 2}, {1, 1}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                    FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 1}], False -> 
                PaneBox[#, 
                  BaseStyle -> {
                   FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                  BaselinePosition -> Baseline]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {
                 FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ),
             Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 1}], False -> 
               PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
                 BaselinePosition -> Baseline]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}},
                    BaselinePosition -> {1, 2}]}, 
                Dynamic[
                 CurrentValue[Evaluatable]], ImageSize -> Automatic, 
                BaselinePosition -> Baseline, 
                BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
               RGBColor[1., 0.504768, 0.], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              PaneSelectorBox[{True -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]], 
                    StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                    Selectable -> False]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}], False -> GridBox[{{
                    PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                    
                    StyleBox[#, FontColor -> 
                    RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                  BaselinePosition -> {1, 2}]}, 
               Dynamic[
                CurrentValue[Evaluatable]], ImageSize -> Automatic, 
               BaselinePosition -> Baseline, 
               BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False,
           TemplateBoxOptions -> {
           DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   
                   StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0]], 
                   StyleBox[
                    RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                    "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                    False]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], False -> GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], 
                   StyleBox[#, FontColor -> GrayLevel[0]]}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}]}, 
              Dynamic[
               CurrentValue[Evaluatable]], ImageSize -> Automatic, 
              BaselinePosition -> Baseline, 
              BaseStyle -> {
               FontWeight -> "Plain", FontFamily -> "Helvetica", 
                ShowStringCharacters -> False, LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityProperty"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               
               PaneBox[#, 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
              FrameBox[
               PaneBox[
                GridBox[{{
                   PaneBox[
                    DynamicBox[
                    FEPrivate`ImportImage[
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                    BaselinePosition -> Bottom], #}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                 BaselinePosition -> {1, 2}], 
                BaseStyle -> {
                 FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
                Baseline], FrameStyle -> 
               RGBColor[0.94227, 0.703639, 0.033387], Background -> 
               RGBColor[1., 0.980392, 0.921569], 
               FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
               ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline,
                RoundingRadius -> 4], #3, 
              BaseStyle -> {
               FontWeight -> "Plain", ShowStringCharacters -> False, 
                LineIndent -> 0, 
                PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
            Editable -> False, InterpretationFunction -> (#2& )}], 
         Cell[
          StyleData["EntityValue"], ShowStringCharacters -> False, 
          TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
              
              GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}},
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0}}}, 
               BaselinePosition -> {1, 1}], Background -> 
              RGBColor[{0.9921568627450981, 0.9529411764705882, 
                0.8509803921568627}], BaselinePosition -> Baseline, 
              FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
              RGBColor[{0.9333333333333333, 0.8470588235294118, 
                0.5529411764705883}], RoundingRadius -> 5]& )}]}, Open]]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Specialized for Klopper", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9, {3.7114709033696413`*^9, 
         3.711470909048764*^9}, {3.73531219927332*^9, 3.735312227736931*^9}, {
         3.745680245296091*^9, 3.7456802496393538`*^9}, {3.745930022124992*^9,
          3.7459300236362534`*^9}, {3.746546663993486*^9, 
         3.7465466650968523`*^9}}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {2, 32}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> "Italic", 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 14}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], LineSpacing -> {1.3, 1., 2.}, 
          MenuSortingValue -> 10010, MenuCommandKey :> "1", FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"], 
          CellMargins -> {{99, Inherited}, {2, 12}}, StripStyleOnPaste -> 
          True, DefaultFormatType -> DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           LanguageCategory -> "Formula", ScriptLevel -> 0, 
          SingleLetterItalics -> True, MenuSortingValue -> 1700, FontFamily -> 
          "Baskerville", FontSize -> 16, FontWeight -> "Regular", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[0.2], 
          UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}], 
              "DisplayFormulaEquationNumber"]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered", MenuSortingValue -> 
          1710, FontFamily -> "Baskerville", FontSize -> 16, FontWeight -> 
          "Regular", FontSlant -> "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       StyleData["InitializationCell"], Background -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Print"], CellMargins -> {{99, 10}, {4, 4}}, FontSize -> 
          15], 
         Cell[
          StyleData["Print", "Presentation"], 
          CellMargins -> {{100, Inherited}, {1.5 Inherited, 1.5 Inherited}}], 
         Cell[
          StyleData["Print", "SlideShow"], 
          CellMargins -> {{
            0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.01 
             FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {8, 15}}, 
          FontSize -> 18], 
         Cell[
          StyleData["Print", "Condensed"], 
          CellMargins -> {{18, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "Printout"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "PrintoutGray"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            RGBColor[0.8, 0.043, 0.008]], CellMargins -> {{81, 10}, {4, 8}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox["\[FilledSmallSquare]", Alignment -> Baseline, 
            GrayLevel[0.2]], 
          CellMargins -> {{80, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemParagraph"], CellMargins -> {{81, 10}, {4, 1}}, 
          ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["ItemParagraph", "Printout"], 
          CellMargins -> {{80, Inherited}, {Inherited, 0.5 Inherited}}]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemNumbered"], CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontWeight -> "Bold"], 
          CellMargins -> {{85, 10}, {4, 8}}, ReturnCreatesNewCell -> True, 
          StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "ItemNumbered", 
          CounterAssignments -> {{"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> 1630, FontFamily -> 
          "Source Sans Pro", FontSize -> 15], 
         Cell[
          StyleData["ItemNumbered", "Printout"], 
          CellMargins -> {{90, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteItem"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontSize -> 12, FontWeight -> 
            Bold, FontColor -> GrayLevel[0.25]], 
          CellMargins -> {{93, Inherited}, {4, 8}}, ReturnCreatesNewCell -> 
          True, CellFrameLabelMargins -> 4, 
          CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9}, 
            3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          CounterIncrements -> "ItemNumbered", MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["TechNoteItem", "Printout"], 
          CellMargins -> {{93, Inherited}, {4, 8}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Epigraph"], CellMargins -> {{100, 78}, {6, 24}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, TextAlignment -> Left, Hyphenation -> 
          True, HyphenationOptions -> {"HyphenationMinLengths" -> {3, 5}}, 
          LineSpacing -> {1, 2}, TabSpacings -> {1.2, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontWeight -> "Plain", FontSlant -> 
          "Plain"], 
         Cell[
          StyleData["Epigraph", "Printout", StyleDefinitions -> None]]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EpigraphAuthor"], CellMargins -> {{125, 100}, {12, 12}}, 
          TextAlignment -> Left, LineSpacing -> {1, 2}, 
          ParagraphIndent -> -17, TabSpacings -> {1.5, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontTracking -> -0.05], 
         Cell[
          StyleData["EpigraphAuthor", "Printout", StyleDefinitions -> None]]},
         Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ReferenceSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 60}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ReferenceSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Reference"], CellDingbat -> Cell[
            TextData[{
              CounterBox["Reference"]}], "SR", FontSize -> 13, 
            CellSize -> {30, Inherited}, TextAlignment -> Right], 
          CellMargins -> {{80, 10}, {3, 4}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, 
          CellChangeTimes -> {{3.7385995432110577`*^9, 3.738599549834622*^9}},
           LineSpacing -> {1, 2}, ParagraphIndent -> -8, 
          TabSpacings -> {0.7, 2.5}, CounterIncrements -> "Reference", 
          MenuSortingValue -> 1870, FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["Reference", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{66, 10}, {3, 4}}, TabSpacings -> {1.2, 2.5}]}, 
        Open]]}, Closed]]}, Visible -> False, FrontEndVersion -> 
  "12.2 for Mac OS X x86 (64-bit) (December 12, 2020)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"161b0f0b-da95-4d6c-ae18-98275733a833"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "C:15"->{
  Cell[580, 22, 407, 9, 113, "Section",ExpressionUUID->"129eafe9-cb43-4ba8-a5aa-31a86c927661",
   CounterAssignments->{{"Section", 14}, {"Subsection", 14}, {"Subsubsection", 14}, {"Exercise", 14}},
   CellTags->"C:15",
   CellID->868451339]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"C:15", 473702, 10077}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 407, 9, 113, "Section",ExpressionUUID->"129eafe9-cb43-4ba8-a5aa-31a86c927661",
 CounterAssignments->{{"Section", 14}, {"Subsection", 14}, {"Subsubsection", 14}, {"Exercise", 14}},
 CellTags->"C:15",
 CellID->868451339],
Cell[990, 33, 859, 13, 188, "Text",ExpressionUUID->"0ff7ffe3-b100-4a51-bbfb-eb94f402deeb",
 CellID->113786317]
}, Open  ]],
Cell[CellGroupData[{
Cell[1886, 51, 334, 4, 57, "Subsection",ExpressionUUID->"92cd6af6-73ce-49fe-80c8-07759da5af2f",
 CellID->581766946],
Cell[2223, 57, 490, 8, 88, "Text",ExpressionUUID->"a01c9569-474a-4818-a6c0-506de93ad508",
 CellID->727016178],
Cell[2716, 67, 269, 5, 63, "Text",ExpressionUUID->"75691a12-2fb0-49f6-813c-a9d969eab519",
 CellID->1520483],
Cell[2988, 74, 355, 6, 63, "Text",ExpressionUUID->"3296013b-9fd5-4c89-b9d7-005e0311fd8b",
 CellID->424683243],
Cell[3346, 82, 789, 12, 138, "Text",ExpressionUUID->"653aa2dd-3700-489c-8b13-d8d4a738387f",
 CellID->183011568],
Cell[4138, 96, 831, 13, 138, "Text",ExpressionUUID->"e0ef61ee-f607-4836-82d4-9ae9e7f9de66",
 CellID->13119533],
Cell[4972, 111, 637, 10, 88, "Text",ExpressionUUID->"1a84708b-0ca1-4c67-af93-7642fe592035",
 CellID->735514005],
Cell[5612, 123, 261, 5, 63, "Text",ExpressionUUID->"e01be72e-ad01-45aa-9d44-26a23bf59519",
 CellID->331792210],
Cell[CellGroupData[{
Cell[5898, 132, 170, 2, 32, "ItemNumbered",ExpressionUUID->"33cdc560-ae12-4254-ae3f-53ea3ce2cf71",
 CellID->246422531],
Cell[6071, 136, 323, 5, 32, "ItemNumbered",ExpressionUUID->"756dd3cb-3c53-4151-8f5f-bbe1d2503d53",
 CellID->7232440]
}, Open  ]],
Cell[6409, 144, 411, 7, 63, "Text",ExpressionUUID->"37ad54e2-5ac5-4067-8cb3-9a28a216c49b",
 CellID->478003943]
}, Open  ]],
Cell[CellGroupData[{
Cell[6857, 156, 382, 5, 57, "Subsection",ExpressionUUID->"0efcebca-8371-4aa2-9b92-f3953abea407",
 CellID->20336226],
Cell[7242, 163, 354, 6, 63, "Text",ExpressionUUID->"d03fc395-e076-44b9-a1e5-dc1fd58004b1",
 CellID->46677548],
Cell[7599, 171, 206, 2, 37, "CodeCaption",ExpressionUUID->"b5315fe4-d22c-462b-84d6-6fc54e90c263",
 CellID->452614806],
Cell[7808, 175, 291, 6, 29, "Input",ExpressionUUID->"8c8473d7-a7d0-43e5-bcf3-7878b73fb6b1",
 CellID->284265542],
Cell[8102, 183, 577, 14, 63, "Text",ExpressionUUID->"f1d0956e-0886-43bd-ae78-d113f227afca",
 CellID->620449441],
Cell[8682, 199, 380, 9, 37, "CodeCaption",ExpressionUUID->"9eea528f-0445-4a9c-bc37-47175b414bde",
 CellID->69220379],
Cell[9065, 210, 305, 7, 29, "Input",ExpressionUUID->"04f6da4a-99f4-40d0-aee6-7ecf6acc722c",
 CellID->203768166],
Cell[9373, 219, 421, 9, 63, "Text",ExpressionUUID->"39e577ef-62d4-4412-b031-48eeccbfd540",
 CellID->56010151],
Cell[9797, 230, 825, 18, 37, "CodeCaption",ExpressionUUID->"6f87b2ce-be8d-4217-bad4-93f6bb51c463",
 CellID->426761083],
Cell[CellGroupData[{
Cell[10647, 252, 282, 5, 29, "Input",ExpressionUUID->"5578d6c5-b8d8-4abb-b07c-2860f73c12b7",
 CellID->64376173],
Cell[10932, 259, 60146, 1154, 211, "Output",ExpressionUUID->"079b84e6-e7f6-46f0-bbfd-f4c802f2ddfa",
 CellID->639738530]
}, Open  ]],
Cell[71093, 1416, 428, 10, 66, "CodeCaption",ExpressionUUID->"06673565-5e97-4d35-ad56-f7d71754c1a0",
 CellID->24592878],
Cell[CellGroupData[{
Cell[71546, 1430, 234, 4, 29, "Input",ExpressionUUID->"ac48279e-2446-45df-9e7a-b6d373d81d3b",
 CellID->157153682],
Cell[71783, 1436, 313, 6, 40, "Output",ExpressionUUID->"543e5027-bed0-493f-b795-6a30fc712106",
 CellID->1782336828]
}, Open  ]],
Cell[72111, 1445, 767, 17, 64, "Text",ExpressionUUID->"1fe3f1a2-5b4b-4561-a1e0-ced0a8000b45",
 CellID->897888979],
Cell[72881, 1464, 402, 9, 37, "CodeCaption",ExpressionUUID->"c3806381-66a1-406e-92c1-974be25c4d5a",
 CellID->229633178],
Cell[CellGroupData[{
Cell[73308, 1477, 262, 5, 29, "Input",ExpressionUUID->"2b3a16f3-1f3e-4385-b7fc-45e5eb5eb234",
 CellID->1231097],
Cell[73573, 1484, 21807, 385, 111, "Output",ExpressionUUID->"4ceb2348-1613-4f09-87bd-1ff30493c05f",
 CellID->485676193]
}, Open  ]],
Cell[95395, 1872, 213, 2, 38, "Text",ExpressionUUID->"2d59d968-1193-420d-80ab-41961713ebf1",
 CellID->41768799]
}, Open  ]],
Cell[CellGroupData[{
Cell[95645, 1879, 396, 5, 57, "Subsection",ExpressionUUID->"e8dcfc08-f3b9-47f1-89a3-e5ba6b53eb60",
 CellID->28983898],
Cell[96044, 1886, 799, 14, 139, "Text",ExpressionUUID->"ba15f436-65ef-48fc-9d55-d56cdeedadc5",
 CellID->158144874],
Cell[96846, 1902, 341, 6, 37, "CodeCaption",ExpressionUUID->"049e770f-82d7-4d2c-82b6-94874a7312e5",
 CellID->81010172],
Cell[CellGroupData[{
Cell[97212, 1912, 339, 7, 29, "Input",ExpressionUUID->"90c4b294-cafe-46ec-8afa-2329a5e63dc2",
 CellID->143984191],
Cell[97554, 1921, 27586, 499, 161, "Output",ExpressionUUID->"fd7cd65e-0b77-4250-91bb-a33131f74bd5",
 CellID->174433504]
}, Open  ]],
Cell[125155, 2423, 300, 6, 38, "Text",ExpressionUUID->"0e67c89f-15e0-49f7-b9a5-7531cb50297d",
 CellID->226541001],
Cell[125458, 2431, 381, 9, 37, "CodeCaption",ExpressionUUID->"3ae668c2-ee03-4c3e-b7e8-cc88f99dde52",
 CellID->140824503],
Cell[CellGroupData[{
Cell[125864, 2444, 344, 10, 29, "Input",ExpressionUUID->"45dd7925-da81-49d2-b72e-603f3811e195",
 CellID->556169803],
Cell[126211, 2456, 406, 10, 40, "Output",ExpressionUUID->"01708b10-4347-43d2-9933-ba21cf2a3e51",
 CellID->388723573]
}, Open  ]],
Cell[126632, 2469, 475, 8, 66, "CodeCaption",ExpressionUUID->"10d6b3ce-53a5-45bd-ae04-5a8be020dbfc",
 CellID->240379572],
Cell[CellGroupData[{
Cell[127132, 2481, 413, 11, 29, "Input",ExpressionUUID->"0a6966d6-4bee-45cd-84cb-c2cde11defd3",
 CellID->260474416],
Cell[127548, 2494, 456, 11, 40, "Output",ExpressionUUID->"2d710fa2-8988-487f-becc-8120b52bfd0c",
 CellID->631837237]
}, Open  ]],
Cell[128019, 2508, 295, 4, 37, "CodeCaption",ExpressionUUID->"1e45c5c1-331a-4676-95f5-837f1d495546",
 CellID->8429640],
Cell[CellGroupData[{
Cell[128339, 2516, 371, 7, 29, "Input",ExpressionUUID->"e5e26342-9f0c-4218-a91b-e52b08201c55",
 CellID->24917477],
Cell[128713, 2525, 1222, 36, 79, "Output",ExpressionUUID->"76b31cdc-78d4-4d45-a8b1-4e307ce4c341",
 CellID->2129291491]
}, Open  ]],
Cell[129950, 2564, 353, 6, 37, "CodeCaption",ExpressionUUID->"c1a99281-974b-4087-aaeb-95ed927f1737",
 CellID->186606889],
Cell[CellGroupData[{
Cell[130328, 2574, 480, 12, 29, "Input",ExpressionUUID->"ef101347-e14b-46bf-bbcf-3690c9e61d71",
 CellID->34317681],
Cell[130811, 2588, 492, 14, 58, "Output",ExpressionUUID->"01cc5ad6-26c1-4c1a-8a13-c677b5eae545",
 CellID->1334595629]
}, Open  ]],
Cell[131318, 2605, 231, 3, 37, "CodeCaption",ExpressionUUID->"146dbee7-6e06-41b4-888c-83bbedd14ced",
 CellID->489639093],
Cell[CellGroupData[{
Cell[131574, 2612, 321, 7, 29, "Input",ExpressionUUID->"e08adcad-97fc-4c97-9974-4f84b2275a75",
 CellID->560541313],
Cell[131898, 2621, 1267, 36, 79, "Output",ExpressionUUID->"9645aecc-535b-49ac-9c05-ba6396ad4152",
 CellID->82043688]
}, Open  ]],
Cell[133180, 2660, 684, 15, 66, "Text",ExpressionUUID->"0a295139-69d8-4eba-bc7f-d568b2dcfe00",
 CellID->291357908],
Cell[133867, 2677, 243, 3, 37, "CodeCaption",ExpressionUUID->"cc71bcd0-0f15-4e05-b796-041dc888ad94",
 CellID->231975037],
Cell[CellGroupData[{
Cell[134135, 2684, 248, 5, 29, "Input",ExpressionUUID->"03e892ab-4a72-4f0d-9f1f-f69726ac3e8a",
 CellID->549547249],
Cell[134386, 2691, 553, 16, 58, "Output",ExpressionUUID->"c60d72c1-a9f0-4506-bf0d-4a6e0e585d90",
 CellID->223762842]
}, Open  ]],
Cell[134954, 2710, 394, 10, 37, "CodeCaption",ExpressionUUID->"a54da5da-0a73-45fe-950b-2089763d6548",
 CellID->156193703],
Cell[CellGroupData[{
Cell[135373, 2724, 256, 6, 54, "Input",ExpressionUUID->"c538213c-878e-4a09-946a-48910d9d1bae",
 CellID->276006547],
Cell[135632, 2732, 511, 14, 58, "Output",ExpressionUUID->"df1ce645-9404-4213-9d18-ed0577499a0f",
 CellID->538219597]
}, Open  ]],
Cell[136158, 2749, 250, 3, 37, "CodeCaption",ExpressionUUID->"a6b677ac-c2d8-448b-9f61-66b4dde5fa63",
 CellID->210702086],
Cell[CellGroupData[{
Cell[136433, 2756, 418, 10, 29, "Input",ExpressionUUID->"98adfc5e-a23e-4a10-babd-14a665e62a7d",
 CellID->55316480],
Cell[136854, 2768, 262, 4, 40, "Output",ExpressionUUID->"e6376b14-66a0-457b-9178-d243cd101a6d",
 CellID->655645615]
}, Open  ]],
Cell[137131, 2775, 614, 15, 37, "CodeCaption",ExpressionUUID->"6c71553c-000f-4300-b3cb-e4516b388cec",
 CellID->427405668],
Cell[CellGroupData[{
Cell[137770, 2794, 529, 11, 54, "Input",ExpressionUUID->"1f295bef-dc53-4128-8ee8-4b3edb4c62ad",
 CellID->556182814],
Cell[138302, 2807, 284, 4, 40, "Output",ExpressionUUID->"1054aff6-f60b-489c-b3d5-5fac03e61d50",
 CellID->697258548]
}, Open  ]],
Cell[138601, 2814, 603, 14, 64, "Text",ExpressionUUID->"4d1615e5-848b-4034-953f-235bdb1add5f",
 CellID->359938689],
Cell[139207, 2830, 589, 17, 37, "CodeCaption",ExpressionUUID->"9e372a30-5833-438b-9549-6c8b579f824a",
 CellID->132657626],
Cell[CellGroupData[{
Cell[139821, 2851, 383, 10, 29, "Input",ExpressionUUID->"b15cd6cb-074a-4f22-a0c8-2a806a142161",
 CellID->199653271],
Cell[140207, 2863, 280, 4, 40, "Output",ExpressionUUID->"f18b7bb3-f4e6-4eea-8b72-1b95521ef0c8",
 CellID->6154557]
}, Open  ]],
Cell[140502, 2870, 1129, 23, 142, "Text",ExpressionUUID->"1f321afe-e098-4dcb-b3d8-aa77549cf082",
 CellID->318146614],
Cell[141634, 2895, 301, 7, 37, "CodeCaption",ExpressionUUID->"8bc0b2cd-50d4-41bc-8129-de1d592e6a94",
 CellID->235476410],
Cell[CellGroupData[{
Cell[141960, 2906, 1540, 39, 78, "Input",ExpressionUUID->"4e89eba6-8cf2-4856-95fc-ce79ead2a769",
 CellID->279258013],
Cell[143503, 2947, 5827, 116, 334, "Output",ExpressionUUID->"1b244716-ec2c-4465-b612-61c68afe9beb",
 CellID->360424443]
}, Open  ]],
Cell[149345, 3066, 1482, 40, 116, "Text",ExpressionUUID->"fa1aa5c9-84b7-4e35-adcd-e6db1c8929fe",
 CellID->114771420],
Cell[150830, 3108, 204, 2, 38, "Text",ExpressionUUID->"7c772da4-0946-4194-87df-5d593605b7db",
 CellID->262180176]
}, Open  ]],
Cell[CellGroupData[{
Cell[151071, 3115, 463, 6, 57, "Subsection",ExpressionUUID->"5d27ae38-cd33-44df-a8e1-51b5e4db1f97",
 CellID->348412897],
Cell[151537, 3123, 871, 15, 139, "Text",ExpressionUUID->"0897739e-c309-43ec-8db8-485216fb79d3",
 CellID->832046646],
Cell[152411, 3140, 302, 6, 38, "Text",ExpressionUUID->"0b9c8b75-19b5-46d2-83a4-bd317d0bce55",
 CellID->76186256],
Cell[152716, 3148, 337, 8, 37, "CodeCaption",ExpressionUUID->"68042cbb-a6db-4ccc-9b1f-4c21192f3b69",
 CellID->316623044],
Cell[CellGroupData[{
Cell[153078, 3160, 510, 11, 54, "Input",ExpressionUUID->"6d77deb6-dd6f-4830-9094-bd366f0956a8",
 CellID->124555380],
Cell[153591, 3173, 30800, 574, 111, "Output",ExpressionUUID->"3c6e6797-7679-42b8-8572-beb4c2169ae6",
 CellID->1749728961]
}, Open  ]],
Cell[184406, 3750, 608, 14, 63, "Text",ExpressionUUID->"26ec73d5-88d6-44e3-9477-cbecbf21699b",
 CellID->11869537],
Cell[185017, 3766, 375, 11, 37, "CodeCaption",ExpressionUUID->"0878b761-73cf-45d0-858b-d6851601a412",
 CellID->584887299],
Cell[185395, 3779, 643, 18, 54, "Input",ExpressionUUID->"5a85c712-22ab-4dbd-9bc1-4aa3b9118fd7",
 CellID->304891001],
Cell[186041, 3799, 384, 8, 63, "Text",ExpressionUUID->"278bdf48-e104-44d0-a48a-c5be66f108c8",
 CellID->398226518],
Cell[186428, 3809, 362, 11, 37, "CodeCaption",ExpressionUUID->"d45e0d5e-62ab-4a9b-afae-d9beaaf81a60",
 CellID->415164823],
Cell[186793, 3822, 730, 19, 54, "Input",ExpressionUUID->"fcc1b231-b8c3-4e0c-adc4-1ee0d2e97907",
 CellID->63692354],
Cell[187526, 3843, 209, 2, 38, "Text",ExpressionUUID->"1ba473b7-835f-4e71-9642-f6fffd7477ec",
 CellID->512262379],
Cell[187738, 3847, 389, 8, 37, "CodeCaption",ExpressionUUID->"19fa5065-e1ff-4fc6-ad6b-6c221ecb794a",
 CellID->221962001],
Cell[CellGroupData[{
Cell[188152, 3859, 692, 14, 54, "Input",ExpressionUUID->"ec01fced-fc24-4b24-97a3-4a7c17ffedee",
 CellID->21890781],
Cell[188847, 3875, 10082, 251, 316, "Output",ExpressionUUID->"8694f8ca-ee0a-4e8e-9362-a2644c926f78",
 CellID->53585509]
}, Open  ]],
Cell[198944, 4129, 441, 11, 63, "Text",ExpressionUUID->"a2fea88d-72d0-4eff-8135-7a6ef1d0f9af",
 CellID->36409792],
Cell[199388, 4142, 246, 5, 38, "Text",ExpressionUUID->"fdfc244b-af22-4814-91a4-c88956020330",
 CellID->697675545],
Cell[199637, 4149, 483, 14, 39, "CodeCaption",ExpressionUUID->"ebe5180c-9b85-47b7-9ccb-c2a30172f20a",
 CellID->441140419],
Cell[CellGroupData[{
Cell[200145, 4167, 883, 18, 78, "Input",ExpressionUUID->"e8284d23-7ef2-4ff6-8452-0d4bf16852fe",
 CellID->162965074],
Cell[201031, 4187, 39313, 766, 231, "Output",ExpressionUUID->"66f5fea1-37db-4486-8b2e-131d74ab5fc6",
 CellID->816001670]
}, Open  ]],
Cell[240359, 4956, 354, 7, 38, "Text",ExpressionUUID->"2b929bc6-f76c-4fbf-89f1-949cd2ba6d9f",
 CellID->257038805],
Cell[CellGroupData[{
Cell[240738, 4967, 633, 15, 54, "Input",ExpressionUUID->"fc072b82-1706-439c-9673-741cd40675d0",
 CellID->113002102],
Cell[241374, 4984, 39278, 828, 157, "Output",ExpressionUUID->"17385892-e0d8-43c9-a225-1c4483ece81b",
 CellID->709497948]
}, Open  ]],
Cell[280667, 5815, 453, 7, 88, "Text",ExpressionUUID->"8de348da-87dc-4cad-826f-1ee773607c42",
 CellID->112250013],
Cell[281123, 5824, 348, 8, 37, "CodeCaption",ExpressionUUID->"f0b2eab6-0ce3-4d2f-9f86-14a33060dc85",
 CellID->60481654],
Cell[CellGroupData[{
Cell[281496, 5836, 286, 6, 29, "Input",ExpressionUUID->"39755826-c6c1-4456-ab6f-20ca9b9d1fe9",
 CellID->178765207],
Cell[281785, 5844, 332, 7, 40, "Output",ExpressionUUID->"617943a4-589a-44ba-8de2-5c36f9230963",
 CellID->1702803892]
}, Open  ]],
Cell[282132, 5854, 698, 13, 90, "Text",ExpressionUUID->"b5410845-2683-4a6a-b34f-b3b9f64f9ee1",
 CellID->213335717],
Cell[282833, 5869, 443, 10, 37, "CodeCaption",ExpressionUUID->"cafd806b-244e-4345-92ef-241070fae9ab",
 CellID->448181809],
Cell[CellGroupData[{
Cell[283301, 5883, 292, 6, 29, "Input",ExpressionUUID->"d985e697-c0dc-4ea3-8e16-fd161094999f",
 CellID->499844789],
Cell[283596, 5891, 262, 4, 40, "Output",ExpressionUUID->"d24e3706-8eab-4ab4-998b-fdcc11f90066",
 CellID->1657932922]
}, Open  ]],
Cell[283873, 5898, 545, 8, 63, "Text",ExpressionUUID->"52d22ad5-d8ff-43b5-a833-b4f92bbf1484",
 CellID->285543940],
Cell[284421, 5908, 315, 6, 37, "CodeCaption",ExpressionUUID->"15677c72-f57d-4ae0-b7c0-a0f76ce6b906",
 CellID->214322229],
Cell[CellGroupData[{
Cell[284761, 5918, 284, 6, 29, "Input",ExpressionUUID->"28eb90ee-7fe1-4782-bf4d-155c5d4b3915",
 CellID->8376257],
Cell[285048, 5926, 243, 4, 40, "Output",ExpressionUUID->"6b83160f-e11f-4c22-8fac-7abc4a339333",
 CellID->1278300229]
}, Open  ]],
Cell[285306, 5933, 1630, 41, 143, "Text",ExpressionUUID->"427f75aa-68de-4da6-b4f9-697400e654d2",
 CellID->129507313]
}, Open  ]],
Cell[CellGroupData[{
Cell[286973, 5979, 524, 6, 57, "Subsection",ExpressionUUID->"29543d62-675e-4bc8-84d1-ea764d4113aa",
 CellID->33009933],
Cell[287500, 5987, 786, 13, 113, "Text",ExpressionUUID->"3f9438f4-6737-4d2a-b593-61ced4746949",
 CellID->153765151],
Cell[288289, 6002, 588, 11, 89, "Text",ExpressionUUID->"684f9609-4b37-4d2f-b836-ea75607f326e",
 CellID->540416205],
Cell[288880, 6015, 2237, 48, 243, "Text",ExpressionUUID->"e8f3191f-f595-4236-8874-93d291e53357",
 CellID->336696017],
Cell[291120, 6065, 857, 31, 66, "CodeCaption",ExpressionUUID->"d0a94d81-e0a5-4622-beea-245f229cf2a1",
 CellID->90795247],
Cell[CellGroupData[{
Cell[292002, 6100, 530, 13, 54, "Input",ExpressionUUID->"0d4b8842-0fca-4eba-ab46-dffb4a9b3e24",
 CellID->76605001],
Cell[292535, 6115, 397, 9, 40, "Output",ExpressionUUID->"c541bf0c-40b8-4084-9f05-9faaa478ab7c",
 CellID->965544215]
}, Open  ]],
Cell[CellGroupData[{
Cell[292969, 6129, 525, 13, 54, "Input",ExpressionUUID->"1fee989b-40bf-40fd-bc48-33481915ecde",
 CellID->353755635],
Cell[293497, 6144, 424, 8, 40, "Output",ExpressionUUID->"c51b90dd-98fb-4893-a5ec-747219bc8c45",
 CellID->1515184773]
}, Open  ]],
Cell[293936, 6155, 636, 17, 66, "CodeCaption",ExpressionUUID->"0abd370a-f8db-4c0c-9ae8-cc6782120707",
 CellID->339221956],
Cell[CellGroupData[{
Cell[294597, 6176, 552, 14, 54, "Input",ExpressionUUID->"c7edcb1f-a231-42b5-b307-c1333b4f8054",
 CellID->57055865],
Cell[295152, 6192, 8731, 258, 190, "Output",ExpressionUUID->"f8cf8621-67c5-4944-9cc1-a05c50b287c5",
 CellID->849393685]
}, Open  ]],
Cell[CellGroupData[{
Cell[303920, 6455, 502, 13, 54, "Input",ExpressionUUID->"7582a6d6-e81f-45d4-99c9-cd2161709c8b",
 CellID->530000948],
Cell[304425, 6470, 6613, 196, 190, "Output",ExpressionUUID->"e9412979-7849-4dfe-8587-e858b9f0a32e",
 CellID->1435862186]
}, Open  ]],
Cell[311053, 6669, 352, 7, 63, "Text",ExpressionUUID->"268308c2-8cdc-45c5-b283-065d3ea99cd5",
 CellID->99958486],
Cell[311408, 6678, 393, 11, 37, "CodeCaption",ExpressionUUID->"0bc7f6d7-effc-47df-868e-4b41d9fa64db",
 CellID->110754988],
Cell[311804, 6691, 681, 18, 54, "Input",ExpressionUUID->"bb9e2c6d-1adc-4c4a-abb0-bed005a4719c",
 CellID->354844629],
Cell[312488, 6711, 348, 8, 37, "CodeCaption",ExpressionUUID->"d641d8b0-e24a-4f84-bea6-481d3731a0f5",
 CellID->64159907],
Cell[CellGroupData[{
Cell[312861, 6723, 335, 7, 29, "Input",ExpressionUUID->"67b14da1-1d5f-48a8-8547-96f2467fc968",
 CellID->255367720],
Cell[313199, 6732, 323, 7, 40, "Output",ExpressionUUID->"65ee056b-0bef-41ad-acac-56965815c179",
 CellID->1262018763]
}, Open  ]],
Cell[313537, 6742, 481, 10, 88, "Text",ExpressionUUID->"1fbb3b42-96e9-4a0e-9737-f2652d196840",
 CellID->246478032],
Cell[314021, 6754, 582, 13, 63, "Text",ExpressionUUID->"27a979d0-1373-4433-bb2b-d45d17797d6a",
 CellID->325497123],
Cell[314606, 6769, 411, 9, 37, "CodeCaption",ExpressionUUID->"31296abb-b7a9-401a-ac9c-f58cf06237df",
 CellID->50061431],
Cell[CellGroupData[{
Cell[315042, 6782, 997, 23, 78, "Input",ExpressionUUID->"63de8351-a72f-46e0-bd4e-5d80142f3253",
 CellID->611368034],
Cell[316042, 6807, 2884, 67, 307, "Output",ExpressionUUID->"1c910fff-7ed3-4f10-a9d9-ed502cfd282c",
 CellID->53368322]
}, Open  ]],
Cell[318941, 6877, 267, 5, 38, "Text",ExpressionUUID->"a5fba6c1-d6bb-4a9c-a3e8-036cdd6621e4",
 CellID->48838305],
Cell[319211, 6884, 475, 12, 37, "CodeCaption",ExpressionUUID->"5b4c5c7d-24f9-43bc-a783-ccb2aac75a92",
 CellID->68413677],
Cell[CellGroupData[{
Cell[319711, 6900, 378, 7, 29, "Input",ExpressionUUID->"0cd758ce-43b7-4dcd-b265-cc7af079a945",
 CellID->157193721],
Cell[320092, 6909, 918, 20, 49, "Output",ExpressionUUID->"04508e30-e320-430e-a791-52e583e69890",
 CellID->1460707055]
}, Open  ]],
Cell[321025, 6932, 1231, 26, 91, "Text",ExpressionUUID->"81b0d5a2-f79b-4694-bd4e-cb3666c7527d",
 CellID->76838211],
Cell[322259, 6960, 340, 6, 38, "Text",ExpressionUUID->"3b76a2ec-c3c0-4d5d-9e04-2e02bc967750",
 CellID->80158902],
Cell[322602, 6968, 428, 12, 54, "DisplayFormulaNumbered",ExpressionUUID->"082a76a4-0aa2-4cf9-8285-3103fe833424",
 CellID->1823253885],
Cell[323033, 6982, 754, 15, 64, "Text",ExpressionUUID->"5e17e857-24ea-42c3-b8b5-904ac065f9c5",
 CellID->337207638],
Cell[323790, 6999, 331, 7, 37, "CodeCaption",ExpressionUUID->"e56a37a6-c751-4806-947b-a3417a95ca9d",
 CellID->2074113553],
Cell[CellGroupData[{
Cell[324146, 7010, 485, 11, 54, "Input",ExpressionUUID->"22a18bc1-56ce-41b6-ac03-5612fee5d749",
 CellID->245452443],
Cell[324634, 7023, 328, 6, 40, "Output",ExpressionUUID->"71d40629-8f8e-4279-8776-23e08bcee9b2",
 CellID->70420881]
}, Open  ]],
Cell[324977, 7032, 1005, 23, 66, "Text",ExpressionUUID->"1d8dc6f2-02e6-4bd6-a824-2eaf379e91df",
 CellID->137749338],
Cell[325985, 7057, 380, 11, 62, "DisplayFormulaNumbered",ExpressionUUID->"1712fe63-a9ac-4927-9a7d-a43fe929fdf9",
 CellID->1794484812],
Cell[326368, 7070, 464, 11, 37, "CodeCaption",ExpressionUUID->"9ef17a38-8bf7-4f84-88eb-8aa4f802a049",
 CellID->78447218],
Cell[CellGroupData[{
Cell[326857, 7085, 383, 11, 67, "Input",ExpressionUUID->"191cd81a-50c0-410f-8708-cbc05ff12269",
 CellID->147515281],
Cell[327243, 7098, 331, 6, 40, "Output",ExpressionUUID->"c835485e-782b-4124-a4b9-caf6ed71c707",
 CellID->300257470]
}, Open  ]],
Cell[327589, 7107, 633, 14, 65, "Text",ExpressionUUID->"b767bd25-9eaa-4794-8d1f-c9d543698b7e",
 CellID->471512326],
Cell[328225, 7123, 930, 17, 68, "CodeCaption",ExpressionUUID->"375bf757-7748-4cf0-883c-33cca9c4fb56",
 CellID->2110711978],
Cell[CellGroupData[{
Cell[329180, 7144, 1220, 33, 54, "Input",ExpressionUUID->"3bfc6f07-d297-4ab9-9d6d-0067ce4c8bd0",
 CellID->310026798],
Cell[330403, 7179, 39703, 671, 203, "Output",ExpressionUUID->"15f08718-df70-444a-adea-70b268eb3ca7",
 CellID->1988211487]
}, Open  ]],
Cell[370121, 7853, 461, 12, 37, "CodeCaption",ExpressionUUID->"1fcafca0-2073-4da8-8463-994658e0693b",
 CellID->52103744],
Cell[CellGroupData[{
Cell[370607, 7869, 489, 10, 29, "Input",ExpressionUUID->"b14542a7-940e-4fbe-8f16-6d402e708e91",
 CellID->475824172],
Cell[371099, 7881, 528, 11, 63, "Output",ExpressionUUID->"76a605f6-41a0-4cc3-9c6b-a12c3fd266bb",
 CellID->1024914689]
}, Open  ]],
Cell[371642, 7895, 866, 23, 65, "Text",ExpressionUUID->"a9433f1a-f383-46cb-901e-9817b9cc15e3",
 CellID->257693548],
Cell[CellGroupData[{
Cell[372533, 7922, 210, 3, 71, "ExerciseSection",ExpressionUUID->"2fe2d798-8be3-4d01-85bc-a8ede58b8b1c",
 CellID->566065673],
Cell[372746, 7927, 1055, 27, 51, "ExerciseNote",ExpressionUUID->"807c42aa-aa70-428e-9099-faf7e8f7ab2d",
 CellID->1980862459],
Cell[373804, 7956, 293, 5, 49, "Exercise",ExpressionUUID->"b4bca651-2fa0-40d5-9d1b-f487ffffef36",
 CellID->166035477],
Cell[374100, 7963, 603, 15, 46, "Exercise",ExpressionUUID->"3ccd0713-0110-4450-b818-d2af310c6e9b",
 CellID->584277686],
Cell[374706, 7980, 773, 20, 48, "Exercise",ExpressionUUID->"c580d4e3-7b90-42b0-b373-29f7a35f27a6",
 CellID->395600393],
Cell[375482, 8002, 1157, 25, 66, "Exercise",ExpressionUUID->"85d4c9b8-c0a9-4503-bc77-6f1e2ab451a9",
 PageBreakAbove->True,
 CellID->513284189],
Cell[376642, 8029, 299, 5, 45, "Exercise",ExpressionUUID->"d7b9922a-77b4-4bc4-bd56-fe8f7bfde295",
 CellID->28284756],
Cell[376944, 8036, 323, 5, 45, "Exercise",ExpressionUUID->"be3ee1e9-f230-4f95-a5ae-79b8095df72c",
 CellID->258378502]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[377316, 8047, 231, 3, 57, "Subsection",ExpressionUUID->"814f0739-2817-42bc-9016-3b020fb83679",
 CellID->73110728],
Cell[377550, 8052, 812, 13, 113, "Text",ExpressionUUID->"174e69f8-8434-4b3e-bcfe-d5a06d56b6bf",
 CellID->215554612],
Cell[378365, 8067, 822, 15, 113, "Text",ExpressionUUID->"22da2da2-494f-4691-bfdd-74505290db6c",
 CellID->125622123],
Cell[379190, 8084, 2139, 46, 238, "Text",ExpressionUUID->"0ae2b8ec-3802-4665-8514-b986f941e661",
 CellID->237108180],
Cell[CellGroupData[{
Cell[381354, 8134, 98, 1, 70, "QASection",ExpressionUUID->"997e06ae-0b0e-4224-ad38-49cc7e33a07a",
 CellID->35474018],
Cell[381455, 8137, 204, 2, 32, "Question",ExpressionUUID->"be4b7ac9-8daf-4ee3-95b4-b96c7b1f3f9e",
 CellID->193396523],
Cell[381662, 8141, 867, 15, 87, "Answer",ExpressionUUID->"29f32b32-0759-44d4-a8a1-2ce12c8084f9",
 CellID->613161291],
Cell[382532, 8158, 192, 2, 32, "Question",ExpressionUUID->"63943bd1-39e3-4587-9d42-02b3c50eeb3b",
 CellID->17500213],
Cell[382727, 8162, 891, 16, 87, "Answer",ExpressionUUID->"1bff3695-8710-400b-827e-a44075c82994",
 CellID->698314370],
Cell[383621, 8180, 308, 4, 32, "Question",ExpressionUUID->"917e2ce8-6de9-4bd0-85e3-d3950846fb75",
 CellID->290534271],
Cell[383932, 8186, 532, 11, 45, "Answer",ExpressionUUID->"4755bd72-872d-41e6-8117-9be60375ffb0",
 CellID->348482271],
Cell[384467, 8199, 240, 3, 32, "Question",ExpressionUUID->"e0cda5dc-6e84-43ce-bd2a-c8d6502c86be",
 CellID->602644645],
Cell[384710, 8204, 536, 8, 45, "Answer",ExpressionUUID->"ad5ba23f-69a4-4f65-b509-4c6806e1de94",
 CellID->109936451]
}, Open  ]],
Cell[CellGroupData[{
Cell[385283, 8217, 119, 1, 100, "MoreExploreSection",ExpressionUUID->"bbf0f155-f49d-42d5-97ef-090e2684502b",
 CellID->19888384],
Cell[385405, 8220, 760, 17, 49, "MoreExplore",ExpressionUUID->"9ae75eb9-7626-43da-85cb-8ada57c46da5",
 CellID->1270860181],
Cell[386168, 8239, 927, 21, 49, "MoreExplore",ExpressionUUID->"10cca2be-63f1-4f56-a222-83149fa11d63",
 CellID->1695003484],
Cell[387098, 8262, 926, 22, 49, "MoreExplore",ExpressionUUID->"03c1ab8b-cc7e-4d9a-8cd5-e65480b4ca23",
 CellID->26626102],
Cell[388027, 8286, 849, 20, 49, "MoreExplore",ExpressionUUID->"3c336968-8616-48ca-a8cf-79200f49e97a",
 CellID->115890670],
Cell[388879, 8308, 788, 18, 49, "MoreExplore",ExpressionUUID->"56dd8848-d3fb-4a3a-9041-7e4aaad92bbf",
 CellID->6822861]
}, Open  ]]
}, Open  ]]
}
]
*)

